<?php

$lista_parentele = "";
$cod_parentele = "";
$cod2_parentele = "";
$cod3_parentele = "";

$lista_parentele[0] = "Familiare";
$cod_parentele[0] = "19";
$lista_parentele[1] = "Membro Gruppo";
$cod_parentele[1] = "20";


?>