<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "El apellido será cambiado de"; break;
case "a":  					$messaggio = "a"; break;
case "Il nome verrà cambiato da":  		$messaggio = "El nombre será cambiado de"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "El sexo será cambiado a"; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "La fecha de nacimiento será cambiada de"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "El teléfono cambiará de"; break;
case "La via  verrà cambiata da":  		$messaggio = "La calle cambiará de"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "El número de la calle cambiará de"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "La ciudad de residencia será cambiada de"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "La nación de residencia será cambiada de"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "El codigo postal será cambiado de"; break;
case "Il fax verrà cambiato da":  		$messaggio = "El fax será cambiado de"; break;
case "L' email verrà cambiata da":  		$messaggio = "El correo electrónico será cambiado de"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "El segundo teléfono será cambiado de"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "El tercer teléfono será cambiado de"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "El <b>comentario</b> será cambiado"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "El <b>nombre</b> será borrado"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "La <b>fecha de nacimiento</b> será borrada"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "El <b>teléfono</b> será borrado"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "La <b>calle</b> será borrada"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "El <b>número de la calle</b> será borrado"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "La <b>ciudad de residencia</b> será borrada"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "La <b>nación de residencia</b> será borrada"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "El <b>codigo postal</b> será borrado"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "El <b>fax</b> será borrado"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "El <b>correo electrónico</b> será borrado"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "El <b>segundo teléfono</b> será borrado"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "El <b>tercer teléfono</b> será borrado"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "Il cliente":  				$messaggio = "El cliente"; break;
case "è stato modificato":  			$messaggio = "ha sido modificado"; break;
case "Torna indietro":  			$messaggio = "Volver atrás"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modificar los datos del cliente"; break;
case "Cognome":  				$messaggio = "Apellido"; break;
case "cambia in":  				$messaggio = "cambia a"; break;
case "Nome":  					$messaggio = "Nombre"; break;
case "cancella":  				$messaggio = "borrar"; break;
case "Sesso":  					$messaggio = "Sexo"; break;
case "Data di nascita":  			$messaggio = "Fecha de nacimiento"; break;
case "Telefono":  				$messaggio = "Teléfono"; break;
case "Via":  					$messaggio = "Calle"; break;
case "Piazza":  				$messaggio = "Plaza"; break;
case "Viale":  					$messaggio = "Avenida"; break;
case "Piazzale":  				$messaggio = "Paseo"; break;
case "Vicolo":  				$messaggio = "Bulevard"; break;
case "Numero civico":  				$messaggio = "Número de la calle"; break;
case "Città di residenza":  			$messaggio = "Ciudad de residencia"; break;
case "Nazione di residenza":  			$messaggio = "Nación de residencia"; break;
case "CAP":  					$messaggio = "Código postal"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "Correo electrónico"; break;
case "2° telefono":  				$messaggio = "Segundo teléfono"; break;
case "3° telefono":  				$messaggio = "Tercer teléfono"; break;
case "Commento":  				$messaggio = "Comentario"; break;
case "documento di tipo":  			$messaggio = "documento tipo"; break;
case "visualizza":  				$messaggio = "ver"; break;
case "visualizza il documento":  		$messaggio = "ver el documento"; break;
case "Prenotazioni del cliente":  		$messaggio = "Reservas del cliente"; break;
case "nel":  					$messaggio = "en el"; break;
case "Cognome_del_cliente":  			$messaggio = "Apellido_del_cliente"; break;
case "Data_iniziale":  				$messaggio = "Fecha_inicial"; break;
case "Data_finale":  				$messaggio = "Fecha_final"; break;
case "Tariffa_completa":  			$messaggio = "Tarifa_completa"; break;
case "Caparra":  				$messaggio = "Fianza"; break;
case "Pagato":  				$messaggio = "Pagado"; break;
case "Commento":  				$messaggio = "Comentario"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Pers":  					$messaggio = "Pers"; break;
case "Inserito da":  				$messaggio = "Insertado por"; break;
case "Si considererà l'utente":  		$messaggio = "El usuario"; break;
case "come colui che ha inserito il cliente":	$messaggio = "será considerado como el que ha insertado el cliente"; break;
case "Cliente cancellato":  			$messaggio = "Cliente borrado"; break;
case "Cancella il cliente":  			$messaggio = "Borra el cliente"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Este cliente no se puede borrar porque todavia tiene reservas asociadas"; break;
case "Annulla":  				$messaggio = "Cancelar"; break;
case "NO":  					$messaggio = "NO"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Estas suguro de querer <div style=\"display: inline; color: red;\">borrar</div> el cliente"; break;
case "SI":  					$messaggio = "SI"; break;
case "Reg./Prov.  di residenza":  		$messaggio = "Región de residencia"; break;
case "Documento":  				$messaggio = "Documento"; break;
case "Scadenza documento":  			$messaggio = "Expiración documento"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "La región de residencia será cambiada de"; break;
case "Il documento verrà cambiato da":  	$messaggio = "El documento será cambiado de"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "La fecha de expiración del documento será cambiada de"; break;
case "La <b>regione di residenza</b> verrà cancellata":  	$messaggio = "La <b>región de residencia</b> será borrada"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "El <b>documento</b> será borrado"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "La <b>fecha de expiración del documento</b> será borrada"; break;
case "Cittadinanza":  				$messaggio = "Nacionalidad"; break;
case "Nazione di nascita":  			$messaggio = "Nación de nacimiento"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Región de nacimiento"; break;
case "Città di nascita":  			$messaggio = "Ciudad de nacimiento"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Región de residencia"; break;
case "Città di rilascio":  			$messaggio = "Ciudad de emisión"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Región de emisión"; break;
case "Nazione di rilascio":  			$messaggio = "Nación emisora"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "La nacionalidad cambiará de"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "La nación de nacimiento cambiará de"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "La región de nacimiento cambiará de"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "La ciudad de nacimiento cambiará de"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "La ciudad de emisión del documento cambiará de"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "La región de emisión del documento cambiará de"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "La nación emisora del documento cambiará de"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "La <b>nacionalidad</b> será borrada"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "La <b>nación de nacimiento</b> será borrada"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "La <b>región de nacimiento</b> será borrada"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "La <b>ciudad de nacimiento</b> será borrada"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "La <b>región de emisión del documento</b> será borrada"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "La <b>ciudad de emisión del documento</b> será borrada"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "La <b>nación emisora del documento</b> será borrada"; break;
case "Codice fiscale":  			$messaggio = "N. Identificación Fiscal"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "El Número de Identificación Fiscal cambiará de"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "El <b>Número de Identificación Fiscal</b> será borrado"; break;
case "Titolo":  				$messaggio = "Título"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "El título fiscal cambiará de"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "El <b>título</b> será borrado"; break;
case "Partita iva":  				$messaggio = "Cert. Identificación Fiscal"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "El Certificado de Identificación Fiscal será cambiado de"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "El <b>Certificado de Identificación Fiscal</b> será borrado"; break;
case "data inserimento":  			$messaggio = "fecha de inserción"; break;
case "carte di credito":  			$messaggio = "tarjetas de crédito"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "contraseña para ver las tarjetas de crédito"; break;
case "invia":  					$messaggio = "enviar"; break;
case "password errata":  			$messaggio = "contraseña equivocada"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "los datos de la tarjeta de crédito han sido borrados"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "el número de la tarjeta de crédito está <span class=\"colred\">equivocado</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "el número de CVC está <span class=\"colred\">equivocado</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "los datos de la tarjeta de crédito han sido insertados"; break;
case "carta di credito del cliente":  		$messaggio = "tarjeta de crédito del cliente"; break;
case "Tipo":  					$messaggio = "Tipo"; break;
case "Numero":  				$messaggio = "Número"; break;
case "Titolare":  				$messaggio = "Titular"; break;
case "Scadenza":  				$messaggio = "Expiración"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "modifica i dati della carta di credito":	$messaggio = "modificar los datos de la tarjeta de crédito"; break;
case "cancella questa carta di credito":  	$messaggio = "borrar esta tarjeta de crédito"; break;
case "soprannome":  				$messaggio = "apodo"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "El apodo cambiará de"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "El <b>apodo</b> será borrado"; break;
case "Lingua":  				$messaggio = "Idioma"; break;
case "La lingua verrà cambiata da":  		$messaggio = "El idioma será cambiado de"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "El <b>idioma</b> será borrado"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Los datos de la tarjeta de crédito pueden ser vistos solo através de una conexión segura"; break;
case "Il campo":  				$messaggio = "El campo"; break;
case "verrà tolto":  				$messaggio = "será eliminado"; break;
case "verrà modificato":  			$messaggio = "será modificado"; break;
case "verrà aggiunto":  			$messaggio = "será añadido"; break;
case "scaduta":  				$messaggio = "caducada"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "Las tarjetas de crédito se podrán ver de nuevo después de cambiar la contraseña"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "Las tarjetas de crédito se podrán ver de nuevo después que el usuario administrador haya cambiado la contraseña"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>