<?php

$lista_citta = "";
$cod_citta = "";
$cod2_citta = "";
$cod3_citta = "";
$cod_regione_citta = "";

#$lista_citta[0] = "Madrid";
#$cod_citta[0] = "000001";
#$cod_regione_citta[0] = "Madrid";
#$lista_citta[1] = "Barcelona";
#$cod_citta[1] = "000002";
#$cod_regione_citta[1] = "Catalunya";


?>