<?php

switch ($messaggio) {

case "Modifica o cancella la prenotazione":	$messaggio = "Modificar o borrar la reserva"; break;
case "Prenotazione a nome di":  		$messaggio = "Reserva a nombre de"; break;
case "nato il":  				$messaggio = "nacido el"; break;
case "nata il":  				$messaggio = "nacida el"; break;
case "e":  					$messaggio = "y"; break;
case "CAP":  					$messaggio = "código postal"; break;
case "Telefono":  				$messaggio = "Teléfono"; break;
case "2º telefono":  				$messaggio = "2° teléfono"; break;
case "3º telefono":  				$messaggio = "3er teléfono"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modificar los datos del cliente"; break;
case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":	$messaggio = "La reserva es del año anterior, se podrá modificar solo la fecha final"; break;
case "settimane":  				$messaggio = "semanas"; break;
case "giorni":  				$messaggio = "días"; break;
case "dal":  					$messaggio = "desde"; break;
case "al":  					$messaggio = "hasta"; break;
case "cambia in":  				$messaggio = "cambiar a"; break;
case "in":  					$messaggio = "en"; break;
case "Nº di piano":  				$messaggio = "N° de piso"; break;
case "e/o di casa":  				$messaggio = "y/o de casa"; break;
case "e/o di persone":  			$messaggio = "y/o de personas"; break;
case "Nº di persone":  				$messaggio = "N° de personas"; break;
case "Commento":  				$messaggio = "Comentario"; break;
case "Cancella il commento":  			$messaggio = "Borrar el comentario"; break;
case "Tipo di tariffa":  			$messaggio = "Tipo de tarifa"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Sconto":  				$messaggio = "Descuento"; break;
case "Caparra":  				$messaggio = "Fianza"; break;
case "resto":  					$messaggio = "resto"; break;
case "Ricalcola la caparra in base alla nuova tariffa":	$messaggio = "Volver a calcular la fianza en base a la nueva tarifa"; break;
case "Costo aggiuntivo unico":  		$messaggio = "Coste añadido único"; break;
case "moltiplicato per":  			$messaggio = "multiplicado por"; break;
case "Costo aggiuntivo settimanale":  		$messaggio = "Coste añadido semanal"; break;
case "Costo aggiuntivo giornaliero":  		$messaggio = "Coste añadido diario"; break;
case "per":  					$messaggio = "por"; break;
case "settimane moltiplicato per":  		$messaggio = "semanas multiplicado por"; break;
case "giorni moltiplicato per":  		$messaggio = "días multiplicado por"; break;
case "della tariffa moltiplicato per":  	$messaggio = "de la tarifa multiplicado por"; break;
case "Prenotazione confermata":  		$messaggio = "Reserva confirmada"; break;
case "Totale da pagare":  			$messaggio = "Total a pagar"; break;
case "Pagato":  				$messaggio = "Pagado"; break;
case "aggiungi":  				$messaggio = "añade"; break;
case "pagato tutto":  				$messaggio = "todo pagado"; break;
case "caparra ":  				$messaggio = "fianza pagada"; break;
case "Ancora da pagare":  			$messaggio = "Todavía a pagar"; break;
case "Nuovo costo aggiuntivo unico":  		$messaggio = "Nuevo coste añadido único"; break;
case "di":  					$messaggio = "de"; break;
case "da moltiplicare per":  			$messaggio = "a multiplicar por"; break;
case "letto":  					$messaggio = "cama"; break;
case "straordinario":  				$messaggio = "extraordinario"; break;
case "Nuovo costo aggiuntivo settimanale":	$messaggio = "Nuevo coste añadido semanal"; break;
case "Nuovo costo aggiuntivo giornaliero":  	$messaggio = "Nuevo coste añadido diario"; break;
case "nº di settimane da applicare":  		$messaggio = "n° de samanas a aplicar"; break;
case "nº di giorni da applicare":  		$messaggio = "n° de días a aplicar"; break;
case "non specificato":  			$messaggio = "no especificado"; break;
case "Modifica la prenotazione":  		$messaggio = "Modificar la reserva"; break;
case "Cancella la prenotazione":  		$messaggio = "Borrar la reserva"; break;
case "documento di tipo":  			$messaggio = "documento tipo"; break;
case "visualizza":  				$messaggio = "ver"; break;
case "visualizza il documento":  		$messaggio = "ver el documento"; break;
case "Torna indietro":  			$messaggio = "Volver atrás"; break;
case "SI":  					$messaggio = "SI"; break;
case "cancella anche ciò che era stato pagato":	$messaggio = "borra también lo que ya había sido pagado"; break;
case "NO":  					$messaggio = "NO"; break;
case "La prenotazione":  			$messaggio = "La reserva"; break;
case "era già stata cancellata":  		$messaggio = "había sido ya borrada"; break;
case "Prenotazione":  				$messaggio = "Reserva"; break;
case "cancellata":  				$messaggio = "borrada"; break;
case "<b>non è stata cancellata</b> perchè è stata modificata nel frattempo":	$messaggio = "<b>no ha sido borrada</b> porque ha sido modificada mientras tanto"; break;
case "Si è sicuri di voler <b>cancellare</b> la prenotazione":	$messaggio = "Estás seguro de que quieres <b>borrar</b> la reserva"; break;
case "Si è sicuri di voler <b>cancellare</b> le prenotazioni":	$messaggio = "Estás seguro de que quieres <b>borrar</b> las reservas"; break;
case "La data iniziale verrà cambiata dal":  	$messaggio = "La fecha inicial será cambiada de"; break;
case "al":  					$messaggio = "a"; break;
case "La data finale verrà cambiata dal":  	$messaggio = "La fecha final será cambiada de"; break;
case "Le <div style=\"display: inline; color: red;\">date</div> sono <b>sbagliate</b>":	$messaggio = "Las <div style=\"display: inline; color: red;\">fechas</div> están <b>equivocadas</b>"; break;
case "°</b> piano":  				$messaggio = "</b>"; break;
case "della casa":  				$messaggio = "de la casa"; break;
case "con massimo numero di occupanti":  	$messaggio = "con máximo número de ocupantes"; break;
case "a":  					$messaggio = "a"; break;
case "Il numero delle persone verrà cambiato da":	$messaggio = "El número de las personas será cambiado de"; break;
case "persone":  				$messaggio = "personas"; break;
case "è stata <b>cancellata</b>":  		$messaggio = "ha sido <b>borrada</b>"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Hay que hacer los siguientes movimientos en períodos de la  <div style=\"display: inline; color: blue;\">regla de asignacón 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "La reserva desde"; break;
case "a nome di":  				$messaggio = "a nombre de"; break;
case "La prenotazione verrà":  			$messaggio = "La reserva será"; break;
case "mantenuta":  				$messaggio = "dejada"; break;
case "spostata":  				$messaggio = "desplazada"; break;
case "La tariffa":  				$messaggio = "La tarifa"; break;
case "non esiste più, cambiala prima di aggiornare":	$messaggio = "ya no existe, cambiarla antes de actualizar"; break;
case "<b>Non</b> è stato ancora inserito il prezzo della":	$messaggio = "Todavía <b>no</b> ha sido insertado el precio de la"; break;
case "per la settimana dal":  			$messaggio = "para la semana desde"; break;
case "per il giorno dal":  			$messaggio = "para el día desde"; break;
case "La tariffa verrà cambiata da":  		$messaggio = "La tarifa será cambiada de"; break;
case "Il costo aggiuntivo":  			$messaggio = "El coste añadido"; break;
case "Il costo aggiuntivo unico":  		$messaggio = "El coste añadido único"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "El coste añadido semanal"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "El coste añadido diario"; break;
case "non può essere moltiplicato per":  	$messaggio = "no puede estar multiplicado por"; break;
case "verrà moltiplicato per":  		$messaggio = "será multiplicado por"; break;
case "prima era":  				$messaggio = "antes era"; break;
case "Le settimane del costo aggiuntivo":  	$messaggio = "Las semanas del coste añadido"; break;
case "I giorni del costo aggiuntivo":  		$messaggio = "Los días del coste añadido"; break;
case "<b>superano</b> la durata della prenotazione":	$messaggio = "<b>superan</b> la duración de la reserva"; break;
case "verranno cabiate da":  			$messaggio = "serán cambiadas de"; break;
case "verranno cabiati da":  			$messaggio = "serán cambiados de"; break;
case "verranno cabiate":  			$messaggio = "serán cambiadas"; break;
case "verranno cabiati":  			$messaggio = "serán cambiados"; break;
case "<b>non</b> verranno cambiate":  		$messaggio = "<b>no</b> serán cambiadas"; break;
case "<b>non</b> verranno cambiati":  		$messaggio = "<b>no</b> serán cambiados"; break;
case "su":  					$messaggio = "sobre"; break;
case "Il prezzo del costo aggiuntivo":  	$messaggio = "El precio del coste añadido"; break;
case "verrà tolto":  				$messaggio = "será quitado"; break;
case "I dati del costo aggiuntivo <b>straordinario</b> sono <div style=\"display: inline; color: red;\">errati o mancanti</div>":	$messaggio = "Los datos del coste añadido <b>extraordinario</b> están <div style=\"display: inline; color: red;\">equivocados o faltan</div>"; break;
case "verrà aggiunto":  			$messaggio = "será añadido"; break;
case "come letto aggiuntivo":  			$messaggio = "como cama extra"; break;
case "Le settimane del nuovo costo aggiuntivo":	$messaggio = "Las semanas del nuevo coste añadido"; break;
case "I giorni del nuovo costo aggiuntivo":  	$messaggio = "Los días del nuevo coste añadido"; break;
case "Lo <div style=\"display: inline; color: red;\">sconto</div> inserito":	$messaggio = "El <div style=\"display: inline; color: red;\">decuento</div> insertado"; break;
case "supera il costo totale senza sconto":  	$messaggio = "supera el coste total sin decuento"; break;
case "Lo sconto verrà cambiato da":  		$messaggio = "El descuento será cambiado de"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div> inserita":	$messaggio = "La <div style=\"display: inline; color: red;\">fianza</div> insertada"; break;
case "supera il costo totale":  		$messaggio = "supera el coste total"; break;
case "La caparra verrà cambiata da":  		$messaggio = "La fianza será cambiada de"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div>":  	$messaggio = "La <div style=\"display: inline; color: red;\">fianza</div>"; break;
case "supera il nuovo costo totale":  		$messaggio = "supera el nuevo coste total"; break;
case "La cifra <div style=\"display: inline; color: red;\">pagata</div> inserita":	$messaggio = "La cantidad <div style=\"display: inline; color: red;\">pagada</div> insertada"; break;
case "I soldi pagati verranno cambiati da":  		$messaggio = "El dinero pagado será cambiados de"; break;
case "verrà <b>confermata</b>":  			$messaggio = "será <b>confirmada</b>"; break;
case "Verrà tolta la <b>conferma</b> alla prenotazione":	$messaggio = "Se quitará <b>confirmación</b>a la reserva"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "El <b>comentario</b> será cambiado"; break;
case "Il <b>commento</b> verrà cancellato":  	$messaggio = "El <b>comentario</b> será borrado"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "modificata":  				$messaggio = "modificada"; break;
case "<b>non è stata modificata</b> perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "<b>no ha sido modificada</b> porqué la tabla de reservas ha cambiado mientras tanto"; break;
case "verrà cambiato da":  			$messaggio = "será cambiado de"; break;
case "con costo agg.":  			$messaggio = "con coste aña."; break;
case "Cliente":  				$messaggio = "Cliente"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "No hay ningun período de las reglas 1 en el que esté consentido insertar reservas para el usuario"; break;
case "Prenotazione non confermata":  		$messaggio = "Reserva no confirmada"; break;
case "Inserita dall'utente":  			$messaggio = "Insertada por el usuario"; break;
case "Si considererà l'utente":  		$messaggio = "El usuario"; break;
case "come colui che ha inserito la prenotazione":	$messaggio = "será considerado como el que ha insertado la reserva"; break;
case "Non si possono inserire altri costi":  	$messaggio = "No se pueden insertar mas costes"; break;
case "in questo periodo, già":  		$messaggio = "en este periodo, ya"; break;
case "presenti":  				$messaggio = "presentes"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "No se puede insertar el coste añadido"; break;
case "in questo periodo":  			$messaggio = "en este periodo"; break;
case "Settimane":  				$messaggio = "Semanas"; break;
case "Giorni":  				$messaggio = "Días"; break;
case "mostra":  				$messaggio = "enseña"; break;
case "nascondi":  				$messaggio = "oculta"; break;
case "numeri diversi":  			$messaggio = "números distintos"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "No se puede insertar mas de un coste añadido con percentual sobre el precio total por reserva"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Escoger las semanas en las que aplicar el coste añadido"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Escoger los días en las que aplicar el coste añadido"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "Hay que insertar el número de personas para el coste añadido"; break;
case "Non si possono inserire altri costi":  	$messaggio = "No se pueden insertar mas costes"; break;
case "in questo periodo, già":  		$messaggio = "en este periodo, ya"; break;
case "presenti":  				$messaggio = "presentes"; break;
case "della tariffa":  				$messaggio = "de la tarifa"; break;
case "del totale":  				$messaggio = "del total"; break;
case "della caparra":  				$messaggio = "de la fianza"; break;
case "del resto caparra":  			$messaggio = "del resto de la fianza"; break;
case "di base":  				$messaggio = "de base"; break;
case "totale":  				$messaggio = "total"; break;
case "registra entrata":  			$messaggio = "registrar entrada"; break;
case "cancella entrata":  			$messaggio = "borrar entrada"; break;
case "registra uscita":  			$messaggio = "registrar salida"; break;
case "cancella uscita":  			$messaggio = "borrar salida"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Atención</div>: horario de entrada ya registrado"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata non registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Atención</div>: horario de entrada no registrado"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Atención</div>: horario de salida ya registrado"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita non registrato, registrare prima l'entrata":	$messaggio = "<div style=\"display: inline; color: red;\">Atención</div>: horario de salida no registrado, registrar antes la entrada"; break;
case "Metodo pagamento caparra":  		$messaggio = "Método pago fianza"; break;
case "Il metodo di pagamento della caparra verrà cambiato a":	$messaggio = "El método de pago de la fianza será cambiado a"; break;
case "Metodo di pagamento":  			$messaggio = "Método de pago"; break;
case "metodo di pagamento":  			$messaggio = "método de pago"; break;
case "Normalmente le prenotazioni già iniziate e quelle che hanno registrato l'orario di entrata non vengono spostate":	$messaggio = "Normalmente las reservas ya empezadas y las que han registrado el horario de entrada no son movidas"; break;
case "Prova di nuovo":  			$messaggio = "Intenta otra vez"; break;
case "muovendo anche le prenotazioni iniziate dopo il":	$messaggio = "moviendo también las reservas empezadas después del"; break;
case "considerate fisse perchè <div style=\"display: inline; color: red;\">ad oggi già iniziate</div>":	$messaggio = "consideradas fijas porqué <div style=\"display: inline; color: red;\">al día de hoy ya empezadas</div>"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "es incompatible con la tarifa seleccionada"; break;
case "non può essere applicato":  		$messaggio = "no puede ser aplicado"; break;
case "Non si può cambiare l'assegnazione di una prenotazione che si trova <div style=\"display: inline; color: red;\">tra due anni</div>":	$messaggio = "No se puede cambiar la asignación de una reserva que se encuentra <div style=\"display: inline; color: red;\">entre dos años</div>"; break;
case "Modifica nell'anno precedente":  		$messaggio = "Modificar en el año anterior"; break;
case "Orario entrata stimato":  		$messaggio = "Horario entrada estimativo"; break;
case "L'orario stimato di entrata verrà cambiato a":	$messaggio = "El horario de entrada estimativo será cambiado a"; break;
case "Codice prenotazione":  			$messaggio = "Código reserva"; break;
case "rigenera":  				$messaggio = "regenerar"; break;
case "Non si è potuto spostare la prenotazione per la registrazione dell'entrata":	$messaggio = "No se ha podido mover la reserva por la registración de la entrada"; break;
case "Cambia cliente":  			$messaggio = "Cambiar cliente"; break;
case "Nuovo titolare della prenotazione":	$messaggio = "Nuevo titular de la reserva"; break;
case "cliente numero":  			$messaggio = "cliente número"; break;
case "Il titolare della prenotazione":  	$messaggio = "El titular de la reserva"; break;
case "Il titolare delle prenotazioni":  	$messaggio = "El titular de las reservas"; break;
case "Cliente non trovato":  			$messaggio = "No se ha encontrado el cliente"; break;
case "Annulla":  				$messaggio = "Anular"; break;
case "Prenotazioni vicine":  			$messaggio = "Reservas cercanas"; break;
case "numero":  				$messaggio = "número"; break;
case "La prenotazione numero":  		$messaggio = "La reserva número"; break;
case "non esiste":  				$messaggio = "no existe"; break;
case "Ospiti della prenotazione":  		$messaggio = "Huéspedes de la reserva"; break;
case "Modifica gli ospiti":  			$messaggio = "Modificar los huéspedes"; break;
case "nato":  					$messaggio = "nacido"; break;
case "nata":  					$messaggio = "nacida"; break;
case "il":  					$messaggio = "el"; break;
case " a":  					$messaggio = " en"; break;
case "scade":  					$messaggio = "caduca"; break;
case "Codice fiscale":  			$messaggio = "N.I.F."; break;
case "Origine":  				$messaggio = "Origen"; break;
case "L'origine della prenotazione verrà cambiata a":	$messaggio = "El origen de la reserva será cambiado a"; break;
case "Modifica o cancella le prenotazioni":  	$messaggio = "Modificar o borrar las reservas"; break;
case "Modifica le prenotazioni":  		$messaggio = "Modificar las reservas"; break;
case "Cancella le prenotazioni":  		$messaggio = "Borrar las reservas"; break;
case "della prenotazione":  			$messaggio = "de la reserva"; break;
case "per la prenotazione":  			$messaggio = "para la reserva"; break;
case "Data inserimento":  			$messaggio = "Fecha de inserción"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "con los costes añadidos seleccionados"; break;
case "I beni richiesti dal costo":  		$messaggio = "Los bienes necesarios para el coste"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "no están disponibles en el inventario"; break;
case "<b><big>i</big></b>":  			$messaggio = "<b><big>i</big></b>"; break;
case "pren.":  					$messaggio = "res."; break;
case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per la tariffa selezionata":	$messaggio = "Hay que insertar el <span class=\"colred\">número de personas</span> para la tarifa seleccionada"; break;
case "Partita iva":  				$messaggio = "C.I.F."; break;
case "i beni richiesti alla registrazione dell'entrata":	$messaggio = "los bienes necesarios para registrar la entrada"; break;
case "Commissioni":  				$messaggio = "Comisiones"; break;
case "Ricalcola le commissioni in base alla nuova tariffa":	$messaggio = "Volver a calcular las comisiones en base a la nueva tarifa"; break;
case "Le commissioni verranno cambiate da":	$messaggio = "Las comisiones serán cambiadas desde"; break;
case "tasse":  					$messaggio = "tasas"; break;
case "Il prezzo totale cambierà da":  		$messaggio = "El precio total cambiará de"; break;
case "saldo di":  				$messaggio = "saldo de"; break;
case "Altre prenotazioni dello stesso cliente nello stesso periodo":	$messaggio = "Otras reservas del mismo cliente en el mismo período"; break;
case "tutte":  					$messaggio = "todas"; break;
case "Attenzione":  				$messaggio = "Atención"; break;
case "vi sono altre prenotazioni dello stesso cliente nello stesso periodo che ancora non sono state pagate":	$messaggio = "hay otras reservas del mismo cliente en el mismo período que todavia no han sido pagadas"; break;
case "Il saldo totale pagato sarà di":  	$messaggio = "El saldo total pagado será de"; break;
case "ln.":  					$messaggio = "id."; break;
case "della tariffa fissa":  			$messaggio = "de la tarifa fija"; break;
case "di una persona":  			$messaggio = "de una persona"; break;
case "non può essere moltiplicato per più di":	$messaggio = "no puede ser multiplicado por más de"; break;
case "Nuovo costo aggiuntivo":  		$messaggio = "Nuevo coste añadido"; break;
case "aggiungi promemoria per l'entrata":  	$messaggio = "añadir un recordatorio para la entrada"; break;
case "aggiungi promemoria per l'uscita":  	$messaggio = "añadir un recordatorio para la salida"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio = "Se añadirá un <b>recodatorio</b> para la <em>entrada</em>"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "Se añadirá un <b>recodatorio</b> para la <em>salida</em>"; break;
case "Promemoria":  				$messaggio = "Recordatorio"; break;
case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in questo periodo":	$messaggio = "La <b>tarifa</b> seleccionada está <span class=\"colred\">cerrada</span> en este período"; break;
case "cambia il commento":  			$messaggio = "cambiar el comentario"; break;
case "Il commento":  				$messaggio = "El comentario"; break;
case "verrà cambiato":  			$messaggio = "será cambiado"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>