<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Volver atrás"; break;
case "Variabili personalizzate dei documenti":  $messaggio = "Variables personalizadas de los documentos"; break;
case "Variabili personalizzate":  		$messaggio = "Variables personalizadas"; break;
case "Elimina":  				$messaggio = "Eliminar"; break;
case "Aggiungi":  				$messaggio = "Añadir"; break;
case "se":  					$messaggio = "si"; break;
case "è uguale a":  				$messaggio = "es igual a"; break;
case "è diverso da":  				$messaggio = "es distinto de"; break;
case "allora porre":  				$messaggio = "entonces poner"; break;
case "uguale a":  				$messaggio = "igual a"; break;
case "Nuova variabile personalizzata inserita":	$messaggio = "Nueva variable personalizada insertada"; break;
case "I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "Los datos insertados están <div style=\"display: inline; color: red;\">equivocados</div>"; break;
case "Variabile personalizzata eliminata":  	$messaggio = "Variable personalizada eliminada"; break;
case "Nuova condizione inserita":  		$messaggio = "Nueva condición insertada"; break;
case "Condizione eliminata":  			$messaggio = "Condición eliminada"; break;
case "porre":  					$messaggio = "poner"; break;
case "sostituendo":  				$messaggio = "substituyendo"; break;
case "con":  					$messaggio = "con"; break;
case "arrotondato a":  				$messaggio = "redondeado a"; break;
case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Utilizar una variable personalizada que acaba con \"_p\" para añadir los separadores de los miles y 2 decimales después de la operación"; break;
case "e":  					$messaggio = "y"; break;
case "o":  					$messaggio = "o"; break;
case "concatenato con":  			$messaggio = "concatenado con"; break;
case "allora":  				$messaggio = "entonces"; break;
case "uguaglia":  				$messaggio = "equiparar"; break;
case "concatena":  				$messaggio = "concatenar"; break;
case "troncare":  				$messaggio = "truncar"; break;
case "dopo":  					$messaggio = "después de"; break;
case "caratteri":  				$messaggio = "caracteres"; break;
case "se mancanti riempire con":  		$messaggio = "si faltan rellenar con"; break;
case "la parte":  				$messaggio = "la parte"; break;
case "finale":  				$messaggio = "final"; break;
case "iniziale":  				$messaggio = "inicial"; break;
case "riempiendo i mancanti con":  		$messaggio = "rellenando los que falten con"; break;
case "all'inizio":  				$messaggio = "al principio"; break;
case "alla fine":  				$messaggio = "al final"; break;
case "Array personalizzati":  			$messaggio = "Arrays personalizados"; break;
case "Array della variabile":  			$messaggio = "Array de la variable"; break;
case "Valori iniziali da assegnare all'array":	$messaggio = "Valores iniciales a asignar al array"; break;
case "Nessun valore predefinito":  		$messaggio = "Ningún valor predefinido"; break;
case "valori progressivi tra le date selezionate":	$messaggio = "valores progresivos entre las fechas seleccionadas"; break;
case "valori progressivi tra il primo arrivo e l'ultima partenza":	$messaggio = "valores progresivos entre la primera llegada y la última salida"; break;
case "una lista di valori predefiniti":  	$messaggio = "una lista de valores predefinidos"; break;
case "separati da virgole":  			$messaggio = "separados por comas"; break;
case "nelle ripetizioni vengono considerate solo le prenotazioni nella data valutata":	$messaggio = "en las repeticiones son consideradas solo las reservas en la fecha evaluada"; break;
case "<b>Condizioni</b> applicate":  		$messaggio = "<b>Condiciones</b> aplicadas"; break;
case "a tutti i documenti":  			$messaggio = "a todos los documentos"; break;
case "al documento":  				$messaggio = "al documento"; break;
case "Modifica le condizioni applicate":  	$messaggio = "Modificar la condiciones aplicadas"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "Array personalizzato eliminato":  	$messaggio = "Array personalizado eliminado"; break;
case "Nuovo array personalizzato inserito":  	$messaggio = "Nuevo array personalizado insertado"; break;
case "azzera l'array":  			$messaggio = "anula el array"; break;
case "non processare le condizioni successive":	$messaggio = "no elaborar las condiciones siguientes"; break;
case "è maggiore di":  				$messaggio = "es mayor de"; break;
case "è minore di":  				$messaggio = "es menor de"; break;
case "solo al documento":  			$messaggio = "solo al documento"; break;
case "solo all'inizio delle ripetizioni delle prenotazioni":	$messaggio = "solo al principio de las repeticiones de las reservas"; break;
case "in tutte le ripetizioni delle prenotazioni":	$messaggio = "en todas la repeticiones de las reservas"; break;
case "Modifica il documento":  			$messaggio = "Modificar el documento"; break;
case "nuova condizione":  			$messaggio = "nueva condición"; break;
case "da applicare":  				$messaggio = "a aplicar"; break;
case "solo all'inizio del documento":  		$messaggio = "solo al principio del codumento"; break;
case "sempre":  				$messaggio = "siempre"; break;
case "azione":  				$messaggio = "ación"; break;
case "aggiungi un altro &quot;se&quot;":  	$messaggio = "añadir otro &quot;si&quot;"; break;
case "azzera l'array":  			$messaggio = "anular el array"; break;
case "assegna all'array":  			$messaggio = "asignar al array"; break;
case "aggiungi la nuova condizione":  		$messaggio = "añadir la nueva condición"; break;
case "i valori":  				$messaggio = "los valores"; break;
case "fino alla fine":  			$messaggio = "hasta el final"; break;
case "fino al prossimo &quot;riprendi&quot;":  	$messaggio = "hasta el próximo &quot;reanudar&quot;"; break;
case "riprendi a processare le condizioni successive":	$messaggio = "reanudar la elaboración de las condiciones siguientes"; break;
case "se precedentemente interrotte":  		$messaggio = "si fueron anteriormente interrumpidas"; break;
case "modifica la condizione":  		$messaggio = "modificar la condición"; break;
case "da applicare":  				$messaggio = "a aplicar"; break;
case "condizione modificata":  			$messaggio = "condición modificada"; break;
case "annulla":  				$messaggio = "anular"; break;
case "Utilizza sempre":				$messaggio = "Utilizar siempre"; break;
case "Importa ora":				$messaggio = "Importar ahora"; break;
case "variabili e condizioni del documento":	$messaggio = "variables y condiciones del documento"; break;
case "le variabili e condizioni attuali verranno cancellate":	$messaggio = "las variables y condiciones actuales serán borradas"; break;
case "Visualizza le condizioni del documento":	$messaggio = "Ver las condiciones del documento"; break;
case "il giorno":  				$messaggio = "el día"; break;
case "il mese":  				$messaggio = "el més"; break;
case "l'anno":  				$messaggio = "el año"; break;
case "il giorno della settimana":  		$messaggio = "el día de la semana"; break;
case "della data":  				$messaggio = "de la fecha"; break;
case "contiene":  				$messaggio = "contiene"; break;
case "maiusc./minusc.":  			$messaggio = "maiúsc./minúsc."; break;
case "la data":  				$messaggio = "la fecha"; break;
case "formato ISO":  				$messaggio = "formato ISO"; break;
case "formato corrente":  			$messaggio = "formato actual"; break;
case "giorni":  				$messaggio = "días"; break;
case "mesi":  					$messaggio = "meses"; break;
case "anni":  					$messaggio = "años"; break;
case "i valori dell'array":  			$messaggio = "los valores del array"; break;
case "elimina questo &quot;se&quot;":  		$messaggio = "Eliminar este &quot;si&quot;"; break;
case "uguale al numero di":  			$messaggio = "igual al número de"; break;
case "numero di":  				$messaggio = "número de"; break;
case "dalla data":  				$messaggio = "desde la fecha"; break;
case "alla data":  				$messaggio = "hasta la fecha"; break;
case "solo nelle ripetizioni degli ospiti":	$messaggio = "solo en las repeticiones de los huéspedes"; break;
case "solo nelle ripetizioni dei costi aggiuntivi":	$messaggio = "solo en las repeticiones de los costes añadidos"; break;
case "solo nelle ripetizioni dei pagamenti":	$messaggio = "solo en las repeticiones de los pagos"; break;
case "solo nelle ripetizioni delle unità":	$messaggio = "solo en las repeticiones de las unidades"; break;
case "Condizioni applicate":  			$messaggio = "Condiciones aplicadas"; break;
case "tutte le altre condizioni non verranno più applicate in queste ripetizioni":	$messaggio = "todas las otras condiciones ya no serán aplicadas en estas repeticiones"; break;
case "solo nelle ripetizioni dell'array":	$messaggio = "solo en las repeticiones del array"; break;
case "prima di con valori negativi":  		$messaggio = "antes de con valores negativos"; break;
case "prima di":  				$messaggio = "antes de"; break;
case "in minuscole":  				$messaggio = "en minúsculas"; break;
case "in maiuscole":  				$messaggio = "en mayúsculas"; break;
case "codificato per URL":  			$messaggio = "codificado para URL"; break;
case "codificato in ASCII":  			$messaggio = "codificado en ASCII"; break;
case "in ASCII esteso":  			$messaggio = "en ASCII extendido"; break;
case "codificato con MD5":  			$messaggio = "codificado con MD5"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>