<?php

switch ($messaggio) {

case "MENU":  				$messaggio = "MENU"; break;
case "PRENOTAZIONE":  			$messaggio = "RESERVATION"; break;
case "TABELLE":  			$messaggio = "TABLES"; break;
case "GENNAIO":  			$messaggio = "JANUARY"; break;
case "FEBBRAIO":  			$messaggio = "FEBRUARY"; break;
case "MARZO":  				$messaggio = "MARCH"; break;
case "APRILE":  			$messaggio = "APRIL"; break;
case "MAGGIO":  			$messaggio = "MAY"; break;
case "GIUGNO":  			$messaggio = "JUNE"; break;
case "LUGLIO":  			$messaggio = "JULY"; break;
case "AGOSTO":  			$messaggio = "AUGUST"; break;
case "SETTEMBRE":  			$messaggio = "SEPTEMBER"; break;
case "OTTOBRE":  			$messaggio = "OCTOBER"; break;
case "NOVEMBRE":  			$messaggio = "NOVEMBER"; break;
case "DICEMBRE":  			$messaggio = "DECEMBER"; break;
case "PRENOTAZIONI":  			$messaggio = "RESERVATIONS"; break;
case "SPESE":  				$messaggio = "EXPENSES"; break;
case "CASSE":  				$messaggio = "CASHBOXES"; break;
case "TARIFFE":  			$messaggio = "RATES"; break;
case "CLIENTI":  			$messaggio = "CLIENTS"; break;
case "INSERIRE":  			$messaggio = "INSERT"; break;
case "CLIENTE":  			$messaggio = "CLIENT"; break;
case "PREZZI":  			$messaggio = "PRICES"; break;
case "REGOLE":  			$messaggio = "RULES"; break;
case "CONFIGURA":  			$messaggio = "CONFIGURE"; break;
case "TUTTE":  				$messaggio = "ALL"; break;
case "CORRENTI":  			$messaggio = "CURRENT"; break;
case "FUTURE":  			$messaggio = "FUTURE"; break;
case "ARRIVI":  			$messaggio = "ARRIVALS"; break;
case "PARTENZE":  			$messaggio = "DEPARTURES"; break;
case "MESSAGGI":  			$messaggio = "MESSAGES"; break;
case "ENTRATE&nbsp;PREN.":  		$messaggio = "RES.&nbsp;PAYMENTS"; break;
case "UTENTI":  			$messaggio = "USERS"; break;
case "SITO WEB":  			$messaggio = "WEBSITE"; break;
case "INTERCONN.":  			$messaggio = "INTERCONN."; break;
case "BACKUP":  			$messaggio = "BACKUP"; break;
case "STATISTICHE":  			$messaggio = "STATISTICS"; break;
case "INVENTARIO":  			$messaggio = "INVENTORY"; break;
case "CERCA":  				$messaggio = "SEARCH"; break;
case "DOCUMENTI":  			$messaggio = "DOCUMENTS"; break;
case "P.TO&nbsp;VENDITA":  		$messaggio = "POINT&nbsp;OF&nbsp;SALE"; break;
case "NUMERO":  			$messaggio = "NUMBER"; break;
case "VAI":  				$messaggio = "GO"; break;
case "COSTI AGGIUNTIVI":  		$messaggio = "EXTRA COSTS"; break;
case "CAPARRE E TASSE":  		$messaggio = "DEPOSITS AND TAXES"; break;
case "PARTENZE E CORRENTI":  		$messaggio = "DEPART. AND CURRENT"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

# Simple theme top menu drop-down menus widths (leave defaults if widths are OK)
case "insert-ddw":  			$messaggio = "100px"; break;
case "tables-ddw":  			$messaggio = "100px"; break;
case "months-ddw":  			$messaggio = "86px"; break;
case "reservations-ddw":  		$messaggio = "150px"; break;
case "clients-ddw":  			$messaggio = "15em"; break;
case "rates-ddw":  			$messaggio = "150px"; break;
case "configure-ddw":  			$messaggio = "86px"; break;

} # fine switch ($messaggio)

?>