<?php

# To translate in other languages change the names of
# the variables on the right. Use only ascii letters,
# numbers and underscore: NO ACCENTS, NO SPACES

$trad_var['cognome'] = 'apellido';
$trad_var['nome'] = 'nombre';
$trad_var['soprannome'] = 'apodo';
$trad_var['titolo'] = 'titulo';
$trad_var['sesso'] = 'sexo';
$trad_var['cittadinanza'] = 'nacionalidad';
$trad_var['data_nascita'] = 'fecha_nacimiento';
$trad_var['citta_nascita'] = 'ciudad_nacimiento';
$trad_var['regione_nascita'] = 'region_nacimiento';
$trad_var['nazione_nascita'] = 'nacion_nacimiento';
$trad_var['citta'] = 'ciudad';
$trad_var['regione'] = 'region';
$trad_var['nazione'] = 'nacion';
$trad_var['via'] = 'calle';
$trad_var['via2'] = 'calle2';
$trad_var['numcivico'] = 'numero_calle';
$trad_var['cap'] = 'codigo_postal';
$trad_var['documento'] = 'documento';
$trad_var['tipo_documento'] = 'tipo_documento';
$trad_var['citta_documento'] = 'ciudad_documento';
$trad_var['regione_documento'] = 'region_documento';
$trad_var['nazione_documento'] = 'nacion_documento';
$trad_var['scadenza_documento'] = 'expiracion_documento';
$trad_var['telefono'] = 'telefono';
$trad_var['telefono2'] = 'telefono2';
$trad_var['telefono3'] = 'telefono3';
$trad_var['fax'] = 'fax';
$trad_var['email'] = 'email';
$trad_var['codice_fiscale'] = 'num_identificacion_fiscal';
$trad_var['partita_iva'] = 'certificado_identificacion_fiscal';
$trad_var['num_persone'] = 'num_personas';
$trad_var['n_letti_agg'] = 'num_camas_extras';
$trad_var['num_persone_tot'] = 'num_personas_tot';
$trad_var['costo_tot'] = 'coste_tot';
$trad_var['caparra'] = 'fianza';
$trad_var['resto_caparra'] = 'resto_fianza';
$trad_var['data_inizio'] = 'fecha_inicial';
$trad_var['data_fine'] = 'fecha_final';
$trad_var['num_periodi'] = 'num_periodos';
$trad_var['orario_entrata_stimato'] = 'horario_entrada_estimativo';
$trad_var['nome_tariffa'] = 'nombre_tarifa';
$trad_var['costo_tariffa'] = 'precio_tarifa';
$trad_var['costo_tariffa_p'] = 'precio_tarifa_p';
$trad_var['costo_tariffa_giorno_array'] = 'precio_tarifa_dia_array';
$trad_var['costo_tariffa_giorno_array_p'] = 'precio_tarifa_dia_array_p';
$trad_var['sconto'] = 'descuento';
$trad_var['commento'] = 'comentario';
$trad_var['promemoria_entrata'] = 'recordatorio_entrada';
$trad_var['promemoria_uscita'] = 'recordatorio_salida';
$trad_var['origine_prenotazione'] = 'origen_reserva';
$trad_var['unita_occupata'] = 'unidad_ocupada';
$trad_var['unita_assegnabili'] = 'lista_unidades';
$trad_var['pagato'] = 'pagado';
$trad_var['pagato_p'] = 'pagado_p';
$trad_var['resto_da_pagare'] = 'resto_a_pagar';
$trad_var['resto_da_pagare_p'] = 'resto_a_pagar_p';
$trad_var['commissioni'] = 'comisiones';
$trad_var['commissioni_p'] = 'comisiones_p';
$trad_var['resto_commissioni'] = 'resto_comisiones';
$trad_var['resto_commissioni_p'] = 'resto_comisiones_p';
$trad_var['percentuale_tasse_tariffa'] = 'porcentage_tasas_tarifa';
$trad_var['tasse_tariffa'] = 'tasas_tarifa';
$trad_var['tasse_tariffa_p'] = 'tasas_tarifa_p';
$trad_var['costo_tariffa_senza_tasse'] = 'precio_tarifa_sin_tasas';
$trad_var['costo_tariffa_senza_tasse_p'] = 'precio_tarifa_sin_tasas_p';
$trad_var['tasse_sconto'] = 'tasas_descuento';
$trad_var['tasse_sconto_p'] = 'tasas_descuento_p';
$trad_var['sconto_senza_tasse'] = 'descuento_sin_tasas';
$trad_var['sconto_senza_tasse_p'] = 'descuento_sin_tasas_p';
$trad_var['nome_costo_agg'] = 'nombre_coste_agna';
$trad_var['valore_costo_agg'] = 'valor_coste_agna';
$trad_var['valore_costo_agg_p'] = 'valor_coste_agna_p';
$trad_var['giorni_costo_agg'] = 'dias_coste_agna';
$trad_var['valore_tutti_costi_agg'] = 'valor_todos_costes_agnadidos';
$trad_var['valore_tutti_costi_agg_p'] = 'valor_todos_costes_agnadidos_p';
$trad_var['tutti_i_costi_agg'] = 'todos_costes_agnadidos';
$trad_var['nome_costo_agg_sel'] = 'nombre_coste_agna_sel';
$trad_var['valore_costo_agg_sel'] = 'valor_coste_agna_sel';
$trad_var['percentuale_tasse_costo_agg'] = 'porcentage_tasas_coste_agna';
$trad_var['tasse_costo_agg'] = 'tasas_coste_agna';
$trad_var['tasse_costo_agg_p'] = 'tasas_coste_agna_p';
$trad_var['valore_costo_agg_senza_tasse'] = 'valor_coste_agna_sin_tasas';
$trad_var['valore_costo_agg_senza_tasse_p'] = 'valor_coste_agna_sin_tasas_p';
$trad_var['moltiplica_max_costo_agg'] = 'multiplicado_max_coste_agna';
$trad_var['moltiplica_max_costo_agg_sel'] = 'multiplicado_max_coste_agna_sel';
$trad_var['data_inserimento_costo_agg'] = 'fecha_insercion_coste_agna';
$trad_var['utente_inserimento_costo_agg'] = 'usuario_insercion_coste_agna';
$trad_var['percentuale_tasse_costo_agg_sel'] = 'porcentage_tasas_coste_agna_sel';
$trad_var['tasse_costo_agg_sel'] = 'tasas_coste_agna_sel';
$trad_var['tasse_costo_agg_sel_p'] = 'tasas_coste_agna_sel_p';
$trad_var['oggi'] = 'hoy';
$trad_var['costo_tot_p'] = 'coste_tot_p';
$trad_var['caparra_p'] = 'fianza_p';
$trad_var['resto_caparra_p'] = 'resto_fianza_p';
$trad_var['tutti_i_costi_agg_p'] = 'todos_costes_agnadidos_p';
$trad_var['valore_costo_agg_sel_p'] = 'valor_coste_agna_sel_p';
$trad_var['sconto_p'] = 'descuento_p';
$trad_var['num_costi_aggiuntivi'] = 'num_costes_agnadidos';
$trad_var['valore_pagamento'] = 'valor_pago';
$trad_var['valore_pagamento_p'] = 'valor_pago_p';
$trad_var['data_pagamento'] = 'fecha_pago';
$trad_var['utente_pagamento'] = 'usuario_pago';
$trad_var['metodo_pagamento'] = 'metodo_pago';
$trad_var['tutti_i_pagamenti'] = 'todos_los_pagos';
$trad_var['tutti_i_pagamenti_p'] = 'todos_los_pagos_p';
$trad_var['valore_ultimo_pagamento'] = 'valor_ultimo_pago';
$trad_var['valore_ultimo_pagamento_p'] = 'valor_ultimo_pago_p';
$trad_var['data_ultimo_pagamento'] = 'fecha_ultimo_pago';
$trad_var['utente_ultimo_pagamento'] = 'usuario_ultimo_pago';
$trad_var['metodo_ultimo_pagamento'] = 'metodo_ultimo_pago';
$trad_var['num_pagamenti'] = 'num_pagos';
$trad_var['numero_prenotazione'] = 'numero_reserva';
$trad_var['numero_ripetizione_prenotazioni'] = 'numero_repeticion_reservas';
$trad_var['codice_prenotazione'] = 'codigo_reserva';
$trad_var['data_inserimento_prenotazione'] = 'fecha_insercion_reserva';
$trad_var['utente_inserimento_prenotazione'] = 'usuario_insercion_reserva';
$trad_var['numero_progressivo_documento'] = 'numero_progresivo_documento';
$trad_var['codice_cittadinanza'] = 'codigo_nacionalidad';
$trad_var['codice_nazione_nascita'] = 'codigo_nacion_nacimiento';
$trad_var['codice_regione_nascita'] = 'codigo_region_nacimiento';
$trad_var['codice_citta_nascita'] = 'codigo_ciudad_nacimiento';
$trad_var['codice_nazione'] = 'codigo_nacion';
$trad_var['codice_regione'] = 'codigo_region';
$trad_var['codice_citta'] = 'codigo_ciudad';
$trad_var['codice_tipo_documento'] = 'codigo_tipo_documento';
$trad_var['codice_citta_documento'] = 'codigo_ciudad_documento';
$trad_var['codice_regione_documento'] = 'codigo_region_documento';
$trad_var['codice_nazione_documento'] = 'codigo_nacion_documento';
$trad_var['codice2_cittadinanza'] = 'codigo2_nacionalidad';
$trad_var['codice2_nazione_nascita'] = 'codigo2_nacion_nacimiento';
$trad_var['codice2_regione_nascita'] = 'codigo2_region_nacimiento';
$trad_var['codice2_citta_nascita'] = 'codigo2_ciudad_nacimiento';
$trad_var['codice2_nazione'] = 'codigo2_nacion';
$trad_var['codice2_regione'] = 'codigo2_region';
$trad_var['codice2_citta'] = 'codigo2_ciudad';
$trad_var['codice2_tipo_documento'] = 'codigo2_tipo_documento';
$trad_var['codice2_citta_documento'] = 'codigo2_ciudad_documento';
$trad_var['codice2_regione_documento'] = 'codigo2_region_documento';
$trad_var['codice2_nazione_documento'] = 'codigo2_nacion_documento';
$trad_var['codice3_cittadinanza'] = 'codigo3_nacionalidad';
$trad_var['codice3_nazione_nascita'] = 'codigo3_nacion_nacimiento';
$trad_var['codice3_regione_nascita'] = 'codigo3_region_nacimiento';
$trad_var['codice3_citta_nascita'] = 'codigo3_ciudad_nacimiento';
$trad_var['codice3_nazione'] = 'codigo3_nacion';
$trad_var['codice3_regione'] = 'codigo3_region';
$trad_var['codice3_citta'] = 'codigo3_ciudad';
$trad_var['codice3_tipo_documento'] = 'codigo3_tipo_documento';
$trad_var['codice3_citta_documento'] = 'codigo3_ciudad_documento';
$trad_var['codice3_regione_documento'] = 'codigo3_region_documento';
$trad_var['codice3_nazione_documento'] = 'codigo3_nacion_documento';
$trad_var['num_ospiti_tot'] = 'num_huespedes_tot';
$trad_var['numero_ospite'] = 'numero_huesped';
$trad_var['cognome_ospite'] = 'apellido_huesped';
$trad_var['nome_ospite'] = 'nombre_huesped';
$trad_var['soprannome_ospite'] = 'apodo_huesped';
$trad_var['titolo_ospite'] = 'titulo_huesped';
$trad_var['sesso_ospite'] = 'sexo_huesped';
$trad_var['cittadinanza_ospite'] = 'nacionalidad_huesped';
$trad_var['parentela_ospite'] = 'emparentado_huesped';
$trad_var['datanascita_ospite'] = 'fecha_nacimiento_huesped';
$trad_var['citta_nascita_ospite'] = 'ciudad_nacimiento_huesped';
$trad_var['regione_nascita_ospite'] = 'region_nacimiento_huesped';
$trad_var['nazione_nascita_ospite'] = 'nacion_nacimiento_huesped';
$trad_var['citta_ospite'] = 'ciudad_huesped';
$trad_var['regione_ospite'] = 'region_huesped';
$trad_var['nazione_ospite'] = 'nacion_huesped';
$trad_var['via_ospite'] = 'calle_huesped';
$trad_var['via2_ospite'] = 'calle2_huesped';
$trad_var['numcivico_ospite'] = 'numero_calle_huesped';
$trad_var['cap_ospite'] = 'codigo_postal_huesped';
$trad_var['documento_ospite'] = 'documento_huesped';
$trad_var['tipo_documento_ospite'] = 'tipo_documento_huesped';
$trad_var['citta_documento_ospite'] = 'ciudad_documento_huesped';
$trad_var['regione_documento_ospite'] = 'region_documento_huesped';
$trad_var['nazione_documento_ospite'] = 'nacion_documento_huesped';
$trad_var['scadenza_documento_ospite'] = 'expiracion_documento_huesped';
$trad_var['telefono_ospite'] = 'telefono_huesped';
$trad_var['telefono2_ospite'] = 'telefono2_huesped';
$trad_var['telefono3_ospite'] = 'telefono3_huesped';
$trad_var['fax_ospite'] = 'fax_huesped';
$trad_var['email_ospite'] = 'email_huesped';
$trad_var['codice_fiscale_ospite'] = 'codigo_fiscal_huesped';
$trad_var['partita_iva_ospite'] = 'num_identificacion_fiscal_huesped';
$trad_var['codice_cittadinanza_ospite'] = 'codigo_nacionalidad_huesped';
$trad_var['codice_parentela_ospite'] = 'codigo_emparentado_huesped';
$trad_var['codice_nazione_nascita_ospite'] = 'codigo_nacion_nacimiento_huesped';
$trad_var['codice_regione_nascita_ospite'] = 'codigo_region_nacimiento_huesped';
$trad_var['codice_citta_nascita_ospite'] = 'codigo_ciudad_nacimiento_huesped';
$trad_var['codice_nazione_ospite'] = 'codigo_nacion_huesped';
$trad_var['codice_regione_ospite'] = 'codigo_region_huesped';
$trad_var['codice_citta_ospite'] = 'codigo_ciudad_huesped';
$trad_var['codice_tipo_documento_ospite'] = 'codigo_tipo_documento_huesped';
$trad_var['codice_citta_documento_ospite'] = 'codigo_ciudad_documento_huesped';
$trad_var['codice_regione_documento_ospite'] = 'codigo_region_documento_huesped';
$trad_var['codice_nazione_documento_ospite'] = 'codigo_nacion_documento_huesped';
$trad_var['codice2_cittadinanza_ospite'] = 'codigo2_nacionalidad_huesped';
$trad_var['codice2_parentela_ospite'] = 'codigo2_emparentado_huesped';
$trad_var['codice2_nazione_nascita_ospite'] = 'codigo2_nacion_nacimiento_huesped';
$trad_var['codice2_regione_nascita_ospite'] = 'codigo2_region_nacimiento_huesped';
$trad_var['codice2_citta_nascita_ospite'] = 'codigo2_ciudad_nacimiento_huesped';
$trad_var['codice2_nazione_ospite'] = 'codigo2_nacion_huesped';
$trad_var['codice2_regione_ospite'] = 'codigo2_region_huesped';
$trad_var['codice2_citta_ospite'] = 'codigo2_ciudad_huesped';
$trad_var['codice2_tipo_documento_ospite'] = 'codigo2_tipo_documento_huesped';
$trad_var['codice2_citta_documento_ospite'] = 'codigo2_ciudad_documento_huesped';
$trad_var['codice2_regione_documento_ospite'] = 'codigo2_region_documento_huesped';
$trad_var['codice2_nazione_documento_ospite'] = 'codigo2_nacion_documento_huesped';
$trad_var['codice3_cittadinanza_ospite'] = 'codigo3_nacionalidad_huesped';
$trad_var['codice3_parentela_ospite'] = 'codigo3_emparentado_huesped';
$trad_var['codice3_nazione_nascita_ospite'] = 'codigo3_nacion_nacimiento_huesped';
$trad_var['codice3_regione_nascita_ospite'] = 'codigo3_region_nacimiento_huesped';
$trad_var['codice3_citta_nascita_ospite'] = 'codigo3_ciudad_nacimiento_huesped';
$trad_var['codice3_nazione_ospite'] = 'codigo3_nacion_huesped';
$trad_var['codice3_regione_ospite'] = 'codigo3_region_huesped';
$trad_var['codice3_citta_ospite'] = 'codigo3_ciudad_huesped';
$trad_var['codice3_tipo_documento_ospite'] = 'codigo3_tipo_documento_huesped';
$trad_var['codice3_citta_documento_ospite'] = 'codigo3_ciudad_documento_huesped';
$trad_var['codice3_regione_documento_ospite'] = 'codigo3_region_documento_huesped';
$trad_var['codice3_nazione_documento_ospite'] = 'codigo3_nacion_documento_huesped';
$trad_var['nome_unita'] = 'nombre_unidad';
$trad_var['casa_unita'] = 'casa_unidad';
$trad_var['piano_unita'] = 'piso_unidad';
$trad_var['capacita_unita'] = 'capacidad_unidad';
$trad_var['priorita_unita'] = 'prioridad_unidad';
$trad_var['num_unita'] = 'num_unidades';
$trad_var['costo_tot_somma_ripetizioni'] = 'coste_tot_suma_repeticiones';
$trad_var['costo_tot_somma_ripetizioni_p'] = 'coste_tot_suma_repeticiones_p';
$trad_var['caparra_somma_ripetizioni'] = 'fianza_suma_repeticiones';
$trad_var['caparra_somma_ripetizioni_p'] = 'fianza_suma_repeticiones_p';
$trad_var['resto_caparra_somma_ripetizioni'] = 'resto_fianza_suma_repeticiones';
$trad_var['resto_caparra_somma_ripetizioni_p'] = 'resto_fianza_suma_repeticiones_p';
$trad_var['pagato_somma_ripetizioni'] = 'pagado_suma_repeticiones';
$trad_var['pagato_somma_ripetizioni_p'] = 'pagado_suma_repeticiones_p';
$trad_var['resto_da_pagare_somma_ripetizioni'] = 'resto_a_pagar_suma_repeticiones';
$trad_var['resto_da_pagare_somma_ripetizioni_p'] = 'resto_a_pagar_suma_repeticiones_p';
$trad_var['num_persone_tot_somma_ripetizioni'] = 'num_personas_tot_suma_repeticiones';
$trad_var['data_inizio_selezione'] = 'fecha_inicial_seleccion';
$trad_var['data_fine_selezione'] = 'fecha_final_seleccion';
$trad_var['utente_attuale'] = 'usuario_actual';
$trad_var['nome_struttura'] = 'nombre_estructura';
$trad_var['tipo_struttura'] = 'tipo_estructura';
$trad_var['email_struttura'] = 'email_estructura';
$trad_var['ragione_sociale_struttura'] = 'razon_social_estructura';
$trad_var['sito_web_struttura'] = 'sitio_web_estructura';
$trad_var['nome_contatto_struttura'] = 'nombre_contacto_estructura';
$trad_var['nazione_struttura'] = 'nacion_estructura';
$trad_var['comune_struttura'] = 'ciudad_estructura';
$trad_var['indirizzo_struttura'] = 'direccion_estructura';
$trad_var['CAP_struttura'] = 'codigo_postal_estructura';
$trad_var['telefono_struttura'] = 'telefono_estructura';
$trad_var['fax_struttura'] = 'fax_estructura';
$trad_var['codice_fiscale_struttura'] = 'num_identificacion_fiscal_estructura';
$trad_var['partita_iva_struttura'] = 'certificado_identificacion_fiscal_estructura';
$trad_var['numero_stelle_struttura'] = 'numero_estrellas_estructura';
$trad_var['logo_struttura'] = 'logo_estructura';
$trad_var['nome_valuta'] = 'nombre_divisa';
$trad_var['testo_email_richiesta'] = 'texto_email_pedido';
$trad_var['testo_quotato_email_richiesta'] = 'texto_citado_email_pedido';
$trad_var['url_base_pagine_web'] = 'url_base_paginas_web';
$trad_var['ritorno_a_capo'] = 'carriage_return';
$trad_var['avanzamento_riga'] = 'new_line';
$trad_var['valore_nullo'] = 'valor_nulo';
$trad_var['errore_ripetizione'] = 'error_repeticion';
$trad_var['messaggio_di_errore'] = 'mensaje_de_error';
$trad_var['codice_lingua'] = 'codigo_idioma';
$trad_var['email_gia_inviata'] = 'email_ya_enviada';
$trad_var['commento_personalizzato'] = 'comentario_personalizado';
$trad_var['campo_personalizzato'] = 'campo_personalizado';


?>