<?php

switch ($messaggio) {

case "Modifica il costo aggiuntivo":  		$messaggio = "Modify extra cost"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Cambia in":  				$messaggio = "Change to"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Prezzo":  				$messaggio = "Price"; break;
case "la tariffa":  				$messaggio = "the rate"; break;
case "unico":  					$messaggio = "single"; break;
case "settimanale":  				$messaggio = "weekly"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case "fisso":  					$messaggio = "fixed"; break;
case "percentuale":  				$messaggio = "percentage"; break;
case "Numero di settimane":  			$messaggio = "Number of weeks"; break;
case "Numero di giorni":  			$messaggio = "Number of days"; break;
case "solo per costi settimanali":  		$messaggio = "only for weekly costs"; break;
case "solo per costi giornalieri":  		$messaggio = "only for daily costs"; break;
case "tutte":  					$messaggio = "all"; break;
case "tutti":  					$messaggio = "all"; break;
case "tutte meno una":  			$messaggio = "all minus one"; break;
case "tutti meno uno":  			$messaggio = "all minus one"; break;
case "chiedere":  				$messaggio = "ask"; break;
case "Assegna automaticamente con le tariffe":	$messaggio = "Automatically assign with rates"; break;
case "Mostrare nella pagina di inserzione prenotazioni?":	$messaggio = "Display in reservation insertion page?"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case "Chiedere per quanto deve essere moltiplicato?":	$messaggio = "Ask by how much it must be multiplied?"; break;
case "Considerare il costo aggiuntivo come letto(i) aggiuntivo(i)?":	$messaggio = "Consider this extra cost as an extra bed(s)?"; break;
case "Modifica il costo":  			$messaggio = "Modify cost"; break;
case "Il costo è stato cancellato":  		$messaggio = "The cost has been deleted"; break;
case "Non si può proseguire perchè il costo aggiuntivo è già stato modificato nel frattempo":	$messaggio = "The extra cost can't be changed because it has already changed meanwhile"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "Not all necessary data has been inserted"; break;
case "I soldi o la percentuale del costo sono sbagliati":	$messaggio = "The price or the percentage of the cost is wrong"; break;
case "Un costo aggiuntivo dello stesso tipo e con lo stesso nome esiste già":	$messaggio = "An extra cost of the same type and price already exists"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo non deve essere applicato automaticamente a nessuna tariffa":	$messaggio = "For asking the number of weeks or by how much it must be multiplied the cost must not be applied to any rate automatically"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo non deve essere applicato automaticamente a nessuna tariffa":	$messaggio = "For asking the number of days or by how much it must be multiplied the cost must not be applied to any rate automatically"; break;
case "Il nome del costo aggiuntivo verrà cambiato da":	$messaggio = "The name of the extra cost will be changed from"; break;
case "a":  					$messaggio = "to"; break;
case "Il tipo di costo aggiuntivo verrà cambiato da":	$messaggio = "The type of the extra cost will be changed from"; break;
case "arrotondato a":  				$messaggio = "rounded to"; break;
case "Il costo verrà applicato":  		$messaggio = "The cost will be applied to"; break;
case "tutte le settimane":  			$messaggio = "all weeks"; break;
case "tutti i giorni":  			$messaggio = "all days"; break;
case "tutte le settimane meno una":  		$messaggio = "all weeks minus one"; break;
case "tutti i giorni meno uno":  		$messaggio = "all days minus one"; break;
case "un numero di settimane a scelta":		$messaggio = "a number of weeks at choice"; break;
case "un numero di giorni a scelta":  		$messaggio = "a number of days at choice"; break;
case "Il valore del costo aggiuntivo verrà cambiato dal":	$messaggio = "The value of the extra cost will be changed from"; break;
case "al":  					$messaggio = "to"; break;
case "Il valore del costo aggiuntivo verrà cambiato da":	$messaggio = "The value of the extra cost will be changed from"; break;
case "L'applicazione del costo verrà cambiata da":	$messaggio = "The cost application will be changed from"; break;
case "Il costo <b>non</b> verrà più associato automaticamente alla":	$messaggio = "The cost will <b>not</b> be automatically assigned anymore to"; break;
case "Il costo verrà associato automaticamente alla":	$messaggio = "The cost will be automatically assigned to"; break;
case "Il costo verrà mostrato nella pagina di inserzione prenotazioni":	$messaggio = "The cost will be displayed in reservation insertion page"; break;
case "Il costo non verrà più mostrato nella pagina di inserzione prenotazioni":	$messaggio = "The cost will not be displayed anymore in reservation insertion page"; break;
case "Verrà chiesto per quanto si deve moltiplicare il costo":	$messaggio = "You will be asked about how much multiply the cost by"; break;
case "Non verrà più chiesto per quanto si deve moltiplicare il costo":	$messaggio = "You will not be asked anymore about how much multiply the cost by"; break;
case "Il costo verrà considerato come letto(i) aggiuntivo(i)":	$messaggio = "The cost will be considered as extra bed(s)"; break;
case "Il costo non verrà più considerato come letto(i) aggiuntivo(i)":	$messaggio = "The cost will not be considered anymore as extra bed(s)"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "% su":  					$messaggio = "% of"; break;
case "il prezzo totale":  			$messaggio = "total price"; break;
case "la caparra":  				$messaggio = "the deposit"; break;
case "totale meno caparra":  			$messaggio = "total minus deposit"; break;
case "minimo":  				$messaggio = "minimum"; break;
case "massimo":  				$messaggio = "maximum"; break;
case "esattamente":  				$messaggio = "exactly"; break;
case "settimane":  				$messaggio = "weeks"; break;
case "giorni":  				$messaggio = "days"; break;
case "Se possibile":  				$messaggio = "If possible"; break;
case "Sempre":  				$messaggio = "Always"; break;
case "Associare a specifiche settimane della prenotazione":	$messaggio = "Associate to specific weeks of the reservation"; break;
case "Associare a specifici giorni della prenotazione":	$messaggio = "Associate to specific days of the reservation"; break;
case "Tutte":  					$messaggio = "All"; break;
case "Tutti":  					$messaggio = "All"; break;
case "Tutte meno":  				$messaggio = "All minus"; break;
case "Tutti meno":  				$messaggio = "All minus"; break;
case "la prima":  				$messaggio = "the first"; break;
case "il primo":  				$messaggio = "the first"; break;
case "l'ultima":  				$messaggio = "the last"; break;
case "l'ultimo":  				$messaggio = "the last"; break;
case "Chiedere":  				$messaggio = "Ask"; break;
case "settimane sì":  				$messaggio = "weeks yes"; break;
case "giorni sì":  				$messaggio = "days yes"; break;
case "settimane no":  				$messaggio = "weeks no"; break;
case "giorni no":  				$messaggio = "days no"; break;
case "e":  					$messaggio = "and"; break;
case "Giorni della settimana selezionati":  	$messaggio = "Selected week days"; break;
case "Lunedì":  				$messaggio = "Monday"; break;
case "Martedì":  				$messaggio = "Tuesday"; break;
case "Mercoledì":  				$messaggio = "Wednesday"; break;
case "Giovedì":  				$messaggio = "Thursday"; break;
case "Venerdì":  				$messaggio = "Friday"; break;
case "Sabato":  				$messaggio = "Saturday"; break;
case "Domenica":  				$messaggio = "Sunday"; break;
case "Moltiplicare il costo per":  		$messaggio = "Multiply the cost by"; break;
case "Uno":  					$messaggio = "One"; break;
case "Chiedere":  				$messaggio = "Ask"; break;
case "Numero di persone":  			$messaggio = "Number of people"; break;
case "Numero di persone totale":  		$messaggio = "Total number of people"; break;
case "escluse quelle dei costi con letti aggiuntivi":	$messaggio = "excluding the ones from costs with extra beds"; break;
case "Periodi in cui è permesso<br> inserire il costo":	$messaggio = "Periods in which it is allowed<br> to insert the cost"; break;
case "In tutti":  				$messaggio = "All"; break;
case "Solo nei periodi selezionati":  		$messaggio = "Only selected periods"; break;
case "dal":  					$messaggio = "from"; break;
case "Elimina un periodo":  			$messaggio = "Delete period"; break;
case "Aggiungi un periodo":  			$messaggio = "Add period"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "if all weeks of the reservation are in the selected periods"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "if all days of the reservation are in the selected periods"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "if even only one week of the reservation is in the selected periods"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "if even only one day of the reservation is in the selected periods"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":	$messaggio = "apply the cost only to permitted weeks in the reservation"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":	$messaggio = "apply the cost only to permitted days in the reservation"; break;
case "Caratteristiche del costo<br> da mantenere quando si<br> modifica una prenotazione":	$messaggio = "Cost characteristics to keep<br> when a reservation is modified"; break;
case "Valore percentuale":  			$messaggio = "Percentage value"; break;
case "e settimane associate":  			$messaggio = "and associated weeks"; break;
case "e giorni associati":  			$messaggio = "and associated days"; break;
case "Assegnazione settimane":  		$messaggio = "Weeks assignment"; break;
case "Assegnazione giorni":  			$messaggio = "Days assignment"; break;
case "Numero per cui viene moltiplicato":  	$messaggio = "Number by which it is multiplied"; break;
case "Periodi permessi":  			$messaggio = "Permitted periods"; break;
case "Associazione alle tariffe":  		$messaggio = "Association to rates"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":	$messaggio = "Display in reservations insertion page"; break;
case "Si":  					$messaggio = "Yes"; break;
case "No":  					$messaggio = "No"; break;
case "Considerare il costo come letto/i aggiuntivo/i":	$messaggio = "Consider this extra cost as an extra bed(s)"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":	$messaggio = "Limit the number that it is possible to have contemporaneously in the same period"; break;
case "I valori inseriti sono <div style=\"display: inline; color: red;\">errati</div> o incongruenti":	$messaggio = "Inserted values are <div style=\"display: inline; color: red;\">wrong</div> or incongruous"; break;
case "Niente da modificare":  			$messaggio = "Nothing to be modified"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "è stato modificato":  			$messaggio = "has been modified"; break;
case "Tariffe incompatibili":  			$messaggio = "Incompatible rates"; break;
case "Quando possibile assegna automaticamente se mancano":	$messaggio = "When possible assign automatically if"; break;
case "meno di":  				$messaggio = "less than"; break;
case "più di":  				$messaggio = "more than"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita":	$messaggio = "days are remaining from the starting date of the reservation when it is inserted"; break;
case "Quando possibile assegna automaticamente se si inseriscono":	$messaggio = "When possible assign automatically if"; break;
case "o più prenotazioni contemporaneamente":	$messaggio = "or more reservations are inserted contemporaneously"; break;
case "Sempre in periodi permessi":  		$messaggio = "Always in allowed periods"; break;
case "Non si può <b style=\"font-weight: normal; color: red;\">contemporaneamente</b> mostrare il costo nella pagina di inserimento delle prenotazioni ed assegnarlo automaticamente con una tariffa":	$messaggio = "You can't <b style=\"font-weight: normal; color: red;\">contemporaneously</b> display the cost in reservation insertion page and automatically assign it with a rate"; break;
case "tra":  					$messaggio = "between"; break;
case "Beni dell'inventario da<br> eliminare quando si<br> inserisce il costo":	$messaggio = "Inventory items to delete<br> when the cost is inserted"; break;
case "Nessuno":  				$messaggio = "No one"; break;
case "Beni selezionati":  			$messaggio = "Selected items"; break;
case "Aggiungi un bene":  			$messaggio = "Add an item"; break;
case "Elimina un bene":  			$messaggio = "Delete an item"; break;
case "elimina i beni dall'inventario del magazzino":	$messaggio = "Delete items from inventory of stockroom"; break;
case "Beni dell'inventario da eliminare":  	$messaggio = "Inventory items to delete"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Display grouped with similar costs from same category in insertion"; break;
case "Tasse":  					$messaggio = "Taxes"; break;
case "Categoria":  				$messaggio = "Category"; break;
case "parte fissa della tariffa":  		$messaggio = "fixed part of the rate"; break;
case "parte per una persona della tariffa":  	$messaggio = "one person part of the rate"; break;
case "Numero massimo":  			$messaggio = "Maximum number"; break;
case "0 se illimitato":  			$messaggio = "0 for unlimited"; break;
case "meno":  					$messaggio = "minus"; break;
case "il costo viene moltiplicato per<br> zero se la somma è negativa":	$messaggio = "the cost will be multiplied by<br> zero if the sum is negative"; break;
case "Combina con altri costi":			$messaggio = "Combine with other costs"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "combined costs are shown all together with category name and each one is inserted when possible"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "Costi combinati":  			$messaggio = "Combined costs"; break;
case "Opzioni in conflitto":  			$messaggio = "Conflicting options"; break;
case "Attenzione":  				$messaggio = "Notice"; break;
case "le seguenti opzioni sono state attivate senza essere mantenute quando la prenotazione viene modificata":	$messaggio = "the following options have been enabled without being kept when a reservation is modified"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>