<?php

switch ($messaggio) {

case "Inserisci i prezzi per l'anno":  		$messaggio = "Insertar los precios para el año"; break;
case "Prezzi della":  				$messaggio = "Precios de la"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "soprannominata":  			$messaggio = "llamada"; break;
case "Dal":  					$messaggio = "Desde"; break;
case "al":  					$messaggio = "hasta"; break;
case "inserisci i nuovi prezzi":  		$messaggio = "inserta nuevos precios"; break;
case "modifica i prezzi già inseriti":  	$messaggio = "modifica precios ya insertados"; break;
case "Costi aggiuntivi":  			$messaggio = "Costes añadidos"; break;
case "Costo aggiuntivo soprannominato":		$messaggio = "Coste añadido llamado"; break;
case "Nome del nuovo costo aggiuntivo":		$messaggio = "Nombre del nuevo coste añadido"; break;
case "da applicare":  				$messaggio = "a aplicar"; break;
case "sempre":  				$messaggio = "siempre"; break;
case "su richiesta":  				$messaggio = "a pedido"; break;
case "chiedi per quanto deve essere moltiplicato":	$messaggio = "preguntar por cuanto tiene que estar multiplicado"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "considera el coste singulo como cama(s) extra(s)"; break;
case "numero di settimane":  			$messaggio = "número de semanas"; break;
case "numero di giorni":  			$messaggio = "número de días"; break;
case "tutte":  					$messaggio = "todas"; break;
case "tutti":  					$messaggio = "todos"; break;
case "tutte meno una":  			$messaggio = "todas menos una"; break;
case "tutti meno uno":  			$messaggio = "todos menos uno"; break;
case "chiedere":  				$messaggio = "preguntar"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio = "considera el coste semanal como cama(s) extra(s)"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "considera el coste diario como cama(s) extra(s)"; break;
case "della tariffa arrotondato a":  		$messaggio = "de la tarifa redondeado a"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "considera el coste percentual como cama(s) extra(s)"; break;
case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Seguir insertando el nuevo coste añadido"; break;
case "Caparra":  				$messaggio = "Fianza"; break;
case "La caparra normale per la":  		$messaggio = "La fianza normal para la"; break;
case "arrotondata a":  				$messaggio = "redondeada a"; break;
case "Inserisci o modifica la caparra":  	$messaggio = "Insertar o modificar la fianza"; break;
case "Vedi i prezzi già inseriti":  		$messaggio = "Mirar los precios ya insertados"; break;
case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
case "Si deve inserire la percentuale":  	$messaggio = "Hay que insertar la percentual"; break;
case "La caparra è stata modificata":  		$messaggio = "La fianza ha sido modificada"; break;
case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "Hay que espicificar cuando aplicar el coste síngulo"; break;
case "Si deve inserire il nome del costo aggiuntivo":	$messaggio = "Hay que insertar el nombre del coste añadido"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "El coste añadido síngulo"; break;
case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "existe ya, vé a la pagina con todos los períodos y las tarifas para cancelarlo"; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":	$messaggio = "Para preguntar el número a multiplicar el coste añadido síngulo no tiene que estar aplicado automaticamente"; break;
case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "Hay que espicificar cuando aplicar el coste semanal"; break;
case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "Hay que espicificar cuando aplicar el coste diario"; break;
case "e il numero di settimane":  		$messaggio = "y el número de semanas"; break;
case "e il numero di giorni":  			$messaggio = "y el número de días"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale non deve essere applicato automaticamente":	$messaggio = "Para preguntar el número de semanas o el número a multiplicar el coste añadido semanal no tiene que estar aplicado automaticamente"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero non deve essere applicato automaticamente":	$messaggio = "Para preguntar el número de semanas o el número a multiplicar el coste añadido diario no tiene que estar aplicado automaticamente"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "El coste añadido semanal"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "El coste añadido diario"; break;
case "Si deve specificare quando applicare il costo percentuale":	$messaggio = "Hay que espicificar cuando aplicar el coste percentual"; break;
case "e il valore dell'arrotondamento":		$messaggio = "y el valor al que redondearlo"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":	$messaggio = "Para preguntar el número a multiplicar el coste añadido percentual no tiene que estar aplicado automaticamente"; break;
case "Il costo aggiuntivo percentuale":		$messaggio = "El coste añadido percentual"; break;
case "è stato inserito":  			$messaggio = "ha sido insertado"; break;
case "Nessun dato è stato inserito":  		$messaggio = "Ningun dato ha sido insertado"; break;
case "Il soprannome della":  			$messaggio = "El nombre de la"; break;
case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "existe ya, utilizar el botón \"modifica precios ya insertados\" para cambiarla, o no ponerlo para insertar precios en nuevos períodos"; break;
case "Il soprannome":  				$messaggio = "El nombre"; break;
case "già esiste, ne devi usare un'altro":  	$messaggio = "ya existe, hay que usar otro"; break;
case "Le date del periodo numero":  		$messaggio = "Las fechas del período número"; break;
case "sono sbagliate":  			$messaggio = "están equivocadas"; break;
case "Il periodo":  				$messaggio = "El período"; break;
case "si sovrappone ad un periodo precedente":	$messaggio = "se sobrepone a un período precedente"; break;
case "Un prezzo nel periodo numero":  		$messaggio = "Un precio el el período número"; break;
case "esiste già, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo":	$messaggio = "existe ya, utilizar el botón \"modifica precios ya insertados\" para cambiarlo"; break;
case "è stato cambiato":  			$messaggio = "ha sido cambiado"; break;
case "Il prezzo del periodo":  			$messaggio = "El precio del período"; break;
case "è stato inserito":  			$messaggio = "ha sido insertado"; break;
case "Il prezzo del periodo numero":  		$messaggio = "El precio del período número"; break;
case "è sbagliato":  				$messaggio = "está equivocado"; break;
case "I soldi del costo finale sono sbagliati":	$messaggio = "El dinero del coste síngulo está equivocado"; break;
case "I soldi del costo settimanale sono sbagliati":	$messaggio = "El dinero del coste semanal está equivocado"; break;
case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "El dinero del coste diario está equivocado"; break;
case "I soldi del costo percentuale sono sbagliati":	$messaggio = "El dinero del coste percentual está equivocado"; break;
case "Inserzione per settimane":		$messaggio = "Inserción por semanas"; break;
case "Inserzione per giorni":			$messaggio = "Inserción por días"; break;
case "Inserzione per settimane":  		$messaggio = "Inserción por semanas"; break;
case "Settimane dal":  				$messaggio = "Semanas desde"; break;
case "Dom/Lun":  				$messaggio = "Dom/Lun"; break;
case "Lun/Mar":  				$messaggio = "Lun/Mar"; break;
case "Mar/Mer":  				$messaggio = "Mar/Mie"; break;
case "Mer/Gio":  				$messaggio = "Mie/Jue"; break;
case "Gio/Ven":  				$messaggio = "Jue/Vie"; break;
case "Ven/Sab":  				$messaggio = "Vie/Sáb"; break;
case "Sab/Dom":  				$messaggio = "Sáb/Dom"; break;
case "inserisci o modifica i prezzi":  		$messaggio = "insertar o modificar los precios"; break;
case "Le date sono sbagliate":  		$messaggio = "Las fechas están equivocadas"; break;
case "Il formato dei soldi è sbagliato":  	$messaggio = "El formato del dinero está equivocado"; break;
case "I prezzi per le settimane dal":  		$messaggio = "Los precios para las semanas desde"; break;
case "della <b>tariffa":  			$messaggio = "de la <b>tarifa"; break;
case "sono stati inseriti":  			$messaggio = "han sido insertados"; break;
case "si":  					$messaggio = "si"; break;
case "no":  					$messaggio = "no"; break;
case "assegnato automaticamente con tariffe":  	$messaggio = "asignado automaticamente con tarifas"; break;
case "nessuna":  				$messaggio = "ninguna"; break;
case "scegliere":  				$messaggio = "escoger"; break;
case "mostrare nella pagina di inserzione prenotazioni":	$messaggio = "enseñar en la página de inserción de reservas"; break;
case "Torna indietro":  			$messaggio = "Volver atrás"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Escoge las tarifas con las que será aplicado automaticamente el coste <b>síngulo</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Escoge las tarifas con las que será aplicado automaticamente el coste <b>semanal</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Escoge las tarifas con las que será aplicado automaticamente el coste <b>diario</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Escoge las tarifas con las que será aplicado automaticamente el coste <b>percentual</b>"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "Tipo di costo aggiuntivo":  		$messaggio = "Tipo de coste añadido"; break;
case "unico":  					$messaggio = "único"; break;
case "settimanale":  				$messaggio = "semanal"; break;
case "giornaliero":  				$messaggio = "diario"; break;
case "il prezzo totale":  			$messaggio = "el precio total"; break;
case "la caparra":  				$messaggio = "la fianza"; break;
case "totale meno caparra":  			$messaggio = "total menos fianza"; break;
case "minimo":  				$messaggio = "mínimo"; break;
case "massimo":  				$messaggio = "máximo"; break;
case "esattamente":  				$messaggio = "exactamente"; break;
case "settimane":  				$messaggio = "semanas"; break;
case "giorni":  				$messaggio = "días"; break;
case "Se possibile":  				$messaggio = "Si es posible"; break;
case "Sempre":  				$messaggio = "Siempre"; break;
case "Associare a specifiche settimane della prenotazione":	$messaggio = "Asociar a semenas específicas de la reserva"; break;
case "Associare a specifici giorni della prenotazione":	$messaggio = "Asociar a días específicos de la reserva"; break;
case "Tutte":  					$messaggio = "Todas"; break;
case "Tutti":  					$messaggio = "Todos"; break;
case "Tutte meno":  				$messaggio = "Todas menos"; break;
case "Tutti meno":  				$messaggio = "Todos menos"; break;
case "la prima":  				$messaggio = "la primera"; break;
case "il primo":  				$messaggio = "el primero"; break;
case "l'ultima":  				$messaggio = "la ultima"; break;
case "l'ultimo":  				$messaggio = "el ultimo"; break;
case "Chiedere":  				$messaggio = "Preguntar"; break;
case "settimane sì":  				$messaggio = "semanas si"; break;
case "giorni sì":  				$messaggio = "días si"; break;
case "settimane no":  				$messaggio = "semanas no"; break;
case "giorni no":  				$messaggio = "días no"; break;
case "e":  					$messaggio = "y"; break;
case "Giorni della settimana selezionati":  	$messaggio = "Días de la semana seleccionados"; break;
case "Lunedì":  				$messaggio = "Lunes"; break;
case "Martedì":  				$messaggio = "Martes"; break;
case "Mercoledì":  				$messaggio = "Miercoles"; break;
case "Giovedì":  				$messaggio = "Jueves"; break;
case "Venerdì":  				$messaggio = "Viernes"; break;
case "Sabato":  				$messaggio = "Sábado"; break;
case "Domenica":  				$messaggio = "Domingo"; break;
case "Moltiplicare il costo per":  		$messaggio = "Multiplicar el coste por"; break;
case "Uno":  					$messaggio = "Uno"; break;
case "Chiedere":  				$messaggio = "Preguntar"; break;
case "Numero di persone":  			$messaggio = "Número de personas"; break;
case "Numero di persone totale":  		$messaggio = "Número total de personas"; break;
case "escluse quelle dei costi con letti aggiuntivi":	$messaggio = "excluídas las de los costes con camas añadidas"; break;
case "Periodi in cui è permesso inserire il costo":	$messaggio = "Períodos en los que está permitido insertar el coste"; break;
case "In tutti":  				$messaggio = "En todos"; break;
case "Solo nei periodi selezionati":  		$messaggio = "Solo en períodos seleccionados"; break;
case "dal":  					$messaggio = "desde"; break;
case "Elimina un periodo":  			$messaggio = "Elimina un período"; break;
case "Aggiungi un periodo":  			$messaggio = "Añade un período"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "si todas las semanas de la reserva estan dentro de los períodos seleccionados"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "si todos los días de la reserva estan dentro de los períodos seleccionados"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "aunque solo una semana de la reserva esté dentro de los períodos seleccionados"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "aunque solo un día de la reserva esté dentro de los períodos seleccionados"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":	$messaggio = "aplicar el coste solo en semanas permitidas en la reserva"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":	$messaggio = "aplicar el coste solo en días permitidos en la reserva"; break;
case "Caratteristiche del costo da mantenere quando si modifica una prenotazione":	$messaggio = "Características del coste a mantener cuando se modifica una reserva"; break;
case "Valore percentuale":  			$messaggio = "Valor percentual"; break;
case "e settimane associate":  			$messaggio = "y semanas asociadas"; break;
case "e giorni associati":  			$messaggio = "y días asociados"; break;
case "Assegnazione settimane":  		$messaggio = "Asignación semanas"; break;
case "Assegnazione giorni":  			$messaggio = "Asignación días"; break;
case "Numero per cui viene moltiplicato":  	$messaggio = "Número por el que está multiplicado"; break;
case "Periodi permessi":  			$messaggio = "Períodos permitidos"; break;
case "Associazione alle tariffe":  		$messaggio = "Asociación a las tarifas"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":	$messaggio = "Enseñar en la página de inserción de reservas"; break;
case "Si":  					$messaggio = "Si"; break;
case "No":  					$messaggio = "No"; break;
case "Considerare il costo come letto/i aggiuntivo/i":	$messaggio = "Considera el coste añadido como cama(s) extra(s)"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":	$messaggio = "Limitar el número que es posible tener contemporaneamente en un mismo período"; break;
case "Valore del costo":  			$messaggio = "Valor del coste"; break;
case "fisso di":  				$messaggio = "fijo de"; break;
case "percentuale su":  			$messaggio = "percentual sobre"; break;
case "la tariffa":  				$messaggio = "la tarifa"; break;
case "indietro":  				$messaggio = "atrás"; break;
case "avanti":  				$messaggio = "adelante"; break;
case "del":  					$messaggio = "del"; break;
case "arrotondato a":  				$messaggio = "redondeado a"; break;
case "Errore nei valori inseriti":  		$messaggio = "Error en los valores insertados"; break;
case "Assegnare automaticamente con le tariffe selezionate":	$messaggio = "Asignar automaticamente con las tarifas seleccionadas"; break;
case "Tariffe":  				$messaggio = "Tarifas"; break;
case "Il costo aggiuntivo":  			$messaggio = "El coste añadido"; break;
case "OK":  					$messaggio = "OK"; break;
case "Le settimane a cui applicare il costo":	$messaggio = "Las semanas en las que aplicar el coste"; break;
case "I giorni a cui applicare il costo":	$messaggio = "Los días en los que aplicar el coste"; break;
case "uno":  					$messaggio = "uno"; break;
case "NO":  					$messaggio = "NO"; break;
case "SI":  					$messaggio = "SI"; break;
case "Costo aggiuntivo già esistente":  	$messaggio = "Coste añadido ya existente"; break;
case "Tariffe incompatibili con il costo":  	$messaggio = "Tarifas incompatibles con el coste"; break;
case "Tariffe incompatibili":  			$messaggio = "Tarifas incompatibles"; break;
case "i prezzi della":  			$messaggio = "los precios de la"; break;
case "dalla":  					$messaggio = "desde la"; break;
case "aggiungendo":  				$messaggio = "añadiendo"; break;
case "I prezzi della tariffa selezionata sono stati importati":	$messaggio = "Los precios de la tarifa seleccionada han sido importados"; break;
case "importa":  				$messaggio = "importar"; break;
case "se selezionato mantenere anche":  	$messaggio = "si seleccionado mantener también"; break;
case "Quando possibile assegna automaticamente se mancano":	$messaggio = "Cuando es posible asignar automaticamente si faltan"; break;
case "meno di":  				$messaggio = "menos de"; break;
case "più di":  				$messaggio = "más de"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita":	$messaggio = "dias a la fecha inicial de la reserva cuando es insertada"; break;
case "Quando possibile assegna automaticamente se si inseriscono":	$messaggio = "Cuando es posible asignar automaticamente si se insertan"; break;
case "o più prenotazioni contemporaneamente":	$messaggio = "o más reservas contemporaneamente"; break;
case "Modifica il costo":  			$messaggio = "Modificar el coste"; break;
case "Inserisci un nuovo costo aggiuntivo chiamato":	$messaggio = "Insertar un nuevo coste añadido llamado"; break;
case "importando le caratteristiche da":	$messaggio = "importando sus características desde"; break;
case "Sempre in periodi permessi":  		$messaggio = "Siempre en períodos permitidos"; break;
case "Prezzo dell'intera settimana":  		$messaggio = "Precio de la semana entera"; break;
case "Prezzi dei giorni":  			$messaggio = "Precios de los días"; break;
case "tra":  					$messaggio = "entre"; break;
case "Beni dell'inventario da eliminare quando si inserisce il costo":	$messaggio = "Bienes del inventario a eliminar cuando se inserta el coste"; break;
case "Nessuno":  				$messaggio = "Ninguno"; break;
case "Beni selezionati":  			$messaggio = "Bienes seleccionados"; break;
case "Aggiungi un bene":  			$messaggio = "Añadir un bien"; break;
case "Elimina un bene":  			$messaggio = "Eliminar un bien"; break;
case "elimina i beni dall'inventario del magazzino":	$messaggio = "Eliminar los bienes del inventario del almacén"; break;
case "Beni dell'inventario da eliminare":  	$messaggio = "Bienes del inventario a eliminar"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Enseñar agrupado con costes similares de la misma categoría en inserción"; break;
case "Il tipo di applicazione della":  		$messaggio = "El tipo de aplicación de la"; break;
case "per persona":  				$messaggio = "por persona"; break;
case "per settimana":  				$messaggio = "por semana"; break;
case "per giorno":  				$messaggio = "por día"; break;
case "La caparra è errata":  			$messaggio = "La fianza está equivocada"; break;
case "è":  					$messaggio = "es"; break;
case "il":  					$messaggio = "el"; break;
case "Commissioni":  				$messaggio = "Comisiones"; break;
case "Le commissioni normali sulla":  		$messaggio = "Las comisiones normales sobre la"; break;
case "sono":  					$messaggio = "son"; break;
case "Tasse":  					$messaggio = "Tasas"; break;
case "Tasse applicate su":  			$messaggio = "Tasas aplicadas sobre"; break;
case "della tariffa":  				$messaggio = "de la tarifa"; break;
case "Inserisci o modifica le tasse":  		$messaggio = "Insertar o modificar las tasas"; break;
case "Le commissioni sono state modificate":  	$messaggio = "Las comisiones han sido modificadas"; break;
case "Le commissioni sono errate":  		$messaggio = "Las comisiones están equivocadas"; break;
case "Le tasse sono state modificate":  	$messaggio = "Las tasas han sido modificadas"; break;
case "Le tasse sono errate":  			$messaggio = "Las tasas están equivocadas"; break;
case "tutti i prezzi delle tariffe si intendono con tasse già incluse":	$messaggio = "todos los precios de las tarifas se consideran con tasas ya incluidas"; break;
case "Inserisci o modifica le commissioni normali":	$messaggio = "Insertar o modificar las comisiones normales"; break;
case "Inserisci o modifica le commissioni in questo periodo":	$messaggio = "Insertar o modificar las comisiones en este período"; break;
case "Sulla":  					$messaggio = "Sobre la"; break;
case "al giorno":  				$messaggio = "al día"; break;
case "alla settimana":  			$messaggio = "por semana"; break;
case "il valore del costo si intente con tasse già incluse":	$messaggio = "el valor del coste se considera con tasas ya incluidas"; break;
case "Categoria":  				$messaggio = "Categoría"; break;
case "il prezzo della tariffa per i primi":  	$messaggio = "el precio de la tarifa para los primeros"; break;
case "il prezzo della tariffa per le prime":  	$messaggio = "el precio de la tarifa para las primeras"; break;
case "della":  					$messaggio = "de la"; break;
case "tariffa + sconto":  			$messaggio = "tarifa + descuento"; break;
case "tariffa + sconto + costi agg.":  		$messaggio = "tarifa + descuento + costes añad."; break;
case "Nome della":  				$messaggio = "Nombre de la"; break;
case "Cambia":  				$messaggio = "Cambiar"; break;
case "prezzo per settimana":  			$messaggio = "precio por semana"; break;
case "prezzo per giorno":  			$messaggio = "precio por día"; break;
case "prezzo per persona per settimana":  	$messaggio = "precio por persona por semana"; break;
case "prezzo per persona per giorno":  		$messaggio = "precio por persona por día"; break;
case "p":  					$messaggio = "p"; break;
case "parte fissa della tariffa":  		$messaggio = "parte fija de la tarifa"; break;
case "parte per una persona della tariffa":  	$messaggio = "parte de una persona de la tarifa"; break;
case "Numero massimo":  			$messaggio = "Número máximo"; break;
case "0 se illimitato":  			$messaggio = "0 para ilimitado"; break;
case "meno":  					$messaggio = "menos"; break;
case "il costo viene moltiplicato per zero se la somma è negativa":	$messaggio = "el coste será multiplicado por zero si la suma es negativa"; break;
case "Combina con altri costi":			$messaggio = "Combinar con otros costes"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "los costes combinables son enseñados todos juntos con el nombre de la categoría y cada uno es insertado si es posible"; break;
case "opzionale":  				$messaggio = "opcionál"; break;
case "Costi combinati":  			$messaggio = "Costes combinados"; break;
case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Inserción rápida de un nuevo coste añadido para"; break;
case "permanenza minima":  			$messaggio = "estadía mínima"; break;
case "numero di bambini":  			$messaggio = "número de niños"; break;
case "letto aggiuntivo":  			$messaggio = "cama extra"; break;
case "offerta speciale":  			$messaggio = "oferta especial"; break;
case "inserisci":  				$messaggio = "insertar"; break;
case "Inserisci il costo aggiuntivo":  		$messaggio = "Insertar el coste añadido"; break;
case "Numero minimo di giorni":  		$messaggio = "Número mínimo de días"; break;
case "Applicato alle tariffe":  		$messaggio = "Aplicar a las tarifas"; break;
case "Periodi in cui viene applicato il costo":	$messaggio = "Períodos en los que se aplica el coste"; break;
case "Valore dello sconto per ogni bambino":  	$messaggio = "Valor del descuento para cada niño"; break;
case "del prezzo di una persona":  		$messaggio = "del precio de una persona"; break;
case "solo per tariffe con prezzi a persona":  	$messaggio = "solo para tarifas con precios por persona"; break;
case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "con este coste hay que incluir el número de niños también en el numero de personas"; break;
case "Valore del letto aggiuntivo":  		$messaggio = "Valor de la cama extra"; break;
case "Valore dello sconto":  			$messaggio = "Valor del descuento"; break;
case "del prezzo totale":  			$messaggio = "del precio total"; break;
case "Se la prenotazione ha una durata di":	$messaggio = "Si la reserva tiene una duración de"; break;
case "o più giorni":  				$messaggio = "o más días"; break;
case "Se":  					$messaggio = "Si"; break;
case "Se si inseriscono":  			$messaggio = "Si se insertan"; break;
case "Importa ora":  				$messaggio = "Importar ahora"; break;
case "Importa sempre":  			$messaggio = "Importar siempre"; break;
case "cancella":  				$messaggio = "borrar"; break;
case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "La importación de los precios ha sido borrada"; break;
case "al prezzo fisso":  			$messaggio = "al precio fijo"; break;
case "al prezzo per persona":  			$messaggio = "al precio por persona"; break;
case "ad entrambi i prezzi":  			$messaggio = "a ambos precios"; break;
case "La tariffa":  				$messaggio = "La tarifa"; break;
case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exporta los precios a otras tarifas, no puede importar precios de manera permanente"; break;
case "tutte le tariffe":  			$messaggio = "todas las tarifas"; break;
case "considerare l'intero costo come tasse":  	$messaggio = "considerar todo el coste como tasas"; break;
case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Excluir este coste del total para el porcentaje de los otros costes"; break;
case "in tutti i periodi in modo predefinito":	$messaggio = "en todos los períodos de manera predefinida"; break;
case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "importa los precios de otras tarifas, no puede exportar sus precios"; break;
case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "ya importa los precios de otras tarifas en estos períodos, no puede importar otros precios"; break;
case "modifica":  				$messaggio = "modificar"; break;
case "In modo predefinito importa":  		$messaggio = "De manera predefinida importar"; break;
case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "los precios de algunos períodos <em>no han sido insertados</em> porque importados desde otras tarifas"; break;
case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "límite no considerado para las personas adicionales en las interconexiones"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>