<?php

$lista_regioni = "";
$cod_regioni = "";
$cod2_regioni = "";
$cod3_regioni = "";
$cod_nazione_regioni = "";

#$lista_regioni[0] = "Scotland";
#$cod_regioni[0] = "00001";
#$cod_nazione_regioni[0] = "United Kingdom";
#$lista_regioni[1] = "Wales";
#$cod_regioni[1] = "00002";
#$cod_nazione_regioni[1] = "United Kingdom";


?>