<?php

switch ($messaggio) {

case "Torna al menù principale":  		$messaggio = "Back to main menu"; break;
case "Altri costi prenotazione":  		$messaggio = "Other reservation costs"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "in cassa":  				$messaggio = "in cashbox"; break;
case "su prenotazione":  			$messaggio = "on reservation"; break;
case "senza categoria":  			$messaggio = "without category"; break;
case "tariffa incompatibile":  			$messaggio = "incompatible rate"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "dal":  					$messaggio = "from"; break;
case "al":  					$messaggio = "to"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "manca numero di persone":  		$messaggio = "missing number of people"; break;
case "periodo non permesso":  			$messaggio = "not permitted period"; break;
case "numero massimo raggiunto":  		$messaggio = "maximum number reached"; break;
case "bene non presente in inventario":  	$messaggio = "good not available in inventory"; break;
case "OK":  					$messaggio = "OK"; break;
case "Calcola":  				$messaggio = "Calculate"; break;
case "Inserisci i costi ora":  			$messaggio = "Insert costs now"; break;
case "Annulla":  				$messaggio = "Cancel"; break;
case "Attualmente non ci sono prenotazioni che abbiano registrato l'entrata":	$messaggio = "Currently there are no checked-in reservations"; break;
case "Oggi non ci sono prenotazioni":  		$messaggio = "There are no reservations today"; break;
case "Metodo pagamento":  			$messaggio = "Payment method"; break;
case "in cassa principale":  			$messaggio = "in main cashbox"; break;
case "I costi sono stati inseriti":		$messaggio = "Costs have been inserted"; break;
case "nella cassa":  				$messaggio = "in cashbox called"; break;
case "nella cassa principale":  		$messaggio = "in main cashbox"; break;
case "moltiplicato per più di":  		$messaggio = "multiplied by more than"; break;
case "documento":  				$messaggio = "document"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>