<?php

switch ($messaggio) {

case "MENU":  				$messaggio = "MENU"; break;
case "PRENOTAZIONE":  			$messaggio = "RESERVA"; break;
case "TABELLE":  			$messaggio = "TABLAS"; break;
case "GENNAIO":  			$messaggio = "ENERO"; break;
case "FEBBRAIO":  			$messaggio = "FEBRERO"; break;
case "MARZO":  				$messaggio = "MARZO"; break;
case "APRILE":  			$messaggio = "ABRIL"; break;
case "MAGGIO":  			$messaggio = "MAYO"; break;
case "GIUGNO":  			$messaggio = "JUNIO"; break;
case "LUGLIO":  			$messaggio = "JULIO"; break;
case "AGOSTO":  			$messaggio = "AGOSTO"; break;
case "SETTEMBRE":  			$messaggio = "SEPTIEMBRE"; break;
case "OTTOBRE":  			$messaggio = "OCTUBRE"; break;
case "NOVEMBRE":  			$messaggio = "NOVIEMBRE"; break;
case "DICEMBRE":  			$messaggio = "DICIEMBRE"; break;
case "PRENOTAZIONI":  			$messaggio = "RESERVAS"; break;
case "SPESE":  				$messaggio = "GASTOS"; break;
case "CASSE":  				$messaggio = "CAJAS"; break;
case "TARIFFE":  			$messaggio = "TARIFAS"; break;
case "CLIENTI":  			$messaggio = "CLIENTES"; break;
case "INSERIRE":  			$messaggio = "INSERTAR"; break;
case "CLIENTE":  			$messaggio = "CLIENTE"; break;
case "PREZZI":  			$messaggio = "PRECIOS"; break;
case "REGOLE":  			$messaggio = "REGLAS"; break;
case "CONFIGURA":  			$messaggio = "CONFIGURAR"; break;
case "TUTTE":  				$messaggio = "TODAS"; break;
case "CORRENTI":  			$messaggio = "ACTUALES"; break;
case "FUTURE":  			$messaggio = "FUTURAS"; break;
case "ARRIVI":  			$messaggio = "LLEGADAS"; break;
case "PARTENZE":  			$messaggio = "SALIDAS"; break;
case "MESSAGGI":  			$messaggio = "MENSAJES"; break;
case "ENTRATE&nbsp;PREN.":  		$messaggio = "PAGOS&nbsp;RESER."; break;
case "UTENTI":  			$messaggio = "USUARIOS"; break;
case "SITO WEB":  			$messaggio = "SITIO WEB"; break;
case "INTERCONN.":  			$messaggio = "INTERCON."; break;
case "BACKUP":  			$messaggio = "BACKUP"; break;
case "STATISTICHE":  			$messaggio = "ESTAD&Iacute;STICAS"; break;
case "INVENTARIO":  			$messaggio = "INVENTARIO"; break;
case "CERCA":  				$messaggio = "BUSCAR"; break;
case "DOCUMENTI":  			$messaggio = "DOCUMENTOS"; break;
case "P.TO&nbsp;VENDITA":  		$messaggio = "P.TO&nbsp;DE&nbsp;VENTA"; break;
case "NUMERO":  			$messaggio = "NÚMERO"; break;
case "VAI":  				$messaggio = "IR"; break;
case "COSTI AGGIUNTIVI":  		$messaggio = "COSTES AÑADIDOS"; break;
case "CAPARRE E TASSE":  		$messaggio = "FIANZAS Y TASAS"; break;
case "PARTENZE E CORRENTI":  		$messaggio = "SALIDAS Y CORRIENTES"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

# Simple theme top menu drop-down menus widths
case "insert-ddw":  			$messaggio = "100px"; break;
case "tables-ddw":  			$messaggio = "100px"; break;
case "months-ddw":  			$messaggio = "86px"; break;
case "reservations-ddw":  		$messaggio = "150px"; break;
case "clients-ddw":  			$messaggio = "15em"; break;
case "rates-ddw":  			$messaggio = "150px"; break;
case "configure-ddw":  			$messaggio = "86px"; break;

} # fine switch ($messaggio)

?>