<?php

$lista_nazioni = "";
$cod_nazioni = "";
$cod2_nazioni = "";
$cod3_nazioni = "";

$lista_nazioni[0] = "Afghanistan";
$cod_nazioni[0] = "100000301";
$cod2_nazioni[0] = "AF";
$lista_nazioni[1] = "Albania";
$cod_nazioni[1] = "100000201";
$cod2_nazioni[1] = "AL.";
$lista_nazioni[2] = "Algeria";
$cod_nazioni[2] = "100000401";
$cod2_nazioni[2] = "DZ";
$lista_nazioni[3] = "Andorra";
$cod_nazioni[3] = "100000202";
$cod2_nazioni[3] = "AD";
$lista_nazioni[4] = "Angola";
$cod_nazioni[4] = "100000402";
$cod2_nazioni[4] = "AO.";
$lista_nazioni[5] = "Anguilla - Isola";
$cod_nazioni[5] = "100000733";
$cod2_nazioni[5] = "AI";
$lista_nazioni[6] = "Antigua E Barbuda";
$cod_nazioni[6] = "100000503";
$cod2_nazioni[6] = "AG.";
$lista_nazioni[7] = "Antille Britanniche";
$cod_nazioni[7] = "100000734";
$lista_nazioni[8] = "Antille Olandesi";
$cod_nazioni[8] = "100000735";
$cod2_nazioni[8] = "AN.";
$lista_nazioni[9] = "Apolide";
$cod_nazioni[9] = "100000999";
$lista_nazioni[10] = "Arabia Meridionale";
$cod_nazioni[10] = "100000736";
$lista_nazioni[11] = "Arabia Saudita";
$cod_nazioni[11] = "100000302";
$cod2_nazioni[11] = "SA.";
$lista_nazioni[12] = "Argentina";
$cod_nazioni[12] = "100000602";
$cod2_nazioni[12] = "AR.";
$lista_nazioni[13] = "Armenia";
$cod_nazioni[13] = "100000358";
$cod2_nazioni[13] = "AM";
$lista_nazioni[14] = "Australia";
$cod_nazioni[14] = "100000701";
$cod2_nazioni[14] = "AU";
$lista_nazioni[15] = "Austria";
$cod_nazioni[15] = "100000203";
$cod2_nazioni[15] = "AT.";
$lista_nazioni[16] = "Azerbaigian";
$cod_nazioni[16] = "100000359";
$cod2_nazioni[16] = "AZ";
$lista_nazioni[17] = "Bahama";
$cod_nazioni[17] = "100000505";
$cod2_nazioni[17] = "BS.";
$lista_nazioni[18] = "Bahrein";
$cod_nazioni[18] = "100000304";
$cod2_nazioni[18] = "BH";
$lista_nazioni[19] = "Bangladesh";
$cod_nazioni[19] = "100000305";
$cod2_nazioni[19] = "BD";
$lista_nazioni[20] = "Barbados";
$cod_nazioni[20] = "100000506";
$cod2_nazioni[20] = "BB";
$lista_nazioni[21] = "Basutoland Sud Af. Brit.";
$cod_nazioni[21] = "100000737";
$lista_nazioni[22] = "Beciuania Sud Af. Brit.";
$cod_nazioni[22] = "100000738";
$lista_nazioni[23] = "Belgio";
$cod_nazioni[23] = "100000206";
$cod2_nazioni[23] = "BE";
$lista_nazioni[24] = "Belize";
$cod_nazioni[24] = "100000507";
$cod2_nazioni[24] = "BZ.";
$lista_nazioni[25] = "Benin";
$cod_nazioni[25] = "100000406";
$cod2_nazioni[25] = "BJ";
$lista_nazioni[26] = "Bermude";
$cod_nazioni[26] = "100000739";
$cod2_nazioni[26] = "BM";
$lista_nazioni[27] = "Bhutan";
$cod_nazioni[27] = "100000306";
$cod2_nazioni[26] = "BT.";
$lista_nazioni[28] = "Bielorussia";
$cod_nazioni[28] = "100000256";
$cod2_nazioni[28] = "BY";
$lista_nazioni[29] = "Bolivia";
$cod_nazioni[29] = "100000604";
$cod2_nazioni[29] = "BO.";
$lista_nazioni[30] = "Bophuthatswana";
$cod_nazioni[30] = "100000740";
$lista_nazioni[31] = "Bosnia Ed Erzegovina";
$cod_nazioni[31] = "100000252";
$cod2_nazioni[31] = "BA.";
$lista_nazioni[32] = "Botswana";
$cod_nazioni[32] = "100000408";
$cod2_nazioni[32] = "BW";
$lista_nazioni[33] = "Brasile";
$cod_nazioni[33] = "100000605";
$cod2_nazioni[33] = "BR.";
$lista_nazioni[34] = "Brunei";
$cod_nazioni[34] = "100000309";
$cod2_nazioni[34] = "BN.";
$lista_nazioni[35] = "Bulgaria";
$cod_nazioni[35] = "100000209";
$cod2_nazioni[35] = "BG.";
$lista_nazioni[36] = "Burkina Faso";
$cod_nazioni[36] = "100000409";
$cod2_nazioni[36] = "BF";
$lista_nazioni[37] = "Burundi";
$cod_nazioni[37] = "100000410";
$cod2_nazioni[37] = "BI.";
$lista_nazioni[38] = "Cambogia";
$cod_nazioni[38] = "100000310";
$cod2_nazioni[38] = "KH";
$lista_nazioni[39] = "Camerun";
$cod_nazioni[39] = "100000411";
$cod2_nazioni[39] = "CM";
$lista_nazioni[40] = "Canada";
$cod_nazioni[40] = "100000509";
$cod2_nazioni[40] = "CA.";
$lista_nazioni[41] = "Canarie Isole";
$cod_nazioni[41] = "110000002";
$lista_nazioni[42] = "Capo Verde";
$cod_nazioni[42] = "100000413";
$cod2_nazioni[42] = "CV";
$lista_nazioni[43] = "Caroline";
$cod_nazioni[43] = "100000741";
$lista_nazioni[44] = "Cayman - isole";
$cod_nazioni[44] = "100000742";
$cod2_nazioni[44] = "KY";
$lista_nazioni[45] = "Cecoslovacchia";
$cod_nazioni[45] = "100000210";
$lista_nazioni[46] = "Centrafrica";
$cod_nazioni[46] = "100000414";
$cod2_nazioni[46] = "CF";
$lista_nazioni[47] = "Christmas";
$cod_nazioni[47] = "100000743";
$cod2_nazioni[47] = "CX";
$lista_nazioni[48] = "Ciad";
$cod_nazioni[48] = "100000415";
$cod2_nazioni[48] = "TD";
$lista_nazioni[49] = "Cile";
$cod_nazioni[49] = "100000606";
$cod2_nazioni[49] = "CL.";
$lista_nazioni[50] = "Cina Popolare";
$cod_nazioni[50] = "100000314";
$cod2_nazioni[50] = "CN.";
$lista_nazioni[51] = "Cina Rep. Nazionale";
$cod_nazioni[51] = "100000744";
$cod2_nazioni[51] = "TW";
$lista_nazioni[52] = "Cipro";
$cod_nazioni[52] = "100000315";
$cod2_nazioni[52] = "CY";
$lista_nazioni[53] = "Ciskei";
$cod_nazioni[53] = "100000745";
$lista_nazioni[54] = "Citta' Del Vaticano";
$cod_nazioni[54] = "100000246";
$cod2_nazioni[54] = "VA.";
$lista_nazioni[55] = "Cocos";
$cod_nazioni[55] = "100000746";
$cod2_nazioni[55] = "CC";
$lista_nazioni[56] = "Colombia";
$cod_nazioni[56] = "100000608";
$cod2_nazioni[56] = "CO.";
$lista_nazioni[57] = "Comore";
$cod_nazioni[57] = "100000417";
$cod2_nazioni[57] = "KM";
$lista_nazioni[58] = "Congo";
$cod_nazioni[58] = "100000418";
$cod2_nazioni[58] = "CG";
$lista_nazioni[59] = "Corea Del Nord";
$cod_nazioni[59] = "100000319";
$cod2_nazioni[59] = "KP";
$lista_nazioni[60] = "Corea Del Sud";
$cod_nazioni[60] = "100000320";
$cod2_nazioni[60] = "KR.";
$lista_nazioni[61] = "Costa D'avorio";
$cod_nazioni[61] = "100000404";
$cod2_nazioni[61] = "CI.";
$lista_nazioni[62] = "Costarica";
$cod_nazioni[62] = "100000513";
$cod2_nazioni[62] = "CR.";
$lista_nazioni[63] = "Croazia";
$cod_nazioni[63] = "100000250";
$cod2_nazioni[63] = "HR";
$lista_nazioni[64] = "Cuba";
$cod_nazioni[64] = "100000514";
$cod2_nazioni[64] = "CU";
$lista_nazioni[65] = "Danimarca";
$cod_nazioni[65] = "100000212";
$cod2_nazioni[65] = "DK";
$lista_nazioni[66] = "Dipendenze Australiane";
$cod_nazioni[66] = "100000747";
$lista_nazioni[67] = "Dipendenze Britanniche";
$cod_nazioni[67] = "100000748";
$lista_nazioni[68] = "Dipendenze Canadesi";
$cod_nazioni[68] = "100000749";
$lista_nazioni[69] = "Dipendenze Francesi";
$cod_nazioni[69] = "100000750";
$lista_nazioni[70] = "Dipendenze Neozelandesi";
$cod_nazioni[70] = "100000751";
$lista_nazioni[71] = "Dipendenze Sovietiche";
$cod_nazioni[71] = "100000752";
$lista_nazioni[72] = "Dipendenze Sudafricane";
$cod_nazioni[72] = "100000753";
$lista_nazioni[73] = "Dominica";
$cod_nazioni[73] = "100000515";
$cod2_nazioni[73] = "DM";
$lista_nazioni[74] = "Ecuador";
$cod_nazioni[74] = "100000609";
$cod2_nazioni[74] = "EC";
$lista_nazioni[75] = "Egitto";
$cod_nazioni[75] = "100000419";
$cod2_nazioni[75] = "EG";
$lista_nazioni[76] = "El Salvador";
$cod_nazioni[76] = "100000517";
$cod2_nazioni[76] = "SV.";
$lista_nazioni[77] = "Ellice";
$cod_nazioni[77] = "100000754";
$lista_nazioni[78] = "Emirati Arabi Uniti";
$cod_nazioni[78] = "100000322";
$cod2_nazioni[78] = "AE";
$lista_nazioni[79] = "Eritrea";
$cod_nazioni[79] = "100000466";
$cod2_nazioni[79] = "ER";
$lista_nazioni[80] = "Estonia";
$cod_nazioni[80] = "100000247";
$cod2_nazioni[80] = "EE";
$lista_nazioni[81] = "Etiopia";
$cod_nazioni[81] = "100000420";
$cod2_nazioni[81] = "ET";
$lista_nazioni[82] = "Faer Oer";
$cod_nazioni[82] = "100000755";
$cod2_nazioni[82] = "FO";
$lista_nazioni[83] = "Figi";
$cod_nazioni[83] = "100000703";
$cod2_nazioni[83] = "FJ";
$lista_nazioni[84] = "Filippine";
$cod_nazioni[84] = "100000323";
$cod2_nazioni[84] = "PH";
$lista_nazioni[85] = "Finlandia";
$cod_nazioni[85] = "100000214";
$cod2_nazioni[85] = "FI.";
$lista_nazioni[86] = "Francia";
$cod_nazioni[86] = "100000215";
$cod2_nazioni[86] = "FR.";
$lista_nazioni[87] = "Gabon";
$cod_nazioni[87] = "100000421";
$cod2_nazioni[87] = "GA";
$lista_nazioni[88] = "Gambia";
$cod_nazioni[88] = "100000422";
$cod2_nazioni[88] = "GM";
$lista_nazioni[89] = "Georgia";
$cod_nazioni[89] = "100000360";
$cod2_nazioni[89] = "GE.";
$lista_nazioni[90] = "Germania";
$cod_nazioni[90] = "100000216";
$cod2_nazioni[90] = "DE";
$lista_nazioni[91] = "Germania Rep. Dem.";
$cod_nazioni[91] = "100000757";
$lista_nazioni[92] = "Ghana";
$cod_nazioni[92] = "100000423";
$cod2_nazioni[92] = "GH";
$lista_nazioni[93] = "Giamaica";
$cod_nazioni[93] = "100000518";
$cod2_nazioni[93] = "JM";
$lista_nazioni[94] = "Giappone";
$cod_nazioni[94] = "100000326";
$cod2_nazioni[94] = "JP";
$lista_nazioni[95] = "Gibilterra";
$cod_nazioni[95] = "110000004";
$cod2_nazioni[95] = "GI";
$lista_nazioni[96] = "Gibuti";
$cod_nazioni[96] = "100000424";
$cod2_nazioni[96] = "DJ";
$lista_nazioni[97] = "Giordania";
$cod_nazioni[97] = "100000327";
$cod2_nazioni[97] = "JO";
$lista_nazioni[98] = "Grecia";
$cod_nazioni[98] = "100000220";
$cod2_nazioni[98] = "GR.";
$lista_nazioni[99] = "Grenada";
$cod_nazioni[99] = "100000519";
$cod2_nazioni[99] = "GD";
$lista_nazioni[100] = "Groenlandia";
$cod_nazioni[100] = "100000758";
$cod2_nazioni[100] = "GL";
$lista_nazioni[101] = "Guadalupa";
$cod_nazioni[101] = "100000759";
$lista_nazioni[102] = "Guam";
$cod_nazioni[102] = "100000760";
$cod2_nazioni[102] = "GU";
$lista_nazioni[103] = "Guatemala";
$cod_nazioni[103] = "100000523";
$cod2_nazioni[103] = "GT";
$lista_nazioni[104] = "Guayana Francese";
$cod_nazioni[104] = "100000761";
$lista_nazioni[105] = "Guinea";
$cod_nazioni[105] = "100000425";
$cod2_nazioni[105] = "GN";
$lista_nazioni[106] = "Guinea Bissau";
$cod_nazioni[106] = "100000426";
$cod2_nazioni[106] = "GW";
$lista_nazioni[107] = "Guinea Equatoriale";
$cod_nazioni[107] = "100000427";
$cod2_nazioni[107] = "GQ";
$lista_nazioni[108] = "Guyana";
$cod_nazioni[108] = "100000612";
$cod2_nazioni[108] = "GY";
$lista_nazioni[109] = "Haiti";
$cod_nazioni[109] = "100000524";
$cod2_nazioni[109] = "HT";
$lista_nazioni[110] = "Honduras";
$cod_nazioni[110] = "100000525";
$cod2_nazioni[110] = "HN";
$lista_nazioni[111] = "Hong Kong";
$cod_nazioni[111] = "110000005";
$cod2_nazioni[111] = "HK";
$lista_nazioni[112] = "Ifni";
$cod_nazioni[112] = "100000762";
$lista_nazioni[113] = "India";
$cod_nazioni[113] = "100000330";
$cod2_nazioni[113] = "IN";
$lista_nazioni[114] = "Indonesia";
$cod_nazioni[114] = "100000331";
$cod2_nazioni[114] = "ID";
$lista_nazioni[115] = "Iran";
$cod_nazioni[115] = "100000332";
$cod2_nazioni[115] = "IR";
$lista_nazioni[116] = "Iran-etnia Curda";
$cod_nazioni[116] = "110000006";
$lista_nazioni[117] = "Iraq";
$cod_nazioni[117] = "100000333";
$cod2_nazioni[117] = "IQ";
$lista_nazioni[118] = "Iraq - Etnia Curda";
$cod_nazioni[118] = "110000007";
$lista_nazioni[119] = "Sudan Del Sud";
$cod_nazioni[119] = "100000455";
$cod2_nazioni[119] = "SS";
$lista_nazioni[120] = "Irlanda";
$cod_nazioni[120] = "100000221";
$cod2_nazioni[120] = "IE";
$lista_nazioni[121] = "Islanda";
$cod_nazioni[121] = "100000223";
$cod2_nazioni[121] = "IS.";
$lista_nazioni[122] = "Isole Vergini";
$cod_nazioni[122] = "100000764";
$cod2_nazioni[122] = "VI.";
$lista_nazioni[123] = "Israele";
$cod_nazioni[123] = "100000334";
$cod2_nazioni[123] = "IL";
$lista_nazioni[124] = "Italia";
$cod_nazioni[124] = "100000100";
$cod2_nazioni[124] = "IT";
$lista_nazioni[125] = "Jugoslavia - Serbia-Mont.";
$cod_nazioni[125] = "100000224";
$cod2_nazioni[125] = "YU";
$lista_nazioni[126] = "Kosovo";
$cod_nazioni[126] = "100001002";
$cod2_nazioni[126] = "XK";
$lista_nazioni[127] = "Kazakistan";
$cod_nazioni[127] = "100000356";
$cod2_nazioni[127] = "KZ";
$lista_nazioni[128] = "Kenia";
$cod_nazioni[128] = "100000428";
$cod2_nazioni[128] = "KE";
$lista_nazioni[129] = "Kirghizistan";
$cod_nazioni[129] = "100000361";
$cod2_nazioni[129] = "KG";
$lista_nazioni[130] = "Kiribati";
$cod_nazioni[130] = "100000708";
$cod2_nazioni[130] = "KI";
$lista_nazioni[131] = "Kuwait";
$cod_nazioni[131] = "100000335";
$cod2_nazioni[131] = "KW";
$lista_nazioni[132] = "La Reunion";
$cod_nazioni[132] = "100000765";
$lista_nazioni[133] = "Laos";
$cod_nazioni[133] = "100000336";
$cod2_nazioni[133] = "LA";
$lista_nazioni[134] = "Lesotho";
$cod_nazioni[134] = "100000429";
$cod2_nazioni[134] = "LS";
$lista_nazioni[135] = "Lettonia";
$cod_nazioni[135] = "100000248";
$cod2_nazioni[135] = "LV";
$lista_nazioni[136] = "Libano";
$cod_nazioni[136] = "100000337";
$cod2_nazioni[136] = "LB";
$lista_nazioni[137] = "Liberia";
$cod_nazioni[137] = "100000430";
$cod2_nazioni[137] = "LR";
$lista_nazioni[138] = "Libia";
$cod_nazioni[138] = "100000431";
$cod2_nazioni[138] = "LY";
$lista_nazioni[139] = "Liechtenstein";
$cod_nazioni[139] = "100000225";
$cod2_nazioni[139] = "LI.";
$lista_nazioni[140] = "Lituania";
$cod_nazioni[140] = "100000249";
$cod2_nazioni[140] = "LT.";
$lista_nazioni[141] = "Lussemburgo";
$cod_nazioni[141] = "100000226";
$cod2_nazioni[141] = "LU.";
$lista_nazioni[142] = "Macao";
$cod_nazioni[142] = "110000003";
$cod2_nazioni[142] = "MO.";
$lista_nazioni[143] = "Macquarie";
$cod_nazioni[143] = "100000766";
$lista_nazioni[144] = "Madagascar";
$cod_nazioni[144] = "100000432";
$cod2_nazioni[144] = "MG";
$lista_nazioni[145] = "Macedonia";
$cod_nazioni[145] = "100000253";
$cod2_nazioni[145] = "MK";
$lista_nazioni[146] = "Mali";
$cod_nazioni[146] = "100000435";
$cod2_nazioni[146] = "ML";
$lista_nazioni[147] = "Malvine - Falkland";
$cod_nazioni[147] = "100000768";
$cod2_nazioni[147] = "FK";
$lista_nazioni[148] = "Man";
$cod_nazioni[148] = "100000769";
$lista_nazioni[149] = "Malaysia";
$cod_nazioni[149] = "100000767";
$cod2_nazioni[149] = "MY";
$lista_nazioni[150] = "Maldive";
$cod_nazioni[150] = "100000339";
$cod2_nazioni[150] = "MV";
$lista_nazioni[151] = "Marcus";
$cod_nazioni[151] = "100000770";
$lista_nazioni[152] = "Malawi";
$cod_nazioni[152] = "100000434";
$cod2_nazioni[152] = "MW";
$lista_nazioni[153] = "Marianne";
$cod_nazioni[153] = "100000771";
$cod2_nazioni[153] = "MP";
$lista_nazioni[154] = "Marocco";
$cod_nazioni[154] = "100000436";
$cod2_nazioni[154] = "MA";
$lista_nazioni[155] = "Marshall";
$cod_nazioni[155] = "100000772";
$cod2_nazioni[155] = "MH";
$lista_nazioni[156] = "Malta";
$cod_nazioni[156] = "100000227";
$cod2_nazioni[156] = "MT.";
$lista_nazioni[157] = "Maurizio";
$cod_nazioni[157] = "100000438";
$cod2_nazioni[157] = "MU";
$lista_nazioni[158] = "Malesia";
$cod_nazioni[158] = "100000340";
$cod2_nazioni[158] = "MY";
$lista_nazioni[159] = "Martinica";
$cod_nazioni[159] = "100000773";
$lista_nazioni[160] = "Mauritania";
$cod_nazioni[160] = "100000437";
$cod2_nazioni[160] = "MR";
$lista_nazioni[161] = "Mayotte";
$cod_nazioni[161] = "100000774";
$cod2_nazioni[161] = "YT";
$lista_nazioni[162] = "Messico";
$cod_nazioni[162] = "100000527";
$cod2_nazioni[162] = "MX";
$lista_nazioni[163] = "Micronesia Stati Federali";
$cod_nazioni[163] = "100000775";
$cod2_nazioni[163] = "FM.";
$lista_nazioni[164] = "Midway";
$cod_nazioni[164] = "100000776";
$lista_nazioni[165] = "Mongolia";
$cod_nazioni[165] = "100000341";
$cod2_nazioni[165] = "MN.";
$lista_nazioni[166] = "Monaco";
$cod_nazioni[166] = "100000229";
$cod2_nazioni[166] = "MC";
$lista_nazioni[167] = "Moldavia";
$cod_nazioni[167] = "100000254";
$cod2_nazioni[167] = "MD";
$lista_nazioni[168] = "Montserrat";
$cod_nazioni[168] = "100000777";
$cod2_nazioni[168] = "MS.";
$lista_nazioni[169] = "Mozambico";
$cod_nazioni[169] = "100000440";
$cod2_nazioni[169] = "MZ";
$lista_nazioni[170] = "Namibia";
$cod_nazioni[170] = "100000441";
$cod2_nazioni[170] = "NA.";
$lista_nazioni[171] = "Niger";
$cod_nazioni[171] = "100000442";
$cod2_nazioni[171] = "NE";
$lista_nazioni[172] = "Nicaragua";
$cod_nazioni[172] = "100000529";
$cod2_nazioni[172] = "NI";
$lista_nazioni[173] = "Nuove Ebridi";
$cod_nazioni[173] = "100000782";
$lista_nazioni[174] = "Nuova Zelanda";
$cod_nazioni[174] = "100000719";
$cod2_nazioni[174] = "NZ";
$lista_nazioni[175] = "Paesi Bassi";
$cod_nazioni[175] = "100000232";
$cod2_nazioni[175] = "NL";
$lista_nazioni[176] = "Panama Zona Canale";
$cod_nazioni[176] = "100000784";
$lista_nazioni[177] = "Peru'";
$cod_nazioni[177] = "100000615";
$cod2_nazioni[177] = "PE.";
$lista_nazioni[178] = "Nepal";
$cod_nazioni[178] = "100000342";
$cod2_nazioni[178] = "NP";
$lista_nazioni[179] = "Nigeria";
$cod_nazioni[179] = "100000443";
$cod2_nazioni[179] = "NG";
$lista_nazioni[180] = "Normanne";
$cod_nazioni[180] = "100000779";
$lista_nazioni[181] = "Myanmar - Birmania";
$cod_nazioni[181] = "100000307";
$cod2_nazioni[181] = "MM";
$lista_nazioni[182] = "Norvegia";
$cod_nazioni[182] = "100000231";
$cod2_nazioni[182] = "NO.";
$lista_nazioni[183] = "Nuova Caledonia";
$cod_nazioni[183] = "100000780";
$cod2_nazioni[183] = "NC";
$lista_nazioni[184] = "Norfolk";
$cod_nazioni[184] = "100000778";
$cod2_nazioni[184] = "NF";
$lista_nazioni[185] = "Oman";
$cod_nazioni[185] = "100000343";
$cod2_nazioni[185] = "OM";
$lista_nazioni[186] = "Nauru";
$cod_nazioni[186] = "100000715";
$cod2_nazioni[186] = "NR";
$lista_nazioni[187] = "Nuova Guinea";
$cod2_nazioni[187] = "PG.";
$cod_nazioni[187] = "100000781";
$lista_nazioni[188] = "Panama";
$cod_nazioni[188] = "100000530";
$cod2_nazioni[188] = "PA.";
$lista_nazioni[189] = "Naz. Brit. - Hong Kong";
$cod_nazioni[189] = "110000011";
$lista_nazioni[190] = "Papuasia - N. Guinea";
$cod_nazioni[190] = "100000721";
$cod2_nazioni[190] = "PG.";
$lista_nazioni[191] = "Palestina";
$cod_nazioni[191] = "110000001";
$cod2_nazioni[191] = "PS";
$lista_nazioni[192] = "Paraguay";
$cod_nazioni[192] = "100000614";
$cod2_nazioni[192] = "PY";
$lista_nazioni[193] = "Pakistan";
$cod_nazioni[193] = "100000344";
$cod2_nazioni[193] = "PK";
$lista_nazioni[194] = "Palau Repubblica";
$cod_nazioni[194] = "100000783";
$cod2_nazioni[194] = "PW";
$lista_nazioni[195] = "Pitcairn";
$cod_nazioni[195] = "100000786";
$cod2_nazioni[195] = "PN.";
$lista_nazioni[196] = "Polonia";
$cod_nazioni[196] = "100000233";
$cod2_nazioni[196] = "PL";
$lista_nazioni[197] = "Pasqua";
$cod_nazioni[197] = "100000785";
$lista_nazioni[198] = "Polinesia";
$cod_nazioni[198] = "100000787";
$cod2_nazioni[198] = "PF";
$lista_nazioni[199] = "Portogallo";
$cod_nazioni[199] = "100000234";
$cod2_nazioni[199] = "PT.";
$lista_nazioni[200] = "Principe";
$cod_nazioni[200] = "100000788";
$lista_nazioni[201] = "Rep. Dominicana";
$cod_nazioni[201] = "100000516";
$cod2_nazioni[201] = "DO";
$lista_nazioni[202] = "Russia";
$cod_nazioni[202] = "100000245";
$cod2_nazioni[202] = "RU";
$lista_nazioni[203] = "S. Vincent E Grenadine";
$cod_nazioni[203] = "100000533";
$cod2_nazioni[203] = "VC.";
$lista_nazioni[204] = "Rep. Dem. Del Congo";
$cod_nazioni[204] = "100000998";
$cod2_nazioni[204] = "CD";
$lista_nazioni[205] = "Protett. Arabia Merid.";
$cod_nazioni[205] = "100000789";
$lista_nazioni[206] = "Repubblica Ceca";
$cod_nazioni[206] = "100000257";
$cod2_nazioni[206] = "CZ.";
$lista_nazioni[207] = "Regno Unito";
$cod_nazioni[207] = "100000219";
$cod2_nazioni[207] = "GB";
$lista_nazioni[208] = "Salomone";
$cod_nazioni[208] = "100000725";
$cod2_nazioni[208] = "SB";
$lista_nazioni[209] = "Ruanda";
$cod_nazioni[209] = "100000446";
$cod2_nazioni[209] = "RW";
$lista_nazioni[210] = "Samoa Americane";
$cod_nazioni[210] = "100000798";
$cod2_nazioni[210] = "AS";
$lista_nazioni[211] = "Puerto Rico";
$cod_nazioni[211] = "100000790";
$lista_nazioni[212] = "Qatar";
$cod_nazioni[212] = "100000345";
$cod2_nazioni[212] = "QA";
$lista_nazioni[213] = "Ryukyu";
$cod_nazioni[213] = "100000794";
$lista_nazioni[214] = "Saint Kitts E Nevis";
$cod_nazioni[214] = "100000534";
$cod2_nazioni[214] = "KN";
$lista_nazioni[215] = "Saint Vincent E Grenadine";
$cod_nazioni[215] = "100000797";
$cod2_nazioni[215] = "VC.";
$lista_nazioni[216] = "Slovacchia";
$cod_nazioni[216] = "100000255";
$cod2_nazioni[216] = "SK";
$lista_nazioni[217] = "Romania";
$cod_nazioni[217] = "100000235";
$cod2_nazioni[217] = "RO.";
$lista_nazioni[218] = "Sahara Spagnolo";
$cod_nazioni[218] = "100000795";
$lista_nazioni[219] = "Samoa";
$cod_nazioni[219] = "100000727";
$cod2_nazioni[219] = "WS";
$lista_nazioni[220] = "Saint Lucia";
$cod_nazioni[220] = "100000532";
$cod2_nazioni[220] = "LC.";
$lista_nazioni[221] = "San Marino";
$cod_nazioni[221] = "100000236";
$cod2_nazioni[221] = "SM";
$lista_nazioni[222] = "Saint Pierre Et Miquelon";
$cod_nazioni[222] = "100000796";
$cod2_nazioni[222] = "PM";
$lista_nazioni[223] = "Seychelles";
$cod_nazioni[223] = "100000449";
$cod2_nazioni[223] = "SC";
$lista_nazioni[224] = "Senegal";
$cod_nazioni[224] = "100000450";
$cod2_nazioni[224] = "SN";
$lista_nazioni[225] = "Savage";
$cod_nazioni[225] = "100000800";
$lista_nazioni[226] = "Sao Tome' E Principe";
$cod_nazioni[226] = "100000448";
$cod2_nazioni[226] = "ST";
$lista_nazioni[227] = "Sant Elena";
$cod_nazioni[227] = "100000799";
$lista_nazioni[228] = "Sikkim";
$cod_nazioni[228] = "100000801";
$lista_nazioni[229] = "Singapore";
$cod_nazioni[229] = "100000346";
$cod2_nazioni[229] = "SG";
$lista_nazioni[230] = "Suriname";
$cod_nazioni[230] = "100000616";
$cod2_nazioni[230] = "SR.";
$lista_nazioni[231] = "Tanganica";
$cod_nazioni[231] = "100000803";
$lista_nazioni[232] = "Sierra Leone";
$cod_nazioni[232] = "100000451";
$cod2_nazioni[232] = "SL";
$lista_nazioni[233] = "Tagikistan";
$cod_nazioni[233] = "100000362";
$cod2_nazioni[233] = "TJ";
$lista_nazioni[234] = "Sud Africa";
$cod_nazioni[234] = "100000454";
$cod2_nazioni[234] = "ZA";
$lista_nazioni[235] = "Svizzera";
$cod_nazioni[235] = "100000241";
$cod2_nazioni[235] = "CH.";
$lista_nazioni[236] = "Siria";
$cod_nazioni[236] = "100000348";
$cod2_nazioni[236] = "SY";
$lista_nazioni[237] = "Siria - Etnia Curda";
$cod_nazioni[237] = "110000008";
$lista_nazioni[238] = "Montenegro";
$cod_nazioni[238] = "100001001";
$cod2_nazioni[238] = "ME";
$lista_nazioni[239] = "Svezia";
$cod_nazioni[239] = "100000240";
$cod2_nazioni[239] = "SE";
$lista_nazioni[240] = "Slovenia";
$cod_nazioni[240] = "100000251";
$cod2_nazioni[240] = "SI.";
$lista_nazioni[241] = "Sri Lanka - Ceylon";
$cod_nazioni[241] = "100000311";
$cod2_nazioni[241] = "LK";
$lista_nazioni[242] = "Territorio Di Gaza";
$cod_nazioni[242] = "100000804";
$lista_nazioni[243] = "Togo";
$cod_nazioni[243] = "100000458";
$cod2_nazioni[243] = "TG";
$lista_nazioni[244] = "Urss";
$cod_nazioni[244] = "100000793";
$lista_nazioni[245] = "Turchia";
$cod_nazioni[245] = "100000351";
$cod2_nazioni[245] = "TR.";
$lista_nazioni[246] = "Turks";
$cod_nazioni[246] = "100000810";
$cod2_nazioni[246] = "TC";
$lista_nazioni[247] = "Sudan";
$cod_nazioni[247] = "100000455";
$cod2_nazioni[247] = "SD";
$lista_nazioni[248] = "Turchia - Etnia Curda";
$cod_nazioni[248] = "110000009";
$lista_nazioni[249] = "Spagna";
$cod_nazioni[249] = "100000239";
$cod2_nazioni[249] = "ES";
$lista_nazioni[250] = "Taiwan";
$cod_nazioni[250] = "100000363";
$cod2_nazioni[250] = "TW";
$lista_nazioni[251] = "Tokelau";
$cod_nazioni[251] = "100000806";
$cod2_nazioni[251] = "TK";
$lista_nazioni[252] = "Somalia";
$cod_nazioni[252] = "100000453";
$cod2_nazioni[252] = "SO.";
$lista_nazioni[253] = "Swaziland";
$cod_nazioni[253] = "100000456";
$cod2_nazioni[253] = "SZ";
$lista_nazioni[254] = "Uzbekistan";
$cod_nazioni[254] = "100000357";
$cod2_nazioni[254] = "UZ";
$lista_nazioni[255] = "Vergini Britann. - Isole";
$cod_nazioni[255] = "100000812";
$cod2_nazioni[255] = "VG";
$lista_nazioni[256] = "Tanzania";
$cod_nazioni[256] = "100000457";
$cod2_nazioni[256] = "TZ";
$lista_nazioni[257] = "Thailandia";
$cod_nazioni[257] = "100000349";
$cod2_nazioni[257] = "TH";
$lista_nazioni[258] = "Tonga";
$cod_nazioni[258] = "100000730";
$cod2_nazioni[258] = "TO.";
$lista_nazioni[259] = "Turkmenistan";
$cod_nazioni[259] = "100000364";
$cod2_nazioni[259] = "TM";
$lista_nazioni[260] = "Tuvalu";
$cod_nazioni[260] = "100000731";
$cod2_nazioni[260] = "TV.";
$lista_nazioni[261] = "Stati Uniti D'America";
$cod_nazioni[261] = "100000536";
$cod2_nazioni[261] = "US";
$lista_nazioni[262] = "Timor Est";
$cod_nazioni[262] = "100000805";
$cod2_nazioni[262] = "TL";
$lista_nazioni[263] = "Transkei";
$cod_nazioni[263] = "100000808";
$lista_nazioni[264] = "Tunisia";
$cod_nazioni[264] = "100000460";
$cod2_nazioni[264] = "TN.";
$lista_nazioni[265] = "Ungheria";
$cod_nazioni[265] = "100000244";
$cod2_nazioni[265] = "HU";
$lista_nazioni[266] = "Vietnam";
$cod_nazioni[266] = "100000353";
$cod2_nazioni[266] = "VN";
$lista_nazioni[267] = "Trinidad E Tobago";
$cod_nazioni[267] = "100000617";
$cod2_nazioni[267] = "TT";
$lista_nazioni[268] = "Uruguay";
$cod_nazioni[268] = "100000618";
$cod2_nazioni[268] = "UY";
$lista_nazioni[269] = "Venda";
$cod_nazioni[269] = "100000811";
$lista_nazioni[270] = "Uganda";
$cod_nazioni[270] = "100000461";
$cod2_nazioni[270] = "UG";
$lista_nazioni[271] = "Zambia";
$cod_nazioni[271] = "100000464";
$cod2_nazioni[271] = "ZM";
$lista_nazioni[272] = "Ucraina";
$cod_nazioni[272] = "100000243";
$cod2_nazioni[272] = "UA";
$lista_nazioni[273] = "Zimbabwe";
$cod_nazioni[273] = "100000465";
$cod2_nazioni[273] = "ZW";
$lista_nazioni[274] = "Zaire";
$cod_nazioni[274] = "100000463";
$cod2_nazioni[274] = "CD";
$lista_nazioni[275] = "Vanuatu";
$cod_nazioni[275] = "100000732";
$cod2_nazioni[275] = "VU";
$lista_nazioni[276] = "Venezuela";
$cod_nazioni[276] = "100000619";
$cod2_nazioni[276] = "VE.";
$lista_nazioni[277] = "Wallis";
$cod_nazioni[277] = "100000815";
$cod2_nazioni[277] = "WF";
$lista_nazioni[278] = "Yemen";
$cod_nazioni[278] = "100000354";
$cod2_nazioni[278] = "YE";

?>