<?php

switch ($messaggio) {

case "situazione alle":  			$messaggio = "situation at"; break;
case "del":  					$messaggio = "of"; break;
case "Tabella prenotazioni del":  		$messaggio = "Reservations table of"; break;
case "ERRORE":  				$messaggio = "ERROR"; break;
case "Torna al menù principale":  		$messaggio = "Back to main menu"; break;
case "Visualizza la tabella per la stampa":  	$messaggio = "View the table for printing"; break;
case "Visualizza la tabella con i giorni":  	$messaggio = "View the table with days"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "Prenotazione non confermata":  		$messaggio = "Reservation not confirmed"; break;
case "Prenotazione confermata, caparra non pagata":	$messaggio = "Reservation confirmed, deposit not paid"; break;
case "Caparra pagata":  			$messaggio = "Deposit paid"; break;
case "Tutto pagato":  				$messaggio = "All paid"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>