<?php

switch ($messaggio) {

case "Modifica il costo aggiuntivo":  		$messaggio = "Modificar el coste añadido"; break;
case "Torna indietro":  			$messaggio = "Volver atrás"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Nome":  					$messaggio = "Nombre"; break;
case "Cambia in":  				$messaggio = "Cambia a"; break;
case "Tipo":  					$messaggio = "Tipo"; break;
case "Prezzo":  				$messaggio = "Precio"; break;
case "la tariffa":  				$messaggio = "la tarifa"; break;
case "unico":  					$messaggio = "único"; break;
case "settimanale":  				$messaggio = "semanal"; break;
case "giornaliero":  				$messaggio = "diario"; break;
case "fisso":  					$messaggio = "fijo"; break;
case "percentuale":  				$messaggio = "percentual"; break;
case "Numero di settimane":  			$messaggio = "Número de semanas"; break;
case "Numero di giorni":  			$messaggio = "Número de días"; break;
case "solo per costi settimanali":  		$messaggio = "solo para costes semanales"; break;
case "solo per costi giornalieri":  		$messaggio = "solo para costes diarios"; break;
case "tutte":  					$messaggio = "todas"; break;
case "tutti":  					$messaggio = "todos"; break;
case "tutte meno una":  			$messaggio = "todas menos una"; break;
case "tutti meno uno":  			$messaggio = "todos menos uno"; break;
case "chiedere":  				$messaggio = "preguntar"; break;
case "Assegna automaticamente con le tariffe":	$messaggio = "Asigna automaticamente<br> con las tarifas"; break;
case "Mostrare nella pagina di inserzione prenotazioni?":	$messaggio = "Enseñar en la página de inserción de reservas?"; break;
case "SI":  					$messaggio = "SI"; break;
case "NO":  					$messaggio = "NO"; break;
case "Chiedere per quanto deve essere moltiplicato?":	$messaggio = "Preguntar por cuanto tiene que estar multiplicado?"; break;
case "Considerare il costo aggiuntivo come letto(i) aggiuntivo(i)?":	$messaggio = "Considera el coste añadido como cama(s) extra(s)?"; break;
case "Modifica il costo":  			$messaggio = "Modificar el coste"; break;
case "Il costo è stato cancellato":  		$messaggio = "El coste ha sido borrado"; break;
case "Non si può proseguire perchè il costo aggiuntivo è già stato modificato nel frattempo":	$messaggio = "No se puede continuar porqué el coste añadido ha sido ya modificado mientras tanto"; break;
case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "No han sido insertados todos los datos necesarios"; break;
case "I soldi o la percentuale del costo sono sbagliati":	$messaggio = "El precio o la percentual astán equivocados"; break;
case "Un costo aggiuntivo dello stesso tipo e con lo stesso nome esiste già":	$messaggio = "Un coste añadido del mismo tipo y con el mismo nombre existe ya"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo non deve essere applicato automaticamente a nessuna tariffa":	$messaggio = "Para preguntar el número de semanas o por cuanto tiene que estar multiplicado el coste añadido no tiene que estar aplicado automaticamente a ninguna tarifa"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo non deve essere applicato automaticamente a nessuna tariffa":	$messaggio = "Para preguntar el número de días o por cuanto tiene que estar multiplicado el coste añadido no tiene que estar aplicado automaticamente a ninguna tarifa"; break;
case "Il nome del costo aggiuntivo verrà cambiato da":	$messaggio = "El nombre del coste añadido será cambiado de"; break;
case "a":  					$messaggio = "a"; break;
case "Il tipo di costo aggiuntivo verrà cambiato da":	$messaggio = "El tipo del coste añadido será cambiado de"; break;
case "arrotondato a":  				$messaggio = "redondeado a"; break;
case "Il costo verrà applicato":  		$messaggio = "El coste será aplicado"; break;
case "tutte le settimane":  			$messaggio = "todas las semanas"; break;
case "tutti i giorni":  			$messaggio = "todos los días"; break;
case "tutte le settimane meno una":  		$messaggio = "todas las semanas menos una"; break;
case "tutti i giorni meno uno":  		$messaggio = "todos los días menos uno"; break;
case "un numero di settimane a scelta":		$messaggio = "un número de semanas a escoger"; break;
case "un numero di giorni a scelta":  		$messaggio = "un número de días a escoger"; break;
case "Il valore del costo aggiuntivo verrà cambiato dal":	$messaggio = "El valor del coste añadido será cambiado del"; break;
case "al":  					$messaggio = "a"; break;
case "Il valore del costo aggiuntivo verrà cambiato da":	$messaggio = "El valor del coste añadido será cambiado de"; break;
case "L'applicazione del costo verrà cambiata da":	$messaggio = "La aplicación del coste será cambiada de"; break;
case "Il costo <b>non</b> verrà più associato automaticamente alla":	$messaggio = "El coste <b>no</b> será más asignado automaticamente a la"; break;
case "Il costo verrà associato automaticamente alla":	$messaggio = "El coste será asignado automaticamente a la"; break;
case "Il costo verrà mostrato nella pagina di inserzione prenotazioni":	$messaggio = "El coste será enseñado en la página de inserción de reservas"; break;
case "Il costo non verrà più mostrato nella pagina di inserzione prenotazioni":	$messaggio = "El coste no será enseñado más en la página de inserción de reservas"; break;
case "Verrà chiesto per quanto si deve moltiplicare il costo":	$messaggio = "Se preguntará por cuanto tiene que estar multiplicado el coste"; break;
case "Non verrà più chiesto per quanto si deve moltiplicare il costo":	$messaggio = "No se preguntará por cuanto tiene que estar multiplicado el coste"; break;
case "Il costo verrà considerato come letto(i) aggiuntivo(i)":	$messaggio = "El coste será considerado como cama(s) extra(s)"; break;
case "Il costo non verrà più considerato come letto(i) aggiuntivo(i)":	$messaggio = "El coste no será más considerado como cama(s) extra(s)"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "% su":  					$messaggio = "% de"; break;
case "il prezzo totale":  			$messaggio = "el precio total"; break;
case "la caparra":  				$messaggio = "la fianza"; break;
case "totale meno caparra":  			$messaggio = "total menos fianza"; break;
case "minimo":  				$messaggio = "mínimo"; break;
case "massimo":  				$messaggio = "máximo"; break;
case "esattamente":  				$messaggio = "exactamente"; break;
case "settimane":  				$messaggio = "semanas"; break;
case "giorni":  				$messaggio = "días"; break;
case "Se possibile":  				$messaggio = "Si es posible"; break;
case "Sempre":  				$messaggio = "Siempre"; break;
case "Associare a specifiche settimane della prenotazione":	$messaggio = "Asociar a semenas específicas de la reserva"; break;
case "Associare a specifici giorni della prenotazione":	$messaggio = "Asociar a días específicos de la reserva"; break;
case "Tutte":  					$messaggio = "Todas"; break;
case "Tutti":  					$messaggio = "Todos"; break;
case "Tutte meno":  				$messaggio = "Todas menos"; break;
case "Tutti meno":  				$messaggio = "Todos menos"; break;
case "la prima":  				$messaggio = "la primera"; break;
case "il primo":  				$messaggio = "el primero"; break;
case "l'ultima":  				$messaggio = "la ultima"; break;
case "l'ultimo":  				$messaggio = "el ultimo"; break;
case "Chiedere":  				$messaggio = "Preguntar"; break;
case "settimane sì":  				$messaggio = "semanas si"; break;
case "giorni sì":  				$messaggio = "días si"; break;
case "settimane no":  				$messaggio = "semanas no"; break;
case "giorni no":  				$messaggio = "días no"; break;
case "e":  					$messaggio = "y"; break;
case "Giorni della settimana selezionati":  	$messaggio = "Días de la semana seleccionados"; break;
case "Lunedì":  				$messaggio = "Lunes"; break;
case "Martedì":  				$messaggio = "Martes"; break;
case "Mercoledì":  				$messaggio = "Miercoles"; break;
case "Giovedì":  				$messaggio = "Jueves"; break;
case "Venerdì":  				$messaggio = "Viernes"; break;
case "Sabato":  				$messaggio = "Sábado"; break;
case "Domenica":  				$messaggio = "Domingo"; break;
case "Moltiplicare il costo per":  		$messaggio = "Multiplicar el coste por"; break;
case "Uno":  					$messaggio = "Uno"; break;
case "Chiedere":  				$messaggio = "Preguntar"; break;
case "Numero di persone":  			$messaggio = "Número de personas"; break;
case "Numero di persone totale":  		$messaggio = "Número total de personas"; break;
case "escluse quelle dei costi con letti aggiuntivi":	$messaggio = "excluídas las de los costes con camas añadidas"; break;
case "Periodi in cui è permesso<br> inserire il costo":	$messaggio = "Períodos en los que está<br> permitido insertar el coste"; break;
case "In tutti":  				$messaggio = "En todos"; break;
case "Solo nei periodi selezionati":  		$messaggio = "Solo en períodos seleccionados"; break;
case "dal":  					$messaggio = "desde"; break;
case "Elimina un periodo":  			$messaggio = "Elimina un período"; break;
case "Aggiungi un periodo":  			$messaggio = "Añade un período"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "si todas las semanas de la reserva estan dentro de los períodos seleccionados"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "si todos los días de la reserva estan dentro de los períodos seleccionados"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "aunque solo una semana de la reserva esté dentro de los períodos seleccionados"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "aunque solo un día de la reserva esté dentro de los períodos seleccionados"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":	$messaggio = "aplicar el coste solo en semanas permitidas en la reserva"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":	$messaggio = "aplicar el coste solo en días permitidos en la reserva"; break;
case "Caratteristiche del costo<br> da mantenere quando si<br> modifica una prenotazione":	$messaggio = "Características del coste<br> a mantener cuando se<br> modifica una reserva"; break;
case "Valore percentuale":  			$messaggio = "Valor percentual"; break;
case "e settimane associate":  			$messaggio = "y semanas asociadas"; break;
case "e giorni associati":  			$messaggio = "y días asociados"; break;
case "Assegnazione settimane":  		$messaggio = "Asignación semanas"; break;
case "Assegnazione giorni":  			$messaggio = "Asignación días"; break;
case "Numero per cui viene moltiplicato":  	$messaggio = "Número por el que está multiplicado"; break;
case "Periodi permessi":  			$messaggio = "Períodos permitidos"; break;
case "Associazione alle tariffe":  		$messaggio = "Asociación a las tarifas"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":	$messaggio = "Enseñar en la página de inserción de reservas"; break;
case "Si":  					$messaggio = "Si"; break;
case "No":  					$messaggio = "No"; break;
case "Considerare il costo come letto/i aggiuntivo/i":	$messaggio = "Considera el coste añadido como cama(s) extra(s)"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":	$messaggio = "Limitar el número que es posible tener contemporaneamente en un mismo período"; break;
case "I valori inseriti sono <div style=\"display: inline; color: red;\">errati</div> o incongruenti":	$messaggio = "Los valores insertados son <div style=\"display: inline; color: red;\">equivocados</div> o incongruentes"; break;
case "Niente da modificare":  			$messaggio = "No hay nada que modificar"; break;
case "Il costo aggiuntivo":  			$messaggio = "El coste añadido"; break;
case "è stato modificato":  			$messaggio = "ha sido modificado"; break;
case "Tariffe incompatibili":  			$messaggio = "Tarifas incompatibles"; break;
case "Quando possibile assegna automaticamente se mancano":	$messaggio = "Cuando es posible asignar automaticamente si faltan"; break;
case "meno di":  				$messaggio = "menos de"; break;
case "più di":  				$messaggio = "más de"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita":	$messaggio = "dias a la fecha inicial de la reserva cuando es insertada"; break;
case "Quando possibile assegna automaticamente se si inseriscono":	$messaggio = "Cuando es posible asignar automaticamente si se insertan"; break;
case "o più prenotazioni contemporaneamente":	$messaggio = "o más reservas contemporaneamente"; break;
case "Sempre in periodi permessi":  		$messaggio = "Siempre en períodos permitidos"; break;
case "Non si può <b style=\"font-weight: normal; color: red;\">contemporaneamente</b> mostrare il costo nella pagina di inserimento delle prenotazioni ed assegnarlo automaticamente con una tariffa":	$messaggio = "No se puede <b style=\"font-weight: normal; color: red;\">contemporaneamente</b> enseñar el coste en la página de inserción de reservas y asignarlo automaticamente con una tarifa"; break;
case "tra":  					$messaggio = "entre"; break;
case "Beni dell'inventario da<br> eliminare quando si<br> inserisce il costo":	$messaggio = "Bienes del inventario<br> a eliminar cuando se<br> inserta el coste"; break;
case "Nessuno":  				$messaggio = "Ninguno"; break;
case "Beni selezionati":  			$messaggio = "Bienes seleccionados"; break;
case "Aggiungi un bene":  			$messaggio = "Añadir un bien"; break;
case "Elimina un bene":  			$messaggio = "Eliminar un bien"; break;
case "elimina i beni dall'inventario del magazzino":	$messaggio = "Eliminar los bienes del inventario del almacén"; break;
case "Beni dell'inventario da eliminare":  	$messaggio = "Bienes del inventario a eliminar"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Enseñar agrupado con costes similares de la misma categoría en inserción"; break;
case "Tasse":  					$messaggio = "Tasas"; break;
case "Categoria":  				$messaggio = "Categoría"; break;
case "parte fissa della tariffa":  		$messaggio = "parte fija de la tarifa"; break;
case "parte per una persona della tariffa":  	$messaggio = "parte de una persona de la tarifa"; break;
case "Numero massimo":  			$messaggio = "Número máximo"; break;
case "0 se illimitato":  			$messaggio = "0 para ilimitado"; break;
case "meno":  					$messaggio = "menos"; break;
case "il costo viene moltiplicato per<br> zero se la somma è negativa":	$messaggio = "el coste será multiplicado por<br> zero si la suma es negativa"; break;
case "Combina con altri costi":			$messaggio = "Combinar con otros costes"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "los costes combinables son enseñados todos juntos con el nombre de la categoría y cada uno es insertado si es posible"; break;
case "aggiungendo":  				$messaggio = "añadiendo"; break;
case "Costi combinati":  			$messaggio = "Costes combinados"; break;
case "Opzioni in conflitto":  			$messaggio = "Opciones en conflicto"; break;
case "Attenzione":  				$messaggio = "Atención"; break;
case "le seguenti opzioni sono state attivate senza essere mantenute quando la prenotazione viene modificata":	$messaggio = "las siguientes opciones han sido activadas sin ser mantenidas cuando se modifica una reserva"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>