<?php

switch ($messaggio) {

case "Vedi le prenotazioni":  			$messaggio = "View the reservations"; break;
case "presenti dal":  				$messaggio = "present from"; break;
case "al":  					$messaggio = "to"; break;
case "Senza colori":  				$messaggio = "Without colors"; break;
case "Con colori":  				$messaggio = "With colors"; break;
case "Tabella prenotazioni precedenti al":  	$messaggio = "Table with reservations previous to"; break;
case "Tabella prenotazioni successive al":  	$messaggio = "Table with reservations subsequent"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Table with all the reservations"; break;
case "Cognome_cliente":  			$messaggio = "Client_surname"; break;
case "Data_iniziale":  				$messaggio = "Starting_date"; break;
case "Data_finale":  				$messaggio = "Ending_date"; break;
case "sett":  					$messaggio = "W"; break;
case "gio":  					$messaggio = "D"; break;
case "Tariffa_completa":  			$messaggio = "Complete_rate"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "Pagato":  				$messaggio = "Paid"; break;
case "Da_pagare":  				$messaggio = "To_pay"; break;
case "Pers.":  					$messaggio = "Peop."; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Costo_uni.":  				$messaggio = "Sing._cost"; break;
case "Costo_sett.":  				$messaggio = "Week._cost"; break;
case "Costo_gio.":  				$messaggio = "Daily_cost"; break;
case "Soldi di prenotazioni cancellate":  	$messaggio = "Money of deleted reservations"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Trasferito in cassa":  			$messaggio = "Transferred in cashbox"; break;
case "RESTO":  					$messaggio = "REST"; break;
case "Sei sicuro di voler cancellare la spesa":	$messaggio = "Are you sure you want to delete cashbox expense"; break;
case "del valore di":  				$messaggio = "of"; break;
case "Sei sicuro di voler cancellare l'entrata":	$messaggio = "Are you sure you want to delete cashbox income"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case "Entrata o spesa":  			$messaggio = "Cashbox expense or income"; break;
case "cacellata":  				$messaggio = "deleted"; break;
case "Costo o spesa già cancellati":  		$messaggio = "Cashbox expense or income already deleted"; break;
case "Tutte le spese del":  			$messaggio = "All expenses of"; break;
case "nella cassa principale":  		$messaggio = "in main cashbox"; break;
case "Natura_spesa":  				$messaggio = "Reason_for_expense"; break;
case "Importo":  				$messaggio = "Value"; break;
case "Inserita_da":  				$messaggio = "Inserted_by"; break;
case "Data_di_inserimento":  			$messaggio = "Insertion_date"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "Tutte le entrate del":  			$messaggio = "All incomes of"; break;
case "Natura_entrata":  			$messaggio = "Reason_for_income"; break;
case "cancella":  				$messaggio = "delete"; break;
case "entrata presa dalle prenotazioni":  	$messaggio = "Cashbox income taken from reservations"; break;
case "Inserisci nuove spese o entrate":  	$messaggio = "Insert new cashbox incomes or expenses"; break;
case "Storia entrate-uscite prenotazioni":  	$messaggio = "History of reservations payments"; break;
case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "Are you sure you want to delete extra cost"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "Il costo aggiuntivo è cambiato nel frattempo, non è stato cancellato":	$messaggio = "The extra cost was changed meanwhile, it has not been deleted"; break;
case "è stato cancellato":  			$messaggio = "has been deleted"; break;
case "I periodi sono stati aggiunti fino al":  	$messaggio = "Periods have been added until"; break;
case "Tabella con periodi e relative tariffe del":	$messaggio = "Table with periods and respective rates of"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "Inizio_settimana":  			$messaggio = "Starting_week"; break;
case "Inizio_giorno":  				$messaggio = "Starting_day"; break;
case "Fine_settimana":  			$messaggio = "Ending_week"; break;
case "Fine_giorno":  				$messaggio = "Ending_day"; break;
case "Aggiungi periodi":  			$messaggio = "Add periods"; break;
case "fino al mese":  				$messaggio = "until month"; break;
case "Tabella con i costi aggiuntivi del":  	$messaggio = "Table with extra costs of"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Prezzo":  				$messaggio = "Value"; break;
case "Da_assegnare":  				$messaggio = "To_assign"; break;
case "finale":  				$messaggio = "single"; break;
case "Sempre":  				$messaggio = "Always"; break;
case "Su_richiesta":  				$messaggio = "On_demand"; break;
case "chidere_per_quanto_moltiplicare":  	$messaggio = "ask_by_how_much_multiply"; break;
case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "consider_as_extra_beds"; break;
case "settimanale":  				$messaggio = "weekly"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case "tutte":  				$messaggio = "all"; break;
case "tutti":  				$messaggio = "all"; break;
case "_le":  					$messaggio = "_the"; break;
case "_i":  					$messaggio = "_the"; break;
case "_settimane":  				$messaggio = "_weeks"; break;
case "_giorni":  				$messaggio = "_days"; break;
case "_meno_una":  				$messaggio = "_minus_one"; break;
case "con_n°_di_settimane":  			$messaggio = "asking_the_number_of_weeks"; break;
case "con_n°_di_giorni":  			$messaggio = "asking_the_number_of_days"; break;
case "_da_chiedere":  				$messaggio = ""; break;
case "percentuale":  				$messaggio = "percentage"; break;
case "% arrotondato_a_":  			$messaggio = "% rounded_to_"; break;
case "Caparre, commissioni e tasse del":  	$messaggio = "Deposits, commissions and taxes of"; break;
case "Arrotondato_a":  				$messaggio = "Rounded_to"; break;
case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Go to the prices insertion page"; break;
case "chiamati":  				$messaggio = "named"; break;
case "Cerca i clienti con cognome o email":  	$messaggio = "Search clients with surname or email"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Table with all the clients"; break;
case "pag. prec.":  				$messaggio = "prev. page"; break;
case "pag. succ.":  				$messaggio = "next page"; break;
case "Cognome":  				$messaggio = "Surname"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "Indirizzo":  				$messaggio = "Address"; break;
case "Città":  					$messaggio = "City"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "CAP":  					$messaggio = "Pos. code"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "Email"; break;
case "Data_di_nascita":  			$messaggio = "Birthday"; break;
case "2°telefono":  				$messaggio = "2nd phone"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 1 for"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 2 for"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 3 for"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 4 for"; break;
case "La regola di assegnazione è stata cancellata":	$messaggio = "The assignment rule has been deleted"; break;
case "La regola di assegnazione è già stata cancellata":	$messaggio = "The assignment rule has already been deleted"; break;
case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Table with the assignment rules 1 of"; break;
case "Motivazione":  				$messaggio = "Motivation"; break;
case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Table with the assignment rules 2 of"; break;
case "Tariffa":  				$messaggio = "Rate"; break;
case "Inserisci nuove regole":  		$messaggio = "Insert new rules"; break;
case "Il numero inserito esiste già":  		$messaggio = "The inserted number already exists"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Casa":  					$messaggio = "House"; break;
case "Piano":  					$messaggio = "Floor"; break;
case "Capienza_massima":  			$messaggio = "Maximum_capacity"; break;
case "Priorità":  				$messaggio = "Priority"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "modifica":  				$messaggio = "modify"; break;
case "Torna al menù principale":  		$messaggio = "Back to main menu"; break;
case "persone":  				$messaggio = "people"; break;
case "s":  					$messaggio = "w"; break;
case "g":  					$messaggio = "d"; break;
case "Mostra":  				$messaggio = "Display"; break;
case "Non_mostrare":  				$messaggio = "Do_not_display"; break;
case "Regole":  				$messaggio = "Rules"; break;
case "Tariffe abbinate":  			$messaggio = "Associated rates"; break;
case "pagine":  				$messaggio = "pages"; break;
case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "You will make this changes"; break;
case "I soldi pagati per la prenotazione":  	$messaggio = "Money paid for reservation"; break;
case "a nome di":  				$messaggio = "for Mr/Mrs"; break;
case "verranno cambiati da":  			$messaggio = "will be changed from"; break;
case "a":  					$messaggio = "to"; break;
case "saldo":  					$messaggio = "difference"; break;
case "Le prenotazioni <b>non sono state modificate</b> perchè sono cambiate nel frattempo":	$messaggio = "The reservations <b>have not been modified</b> because the reservations table changed meanwhile"; break;
case "porre per le prenotazioni selezionate":  	$messaggio = "selected reservations to"; break;
case "cambia":  				$messaggio = "change"; break;
case "tutto pagato":  				$messaggio = "all paid"; break;
case "caparra pagata":  			$messaggio = "deposit paid"; break;
case "pagato niente":  				$messaggio = "nothing paid"; break;
case "pagina":  				$messaggio = "page"; break;
case "di":  					$messaggio = "of"; break;
case "la conferma":  				$messaggio = "confirmed"; break;
case "La prenotazione":  			$messaggio = "The reservation"; break;
case "verrà confermata":  			$messaggio = "will be confirmed"; break;
case "Data di inserimento":  			$messaggio = "Insertion date"; break;
case "Calcola il subtotale delle prenotazioni selezionate":	$messaggio = "Calculate subtotal of selected reservations"; break;
case "selezionate precedentemente":  		$messaggio = "previously selected"; break;
case "Saldo totale":  				$messaggio = "Total difference"; break;
case "l'anno":  				$messaggio = "year"; break;
case "dal database":  				$messaggio = "from database"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<b style=\"color: red;\">WARNING</b>: if you press <b>\"<i>Continue</i>\"</b>, all data regarding year"; break;
case "verranno <b>cancellati</b>":  		$messaggio = "will be <b>deleted</b>"; break;
case "L'anno":  				$messaggio = "Year"; break;
case "è stato cancellato dal batabase":  	$messaggio = "has been deleted from database"; break;
case "Non è stato possibile cancellare l'anno":	$messaggio = "It has not been possible to delete year"; break;
case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "from database, check permissions on dati folder"; break;
case "Profilo":  				$messaggio = "Profile"; break;
case "Cliente":  				$messaggio = "Client"; break;
case "cliente":  				$messaggio = "client"; break;
case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Table with the assignment rules 3 of"; break;
case "Utente":  				$messaggio = "User"; break;
case "Periodi_permessi":  			$messaggio = "Permitted_periods"; break;
case "unico":  					$messaggio = "single"; break;
case "fisso":  					$messaggio = "fixed"; break;
case "percentuale su tariffa":  		$messaggio = "percentage of rate"; break;
case "percentuale su totale":  			$messaggio = "percentage of total"; break;
case "varia_con_la_prenotazione":  		$messaggio = "changes_with_reservation"; break;
case "non_varia_con_la_prenotazione":  		$messaggio = "does_not_change_with_reservation"; break;
case "_meno_l'ultima":  			$messaggio = "_except_the_last"; break;
case "_meno_l'ultimo":  			$messaggio = "_except_the_last"; break;
case "_meno_la_prima":  			$messaggio = "_except_the_first"; break;
case "_meno_il_primo":  			$messaggio = "_except_the_first"; break;
case "giorni":  				$messaggio = "days"; break;
case "moltiplicare_per_persone":  		$messaggio = "multply_by_people"; break;
case "moltiplicare_per_persone_totali":  	$messaggio = "multply_by_total_people"; break;
case "moltiplicare_per_1":  			$messaggio = "multply_by_1"; break;
case "massimo_":  				$messaggio = "maximum_"; break;
case "_nella_stessa_settimana":  		$messaggio = "_in_the_same_week"; break;
case "_nello_stesso_giorno":  			$messaggio = "_in_the_same_day"; break;
case "Prenotazione intera in":  		$messaggio = "Entire reservation in"; break;
case "Parte della prentoazione in":  		$messaggio = "Part of reservation in"; break;
case "Solo settimane della prenotazione in":  	$messaggio = "Only weeks of reservation in"; break;
case "Solo giorni della prenotazione in":  	$messaggio = "Only days of reservation in"; break;
case " o ":  					$messaggio = " or "; break;
case " a ":  					$messaggio = " to "; break;
case "_si":  					$messaggio = "_yes"; break;
case "_no":  					$messaggio = "_no"; break;
case "_e_":  					$messaggio = "_and_"; break;
case "associato_a_settimane_specifiche":  	$messaggio = "associated_to_specific_weeks"; break;
case "non_associato_a_settimane_specifiche":  	$messaggio = "not_associated_to_specific_weeks"; break;
case "associato_a_giorni_specifici":  		$messaggio = "associated_to_specific_days"; break;
case "non_associato_a_giorni_specifici":  	$messaggio = "not_associated_to_specific_days"; break;
case "modifica con prenotazione":  		$messaggio = "modify with reservation"; break;
case "percentuale su caparra":  		$messaggio = "percentage of deposit"; break;
case "percentuale su resto caparra":  		$messaggio = "percentage of deposit difference"; break;
case "Cancellati":  				$messaggio = "Deleted"; break;
case "clienti":  				$messaggio = "clients"; break;
case "OK":  					$messaggio = "OK"; break;
case "Annulla":  				$messaggio = "Cancel"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\"><b>delete"; break;
case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "clients</b></div> that don't have any associated reservation or payment"; break;
case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
case "Cancella i clienti senza prenotazioni":	$messaggio = "Delete clients without reservations"; break;
case "Metodo pagamento":  			$messaggio = "Payment method"; break;
case "Tariffe":  				$messaggio = "Rates"; break;
case "del":  					$messaggio = "of"; break;
case "Modifica tutti i campi della tabella":  	$messaggio = "Modify all table fields"; break;
case "Modifica i campi della tabella":  	$messaggio = "Modify table fields"; break;
case "Applica i cambiamenti":  			$messaggio = "Apply changes"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "Vedi tutte le prenotazioni":  		$messaggio = "View all reservations"; break;
case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Table with the assignment rules 4 of"; break;
case "Numero di persone":  			$messaggio = "Number of people"; break;
case "assegna_se_":  				$messaggio = "assign_if_"; break;
case "più_di_":  				$messaggio = "less_than_"; break;
case "meno_di_":  				$messaggio = "more_than_"; break;
case "_giorni_da_inizio":  			$messaggio = "_days_from_beginning"; break;
case "assegna_con_":  				$messaggio = "assign_with_"; break;
case "_o_più_prenotazioni":  			$messaggio = "_or_more_reservations"; break;
case "Modifica i prezzi":  			$messaggio = "Modify prices"; break;
case "<div style=\"display: inline; color: red;\">Non</div> è stato possibile inserire alcuni prezzi":	$messaggio = "It was <div style=\"display: inline; color: red;\">not</div> possible to insert some prices"; break;
case "I prezzi sono stati aggiornati":  	$messaggio = "The prices have been updated"; break;
case "Tutte le prenotazioni":  			$messaggio = "All reservations"; break;
case "Solo arrivi":  				$messaggio = "Only arrivals"; break;
case "Solo partenze":  				$messaggio = "Only departures"; break;
case "dal":  					$messaggio = "from"; break;
case "Vedi":  					$messaggio = "View"; break;
case "Tabella con tutti gli arrivi":  		$messaggio = "Table with all the arrivals"; break;
case "Tabella con tutte le partenze":  		$messaggio = "Table with all the departures"; break;
case "prova ad importare i prezzi":  		$messaggio = "try to import prices"; break;
case "giornalmente":  				$messaggio = "daily"; break;
case "settimanalmente":  			$messaggio = "weekly"; break;
case "Origine":  				$messaggio = "Origin"; break;
case "Modifica come gruppo le prenotazioni mostrate in tabella":	$messaggio = "Modify reservations shown in table as a group"; break;
case "Modifica come gruppo le prenotazioni selezionate":	$messaggio = "Modify selected reservations as a group"; break;
case "Statistiche":  				$messaggio = "Statistics"; break;
case "Anni":  					$messaggio = "Years"; break;
case "Numero di prenotazioni per mese":  	$messaggio = "Number of reservations per month"; break;
case "Entrate dalle prenotazioni per mese":  	$messaggio = "Incomes from reservations per month"; break;
case "Entrate progressive dalle prenotazioni":	$messaggio = "Progressive incomes from reservations"; break;
case "Numero di prenotazioni per origine":  	$messaggio = "Number of reservations per origin"; break;
case "Entrate dalle prenotazioni per origine":	$messaggio = "Incomes from reservations per origin"; break;
case "Cambia":  				$messaggio = "Change"; break;
case "Mesi":  					$messaggio = "Months"; break;
case "Entrate per metodo di pagamento":  	$messaggio = "Incomes per payment method"; break;
case "Descrizione":  				$messaggio = "Description"; break;
case "magazzino":  				$messaggio = "stockroom"; break;
case "inventario":  				$messaggio = "inventory"; break;
case "aggiungi":  				$messaggio = "add"; break;
case "Codice":  				$messaggio = "Code"; break;
case "Beni inventario":  			$messaggio = "Inventory items"; break;
case "Mancanti":  				$messaggio = "Missing"; break;
case "bene eliminato":  			$messaggio = "item deleted"; break;
case "bene aggiunto":  				$messaggio = "item added"; break;
case "magazzino eliminato":  			$messaggio = "stockroom deleted"; break;
case "magazzino aggiunto":  			$messaggio = "stockroom added"; break;
case "Inventario importato":  			$messaggio = "Inventory imported"; break;
case "Importa l'invetario":  			$messaggio = "Import inventory"; break;
case "dal magazzino":  				$messaggio = "from stockroom"; break;
case "Incompatibilità":  			$messaggio = "Incompatibilities"; break;
case "raggruppa":  				$messaggio = "group"; break;
case "con email":  				$messaggio = "with email"; break;
case "Importa":  				$messaggio = "Import"; break;
case "per persona":  				$messaggio = "per person"; break;
case "con meno di":  				$messaggio = "with less than"; break;
case "dall'inizio":  				$messaggio = "from beginning"; break;
case "dalla fine":  				$messaggio = "from ending"; break;
case "Mostra solo tariffe selezionate":  	$messaggio = "Show only selected rates"; break;
case "mostra prezzi settimanali":  		$messaggio = "show weekly prices"; break;
case "mostra prezzi giornalieri":  		$messaggio = "show daily prices"; break;
case "periodi di":  				$messaggio = "periods of"; break;
case "Valore":  				$messaggio = "Value"; break;
case "della tariffa":  				$messaggio = "of rate"; break;
case "piano":  					$messaggio = "floor"; break;
case "casa":  					$messaggio = "house"; break;
case "documento":  				$messaggio = "document"; break;
case "documenti salvati":  			$messaggio = "saved documents"; break;
case "in":  					$messaggio = "in"; break;
case "numero":  				$messaggio = "number"; break;
case "nome file":  				$messaggio = "filename"; break;
case "prenotazioni":  				$messaggio = "reservations"; break;
case "azione":  				$messaggio = "action"; break;
case "anno":  					$messaggio = "year"; break;
case "elimina":  				$messaggio = "delete"; break;
case "fai l'upload del documento numero":  	$messaggio = "upload document number"; break;
case "fai l'upload":  				$messaggio = "upload"; break;
case "si è sicuri di voler <b class=\"colred\">cancellare</b> il documento":	$messaggio = "Are you sure you want to <b class=\"colred\">delete</b> document"; break;
case "cancellato":  				$messaggio = "deleted"; break;
case "inviato":  				$messaggio = "uploaded"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Tasse":  					$messaggio = "Taxes"; break;
case "senza_commissioni":  			$messaggio = "without_commissions"; break;
case "Documenti_salvati":  			$messaggio = "Saved_documents"; break;
case "TASSE":  					$messaggio = "TAXES"; break;
case "resto":  					$messaggio = "rest"; break;
case "cancella_periodi":  			$messaggio = "delete_periods"; break;
case "Sei sicuro di voler cancellare le commissioni dal":	$messaggio = "Are you sure you want to delete commissions from"; break;
case "sulla tariffa":  				$messaggio = "on rate"; break;
case "Le commissioni sono state cancellate":  	$messaggio = "Commissions have been deleted"; break;
case "Le commissioni sono cambiate nel frattempo, non sono state cancellate":	$messaggio = "Commissions have changed meanwhile, they have not been deleted"; break;
case "giorno":  				$messaggio = "day"; break;
case "settimana":  				$messaggio = "week"; break;
case "costi agg.":  				$messaggio = "extra costs"; break;
case "sconto":  				$messaggio = "discount"; break;
case "Numero di prenotazioni per nazionalità del cliente titolare":	$messaggio = "Number of reservations per nationality of titular client"; break;
case "Entrate dalle prenotazioni per nazionalità del cliente titolare":	$messaggio = "Incomes from reservations per nationality of titular client"; break;
case "Prezzi con":  				$messaggio = "Prices with"; break;
case "Prenotazioni anno corrente":  		$messaggio = "Current year reservations"; break;
case "con prenotazioni inserite":  		$messaggio = "with reservations inserted"; break;
case "fino al":  				$messaggio = "until"; break;
case "nella cassa chiamata":  			$messaggio = "in the cashbox called"; break;
case "Totale nella cassa principale":  		$messaggio = "Total in main cashbox"; break;
case "Totale nella cassa":  			$messaggio = "Total in cashbox"; break;
case "Nuova cassa chiamata":  			$messaggio = "New cashbox called"; break;
case "Crea":  					$messaggio = "Create it"; break;
case "Una cassa chiamata":  			$messaggio = "A cashbox called"; break;
case "è stata creata":  			$messaggio = "has been created"; break;
case "Cassa chiamata":  			$messaggio = "Cashbox called"; break;
case "La cassa chiamata":  			$messaggio = "The cashbox called"; break;
case "è stata cancellata":  			$messaggio = "has been deleted"; break;
case "Eventuali entrate e spese presenti in cassa non sono state cancellate":	$messaggio = "Any incomes and expenses present in this cashbox have not been deleted"; break;
case "Modifica i beni già inseriti":  		$messaggio = "Modify already inserted items"; break;
case "Modifica i beni":  			$messaggio = "Modify items"; break;
case "I beni sono stati modificati":  		$messaggio = "The items have been modified"; break;
case "p":  					$messaggio = "p"; break;
case "e combina":  				$messaggio = "and combine"; break;
case "percentuale su fisso della tariffa":	$messaggio = "percentage of fixed rate"; break;
case "percentuale su una persona della tariffa":	$messaggio = "percentage of one person of the rate"; break;
case "non più di":  				$messaggio = "no more than"; break;
case "non più del numero di persone":  		$messaggio = "no more than the number of people"; break;
case "non più del numero totale di persone":  	$messaggio = "no more than the total number of people"; break;
case "meno":  					$messaggio = "minus"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "più di":  				$messaggio = "more than"; break;
case "prezzi importati":  			$messaggio = "prices imported"; break;
case "dalla tariffa":  				$messaggio = "from rate"; break;
case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Delete credit cards of past reservations"; break;
case "password per le carte di credito":  	$messaggio = "password for credit cards"; break;
case "Cancellate":  				$messaggio = "Deleted"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "Creare":  				$messaggio = "Create"; break;
case "Aggiungi":  				$messaggio = "Add"; break;
case "persona":  				$messaggio = "person"; break;
case "chiusa":  				$messaggio = "closed"; break;
case "presenti in data":  			$messaggio = "present on"; break;
case "comprese partenze":  			$messaggio = "including departures"; break;
case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
case "da varie tariffe":  			$messaggio = "from different<br>rates"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>