<?php

##################################################################################
#    HOTELDRUID
#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    any later version accepted by Marco Maria Francesco De Santis, which
#    shall act as a proxy as defined in Section 14 of version 3 of the
#    license.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
##################################################################################



# files that contain hoteldruid source code
$files_sorgente = array(
'aggiorna.php',
'api.php',
'base.css',
'base.js',
'clienti.php',
'COPYING',
'costanti.php',
'costi.php',
'creaanno.php',
'crea_backup.php',
'creadb.php',
'crea_modelli.php',
'creaprezzi.php',
'crearegole.php',
'dati_relutenti.php',
'disponibilita.php',
'gestione_utenti.php',
'index.html',
'inizio.php',
'interconnessioni.php',
'inventario.php',
'messaggi.php',
'modifica_app.php',
'modifica_cliente.php',
'modifica_contratto.php',
'modifica_costi.php',
'modifica_ospiti.php',
'modifica_prenota.php',
'modifica_var_contr.php',
'mostra_sorgente.php',
'personalizza.php',
'prenota.php',
'privilegi_utenti.php',
'punto_vendita.php',
'README',
'storia_soldi.php',
'tabella2.php',
'tabella3.php',
'tabella.php',
'tab_tariffe.php',
'visualizza_contratto.php',
'visualizza_tabelle.php',
'dati/',
'dati/DATI',
'doc/',
'doc/CHANGELOG',
'doc/README.english',
'doc/README.espagnol',
'doc/README.italiano',
'doc/README.themes',
'doc/README.translation',
'doc/TODO',
'img/',
'img/button28.gif',
'img/button.gif',
'img/croce.gif',
'img/dir1_des.png',
'img/dir1_sin.png',
'img/dir2_des.png',
'img/dir2_sin.png',
'img/dir3_des.png',
'img/dir3_sin.png',
'img/favicon.ico',
'img/freccia_destra_marg.png',
'img/freccia_giu_marg.png',
'img/freccia_sinistra_marg.png',
'img/freccia_su_marg.png',
'img/fr_sx_checkin.gif',
'img/fr_sx_rossa.gif',
'img/logo.png',
'includes/',
'includes/costanti.php',
'includes/dati_form_prenotazione.php',
'includes/dati_lista_prenota.php',
'includes/dati_lista_clienti.php',
'includes/files_sorgente.php',
'includes/foot.php',
'includes/funzioni_aggiorna.php',
'includes/funzioni_anno.php',
'includes/funzioni_appartamenti.php',
'includes/funzioni_backup.php',
'includes/funzioni_clienti.php',
'includes/funzioni_contratti.php',
'includes/funzioni_costi_agg.php',
'includes/funzioni_dati_relutenti.php',
'includes/funzioni_ins_prenota.php',
'includes/funzioni_log.php',
'includes/funzioni_menu.php',
'includes/funzioni_mod_prenota.php',
'includes/funzioni_mysqli.php',
'includes/funzioni_mysql.php',
'includes/funzioni.php',
'includes/funzioni_postgresql.php',
'includes/funzioni_quadro_disp.php',
'includes/funzioni_relutenti.php',
'includes/funzioni_sqlite.php',
'includes/funzioni_tariffe.php',
'includes/funzioni_testo.php',
'includes/head.php',
'includes/.htaccess',
'includes/liberasettimane.php',
'includes/lista_citta.php',
'includes/lista_documentiid.php',
'includes/lista_nazioni.php',
'includes/lista_parentele.php',
'includes/lista_regioni.php',
'includes/hoteld_doc_backup.php',
'includes/sett_gio.php',
'includes/spezzaprenota.php',
'includes/variabili_contratto.php',
'includes/interconnect/',
'includes/interconnect/aggiorna_ic_fork.php',
'includes/interconnect/aggiorna_ic.php',
'includes/lang/',
'includes/lang/en/',
'includes/lang/en/aggiorna.php',
'includes/lang/en/clienti.php',
'includes/lang/en/costi.php',
'includes/lang/en/crea_backup.php',
'includes/lang/en/creadb.php',
'includes/lang/en/crea_modelli.php',
'includes/lang/en/creaprezzi.php',
'includes/lang/en/crearegole.php',
'includes/lang/en/disponibilita.php',
'includes/lang/en/foot.php',
'includes/lang/en/funzioni.php',
'includes/lang/en/gestione_utenti.php',
'includes/lang/en/giorni_mesi.php',
'includes/lang/en/head.php',
'includes/lang/en/inizio.php',
'includes/lang/en/interconnessioni.php',
'includes/lang/en/inventario.php',
'includes/lang/en/lista_citta.php',
'includes/lang/en/lista_documentiid.php',
'includes/lang/en/lista_nazioni.php',
'includes/lang/en/lista_parentele.php',
'includes/lang/en/lista_regioni.php',
'includes/lang/en/l_n',
'includes/lang/en/messaggi.php',
'includes/lang/en/modifica_app.php',
'includes/lang/en/modifica_cliente.php',
'includes/lang/en/modifica_contratto.php',
'includes/lang/en/modifica_costi.php',
'includes/lang/en/modifica_ospiti.php',
'includes/lang/en/modifica_prenota.php',
'includes/lang/en/modifica_var_contr.php',
'includes/lang/en/ordine_frasi.php',
'includes/lang/en/personalizza.php',
'includes/lang/en/hoteld_doc_backup.php',
'includes/lang/en/prenota.php',
'includes/lang/en/privilegi_utenti.php',
'includes/lang/en/punto_vendita.php',
'includes/lang/en/storia_soldi.php',
'includes/lang/en/tabella2.php',
'includes/lang/en/tabella3.php',
'includes/lang/en/tabella.php',
'includes/lang/en/tab_tariffe.php',
'includes/lang/en/unit.php',
'includes/lang/en/visualizza_contratto.php',
'includes/lang/en/visualizza_contratto_var.php',
'includes/lang/en/visualizza_tabelle.php',
'includes/lang/es/',
'includes/lang/es/aggiorna.php',
'includes/lang/es/clienti.php',
'includes/lang/es/costi.php',
'includes/lang/es/crea_backup.php',
'includes/lang/es/creadb.php',
'includes/lang/es/crea_modelli.php',
'includes/lang/es/creaprezzi.php',
'includes/lang/es/crearegole.php',
'includes/lang/es/disponibilita.php',
'includes/lang/es/foot.php',
'includes/lang/es/funzioni.php',
'includes/lang/es/gestione_utenti.php',
'includes/lang/es/giorni_mesi.php',
'includes/lang/es/head.php',
'includes/lang/es/inizio.php',
'includes/lang/es/interconnessioni.php',
'includes/lang/es/inventario.php',
'includes/lang/es/lista_citta.php',
'includes/lang/es/lista_documentiid.php',
'includes/lang/es/lista_nazioni.php',
'includes/lang/es/lista_parentele.php',
'includes/lang/es/lista_regioni.php',
'includes/lang/es/l_n',
'includes/lang/es/messaggi.php',
'includes/lang/es/modifica_app.php',
'includes/lang/es/modifica_cliente.php',
'includes/lang/es/modifica_contratto.php',
'includes/lang/es/modifica_costi.php',
'includes/lang/es/modifica_ospiti.php',
'includes/lang/es/modifica_prenota.php',
'includes/lang/es/modifica_var_contr.php',
'includes/lang/es/ordine_frasi.php',
'includes/lang/es/personalizza.php',
'includes/lang/es/hoteld_doc_backup.php',
'includes/lang/es/prenota.php',
'includes/lang/es/privilegi_utenti.php',
'includes/lang/es/punto_vendita.php',
'includes/lang/es/storia_soldi.php',
'includes/lang/es/tabella2.php',
'includes/lang/es/tabella3.php',
'includes/lang/es/tabella.php',
'includes/lang/es/tab_tariffe.php',
'includes/lang/es/unit.php',
'includes/lang/es/visualizza_contratto.php',
'includes/lang/es/visualizza_contratto_var.php',
'includes/lang/es/visualizza_tabelle.php',
'includes/templates/',
'includes/templates/frasi_mod_disp.php',
'includes/templates/funzioni_mod_disp.php',
'includes/templates/funzioni_modelli.php',
'includes/templates/modello_disponibilita.php',
'includes/templates/temi_mod_disp.php',
'includes/templates/cal/',
'includes/templates/cal/form.php',
'includes/templates/cal/functions.php',
'includes/templates/cal/name.php',
'includes/templates/cal/phrases.php',
'includes/templates/cal/template.php',
'includes/templates/cal/themes.php',
'includes/templates/rat/',
'includes/templates/rat/form.php',
'includes/templates/rat/functions.php',
'includes/templates/rat/name.php',
'includes/templates/rat/phrases.php',
'includes/templates/rat/template.php',
'includes/templates/rat/themes.php',
'includes/unit.php',
'themes/',
'themes/blu/',
'themes/blu/img/',
'themes/blu/img/addbackup.png',
'themes/blu/img/adddocument.png',
'themes/blu/img/addextracost.png',
'themes/blu/img/addinventory.png',
'themes/blu/img/addmonths.png',
'themes/blu/img/addphoto.png',
'themes/blu/img/addroom.png',
'themes/blu/img/adduser.png',
'themes/blu/img/backmenu.png',
'themes/blu/img/backup_mini.png',
'themes/blu/img/backup.png',
'themes/blu/img/bar_bg_bot.png',
'themes/blu/img/bar_bg_top.png',
'themes/blu/img/calpick.png',
'themes/blu/img/cancel_mini.png',
'themes/blu/img/cancel.png',
'themes/blu/img/cancelred_mini.png',
'themes/blu/img/cancelred.png',
'themes/blu/img/cbackup.png',
'themes/blu/img/cclient.png',
'themes/blu/img/ccreditcard.png',
'themes/blu/img/cdocument.png',
'themes/blu/img/cexpenses.png',
'themes/blu/img/cextracost.png',
'themes/blu/img/check_avail.png',
'themes/blu/img/cinventory.png',
'themes/blu/img/client_mini.png',
'themes/blu/img/client.png',
'themes/blu/img/cmonths.png',
'themes/blu/img/configure_mini.png',
'themes/blu/img/configure.png',
'themes/blu/img/cphoto.png',
'themes/blu/img/creditcard_mini.png',
'themes/blu/img/creditcard.png',
'themes/blu/img/creserv.png',
'themes/blu/img/creservs.png',
'themes/blu/img/crespayment.png',
'themes/blu/img/croom.png',
'themes/blu/img/crule.png',
'themes/blu/img/ctaxes.png',
'themes/blu/img/cuser.png',
'themes/blu/img/docbackup.png',
'themes/blu/img/documents_mini.png',
'themes/blu/img/documents.png',
'themes/blu/img/downbackup.png',
'themes/blu/img/edit2_mini.png',
'themes/blu/img/edit_mini.png',
'themes/blu/img/edit.png',
'themes/blu/img/emailsend.png',
'themes/blu/img/emails_mini.png',
'themes/blu/img/expenses.png',
'themes/blu/img/expinc.png',
'themes/blu/img/extracosts_mini.png',
'themes/blu/img/extracosts.png',
'themes/blu/img/goarrow_mini.png',
'themes/blu/img/goarrow.png',
'themes/blu/img/goarrow_xmini.png',
'themes/blu/img/goback.png',
'themes/blu/img/guests.png',
'themes/blu/img/iclient.png',
'themes/blu/img/iexpense.png',
'themes/blu/img/iexpenses.png',
'themes/blu/img/iincome.png',
'themes/blu/img/incomes_mini.png',
'themes/blu/img/incomes.png',
'themes/blu/img/interconn_mini.png',
'themes/blu/img/interconn.png',
'themes/blu/img/inventory_mini.png',
'themes/blu/img/inventory.png',
'themes/blu/img/iprices.png',
'themes/blu/img/ireserv_mini.png',
'themes/blu/img/ireserv.png',
'themes/blu/img/irules.png',
'themes/blu/img/key_mini.png',
'themes/blu/img/key.png',
'themes/blu/img/less_mini.png',
'themes/blu/img/mclient.png',
'themes/blu/img/menu_mini.png',
'themes/blu/img/menu.png',
'themes/blu/img/messages_mini.png',
'themes/blu/img/messages.png',
'themes/blu/img/minventory.png',
'themes/blu/img/month1_mini.png',
'themes/blu/img/month2_mini.png',
'themes/blu/img/month_mini.png',
'themes/blu/img/month.png',
'themes/blu/img/mprices.png',
'themes/blu/img/mreserv.png',
'themes/blu/img/mreservs.png',
'themes/blu/img/mroom.png',
'themes/blu/img/muser.png',
'themes/blu/img/ok.png',
'themes/blu/img/plus_mini.png',
'themes/blu/img/plus.png',
'themes/blu/img/pos_mini.png',
'themes/blu/img/pos.png',
'themes/blu/img/prices_mini.png',
'themes/blu/img/print.png',
'themes/blu/img/rates.png',
'themes/blu/img/resall_mini.png',
'themes/blu/img/resarrivals_mini.png',
'themes/blu/img/rescurrent_mini.png',
'themes/blu/img/resdepartures_mini.png',
'themes/blu/img/resdepcurr_mini.png',
'themes/blu/img/resdocbackup.png',
'themes/blu/img/reservations_mini.png',
'themes/blu/img/reservations.png',
'themes/blu/img/respayments_mini.png',
'themes/blu/img/respayments.png',
'themes/blu/img/restorebackup.png',
'themes/blu/img/rooms_mini.png',
'themes/blu/img/roomsnear.png',
'themes/blu/img/rooms.png',
'themes/blu/img/ruleperiod.png',
'themes/blu/img/rules_mini.png',
'themes/blu/img/rules.png',
'themes/blu/img/search_mini.png',
'themes/blu/img/selected_mini.png',
'themes/blu/img/selected.png',
'themes/blu/img/send.png',
'themes/blu/img/statistics_mini.png',
'themes/blu/img/statistics.png',
'themes/blu/img/stockroom.png',
'themes/blu/img/table.png',
'themes/blu/img/tables_mini.png',
'themes/blu/img/taxes_mini.png',
'themes/blu/img/taxes.png',
'themes/blu/img/taxperiod.png',
'themes/blu/img/upbackup.png',
'themes/blu/img/users_mini.png',
'themes/blu/img/users.png',
'themes/blu/img/websites_mini.png',
'themes/blu/img/websites.png',
'themes/blu/img/xavail.png',
'themes/blu/img/xchange_mini.png',
'themes/blu/img/xchange.png',
'themes/blu/img/xclient.png',
'themes/blu/img/xdocument.png',
'themes/blu/img/xextracost.png',
'themes/blu/img/xinventory.png',
'themes/blu/img/xprices.png',
'themes/blu/img/xuser.png',
'themes/blu/inc/',
'themes/blu/inc/functions.js',
'themes/blu/inc/mobile.css',
'themes/blu/inc/paper.css',
'themes/blu/inc/screen.css',
'themes/blu/inc/stylesheet.css',
'themes/blu/php/',
'themes/blu/php/foot.php',
'themes/blu/php/head.php',
'themes/blu/php/menu.php',
'themes/blu/php/name.php',
'themes/col/',
'themes/col/img/',
'themes/col/img/addbackup.png',
'themes/col/img/adddocument.png',
'themes/col/img/addextracost.png',
'themes/col/img/addinventory.png',
'themes/col/img/addmonths.png',
'themes/col/img/addphoto.png',
'themes/col/img/addroom.png',
'themes/col/img/adduser.png',
'themes/col/img/backmenu.png',
'themes/col/img/backup_mini.png',
'themes/col/img/backup.png',
'themes/col/img/bar_bg_bot.png',
'themes/col/img/bar_bg_top.png',
'themes/col/img/button28.gif',
'themes/col/img/button.gif',
'themes/col/img/calpick.png',
'themes/col/img/cancel_mini.png',
'themes/col/img/cancel.png',
'themes/col/img/cbackup.png',
'themes/col/img/cclient.png',
'themes/col/img/ccreditcard.png',
'themes/col/img/cdocument.png',
'themes/col/img/cexpenses.png',
'themes/col/img/cextracost.png',
'themes/col/img/check_avail.png',
'themes/col/img/cinventory.png',
'themes/col/img/client_mini.png',
'themes/col/img/client.png',
'themes/col/img/cmonths.png',
'themes/col/img/configure_mini.png',
'themes/col/img/configure.png',
'themes/col/img/cphoto.png',
'themes/col/img/creditcard_mini.png',
'themes/col/img/creditcard.png',
'themes/col/img/creserv.png',
'themes/col/img/creservs.png',
'themes/col/img/crespayment.png',
'themes/col/img/croom.png',
'themes/col/img/crule.png',
'themes/col/img/ctaxes.png',
'themes/col/img/cuser.png',
'themes/col/img/docbackup.png',
'themes/col/img/documents_mini.png',
'themes/col/img/documents.png',
'themes/col/img/downbackup.png',
'themes/col/img/edit2_mini.png',
'themes/col/img/edit_mini.png',
'themes/col/img/edit.png',
'themes/col/img/emailsend.png',
'themes/col/img/emails_mini.png',
'themes/col/img/expenses.png',
'themes/col/img/expinc.png',
'themes/col/img/extracosts_mini.png',
'themes/col/img/extracosts.png',
'themes/col/img/goarrow_mini.png',
'themes/col/img/goarrow.png',
'themes/col/img/goarrow_xmini.png',
'themes/col/img/goback.png',
'themes/col/img/guests.png',
'themes/col/img/iclient.png',
'themes/col/img/iexpense.png',
'themes/col/img/iexpenses.png',
'themes/col/img/iincome.png',
'themes/col/img/incomes_mini.png',
'themes/col/img/incomes.png',
'themes/col/img/interconn_mini.png',
'themes/col/img/interconn.png',
'themes/col/img/inventory_mini.png',
'themes/col/img/inventory.png',
'themes/col/img/iprices.png',
'themes/col/img/ireserv_mini.png',
'themes/col/img/ireserv.png',
'themes/col/img/irules.png',
'themes/col/img/key_mini.png',
'themes/col/img/key.png',
'themes/col/img/less_mini.png',
'themes/col/img/mclient.png',
'themes/col/img/menu_mini.png',
'themes/col/img/menu.png',
'themes/col/img/messages_mini.png',
'themes/col/img/messages.png',
'themes/col/img/minventory.png',
'themes/col/img/month1_mini.png',
'themes/col/img/month2_mini.png',
'themes/col/img/month3_mini.png',
'themes/col/img/month4_mini.png',
'themes/col/img/month_mini.png',
'themes/col/img/month.png',
'themes/col/img/mprices.png',
'themes/col/img/mreserv.png',
'themes/col/img/mreservs.png',
'themes/col/img/mroom.png',
'themes/col/img/muser.png',
'themes/col/img/ok.png',
'themes/col/img/plus_mini.png',
'themes/col/img/plus.png',
'themes/col/img/pos_mini.png',
'themes/col/img/pos.png',
'themes/col/img/prices_mini.png',
'themes/col/img/print.png',
'themes/col/img/rates.png',
'themes/col/img/resall_mini.png',
'themes/col/img/resarrivals_mini.png',
'themes/col/img/rescurrent_mini.png',
'themes/col/img/resdepartures_mini.png',
'themes/col/img/resdepcurr_mini.png',
'themes/col/img/resdocbackup.png',
'themes/col/img/reservations_mini.png',
'themes/col/img/reservations.png',
'themes/col/img/respayments_mini.png',
'themes/col/img/respayments.png',
'themes/col/img/restorebackup.png',
'themes/col/img/rooms_mini.png',
'themes/col/img/roomsnear.png',
'themes/col/img/rooms.png',
'themes/col/img/ruleperiod.png',
'themes/col/img/rules_mini.png',
'themes/col/img/rules.png',
'themes/col/img/search_mini.png',
'themes/col/img/selected_mini.png',
'themes/col/img/selected.png',
'themes/col/img/send.png',
'themes/col/img/statistics_mini.png',
'themes/col/img/statistics.png',
'themes/col/img/stockroom.png',
'themes/col/img/table.png',
'themes/col/img/tables_mini.png',
'themes/col/img/taxes_mini.png',
'themes/col/img/taxes.png',
'themes/col/img/taxperiod.png',
'themes/col/img/upbackup.png',
'themes/col/img/upload_mini.png',
'themes/col/img/users_mini.png',
'themes/col/img/users.png',
'themes/col/img/websites_mini.png',
'themes/col/img/websites.png',
'themes/col/img/xavail.png',
'themes/col/img/xchange_mini.png',
'themes/col/img/xchange.png',
'themes/col/img/xclient.png',
'themes/col/img/xdocument.png',
'themes/col/img/xextracost.png',
'themes/col/img/xinventory.png',
'themes/col/img/xprices.png',
'themes/col/img/xuser.png',
'themes/col/inc/',
'themes/col/inc/functions.js',
'themes/col/inc/mobile.css',
'themes/col/inc/paper.css',
'themes/col/inc/screen.css',
'themes/col/inc/stylesheet.css',
'themes/col/php/',
'themes/col/php/foot.php',
'themes/col/php/head.php',
'themes/col/php/menu.php',
'themes/col/php/name.php',
'themes/col/php/selectperiod.php',
'themes/sim/',
'themes/sim/img/',
'themes/sim/img/bar_bg_bot.png',
'themes/sim/img/bar_bg_top.png',
'themes/sim/img/calpick.png',
'themes/sim/inc/',
'themes/sim/inc/functions.js',
'themes/sim/inc/mobile.css',
'themes/sim/inc/paper.css',
'themes/sim/inc/screen.css',
'themes/sim/inc/stylesheet.css',
'themes/sim/php/',
'themes/sim/php/foot.php',
'themes/sim/php/head.php',
'themes/sim/php/.htaccess',
'themes/sim/php/menu.php',
'themes/sim/php/name.php',
'themes/sim/php/selectperiod.php',
'themes/snj/',
'themes/snj/img/',
'themes/snj/img/bar_bg_bot.png',
'themes/snj/img/bar_bg_top.png',
'themes/snj/inc/',
'themes/snj/inc/stylesheet.css',
'themes/snj/php/',
'themes/snj/php/foot.php',
'themes/snj/php/head.php',
'themes/snj/php/.htaccess',
'themes/snj/php/menu.php',
'themes/snj/php/name.php',
'themes/snj/php/selectperiod.php'
);



?>