<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Las fechas están equivocadas"; break;
case "Si deve inserire il tipo di tariffa":  	$messaggio = "Hay que insertar el tipo de tarifa"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Non è stato ancora inserito il prezzo della":	$messaggio = "No ha sido todavía insertado el precio de la"; break;
case "per la settimana dal":  			$messaggio = "para la semana desde el"; break;
case "per il giorno dal":  			$messaggio = "para el día desde el"; break;
case "al":  					$messaggio = "hasta el"; break;
case "La settimana dal":  			$messaggio = "La semana desde el"; break;
case "Il giorno dal":  				$messaggio = "El día desde el"; break;
case "è piena":  				$messaggio = "está llena"; break;
case "è pieno":  				$messaggio = "está lleno"; break;
case "Il numero di settimane del costo aggiuntivo settimanale nº":	$messaggio = "El número de semanas del coste añadido semanal nº"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero nº":	$messaggio = "El número de días del coste añadido diario nº"; break;
case "supera il numero totale di settimane della prenotazione":	$messaggio = "supera el número total de semanas de la reserva"; break;
case "supera il numero totale di giorni della prenotazione":	$messaggio = "supera el número total de días de la reserva"; break;
case "persone":  				$messaggio = "personas"; break;
case "Si dovrà occupare almeno un periodo della regola di assegnazione 1":	$messaggio = "Habrá que ocupar por lo menos un período de la regla de asignación 1"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <font color=\"blue\">regola di assegnazione 1</font>":	$messaggio = "Hay que hacer los siguientes movimientos en los períodos de la <font color=\"blue\">regla de asignación 1</font>"; break;
case "Sono stati fatti i seguenti spostamenti nei periodi della <font color=\"blue\">regola di assegnazione 1</font>":	$messaggio = "Se han llevado a cabo los siguientes movimientos en los períodos de la <font color=\"blue\">regla de asignación 1</font>"; break;
case "La prenotazione dal":  			$messaggio = "La reserva desde el"; break;
case "a nome di":  				$messaggio = "a nombre de"; break;
case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "No se puede continuar porque ha cambiado la tabla de reservas mientras tanto"; break;
case "Continua lo stesso":  			$messaggio = "Continua lo mismo"; break;
case "Torna indietro":  			$messaggio = "Volver atrás"; break;
case "Non esistono clienti chiamati":  		$messaggio = "No existen clientes llamados"; break;
case "nel database":  				$messaggio = "en la base de datos"; break;
case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Insertar los datos de un nuevo cliente"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "Existen los siguientes clientes con apedillo igual o similar"; break;
case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messaggio = "Existen los siguientes clientes con apedillo y nombre igual o similar"; break;
case "nato il":	  				$messaggio = "nacido el"; break;
case "nata il":	  				$messaggio = "nacida el"; break;
case "CAP":  					$messaggio = "codigo postal"; break;
case "Telefono":  				$messaggio = "Teléfono"; break;
case "2º telefono":  				$messaggio = "2º teléfono"; break;
case "3º telefono":  				$messaggio = "3º teléfono"; break;
case "Utilizza il cliente":  			$messaggio = "Utiliza el cliente"; break;
case "per la prenotazione":  			$messaggio = "para la reserva"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modificar los datos del cliente"; break;
case "Inserisci un nuovo cliente":  		$messaggio = "Insertar un nuevo cliente"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Hay que insertar el apellido del cliente"; break;
case "I dati del cliente":  			$messaggio = "Los datos del cliente"; break;
case "sono stati inseriti":  			$messaggio = "han sido insertados"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Insertar o modificar los datos de un cliente"; break;
case "Cognome":  				$messaggio = "Apellido"; break;
case "nome":  					$messaggio = "nombre"; break;
case "sesso":  					$messaggio = "sexo"; break;
case "Data di nascita":  			$messaggio = "Fecha de nacimiento"; break;
case "anno con 4 cifre":  			$messaggio = "año con 4 cifras"; break;
case "Nazione":  				$messaggio = "Nación"; break;
case "città":  					$messaggio = "ciudad"; break;
case "Via":  					$messaggio = "Calle"; break;
case "Piazza":  				$messaggio = "Plaza"; break;
case "Viale":  					$messaggio = "Avenida"; break;
case "Piazzale":  				$messaggio = "Paseo"; break;
case "Vicolo":  				$messaggio = "Bulevard"; break;
case "Numero di telefono":  			$messaggio = "Número de teléfono"; break;
case "Secondo telefono":  			$messaggio = "Seguno teléfono"; break;
case "Terzo telefono":  			$messaggio = "Tercer teléfono"; break;
case "Numero di fax":  				$messaggio = "Número de fax"; break;
case "Seconda persona di riferimento":  	$messaggio = "Segunda persona de referencia"; break;
case "Inserisci i dati":  			$messaggio = "Insertar los datos"; break;
case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
case "Italia":  				$messaggio = ""; break;
case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "no serán modificados los datos específicos de las 2 personas de referencia"; break;
case "sono stati modificati":  			$messaggio = "han sido modificados"; break;
case "e":  					$messaggio = "y"; break;
case "Il numero di prenotazioni è sbagliato":	$messaggio = "El número de reservas está equivocado"; break;
case "Aggiungi":  				$messaggio = "Añadir"; break;
case "Nº di tipologie da aggiungere":  		$messaggio = "Nº de tipologías a añadir"; break;
case "Non si è trovato nessun cliente chiamato":	$messaggio = "No se ha encontrado ningún cliente llamado"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "No hay ningún período de las reglas 1 en el que esté consentido insertar reservas para el usuario"; break;
case "Il numero di persone è sbagliato":  	$messaggio = "El número de personas está equivocado"; break;
case "I dati di un costo aggiuntivo sono errati":	$messaggio = "Los datos de un coste añadido están equivocados"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "No se puede insertar mas de un coste añadido con percentual sobre el precio total por reserva"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "No se puede insertar el coste añadido"; break;
case "in questo periodo":  			$messaggio = "en este periodo"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Escoger las semanas en las que aplicar el coste añadido"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Escoger los días en las que aplicar el coste añadido"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "Non si possono inserire altri costi":  	$messaggio = "No se pueden insertar mas costes"; break;
case "in questo periodo, già":  		$messaggio = "en este periodo, ya"; break;
case "presenti":  				$messaggio = "presentes"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "Hay que insertar el número de personas para el coste añadido"; break;
case "Il costo aggiuntivo":  			$messaggio = "El coste añadido"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "es incompatible con la tarifa seleccionada"; break;
case "non può essere applicato":  		$messaggio = "no puede ser aplicado"; break;
case "regione":  				$messaggio = "región"; break;
case "Documento":  				$messaggio = "Documento"; break;
case "scadenza":  				$messaggio = "expiración"; break;
case "Torna all'inserimento clienti":  		$messaggio = "Volver a la inserción de los clientes"; break;
case "Annulla":  				$messaggio = "Anular"; break;
case "Ospite della prenotazione":  		$messaggio = "Huésped de la reserva"; break;
case "tipologia":  				$messaggio = "tipología"; break;
case "Ospiti della prenotazione":  		$messaggio = "Huéspedes de la reserva"; break;
case "Altri ospiti":  				$messaggio = "Otros huéspedes"; break;
case "nato":  					$messaggio = "nacido"; break;
case "nata":  					$messaggio = "nacida"; break;
case "il":  					$messaggio = "el"; break;
case " a":  					$messaggio = " en"; break;
case "scade":  					$messaggio = "caduca"; break;
case "cittadinanza":  				$messaggio = "nacionalidad"; break;
case "città di nascita":  			$messaggio = "ciudad de nacimiento"; break;
case "reg./prov. di nascita":  			$messaggio = "región de nacimiento"; break;
case "nazione di nascita":  			$messaggio = "nación de nacimiento"; break;
case "Residenza":  				$messaggio = "Residencia"; break;
case "reg./prov.":  				$messaggio = "región"; break;
case "nazione":  				$messaggio = "nación"; break;
case "rilasciato da":  				$messaggio = "emitido por"; break;
case "nazione di rilascio":  			$messaggio = "nación emisora"; break;
case "parentela":  				$messaggio = "emparentado"; break;
case "Codice fiscale":  			$messaggio = "N. Identificación Fiscal"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "con los costes añadidos seleccionados"; break;
case "I beni richiesti dal costo":  		$messaggio = "Los bienes necesarios para el coste"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "no están disponibles en el inventario"; break;
case "Si deve inserire il numero delle persone per questa tariffa":	$messaggio = "Hay que insertar el número de personas para esta tarifa"; break;
case "Partita iva":  				$messaggio = "Cert. Identificación Fiscal"; break;
case "lo sconto è sbagliato":  			$messaggio = "el descuento está equivocado"; break;
case "la caparra è sbagliata":  		$messaggio = "la fianza está equivocada"; break;
case "soprannome":  				$messaggio = "apodo"; break;
case "le commissioni sono sbagliate":  		$messaggio = "las comisiones están equivocas"; break;
case "lingua":  				$messaggio = "idioma"; break;
case "ln.":  					$messaggio = "id."; break;
case "non può essere moltiplicato per più di":	$messaggio = "no puede ser multiplicado por más de"; break;
case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "La tarifa seleccionada está cerrada en este período"; break;
case "Commento":  				$messaggio = "Comentario"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>