<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Menú principal del año"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Insertar una nueva reserva"; break;
case "prenotazioni del mese di": 		$messaggio = "reservas del més de"; break;
case "visualizza": 				$messaggio = "ver"; break;
case "Gennaio":                               	$messaggio = "Enero"; break;
case "Febbraio":                              	$messaggio = "Febrero"; break;
case "Marzo":                                 	$messaggio = "Marzo"; break;
case "Aprile":      				$messaggio = "Abril"; break;
case "Maggio":                           	$messaggio = "Mayo"; break;
case "Giugno":                            	$messaggio = "Junio"; break;
case "Luglio":                            	$messaggio = "Julio"; break;
case "Agosto":  				$messaggio = "Agosto"; break;
case "Settembre":  				$messaggio = "Septiembre"; break;
case "Ottobre":  				$messaggio = "Octubre"; break;
case "Novembre":  				$messaggio = "Noviembre"; break;
case "Dicembre":  				$messaggio = "Diciembre"; break;
case "tabella con":  				$messaggio = "tabla con"; break;
case "tutte le prenotazioni":  			$messaggio = "todas la reservas"; break;
case "le spese e le entrate":  			$messaggio = "los gastos y las entradas"; break;
case "i periodi e le tariffe":  		$messaggio = "los períodos y las tarifas"; break;
case "tutti i clienti":  			$messaggio = "todos los clientes"; break;
case "le regole di assegnazione":  		$messaggio = "las reglas de asignación"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Insertar un nuevo cliente"; break;
case "Spese ed entrate":  			$messaggio = "Gastos y entradas"; break;
case "disponibilità dal":  			$messaggio = "disponibilidad desde"; break;
case "al":  					$messaggio = "hasta"; break;
case "per":  					$messaggio = "para"; break;
case "persone":	  				$messaggio = "personas"; break;
case "controlla":  				$messaggio = "controlar"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Insertar o modificar los precios"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Insertar o modificar las reglas de asignación"; break;
case "Configura e personalizza":	$messaggio = "Configurar y personalizar"; break;
case "richiedi l'anno":  			$messaggio = "Ir al año"; break;
case "vai":  					$messaggio = "ir"; break;
case "Non esiste l'anno ":  			$messaggio = "No existe el año "; break;
case " nel database":  				$messaggio = " en la base de datos"; break;
case "Crea l'anno":  				$messaggio = "Crear el año"; break;
case "Domenica":  				$messaggio = "Domingo"; break;
case "Lunedì":  				$messaggio = "Lunes"; break;
case "Martedì":  				$messaggio = "Martes"; break;
case "Mercoledì":  				$messaggio = "Miércoles"; break;
case "Giovedì":  				$messaggio = "Jueves"; break;
case "Venerdì":  				$messaggio = "Viernes"; break;
case "Sabato":	 		 		$messaggio = "Sabado"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "como día de principio/final de alquiler"; break;
case "con periodi":  				$messaggio = "con períodos"; break;
case "settimanali":  				$messaggio = "semanales"; break;
case "giornalieri":  				$messaggio = "diarios"; break;
case "e prenotazioni da":  			$messaggio = "y reservas desde"; break;
case "a":  					$messaggio = "hasta"; break;
case "anno successivo": 			$messaggio = "año siguiente"; break;
case "Feb. anno successivo":                   	$messaggio = "Feb. año siguiente"; break;
case "anni successivi":  			$messaggio = "años siguientes"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Importa desde el año anterior reservas, tarifas (incluídos los costes añadidos), privilegios de los usuarios y reglas de asignación."; break;
case "Anno ":  					$messaggio = "Año "; break;
case " creato":  				$messaggio = " creado"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "No hay períodos que se refieren al "; break;
case " nel ":  					$messaggio = " en el "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":  	$messaggio = ", o el día de principio/final alquiler era diferente, han sido importados solo los datos que se refieren a costes añadidos, fianza, nombres de las tarifas, privilegios de los usuarios y a las reglas de asignación 2 y 3"; break;
case "Attenzione</b>: i periodi del ":  	$messaggio = "Atencíon</b>: los períodos del "; break;
case " finivano dopo quelli del ":  		$messaggio = " acababan después de los del "; break;
case " e vi erano":  				$messaggio = " y habían"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservas que acababan después del limite dado para el "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", estas reservas no han sido importadas"; break;
case "Anno già creato": 			$messaggio = "Año ya creado"; break;
case " Do":  					$messaggio = " Do"; break;
case " Lu":  					$messaggio = " Lu"; break;
case " Ma":  					$messaggio = " Ma"; break;
case " Me":  					$messaggio = " Mi"; break;
case " Gi":  					$messaggio = " Ju"; break;
case " Ve":  					$messaggio = " Vi"; break;
case " Sa":  					$messaggio = " Sá"; break;
case "Gen":  					$messaggio = "Ene"; break;
case "Feb":  					$messaggio = "Feb"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Abr"; break;
case "Mag":  					$messaggio = "May"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Ago"; break;
case "Set":  					$messaggio = "Sep"; break;
case "Ott":  					$messaggio = "Oct"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dic"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "El formato del año pedido está equivocado"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Los meses estaban indicados en modo erroneo, han sido insertados los meses desde Enero hasta Diciembre"; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "Cognome del cliente":  			$messaggio = "Apellido cliente 	"; break;
case "Data iniziale":  				$messaggio = "Fecha inicial"; break;
case "Data finale":  				$messaggio = "Fecha final"; break;
case "Tariffa completa":  			$messaggio = "Tarifa comleta"; break;
case "Da pagare":  				$messaggio = "A pagar"; break;
case "Pers":  					$messaggio = "Pers"; break;
case "Registra":  				$messaggio = "Registrar"; break;
case "Entrata":  				$messaggio = "Entrada"; break;
case "Uscita":  				$messaggio = "Salida"; break;
case "Entrata e pagato":  			$messaggio = "Entrada y pagado"; break;
case "Uscita e pagato":  			$messaggio = "Salida y pagado"; break;
case "mostra tutte le date":  			$messaggio = "enseña todas las fechas"; break;
case "Utente":  				$messaggio = "Usuario"; break;
case "Esci":  					$messaggio = "Salir"; break;
case "Messaggi":  				$messaggio = "Mensajes"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Aviso</span>: es aconsejable esperar hasta el"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "para crear el nuevo año, mientras tanto se pueden añadir períodos más allá del"; break;
case "dalla":  					$messaggio = "desde la"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "tabla con los períodos y las tarifas"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "también sin crear un nuevo año"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "No tengo los permisos de escritura sobre el directorio dati"; break;
case "le statistiche":  			$messaggio = "las estadísticas"; break;
case "inventario e magazzini":  		$messaggio = "inventario y almacenes"; break;
case "obsoleti":  				$messaggio = "obsoletos"; break;
case "Ultimo aggiornamento":  			$messaggio = "Ultima actualización"; break;
case "Aggiorna":  				$messaggio = "Actualizar"; break;
case "i documenti salvati":  			$messaggio = "los documentos salvados"; break;
case "Punto vendita":  				$messaggio = "Punto de venta"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "No tengo los permisos para crear nuevas tablas en la base de datos"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Bienvenido a HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Escoger el idioma"; break;
case "crea il database":  			$messaggio = "crear la base de datos"; break;
case "Promemoria":  				$messaggio = "Recordatorio"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "Este usuario no tiene los privilegios para crear nuevos años"; break;
case "Avviso":  				$messaggio = "Aviso"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "el la base de datos hay todavía disponibles períodos solo por menos de"; break;
case "mesi":  					$messaggio = "meses"; break;
case "OK, ho capito":  				$messaggio = "OK, entendido"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>