<?php

switch ($messaggio) {

case "Inserisci i prezzi per l'anno":  		$messaggio = "Insert the prices for year"; break;
case "Prezzi della":  				$messaggio = "Prices of"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "soprannominata":  			$messaggio = "called"; break;
case "Dal":  					$messaggio = "From"; break;
case "al":  					$messaggio = "to"; break;
case "inserisci i nuovi prezzi":  		$messaggio = "insert the new prices"; break;
case "modifica i prezzi già inseriti":  	$messaggio = "modify already inserted prices"; break;
case "Costi aggiuntivi":  			$messaggio = "Extra costs"; break;
case "Nome del nuovo costo aggiuntivo":		$messaggio = "New extra cost name"; break;
case "da applicare":  				$messaggio = "to apply"; break;
case "sempre":  				$messaggio = "always"; break;
case "su richiesta":  				$messaggio = "on demand"; break;
case "chiedi per quanto deve essere moltiplicato":	$messaggio = "ask by how much it must be multiplied"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "consider this single cost as an extra bed(s)"; break;
case "numero di settimane":  			$messaggio = "number of weeks"; break;
case "numero di giorni":  			$messaggio = "number of days"; break;
case "tutte":  					$messaggio = "all"; break;
case "tutti":  					$messaggio = "all"; break;
case "tutte meno una":  			$messaggio = "all minus one"; break;
case "tutti meno uno":  			$messaggio = "all minus one"; break;
case "chiedere":  				$messaggio = "ask"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio = "consider this weekly cost as an extra bed(s)"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "consider this daily cost as an extra bed(s)"; break;
case "della tariffa arrotondato a":  		$messaggio = "of the rate rounded to"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "consider this percentage cost as an extra bed(s)"; break;
case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Proceed inserting the new extra cost"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "La caparra normale per la":  		$messaggio = "The normal deposit for"; break;
case "arrotondata a":  				$messaggio = "rounded to"; break;
case "Inserisci o modifica la caparra":  	$messaggio = "Insert or modify the deposit"; break;
case "Vedi i prezzi già inseriti":  		$messaggio = "View the prices already inserted"; break;
case "Torna al menù principale":  		$messaggio = "Back to main menu"; break;
case "Si deve inserire la percentuale":  	$messaggio = "You must insert the percentage"; break;
case "La caparra è stata modificata":  		$messaggio = "The deposit has been modified"; break;
case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "You must choose how to apply the single cost"; break;
case "Si deve inserire il nome del costo aggiuntivo":	$messaggio = "You must insert the name of the extra cost"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "The single extra cost"; break;
case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "already exists, go to the page with the periods and the rates to delete it"; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":	$messaggio = "To ask by how much it must be multiplied the single extra cost must not be applied automatically"; break;
case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "You must choose how to apply the weekly cost"; break;
case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "You must choose how to apply the daily cost"; break;
case "e il numero di settimane":  		$messaggio = "and the number of weeks"; break;
case "e il numero di giorni":  			$messaggio = "and the number of days"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale non deve essere applicato automaticamente":	$messaggio = "To ask the number of weeks or by how much it must be multiplied the weekly extra cost must not be applied automatically"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero non deve essere applicato automaticamente":	$messaggio = "To ask the number of days or by how much it must be multiplied the daily extra cost must not be applied automatically"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "The weekly extra cost"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "The daily extra cost"; break;
case "Si deve specificare quando applicare il costo percentuale":	$messaggio = "You must choose how to apply the percentage cost"; break;
case "e il valore dell'arrotondamento":		$messaggio = "and the value to round to"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":	$messaggio = "To ask by how much it must be multiplied the percentage extra cost must not be applied automatically"; break;
case "Il costo aggiuntivo percentuale":		$messaggio = "The percentage extra cost"; break;
case "è stato inserito":  			$messaggio = "has been inserted"; break;
case "Nessun dato è stato inserito":  		$messaggio = "No data has been inserted"; break;
case "Il soprannome della":  			$messaggio = "The name of"; break;
case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "already exists, use the button \"modify already inserted prices\" to change it, or don't insert it to insert prices in new periods"; break;
case "Il soprannome":  				$messaggio = "The name"; break;
case "già esiste, ne devi usare un'altro":  	$messaggio = "already exists, you must use another one"; break;
case "Le date del periodo numero":  		$messaggio = "The dates of period number"; break;
case "sono sbagliate":  			$messaggio = "are wrong"; break;
case "Il periodo":  				$messaggio = "The period"; break;
case "si sovrappone ad un periodo precedente":	$messaggio = "overlaps on another period"; break;
case "Un prezzo nel periodo numero":  		$messaggio = "A price in the period number"; break;
case "esiste già, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo":	$messaggio = "already exists, use the button \"modify already inserted prices\" to change it"; break;
case "è stato cambiato":  			$messaggio = "has been changed"; break;
case "Il prezzo del periodo":  			$messaggio = "The price of period"; break;
case "è stato inserito":  			$messaggio = "has been inserted"; break;
case "Il prezzo del periodo numero":  		$messaggio = "The price of period number"; break;
case "è sbagliato":  				$messaggio = "is wrong"; break;
case "I soldi del costo finale sono sbagliati":	$messaggio = "The money for single cost is wrong"; break;
case "I soldi del costo settimanale sono sbagliati":	$messaggio = "The money for weekly cost is wrong"; break;
case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "The money for daily cost is wrong"; break;
case "I soldi del costo percentuale sono sbagliati":	$messaggio = "The money for percentage cost is wrong"; break;
case "Inserzione per settimane":		$messaggio = "Insertion on weekly basis"; break;
case "Inserzione per giorni":			$messaggio = "Insertion on daily basis"; break;
case "Inserzione per settimane":  		$messaggio = "Insertion on weekly basis"; break;
case "Settimane dal":  				$messaggio = "Weeks from"; break;
case "Dom/Lun":  				$messaggio = "Sun/Mon"; break;
case "Lun/Mar":  				$messaggio = "Mon/Tue"; break;
case "Mar/Mer":  				$messaggio = "Tue/Wed"; break;
case "Mer/Gio":  				$messaggio = "Wed/Thu"; break;
case "Gio/Ven":  				$messaggio = "Thu/Fri"; break;
case "Ven/Sab":  				$messaggio = "Fri/Sat"; break;
case "Sab/Dom":  				$messaggio = "Sat/Sun"; break;
case "inserisci o modifica i prezzi":  		$messaggio = "Insert or modify the prices"; break;
case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "Il formato dei soldi è sbagliato":  	$messaggio = "Money format is wrong"; break;
case "I prezzi per le settimane dal":  		$messaggio = "The prices for weeks from"; break;
case "della <b>tariffa":  			$messaggio = "of <b>rate"; break;
case "sono stati inseriti":  			$messaggio = "have been inserted"; break;
case "si":  					$messaggio = "yes"; break;
case "no":  					$messaggio = "no"; break;
case "assegnato automaticamente con tariffe":  	$messaggio = "automatically assigned for rates"; break;
case "nessuna":  				$messaggio = "no one"; break;
case "scegliere":  				$messaggio = "choose"; break;
case "mostrare nella pagina di inserzione prenotazioni":	$messaggio = "display in reservation insertion page"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>single</b> extra cost"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>weekly</b> extra cost"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Choose the rates to which apply automatically the <b>daily</b> extra cost"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>percentage</b> extra cost"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "Tipo di costo aggiuntivo":  		$messaggio = "Extra cost type"; break;
case "unico":  					$messaggio = "single"; break;
case "settimanale":  				$messaggio = "weekly"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case "il prezzo totale":  			$messaggio = "total price"; break;
case "la caparra":  				$messaggio = "the deposit"; break;
case "totale meno caparra":  			$messaggio = "total minus deposit"; break;
case "minimo":  				$messaggio = "minimum"; break;
case "massimo":  				$messaggio = "maximum"; break;
case "esattamente":  				$messaggio = "exactly"; break;
case "settimane":  				$messaggio = "weeks"; break;
case "giorni":  				$messaggio = "days"; break;
case "Se possibile":  				$messaggio = "If possible"; break;
case "Sempre":  				$messaggio = "Always"; break;
case "Associare a specifiche settimane della prenotazione":	$messaggio = "Associate to specific weeks of the reservation"; break;
case "Associare a specifici giorni della prenotazione":	$messaggio = "Associate to specific days of the reservation"; break;
case "Tutte":  					$messaggio = "All"; break;
case "Tutti":  					$messaggio = "All"; break;
case "Tutte meno":  				$messaggio = "All minus"; break;
case "Tutti meno":  				$messaggio = "All minus"; break;
case "la prima":  				$messaggio = "the first"; break;
case "il primo":  				$messaggio = "the first"; break;
case "l'ultima":  				$messaggio = "the last"; break;
case "l'ultimo":  				$messaggio = "the last"; break;
case "Chiedere":  				$messaggio = "Ask"; break;
case "settimane sì":  				$messaggio = "weeks yes"; break;
case "giorni sì":  				$messaggio = "days yes"; break;
case "settimane no":  				$messaggio = "weeks no"; break;
case "giorni no":  				$messaggio = "days no"; break;
case "e":  					$messaggio = "and"; break;
case "Giorni della settimana selezionati":  	$messaggio = "Selected week days"; break;
case "Lunedì":  				$messaggio = "Monday"; break;
case "Martedì":  				$messaggio = "Tuesday"; break;
case "Mercoledì":  				$messaggio = "Wednesday"; break;
case "Giovedì":  				$messaggio = "Thursday"; break;
case "Venerdì":  				$messaggio = "Friday"; break;
case "Sabato":  				$messaggio = "Saturday"; break;
case "Domenica":  				$messaggio = "Sunday"; break;
case "Moltiplicare il costo per":  		$messaggio = "Multiply the cost by"; break;
case "Uno":  					$messaggio = "One"; break;
case "Chiedere":  				$messaggio = "Ask"; break;
case "Numero di persone":  			$messaggio = "Number of people"; break;
case "Numero di persone totale":  		$messaggio = "Total number of people"; break;
case "escluse quelle dei costi con letti aggiuntivi":	$messaggio = "excluding the ones from costs with extra beds"; break;
case "Periodi in cui è permesso inserire il costo":	$messaggio = "Periods in which it is allowed to insert the cost"; break;
case "In tutti":  				$messaggio = "All"; break;
case "Solo nei periodi selezionati":  		$messaggio = "Only selected periods"; break;
case "dal":  					$messaggio = "from"; break;
case "Elimina un periodo":  			$messaggio = "Delete period"; break;
case "Aggiungi un periodo":  			$messaggio = "Add period"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "if all weeks of the reservation are in the selected periods"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "if all days of the reservation are in the selected periods"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "if even only one week of the reservation is in the selected periods"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "if even only one day of the reservation is in the selected periods"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":	$messaggio = "apply the cost only to permitted weeks in the reservation"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":	$messaggio = "apply the cost only to permitted days in the reservation"; break;
case "Caratteristiche del costo da mantenere quando si modifica una prenotazione":	$messaggio = "Cost characteristics to keep when a reservation is modified"; break;
case "Valore percentuale":  			$messaggio = "Percentage value"; break;
case "e settimane associate":  			$messaggio = "and associated weeks"; break;
case "e giorni associati":  			$messaggio = "and associated days"; break;
case "Assegnazione settimane":  		$messaggio = "Weeks assignment"; break;
case "Assegnazione giorni":  			$messaggio = "Days assignment"; break;
case "Numero per cui viene moltiplicato":  	$messaggio = "Number by which it is multiplied"; break;
case "Periodi permessi":  			$messaggio = "Permitted periods"; break;
case "Associazione alle tariffe":  		$messaggio = "Association to rates"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":	$messaggio = "Display in reservations insertion page"; break;
case "Si":  					$messaggio = "Yes"; break;
case "No":  					$messaggio = "No"; break;
case "Considerare il costo come letto/i aggiuntivo/i":	$messaggio = "Consider this extra cost as an extra bed(s)"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":	$messaggio = "Limit the number that it is possible to have contemporaneously in the same period"; break;
case "Valore del costo":  			$messaggio = "Value of the cost"; break;
case "fisso di":  				$messaggio = "fixed of"; break;
case "percentuale su":  			$messaggio = "percentage on"; break;
case "la tariffa":  				$messaggio = "the rate"; break;
case "indietro":  				$messaggio = "back"; break;
case "avanti":  				$messaggio = "forward"; break;
case "del":  					$messaggio = "of"; break;
case "arrotondato a":  				$messaggio = "rounded to"; break;
case "Errore nei valori inseriti":  		$messaggio = "Error in inserted values"; break;
case "Assegnare automaticamente con le tariffe selezionate":	$messaggio = "Assign automatically with selected rates"; break;
case "Tariffe":  				$messaggio = "Rates"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "OK":  					$messaggio = "OK"; break;
case "Le settimane a cui applicare il costo":	$messaggio = "Weeks to apply the cost to"; break;
case "I giorni a cui applicare il costo":	$messaggio = "Days to apply the cost to"; break;
case "uno":  					$messaggio = "one"; break;
case "NO":  					$messaggio = "NO"; break;
case "SI":  					$messaggio = "YES"; break;
case "Costo aggiuntivo già esistente":  	$messaggio = "Extra cost already inserted"; break;
case "Tariffe incompatibili con il costo":  	$messaggio = "Rates that are incompatible with the cost"; break;
case "Tariffe incompatibili":  			$messaggio = "Incompatible rates"; break;
case "i prezzi della":  			$messaggio = "the prices to"; break;
case "dalla":  					$messaggio = "from"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "I prezzi della tariffa selezionata sono stati importati":	$messaggio = "The prices of the selected rate have been imported"; break;
case "importa":  				$messaggio = "import"; break;
case "se selezionato mantenere anche":  	$messaggio = "if selected keep also"; break;
case "Quando possibile assegna automaticamente se mancano":	$messaggio = "When possible assign automatically if"; break;
case "meno di":  				$messaggio = "less than"; break;
case "più di":  				$messaggio = "more than"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita":	$messaggio = "days are remaining from the starting date of the reservation when it is inserted"; break;
case "Quando possibile assegna automaticamente se si inseriscono":	$messaggio = "When possible assign automatically if"; break;
case "o più prenotazioni contemporaneamente":	$messaggio = "or more reservations are inserted contemporaneously"; break;
case "Modifica il costo":  			$messaggio = "Modify the cost"; break;
case "Inserisci un nuovo costo aggiuntivo chiamato":	$messaggio = "Insert a new extra cost called"; break;
case "importando le caratteristiche da":	$messaggio = "importing settings from"; break;
case "Sempre in periodi permessi":  		$messaggio = "Always in allowed periods"; break;
case "Prezzo dell'intera settimana":  		$messaggio = "Price of entire week"; break;
case "Prezzi dei giorni":  			$messaggio = "Prices of days"; break;
case "tra":  					$messaggio = "between"; break;
case "Beni dell'inventario da eliminare quando si inserisce il costo":	$messaggio = "Inventory items to delete when the cost is inserted"; break;
case "Nessuno":  				$messaggio = "No one"; break;
case "Beni selezionati":  			$messaggio = "Selected items"; break;
case "Aggiungi un bene":  			$messaggio = "Add an item"; break;
case "Elimina un bene":  			$messaggio = "Delete an item"; break;
case "elimina i beni dall'inventario del magazzino":	$messaggio = "Delete items from inventory of stockroom"; break;
case "Beni dell'inventario da eliminare":  	$messaggio = "Inventory items to delete"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Display grouped with similar costs from same category in insertion"; break;
case "Il tipo di applicazione della":  		$messaggio = "The enforcement type of"; break;
case "per persona":  				$messaggio = "per person"; break;
case "per settimana":  				$messaggio = "per week"; break;
case "per giorno":  				$messaggio = "per day"; break;
case "La caparra è errata":  			$messaggio = "The deposit is wrong"; break;
case "è":  					$messaggio = "is"; break;
case "il":  					$messaggio = "the"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Le commissioni normali sulla":  		$messaggio = "The normal commissions on"; break;
case "sono":  					$messaggio = "are"; break;
case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
case "Tasse":  					$messaggio = "Taxes"; break;
case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
case "della tariffa":  				$messaggio = "of the rate"; break;
case "Inserisci o modifica le tasse":  		$messaggio = "Insert or modify taxes"; break;
case "Le commissioni sono state modificate":  	$messaggio = "Commissions have been modified"; break;
case "Le commissioni sono errate":  		$messaggio = "Commissions are wrong"; break;
case "Le tasse sono state modificate":  	$messaggio = "Taxes have been modified"; break;
case "Le tasse sono errate":  			$messaggio = "Taxes are wrong"; break;
case "tutti i prezzi delle tariffe si intendono con tasse già incluse":	$messaggio = "All rate prices are considered as already including taxes"; break;
case "Inserisci o modifica le commissioni normali":  	$messaggio = "Insert or modify the normal commissions"; break;
case "Inserisci o modifica le commissioni in questo periodo":  	$messaggio = "Insert or modify commissions in this period"; break;
case "Sulla":  					$messaggio = "On"; break;
case "al giorno":  				$messaggio = "per day"; break;
case "alla settimana":  			$messaggio = "per week"; break;
case "il valore del costo si intente con tasse già incluse":	$messaggio = "the cost value is considered as already including taxes"; break;
case "Categoria":  				$messaggio = "Category"; break;
case "il prezzo della tariffa per i primi":  	$messaggio = "the rate price for the first"; break;
case "il prezzo della tariffa per le prime":  	$messaggio = "the rate price for the first"; break;
case "della":  					$messaggio = "of the"; break;
case "tariffa + sconto":  			$messaggio = "rate + discount"; break;
case "tariffa + sconto + costi agg.":  		$messaggio = "rate + discount + extra costs"; break;
case "Nome della":  				$messaggio = "Name of"; break;
case "Cambia":  				$messaggio = "Change"; break;
case "prezzo per settimana":  			$messaggio = "price per week"; break;
case "prezzo per giorno":  			$messaggio = "price per day"; break;
case "prezzo per persona per settimana":  	$messaggio = "price per person per week"; break;
case "prezzo per persona per giorno":  		$messaggio = "price per person per day"; break;
case "p":  					$messaggio = "p"; break;
case "parte fissa della tariffa":  		$messaggio = "fixed part of the rate"; break;
case "parte per una persona della tariffa":  	$messaggio = "one person part of the rate"; break;
case "Numero massimo":  			$messaggio = "Maximum number"; break;
case "0 se illimitato":  			$messaggio = "0 for unlimited"; break;
case "meno":  					$messaggio = "minus"; break;
case "il costo viene moltiplicato per zero se la somma è negativa":	$messaggio = "the cost will be multiplied by zero if the sum is negative"; break;
case "Combina con altri costi":			$messaggio = "Combine with other costs"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "combined costs are shown all together with category name and each one is inserted when possible"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Costi combinati":  			$messaggio = "Combined costs"; break;
case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Fast insertion of a new extra cost for"; break;
case "permanenza minima":  			$messaggio = "minimum stay"; break;
case "numero di bambini":  			$messaggio = "number of children"; break;
case "letto aggiuntivo":  			$messaggio = "extra bed"; break;
case "offerta speciale":  			$messaggio = "special offer"; break;
case "inserisci":  				$messaggio = "insert"; break;
case "Inserisci il costo aggiuntivo":  		$messaggio = "Insert the extra cost"; break;
case "Numero minimo di giorni":  		$messaggio = "Minimum number of days"; break;
case "Applicato alle tariffe":  		$messaggio = "Applied to rates"; break;
case "Periodi in cui viene applicato il costo":	$messaggio = "Periods in which the cost is applied"; break;
case "Valore dello sconto per ogni bambino":  	$messaggio = "Discount value for each child"; break;
case "del prezzo di una persona":  		$messaggio = "of the price for one person"; break;
case "solo per tariffe con prezzi a persona":  	$messaggio = "only for rates with per person prices"; break;
case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "with this cost the number of children must be included in the number of people too"; break;
case "Valore del letto aggiuntivo":  		$messaggio = "Value of the extra bed"; break;
case "Valore dello sconto":  			$messaggio = "Discount value"; break;
case "del prezzo totale":  			$messaggio = "of total price"; break;
case "Se la prenotazione ha una durata di":	$messaggio = "If the reservation length is"; break;
case "o più giorni":  				$messaggio = "days or more"; break;
case "Se":  					$messaggio = "If"; break;
case "Se si inseriscono":  			$messaggio = "If"; break;
case "Importa ora":  				$messaggio = "Import now"; break;
case "Importa sempre":  			$messaggio = "Always import"; break;
case "cancella":  				$messaggio = "delete"; break;
case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "The prices import has been deleted"; break;
case "al prezzo fisso":  			$messaggio = "to fixed price"; break;
case "al prezzo per persona":  			$messaggio = "to per person price"; break;
case "ad entrambi i prezzi":  			$messaggio = "to both prices"; break;
case "La tariffa":  				$messaggio = "The rate"; break;
case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exports its prices to other rates, it can't import prices permanently"; break;
case "tutte le tariffe":  			$messaggio = "all rates"; break;
case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
case "in tutti i periodi in modo predefinito":	$messaggio = "in all periods by default"; break;
case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "imports its prices from other rates, so can't export its prices"; break;
case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "already imports its prices from other rates in these periods, can't import other prices"; break;
case "modifica":  				$messaggio = "modify"; break;
case "In modo predefinito importa":  		$messaggio = "By default import"; break;
case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>