<?php

# To translate in other languages change the names of
# the variables on the right. Use only ascii letters,
# numbers and underscore: NO ACCENTS, NO SPACES

$trad_var['cognome'] = 'surname';
$trad_var['nome'] = 'name';
$trad_var['soprannome'] = 'nickname';
$trad_var['titolo'] = 'title';
$trad_var['sesso'] = 'sex';
$trad_var['cittadinanza'] = 'nationality';
$trad_var['data_nascita'] = 'birthdate';
$trad_var['citta_nascita'] = 'birthcity';
$trad_var['regione_nascita'] = 'birthregion';
$trad_var['nazione_nascita'] = 'birthnation';
$trad_var['citta'] = 'city';
$trad_var['regione'] = 'region';
$trad_var['nazione'] = 'nation';
$trad_var['via'] = 'street';
$trad_var['via2'] = 'street2';
$trad_var['numcivico'] = 'street_number';
$trad_var['cap'] = 'postal_code';
$trad_var['documento'] = 'document';
$trad_var['tipo_documento'] = 'document_type';
$trad_var['citta_documento'] = 'document_city';
$trad_var['regione_documento'] = 'document_region';
$trad_var['nazione_documento'] = 'document_nation';
$trad_var['scadenza_documento'] = 'document_expiry';
$trad_var['telefono'] = 'telephone';
$trad_var['telefono2'] = 'telephone2';
$trad_var['telefono3'] = 'telephone3';
$trad_var['fax'] = 'fax';
$trad_var['email'] = 'email';
$trad_var['codice_fiscale'] = 'fiscal_code';
$trad_var['partita_iva'] = 'vat_number';
$trad_var['num_persone'] = 'people_num';
$trad_var['n_letti_agg'] = 'extra_beds_num';
$trad_var['num_persone_tot'] = 'people_num_tot';
$trad_var['costo_tot'] = 'price_tot';
$trad_var['caparra'] = 'deposit';
$trad_var['resto_caparra'] = 'deposit_rest';
$trad_var['data_inizio'] = 'starting_date';
$trad_var['data_fine'] = 'ending_date';
$trad_var['num_periodi'] = 'periods_num';
$trad_var['orario_entrata_stimato'] = 'estimated_checkin_time';
$trad_var['nome_tariffa'] = 'rate_name';
$trad_var['costo_tariffa'] = 'rate_price';
$trad_var['costo_tariffa_p'] = 'rate_price_p';
$trad_var['costo_tariffa_giorno_array'] = 'rate_price_of_array_day';
$trad_var['costo_tariffa_giorno_array_p'] = 'rate_price_of_array_day_p';
$trad_var['sconto'] = 'discount';
$trad_var['commento'] = 'comment';
$trad_var['promemoria_entrata'] = 'checkin_reminder';
$trad_var['promemoria_uscita'] = 'checkout_reminder';
$trad_var['origine_prenotazione'] = 'reservation_origin';
$trad_var['unita_occupata'] = 'occupied_unit';
$trad_var['unita_assegnabili'] = 'units_list';
$trad_var['pagato'] = 'paid';
$trad_var['pagato_p'] = 'paid_p';
$trad_var['resto_da_pagare'] = 'rest_to_pay';
$trad_var['resto_da_pagare_p'] = 'rest_to_pay_p';
$trad_var['commissioni'] = 'commissions';
$trad_var['commissioni_p'] = 'commissions_p';
$trad_var['resto_commissioni'] = 'commissions_rest';
$trad_var['resto_commissioni_p'] = 'commissions_rest_p';
$trad_var['percentuale_tasse_tariffa'] = 'rate_taxes_percentage';
$trad_var['tasse_tariffa'] = 'rate_taxes';
$trad_var['tasse_tariffa_p'] = 'rate_taxes_p';
$trad_var['costo_tariffa_senza_tasse'] = 'rate_price_without_taxes';
$trad_var['costo_tariffa_senza_tasse_p'] = 'rate_price_without_taxes_p';
$trad_var['tasse_sconto'] = 'discount_taxes';
$trad_var['tasse_sconto_p'] = 'discount_taxes_p';
$trad_var['sconto_senza_tasse'] = 'discount_without_taxes';
$trad_var['sconto_senza_tasse_p'] = 'discount_without_taxes_p';
$trad_var['nome_costo_agg'] = 'extra_cost_name';
$trad_var['valore_costo_agg'] = 'extra_cost_value';
$trad_var['valore_costo_agg_p'] = 'extra_cost_value_p';
$trad_var['giorni_costo_agg'] = 'extra_cost_days';
$trad_var['valore_tutti_costi_agg'] = 'value_all_extra_costs';
$trad_var['valore_tutti_costi_agg_p'] = 'value_all_extra_costs_p';
$trad_var['tutti_i_costi_agg'] = 'all_extra_costs';
$trad_var['nome_costo_agg_sel'] = 'sel_extra_cost_name';
$trad_var['valore_costo_agg_sel'] = 'sel_extra_cost_value';
$trad_var['oggi'] = 'today';
$trad_var['costo_tot_p'] = 'price_tot_p';
$trad_var['caparra_p'] = 'deposit_p';
$trad_var['resto_caparra_p'] = 'deposit_rest_p';
$trad_var['tutti_i_costi_agg_p'] = 'all_extra_costs_p';
$trad_var['valore_costo_agg_sel_p'] = 'sel_extra_cost_value_p';
$trad_var['percentuale_tasse_costo_agg'] = 'extra_cost_taxes_percentage';
$trad_var['tasse_costo_agg'] = 'extra_cost_taxes';
$trad_var['tasse_costo_agg_p'] = 'extra_cost_taxes_p';
$trad_var['valore_costo_agg_senza_tasse'] = 'extra_cost_value_without_taxes';
$trad_var['valore_costo_agg_senza_tasse_p'] = 'extra_cost_value_without_taxes_p';
$trad_var['moltiplica_max_costo_agg'] = 'extra_cost_max_multiply';
$trad_var['moltiplica_max_costo_agg_sel'] = 'sel_extra_cost_max_multiply';
$trad_var['data_inserimento_costo_agg'] = 'extra_cost_insertion_date';
$trad_var['utente_inserimento_costo_agg'] = 'extra_cost_insertion_user';
$trad_var['percentuale_tasse_costo_agg_sel'] = 'sel_extra_cost_taxes_percentage';
$trad_var['tasse_costo_agg_sel'] = 'sel_extra_cost_taxes';
$trad_var['tasse_costo_agg_sel_p'] = 'sel_extra_cost_taxes_p';
$trad_var['sconto_p'] = 'discount_p';
$trad_var['num_costi_aggiuntivi'] = 'extra_costs_number';
$trad_var['valore_pagamento'] = 'payment_value';
$trad_var['valore_pagamento_p'] = 'payment_value_p';
$trad_var['data_pagamento'] = 'payment_date';
$trad_var['utente_pagamento'] = 'payment_user';
$trad_var['metodo_pagamento'] = 'payment_method';
$trad_var['tutti_i_pagamenti'] = 'all_payments';
$trad_var['tutti_i_pagamenti_p'] = 'all_payments_p';
$trad_var['valore_ultimo_pagamento'] = 'last_payment_value';
$trad_var['valore_ultimo_pagamento_p'] = 'last_payment_value_p';
$trad_var['data_ultimo_pagamento'] = 'last_payment_date';
$trad_var['utente_ultimo_pagamento'] = 'last_payment_user';
$trad_var['metodo_ultimo_pagamento'] = 'last_payment_method';
$trad_var['num_pagamenti'] = 'payments_number';
$trad_var['numero_prenotazione'] = 'reservation_number';
$trad_var['numero_ripetizione_prenotazioni'] = 'reservations_repetition_number';
$trad_var['codice_prenotazione'] = 'reservation_code';
$trad_var['data_inserimento_prenotazione'] = 'reservation_insertion_date';
$trad_var['utente_inserimento_prenotazione'] = 'reservation_insertion_user';
$trad_var['numero_progressivo_documento'] = 'document_progressive_number';
$trad_var['document_progressive_number'] = 'contract_progressive_number';
$trad_var['document_progressive_number'] = 'numero_progressivo_contratto';
$trad_var['codice_cittadinanza'] = 'nationality_code';
$trad_var['codice_nazione_nascita'] = 'birthnation_code';
$trad_var['codice_regione_nascita'] = 'birthregion_code';
$trad_var['codice_citta_nascita'] = 'birthcity_code';
$trad_var['codice_nazione'] = 'nation_code';
$trad_var['codice_regione'] = 'region_code';
$trad_var['codice_citta'] = 'city_code';
$trad_var['codice_tipo_documento'] = 'document_type_code';
$trad_var['codice_citta_documento'] = 'document_city_code';
$trad_var['codice_regione_documento'] = 'document_region_code';
$trad_var['codice_nazione_documento'] = 'document_nation_code';
$trad_var['codice2_cittadinanza'] = 'nationality_code2';
$trad_var['codice2_nazione_nascita'] = 'birthnation_code2';
$trad_var['codice2_regione_nascita'] = 'birthregion_code2';
$trad_var['codice2_citta_nascita'] = 'birthcity_code2';
$trad_var['codice2_nazione'] = 'nation_code2';
$trad_var['codice2_regione'] = 'region_code2';
$trad_var['codice2_citta'] = 'city_code2';
$trad_var['codice2_tipo_documento'] = 'document_type_code2';
$trad_var['codice2_citta_documento'] = 'document_city_code2';
$trad_var['codice2_regione_documento'] = 'document_region_code2';
$trad_var['codice2_nazione_documento'] = 'document_nation_code2';
$trad_var['codice3_cittadinanza'] = 'nationality_code3';
$trad_var['codice3_nazione_nascita'] = 'birthnation_code3';
$trad_var['codice3_regione_nascita'] = 'birthregion_code3';
$trad_var['codice3_citta_nascita'] = 'birthcity_code3';
$trad_var['codice3_nazione'] = 'nation_code3';
$trad_var['codice3_regione'] = 'region_code3';
$trad_var['codice3_citta'] = 'city_code3';
$trad_var['codice3_tipo_documento'] = 'document_type_code3';
$trad_var['codice3_citta_documento'] = 'document_city_code3';
$trad_var['codice3_regione_documento'] = 'document_region_code3';
$trad_var['codice3_nazione_documento'] = 'document_nation_code3';
$trad_var['num_ospiti_tot'] = 'guests_tot_num';
$trad_var['numero_ospite'] = 'number_guest';
$trad_var['cognome_ospite'] = 'surname_guest';
$trad_var['nome_ospite'] = 'name_guest';
$trad_var['soprannome_ospite'] = 'nickname_guest';
$trad_var['titolo_ospite'] = 'title_guest';
$trad_var['sesso_ospite'] = 'sex_guest';
$trad_var['cittadinanza_ospite'] = 'nationality_guest';
$trad_var['parentela_ospite'] = 'relatedness_guest';
$trad_var['data_nascita_ospite'] = 'birthdate_guest';
$trad_var['citta_nascita_ospite'] = 'birthcity_guest';
$trad_var['regione_nascita_ospite'] = 'birthregion_guest';
$trad_var['nazione_nascita_ospite'] = 'birthnation_guest';
$trad_var['citta_ospite'] = 'city_guest';
$trad_var['regione_ospite'] = 'region_guest';
$trad_var['nazione_ospite'] = 'nation_guest';
$trad_var['via_ospite'] = 'street_guest';
$trad_var['via2_ospite'] = 'street2_guest';
$trad_var['numcivico_ospite'] = 'street_number_guest';
$trad_var['cap_ospite'] = 'postal_code_guest';
$trad_var['documento_ospite'] = 'document_guest';
$trad_var['tipo_documento_ospite'] = 'document_type_guest';
$trad_var['citta_documento_ospite'] = 'document_city_guest';
$trad_var['regione_documento_ospite'] = 'document_region_guest';
$trad_var['nazione_documento_ospite'] = 'document_nation_guest';
$trad_var['scadenza_documento_ospite'] = 'document_expiry_guest';
$trad_var['telefono_ospite'] = 'telephone_guest';
$trad_var['telefono2_ospite'] = 'telephone2_guest';
$trad_var['telefono3_ospite'] = 'telephone3_guest';
$trad_var['fax_ospite'] = 'fax_guest';
$trad_var['email_ospite'] = 'email_guest';
$trad_var['codice_fiscale_ospite'] = 'fiscal_code_guest';
$trad_var['partita_iva_ospite'] = 'vat_number_guest';
$trad_var['codice_cittadinanza_ospite'] = 'nationality_code_guest';
$trad_var['codice_parentela_ospite'] = 'relatedness_code_guest';
$trad_var['codice_nazione_nascita_ospite'] = 'birthnation_code_guest';
$trad_var['codice_regione_nascita_ospite'] = 'birthregion_code_guest';
$trad_var['codice_citta_nascita_ospite'] = 'birthcity_code_guest';
$trad_var['codice_nazione_ospite'] = 'nation_code_guest';
$trad_var['codice_regione_ospite'] = 'region_code_guest';
$trad_var['codice_citta_ospite'] = 'city_code_guest';
$trad_var['codice_tipo_documento_ospite'] = 'document_type_code_guest';
$trad_var['codice_citta_documento_ospite'] = 'document_city_code_guest';
$trad_var['codice_regione_documento_ospite'] = 'document_region_code_guest';
$trad_var['codice_nazione_documento_ospite'] = 'document_nation_code_guest';
$trad_var['codice2_cittadinanza_ospite'] = 'nationality_code2_guest';
$trad_var['codice2_parentela_ospite'] = 'relatedness_code2_guest';
$trad_var['codice2_nazione_nascita_ospite'] = 'birthnation_code2_guest';
$trad_var['codice2_regione_nascita_ospite'] = 'birthregion_code2_guest';
$trad_var['codice2_citta_nascita_ospite'] = 'birthcity_code2_guest';
$trad_var['codice2_nazione_ospite'] = 'nation_code2_guest';
$trad_var['codice2_regione_ospite'] = 'region_code2_guest';
$trad_var['codice2_citta_ospite'] = 'city_code2_guest';
$trad_var['codice2_tipo_documento_ospite'] = 'document_type_code2_guest';
$trad_var['codice2_citta_documento_ospite'] = 'document_city_code2_guest';
$trad_var['codice2_regione_documento_ospite'] = 'document_region_code2_guest';
$trad_var['codice2_nazione_documento_ospite'] = 'document_nation_code2_guest';
$trad_var['codice3_cittadinanza_ospite'] = 'nationality_code3_guest';
$trad_var['codice3_parentela_ospite'] = 'relatedness_code3_guest';
$trad_var['codice3_nazione_nascita_ospite'] = 'birthnation_code3_guest';
$trad_var['codice3_regione_nascita_ospite'] = 'birthregion_code3_guest';
$trad_var['codice3_citta_nascita_ospite'] = 'birthcity_code3_guest';
$trad_var['codice3_nazione_ospite'] = 'nation_code3_guest';
$trad_var['codice3_regione_ospite'] = 'region_code3_guest';
$trad_var['codice3_citta_ospite'] = 'city_code3_guest';
$trad_var['codice3_tipo_documento_ospite'] = 'document_type_code3_guest';
$trad_var['codice3_citta_documento_ospite'] = 'document_city_code3_guest';
$trad_var['codice3_regione_documento_ospite'] = 'document_region_code3_guest';
$trad_var['codice3_nazione_documento_ospite'] = 'document_nation_code3_guest';
$trad_var['nome_unita'] = 'unit_name';
$trad_var['casa_unita'] = 'unit_house';
$trad_var['piano_unita'] = 'unit_floor';
$trad_var['capacita_unita'] = 'unit_capacity';
$trad_var['priorita_unita'] = 'unit_priority';
$trad_var['num_unita'] = 'units_num';
$trad_var['costo_tot_somma_ripetizioni'] = 'price_tot_repetitions_sum';
$trad_var['costo_tot_somma_ripetizioni_p'] = 'price_tot_repetitions_sum_p';
$trad_var['caparra_somma_ripetizioni'] = 'deposit_repetitions_sum';
$trad_var['caparra_somma_ripetizioni_p'] = 'deposit_repetitions_sum_p';
$trad_var['resto_caparra_somma_ripetizioni'] = 'deposit_rest_repetitions_sum';
$trad_var['resto_caparra_somma_ripetizioni_p'] = 'deposit_rest_repetitions_sum_p';
$trad_var['pagato_somma_ripetizioni'] = 'paid_repetitions_sum';
$trad_var['pagato_somma_ripetizioni_p'] = 'paid_repetitions_sum_p';
$trad_var['resto_da_pagare_somma_ripetizioni'] = 'rest_to_pay_repetitions_sum';
$trad_var['resto_da_pagare_somma_ripetizioni_p'] = 'rest_to_pay_repetitions_sum_p';
$trad_var['num_persone_tot_somma_ripetizioni'] = 'people_num_tot_repetitions_sum';
$trad_var['data_inizio_selezione'] = 'selection_starting_date';
$trad_var['data_fine_selezione'] = 'selection_ending_date';
$trad_var['utente_attuale'] = 'current_user';
$trad_var['nome_struttura'] = 'structure_name';
$trad_var['tipo_struttura'] = 'structure_type';
$trad_var['email_struttura'] = 'structure_email';
$trad_var['ragione_sociale_struttura'] = 'structure_company_name';
$trad_var['sito_web_struttura'] = 'structure_website';
$trad_var['nome_contatto_struttura'] = 'structure_contact_name';
$trad_var['nazione_struttura'] = 'structure_nation';
$trad_var['comune_struttura'] = 'structure_city';
$trad_var['indirizzo_struttura'] = 'structure_address';
$trad_var['CAP_struttura'] = 'structure_postal_code';
$trad_var['telefono_struttura'] = 'structure_telephone';
$trad_var['fax_struttura'] = 'structure_fax';
$trad_var['codice_fiscale_struttura'] = 'structure_fiscal_code';
$trad_var['partita_iva_struttura'] = 'structure_vat_number';
$trad_var['numero_stelle_struttura'] = 'structure_stars_number';
$trad_var['logo_struttura'] = 'structure_logo';
$trad_var['nome_valuta'] = 'currency_name';
$trad_var['testo_email_richiesta'] = 'enquiry_email_text';
$trad_var['testo_quotato_email_richiesta'] = 'enquiry_email_quoted_text';
$trad_var['url_base_pagine_web'] = 'base_url_for_webpages';
$trad_var['ritorno_a_capo'] = 'carriage_return';
$trad_var['avanzamento_riga'] = 'new_line';
$trad_var['valore_nullo'] = 'null_value';
$trad_var['errore_ripetizione'] = 'repetition_error';
$trad_var['messaggio_di_errore'] = 'error_message';
$trad_var['codice_lingua'] = 'language_code';
$trad_var['email_gia_inviata'] = 'email_already_sent';
$trad_var['commento_personalizzato'] = 'custom_comment';
$trad_var['campo_personalizzato'] = 'custom_field';


?>