<?php

$lista_documentiid = "";
$cod_documentiid = "";
$cod2_documentiid = "";
$cod3_documentiid = "";

#$lista_documentiid[0] = "Passport";
#$cod_documentiid[0] = "001";
#$lista_documentiid[1] = "National ID";
#$cod_documentiid[1] = "002";

?>