<?php

switch ($messaggio) {

case "Modifica o cancella la prenotazione":	$messaggio = "Modify or delete reservation"; break;
case "Prenotazione a nome di":  		$messaggio = "Reservation for"; break;
case "nato il":  				$messaggio = "born the"; break;
case "nata il":  				$messaggio = "born the"; break;
case "e":  					$messaggio = "and"; break;
case "CAP":  					$messaggio = "postal code"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "2º telefono":  				$messaggio = "2nd telephone"; break;
case "3º telefono":  				$messaggio = "3rd telephone"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modify client's data"; break;
case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":	$messaggio = "The reservation is from previus year, you will be able to modify only the final date"; break;
case "settimane":  				$messaggio = "weeks"; break;
case "giorni":  				$messaggio = "days"; break;
case "dal":  					$messaggio = "from"; break;
case "al":  					$messaggio = "to"; break;
case "cambia in":  				$messaggio = "change to"; break;
case "in":  					$messaggio = "in"; break;
case "Nº di piano":  				$messaggio = "Floor number"; break;
case "e/o di casa":  				$messaggio = "and/or house number"; break;
case "e/o di persone":  			$messaggio = "and/or people number"; break;
case "Nº di persone":  				$messaggio = "Number of people"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Cancella il commento":  			$messaggio = "Delete comment"; break;
case "Tipo di tariffa":  			$messaggio = "Rate type"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "Sconto":  				$messaggio = "Discount"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "resto":  					$messaggio = "rest"; break;
case "Ricalcola la caparra in base alla nuova tariffa":	$messaggio = "Calculate again the deposit from the new rate"; break;
case "Costo aggiuntivo unico":  		$messaggio = "Single extra cost"; break;
case "moltiplicato per":  			$messaggio = "multiplied by"; break;
case "Costo aggiuntivo settimanale":  		$messaggio = "Weekly extra cost"; break;
case "Costo aggiuntivo giornaliero":  		$messaggio = "Daily extra cost"; break;
case "per":  					$messaggio = "for"; break;
case "settimane moltiplicato per":  		$messaggio = "weeks multiplied by"; break;
case "giorni moltiplicato per":  		$messaggio = "days multiplied by"; break;
case "della tariffa moltiplicato per":  	$messaggio = "of the rate multiplied by"; break;
case "Prenotazione confermata":  		$messaggio = "Reservation confirmed"; break;
case "Totale da pagare":  			$messaggio = "Total to be paid"; break;
case "Pagato":  				$messaggio = "Paid"; break;
case "aggiungi":  				$messaggio = "add"; break;
case "pagato tutto":  				$messaggio = "all paid"; break;
case "caparra ":  				$messaggio = "deposit paid"; break;
case "Ancora da pagare":  			$messaggio = "Still to be paid"; break;
case "Nuovo costo aggiuntivo unico":  		$messaggio = "New single extra cost"; break;
case "di":  					$messaggio = "of"; break;
case "da moltiplicare per":  			$messaggio = "to multiply by"; break;
case "letto":  					$messaggio = "bed"; break;
case "straordinario":  				$messaggio = "extraordinary"; break;
case "Nuovo costo aggiuntivo settimanale":	$messaggio = "New weekly extra cost"; break;
case "Nuovo costo aggiuntivo giornaliero":  	$messaggio = "New daily extra cost"; break;
case "nº di settimane da applicare":  		$messaggio = "number of weeks to apply"; break;
case "nº di giorni da applicare":  		$messaggio = "number of days to apply"; break;
case "non specificato":  			$messaggio = "not available"; break;
case "Modifica la prenotazione":  		$messaggio = "Modify reservation"; break;
case "Cancella la prenotazione":  		$messaggio = "Delete reservation"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "SI":  					$messaggio = "YES"; break;
case "cancella anche ciò che era stato pagato":	$messaggio = "delete also what was paid"; break;
case "NO":  					$messaggio = "NO"; break;
case "La prenotazione":  			$messaggio = "Reservation"; break;
case "era già stata cancellata":  		$messaggio = "has already been deleted"; break;
case "Prenotazione":  				$messaggio = "Reservation"; break;
case "cancellata":  				$messaggio = "deleted"; break;
case "<b>non è stata cancellata</b> perchè è stata modificata nel frattempo":	$messaggio = "<b>has not been deleted</b> because has been modified meanwhile"; break;
case "Si è sicuri di voler <b>cancellare</b> la prenotazione":	$messaggio = "Are you sure you want to <b>delete</b> reservation"; break;
case "Si è sicuri di voler <b>cancellare</b> le prenotazioni":	$messaggio = "Are you sure you want to <b>delete</b> reservations"; break;
case "La data iniziale verrà cambiata dal":  	$messaggio = "The beginning date will be changed from"; break;
case "al":  					$messaggio = "to"; break;
case "La data finale verrà cambiata dal":  	$messaggio = "The final date will be changed from"; break;
case "Le <div style=\"display: inline; color: red;\">date</div> sono <b>sbagliate</b>":	$messaggio = "The <div style=\"display: inline; color: red;\">dates</div> are <b>wrong</b>"; break;
case "°</b> piano":  				$messaggio = "</b>"; break;
case "della casa":  				$messaggio = "of house"; break;
case "con massimo numero di occupanti":  	$messaggio = "with maximum number of hosted people"; break;
case "a":  					$messaggio = "to"; break;
case "Il numero delle persone verrà cambiato da":	$messaggio = "The number of people will be changed from"; break;
case "persone":  				$messaggio = "people"; break;
case "è stata <b>cancellata</b>":  		$messaggio = "has been <b>deleted</b>"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that must be done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "The reservation from"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "La prenotazione verrà":  			$messaggio = "The reservation will be"; break;
case "mantenuta":  				$messaggio = "left"; break;
case "spostata":  				$messaggio = "moved"; break;
case "La tariffa":  				$messaggio = "The rate"; break;
case "non esiste più, cambiala prima di aggiornare":	$messaggio = "doesn't exist anymore, change it before updating"; break;
case "<b>Non</b> è stato ancora inserito il prezzo della":	$messaggio = "You must <b>still</b> insert the price of"; break;
case "per la settimana dal":  			$messaggio = "for the week from"; break;
case "per il giorno dal":  			$messaggio = "for the day from"; break;
case "La tariffa verrà cambiata da":  		$messaggio = "The rate will be changed from"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "Il costo aggiuntivo unico":  		$messaggio = "The sigle extra cost"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "The weekly extra cost"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "The daily extra cost"; break;
case "non può essere moltiplicato per":  	$messaggio = "can't be multiplied by"; break;
case "verrà moltiplicato per":  		$messaggio = "will be multiplied by"; break;
case "prima era":  				$messaggio = "it was"; break;
case "Le settimane del costo aggiuntivo":  	$messaggio = "The weeks of the extra cost"; break;
case "I giorni del costo aggiuntivo":  		$messaggio = "The days of the extra cost"; break;
case "<b>superano</b> la durata della prenotazione":	$messaggio = "<b>exceed</b> the duration of the reservation"; break;
case "verranno cabiate da":  			$messaggio = "will be changed from"; break;
case "verranno cabiati da":  			$messaggio = "will be changed from"; break;
case "verranno cabiate":  			$messaggio = "will be changed"; break;
case "verranno cabiati":  			$messaggio = "will be changed"; break;
case "<b>non</b> verranno cambiate":  		$messaggio = "will <b>not</b> be changed"; break;
case "<b>non</b> verranno cambiati":  		$messaggio = "will <b>not</b> be changed"; break;
case "su":  					$messaggio = "on"; break;
case "Il prezzo del costo aggiuntivo":  	$messaggio = "The price of the extra cost"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "I dati del costo aggiuntivo <b>straordinario</b> sono <div style=\"display: inline; color: red;\">errati o mancanti</div>":	$messaggio = "Data for the <b>extraordinary</b> extra cost are <div style=\"display: inline; color: red;\">wrong or lacking</div>"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "come letto aggiuntivo":  			$messaggio = "as extra bed"; break;
case "Le settimane del nuovo costo aggiuntivo":	$messaggio = "The weeks of the new extra cost"; break;
case "I giorni del nuovo costo aggiuntivo":  	$messaggio = "The days of the new extra cost"; break;
case "Lo <div style=\"display: inline; color: red;\">sconto</div> inserito":	$messaggio = "The inserted <div style=\"display: inline; color: red;\">discount</div>"; break;
case "supera il costo totale senza sconto":  	$messaggio = "is bigger than the complete cost without discount"; break;
case "Lo sconto verrà cambiato da":  		$messaggio = "The discount will be changed from"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div> inserita":	$messaggio = "The inserted <div style=\"display: inline; color: red;\">deposit</div>"; break;
case "supera il costo totale":  		$messaggio = "is bigger than the complete cost"; break;
case "La caparra verrà cambiata da":  		$messaggio = "The deposit will be changed from"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div>":  	$messaggio = "The <div style=\"display: inline; color: red;\">deposit</div>"; break;
case "supera il nuovo costo totale":  		$messaggio = "is bigger than the new complete cost"; break;
case "La cifra <div style=\"display: inline; color: red;\">pagata</div> inserita":	$messaggio = "The inserted <div style=\"display: inline; color: red;\">paid</div> amount"; break;
case "I soldi pagati verranno cambiati da":  		$messaggio = "The paid money will be changed from"; break;
case "verrà <b>confermata</b>":  			$messaggio = "will be <b>confirmed</b>"; break;
case "Verrà tolta la <b>conferma</b> alla prenotazione":	$messaggio = "The <b>confirmation</b> will be removed from reservation"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "The <b>comment</b> will be changed"; break;
case "Il <b>commento</b> verrà cancellato":  	$messaggio = "The <b>comment</b> will be deleted"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "modificata":  				$messaggio = "modified"; break;
case "<b>non è stata modificata</b> perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "<b>has not been modified</b> because the reservations table has changed meanwhile"; break;
case "verrà cambiato da":  			$messaggio = "will be changed from"; break;
case "con costo agg.":  			$messaggio = "with extra cost"; break;
case "Cliente":  				$messaggio = "Client"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no periods in assignment rule 1 in which is allowed to insert reservations for user"; break;
case "Prenotazione non confermata":  		$messaggio = "Reservation not confirmed"; break;
case "Inserita dall'utente":  			$messaggio = "Inserted by user"; break;
case "Si considererà l'utente":  		$messaggio = "User"; break;
case "come colui che ha inserito la prenotazione":	$messaggio = "will be considered as the one who inserted the reservation"; break;
case "Non si possono inserire altri costi":  	$messaggio = "You can't insert more costs"; break;
case "in questo periodo, già":  		$messaggio = "in this period, already"; break;
case "presenti":  				$messaggio = "present"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "The extra cost"; break;
case "in questo periodo":  			$messaggio = "can't be inserted in this period"; break;
case "Settimane":  				$messaggio = "Weeks"; break;
case "Giorni":  				$messaggio = "Days"; break;
case "mostra":  				$messaggio = "show"; break;
case "nascondi":  				$messaggio = "hide"; break;
case "numeri diversi":  			$messaggio = "different numbers"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "You can't insert more than one extra cost with percentage on total price per reservation"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "The number of people must be inserted for the extra cost"; break;
case "Non si possono inserire altri costi":  	$messaggio = "You can't insert more costs"; break;
case "in questo periodo, già":  		$messaggio = "in this period, already"; break;
case "presenti":  				$messaggio = "present"; break;
case "della tariffa":  				$messaggio = "of rate"; break;
case "del totale":  				$messaggio = "of total"; break;
case "della caparra":  				$messaggio = "of deposit"; break;
case "del resto caparra":  			$messaggio = "of deposit rest"; break;
case "di base":  				$messaggio = "of base"; break;
case "totale":  				$messaggio = "total"; break;
case "registra entrata":  			$messaggio = "check-in"; break;
case "cancella entrata":  			$messaggio = "cancel check-in"; break;
case "registra uscita":  			$messaggio = "check-out"; break;
case "cancella uscita":  			$messaggio = "cancel check-out"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in already registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata non registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-in not registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out already registered"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita non registrato, registrare prima l'entrata":	$messaggio = "<div style=\"display: inline; color: red;\">Warning</div>: check-out not registered, register check-in before"; break;
case "Metodo pagamento caparra":  		$messaggio = "Deposit payment method"; break;
case "Il metodo di pagamento della caparra verrà cambiato a":	$messaggio = "Deposit payment method will be changed to"; break;
case "Metodo di pagamento":  			$messaggio = "Payment method"; break;
case "metodo di pagamento":  			$messaggio = "payment method"; break;
case "Normalmente le prenotazioni già iniziate e quelle che hanno registrato l'orario di entrata non vengono spostate":	$messaggio = "Normally already begun reservations and the ones that have done check-in are not moved"; break;
case "Prova di nuovo":  			$messaggio = "Try again"; break;
case "muovendo anche le prenotazioni iniziate dopo il":	$messaggio = "moving also reservations begun after"; break;
case "considerate fisse perchè <div style=\"display: inline; color: red;\">ad oggi già iniziate</div>":	$messaggio = "considered fixed because <div style=\"display: inline; color: red;\">as of today already begun</div>"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "is incompatible with selected rate"; break;
case "non può essere applicato":  		$messaggio = "can't be applied"; break;
case "Non si può cambiare l'assegnazione di una prenotazione che si trova <div style=\"display: inline; color: red;\">tra due anni</div>":	$messaggio = "You can't change the assignment of a reservation that is <div style=\"display: inline; color: red;\">between two years</div>"; break;
case "Modifica nell'anno precedente":  		$messaggio = "Modify in previous year"; break;
case "Orario entrata stimato":  		$messaggio = "Estimated check-in time"; break;
case "L'orario stimato di entrata verrà cambiato a":	$messaggio = "The estimated check-in time will be changed to"; break;
case "Codice prenotazione":  			$messaggio = "Reservation code"; break;
case "rigenera":  				$messaggio = "regenerate"; break;
case "Non si è potuto spostare la prenotazione per la registrazione dell'entrata":	$messaggio = "It was not possible moving the reservation due to the checkin"; break;
case "Cambia cliente":  			$messaggio = "Change client"; break;
case "Nuovo titolare della prenotazione":	$messaggio = "New titular of the reservation"; break;
case "cliente numero":  			$messaggio = "client number"; break;
case "Il titolare della prenotazione":  	$messaggio = "The titular of reservation"; break;
case "Il titolare delle prenotazioni":  	$messaggio = "The titular of reservations"; break;
case "Cliente non trovato":  			$messaggio = "Client not found"; break;
case "Annulla":  				$messaggio = "Cancel"; break;
case "Prenotazioni vicine":  			$messaggio = "Nearby reservations"; break;
case "numero":  				$messaggio = "number"; break;
case "La prenotazione numero":  		$messaggio = "The reservation number"; break;
case "non esiste":  				$messaggio = "does not exist"; break;
case "Ospiti della prenotazione":  		$messaggio = "Reservation guests"; break;
case "Modifica gli ospiti":  			$messaggio = "Modify guests"; break;
case "nato":  					$messaggio = "born"; break;
case "nata":  					$messaggio = "born"; break;
case "il":  					$messaggio = "the"; break;
case " a":  					$messaggio = " in"; break;
case "scade":  					$messaggio = "expires"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Origine":  				$messaggio = "Origin"; break;
case "L'origine della prenotazione verrà cambiata a":	$messaggio = "The reservation origin will be changed to"; break;
case "Modifica o cancella le prenotazioni":  	$messaggio = "Modify or delete reservations"; break;
case "Modifica le prenotazioni":  		$messaggio = "Modify reservations"; break;
case "Cancella le prenotazioni":  		$messaggio = "Delete reservations"; break;
case "della prenotazione":  			$messaggio = "from reservation"; break;
case "per la prenotazione":  			$messaggio = "for reservation"; break;
case "Data inserimento":  			$messaggio = "Insertion date"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
case "<b><big>i</big></b>":  			$messaggio = "<b><big>i</big></b>"; break;
case "pren.":  					$messaggio = "res."; break;
case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per la tariffa selezionata":	$messaggio = "The <span class=\"colred\">number of people</span> must be inserted for the selected rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "i beni richiesti alla registrazione dell'entrata":	$messaggio = "items needed by check-in"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Ricalcola le commissioni in base alla nuova tariffa":	$messaggio = "Calculate again the commissions from the new rate"; break;
case "Le commissioni verranno cambiate da":	$messaggio = "Commissions will be changed from"; break;
case "tasse":  					$messaggio = "taxes"; break;
case "Il prezzo totale cambierà da":  		$messaggio = "The total price will change from"; break;
case "saldo di":  				$messaggio = "balance"; break;
case "Altre prenotazioni dello stesso cliente nello stesso periodo":	$messaggio = "Other reservations from the same client in the same period"; break;
case "tutte":  					$messaggio = "all"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "vi sono altre prenotazioni dello stesso cliente nello stesso periodo che ancora non sono state pagate":	$messaggio = "there are other reservations from the same client in the same period that have not been paid yet"; break;
case "Il saldo totale pagato sarà di":  	$messaggio = "The total balance of money paid will be"; break;
case "ln.":  					$messaggio = "ln."; break;
case "della tariffa fissa":  			$messaggio = "of fixed rate"; break;
case "di una persona":  			$messaggio = "of one person"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "Nuovo costo aggiuntivo":  		$messaggio = "New extra cost"; break;
case "aggiungi promemoria per l'entrata":  	$messaggio = "add a reminder for checkin"; break;
case "aggiungi promemoria per l'uscita":  	$messaggio = "add a reminder for checkout"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio = "A <b>reminder</b> for <em>checkin</em> will be added"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "A <b>reminder</b> for <em>checkout</em> will be added"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in questo periodo":	$messaggio = "The requested <b>rate</b> is <span class=\"colred\">closed</span> in this period"; break;
case "cambia il commento":  			$messaggio = "change comment"; break;
case "Il commento":  				$messaggio = "Comment"; break;
case "verrà cambiato":  			$messaggio = "will be changed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>