<?php

switch ($messaggio) {

case "Configura e personalizza HotelDruid":	$messaggio = "Configurar y personalizar HotelDruid"; break;
case "Scegli la lingua":  			$messaggio = "Escoger el idioma"; break;
case "cambia la lingua":  			$messaggio = "cambiar el idioma"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Tabla con todas las reservas"; break;
case "Cambia la valuta":  			$messaggio = "Cambiar la divisa"; break;
case "Scegli le colonne da far comparire":  	$messaggio = "Escoger las columnas que aparecerán"; break;
case "n° di settimane":  			$messaggio = "n° de semanas"; break;
case "n° di giorni":  				$messaggio = "n° de días"; break;
case "caparra":  				$messaggio = "fianza"; break;
case "pagato":  				$messaggio = "pagado"; break;
case "resto da pagare":  			$messaggio = "resto a pagar"; break;
case "n° di persone":  				$messaggio = "n° de personas"; break;
case "commento":  				$messaggio = "comentario"; break;
case "costo aggiuntivo unico":  		$messaggio = "coste añadido único"; break;
case "abbreviazione":  				$messaggio = "abreviación"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "coste añadido semanal"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "coste añadido diario"; break;
case "cambia le colonne":  			$messaggio = "cambiar las columnas"; break;
case "Tabelle dei mesi":  			$messaggio = "Tabla de los meses"; break;
case "Numero di tabelle del 2° tipo":  		$messaggio = "Número de tablas del 2° tipo"; break;
case "cambia":  				$messaggio = "cambiar"; break;
case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
case "a":  					$messaggio = "a"; break;
case "La lingua è stata cambiata":  		$messaggio = "El idioma ha sido cambiado"; break;
case "La valuta è stata cambiata":  		$messaggio = "La divisa ha sido cambiada"; break;
case "Le colonne sono state cambiate":  	$messaggio = "Las columnas han sido cambiadas"; break;
case "Il numero di tabelle è stato cambiato":  	$messaggio = "El númenro de tablas ha sido cambiado"; break;
case "Documenti":  				$messaggio = "Documentos"; break;
case "documento":  				$messaggio = "documento"; break;
case "cambia i nomi dei documenti":  		$messaggio = "cambiar los nombres de los documentos"; break;
case "I nomi dei documenti sono stati cambiati":	$messaggio = "Los nombres de los documentos han sido cambiados"; break;
case "Formato di visualizzazione dei soldi":  	$messaggio = "Formato de visualización de monedas"; break;
case "cambia formato":  			$messaggio = "cambiar formato"; break;
case "Il formato di visualizzazione dei soldi è stato cambiato":	$messaggio = "el formato de visualización de monedas ha sido cambiado"; break;
case "Le date sono sbagliate":  		$messaggio = "Las fechas están equivocadas"; break;
case "Le date dei menù a tendina sono state cambiate":	$messaggio = "Las fechas en las listas han sido cambiadas"; break;
case "Scegli le date":  			$messaggio = "Escoger las fechas"; break;
case "nei menù a tendina":  			$messaggio = "en las listas"; break;
case "dal":  					$messaggio = "desde"; break;
case "al":  					$messaggio = "hasta"; break;
case "Tronca i cognomi nelle tabelle dopo ":	$messaggio = "Corta los apellidos el las tablas después de "; break;
case "caratteri per colonna":  			$messaggio = "letras por columna"; break;
case "La lunghezza dei cognomi nelle tabelle dei mesi è stata cambiata":	$messaggio = "El número de letras de los apellidos en la tabla de los meses ha sido cambiada"; break;
case "Cambia il numero delle tariffe":  	$messaggio = "Cambiar el número de tarifas"; break;
case "per l'anno":  				$messaggio = "para el año"; break;
case "Il numero delle tariffe è stato cambiato":	$messaggio = "El número de las tarifas ha sido cambiado"; break;
case "Il numero di tariffe è sbagliato":  	$messaggio = "El número de las tarifas está equivocado"; break;
case "Sistema di backup":  			$messaggio = "sistema de backup"; break;
case "Il numero delle righe è sbagliato":  	$messaggio = "El número de líneas está equivocado"; break;
case "Cambia il numero delle righe":  		$messaggio = "Cambiar el número de líneas"; break;
case "Il numero delle righe della tabella con tutte le prenotazioni è stato cambiato":	$messaggio = "El número de líneas de la tabla con todas las reservas ha sido cambiado"; break;
case "Il numero delle righe della tabella con la storia delle entrate e delle uscite è stato cambiato":	$messaggio = "El número de líneas de la tabla de historial de pagos ha sido cambiado"; break;
case "Tabella con la storia delle entate e uscite":	$messaggio = "Tabla historial de pagos"; break;
case "Il formato di visualizzazione delle date è stato cambiato":	$messaggio = "El formato de visualización de las fechas ha sido cambiado"; break;
case "Formato di visualizzazione delle date":	$messaggio = "Formato de visualización de fechas"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Tabla con todos los clientes"; break;
case "Il numero delle righe della tabella con tutti i clienti è stato cambiato":	$messaggio = "El número de líneas de la tabla con todos los clientes ha sido cambiado"; break;
case "Si deve sceliere qualche dato da inserire nella colonna gruppo":	$messaggio = "Hay que escoger algún dato para insertar en la columna grupo"; break;
case "Si deve inserire il nome della colonna gruppo":	$messaggio = "Hay que insertar el nombre de la columna grupo"; break;
case "La colonna gruppo è stata aggiunta":  	$messaggio = "La columna grupo ha sido añadida"; break;
case "Aggiungi una colonna gruppo":  		$messaggio = "Añadir una columna grupo"; break;
case "Aggiungi colonna gruppo":  		$messaggio = "Añadir columna grupo"; break;
case "chiamata":  				$messaggio = "llamada"; break;
case "con":  					$messaggio = "con"; break;
case "colonna gruppo":  			$messaggio = "columna grupo"; break;
case "separatore":  				$messaggio = "separador"; break;
case "spazio":  				$messaggio = "espacio"; break;
case "trattino":  				$messaggio = "raya"; break;
case "a capo":  				$messaggio = "nueva línea"; break;
case "Pagine per il sito web":  		$messaggio = "Páginas para el sitio web"; break;
case " Do":  					$messaggio = " Do"; break;
case " Lu":  					$messaggio = " Lu"; break;
case " Ma":  					$messaggio = " Ma"; break;
case " Me":  					$messaggio = " Mi"; break;
case " Gi":  					$messaggio = " Ju"; break;
case " Ve":  					$messaggio = " Vi"; break;
case " Sa":  					$messaggio = " Sá"; break;
case "Gen":  					$messaggio = "Ene"; break;
case "Feb":  					$messaggio = "Feb"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Abr"; break;
case "Mag":  					$messaggio = "May"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Ago"; break;
case "Set":  					$messaggio = "Sep"; break;
case "Ott":  					$messaggio = "Oct"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dic"; break;
case "nome della tariffa":  			$messaggio = "nombre de la tarifa"; break;
case "data di inserimento":  			$messaggio = "fecha de inserción"; break;
case "tariffa completa":  			$messaggio = "tarifa completa"; break;
case "Gestione utenti":  			$messaggio = "Gestión de usuarios"; break;
case "Personalizzazioni dell'utente":  		$messaggio = "Personalizaciones del usuario"; break;
case "Cambia":  				$messaggio = "Cambiar"; break;
case "quelle di":  				$messaggio = "las de"; break;
case "Importa i nomi dei documenti":  		$messaggio = "Importar los nombres de los documentos"; break;
case "Importa":  				$messaggio = "Importar"; break;
case "dell'utente":  				$messaggio = "del usuario"; break;
case "I minuti di durata di sessioni e transazioni sono stati cambiati":	$messaggio = "Los minutos de duración de sesiones y transacciones han sido cambiados"; break;
case "Le ore di anticipo dell'inizio delle prenotazioni sono state cambiate":	$messaggio = "Las horas de antelación del principio de las reservas han sido cambiadas"; break;
case "Minuti dopo i quali considerare scadute sessioni e transazioni non aggiornate":	$messaggio = "Minutos después de los que considerar acabadas las sesiones y transacciones no actualizadas"; break;
case "Numero di ore di cui anticipare il momento in cui si considera iniziata una prenotazione":	$messaggio = "Número de horas de las que adelantar el momento en que se considera empezada una reserva"; break;
case "utente":  				$messaggio = "usuario"; break;
case "Interconnessioni":  			$messaggio = "Interconexiones"; break;
case "Assegnazione automatica disattivata":  	$messaggio = "Asignación automatica desactivada"; break;
case "Assegnazione automatica attivata":  	$messaggio = "Asignación automatica activada"; break;
case "Attiva":  				$messaggio = "Activar"; break;
case "Disattiva":  				$messaggio = "Desactivar"; break;
case "Scegli il tema grafico":  		$messaggio = "Escoger el tema gráfico"; break;
case "Il tema grafico è stato cambiato":  	$messaggio = "El tema gráfico ha sido cambiado"; break;
case "Registrazione degli orari di entrata ed uscita attivata":	$messaggio = "Registro de los horarios de entrada y salida activado"; break;
case "Registrazione degli orari di entrata ed uscita disattivata":	$messaggio = "Registro de los horarios de entrada y salida desactivado"; break;
case "Le ore di differenza con l'orario del server sono state cambiate":	$messaggio = "Las horas de diferencia con el horario del servidor han sido cambiadas"; break;
case "Ore di differenza con l'orario del server":	$messaggio = "Horas de diferencia con el horario del servidor"; break;
case "ora attuale":  				$messaggio = "hora actual"; break;
case "numero":  				$messaggio = "número"; break;
case "cognome cliente":  			$messaggio = "apellido cliente"; break;
case "data iniziale":  				$messaggio = "fecha inicial"; break;
case "data finale":  				$messaggio = "fecha final"; break;
case "Le colonne necessarie sono state cambiate":	$messaggio = "Las columnas necesarias han sido cambiadas"; break;
case "Non mostrare prenotazioni che non hanno almeno una di queste colonne necessarie (non selezionarene per mostrare tutte)":	$messaggio = "Columnas necesarias para enseñar las reservas (no seleccionar ninguna para enseñar todas)"; break;
case "cambia le colonne necessarie":  		$messaggio = "cambiar las columnas necesarias"; break;
case "Metodo di pagamento eliminato":  		$messaggio = "Método de pago eliminado"; break;
case "Nuovo metodo di pagamento aggiunto":  	$messaggio = "Nuevo método de pago añadido"; break;
case "Metodi di pagamento":  			$messaggio = "Métodos de pago"; break;
case "elimina":  				$messaggio = "eliminar"; break;
case "aggiungi":  				$messaggio = "añadir"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Cuadro indicativo de disponibilidad"; break;
case "non mostrare":  				$messaggio = "no enseñar"; break;
case "Il modo di visualizzazione del quadro di disponibilità è stato cambiato":	$messaggio = "El modo de visualización del cuadro de disponidilidad ha sido cambiado"; break;
case "Controllo disponibilità":  		$messaggio = "Control disponibilidad"; break;
case "settimane di intervallo":  		$messaggio = "semanas de intervalo"; break;
case "giorni di intervallo":  			$messaggio = "días de intervalo"; break;
case "Giorno di inizio/fine settimana cambiato":	$messaggio = "Día de principio/final de semana cambiado"; break;
case "Giorno di inizio/fine settimana nelle tabelle":	$messaggio = "Día de principio/final de semana en las tablas"; break;
case "Anno":  					$messaggio = "Año"; break;
case "Creazione automatica del nuovo anno disattivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Creación automatica del nuevo año desactivada (importando los datos del año anterior al primer login de un usuario)"; break;
case "Creazione automatica del nuovo anno attivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Creación automatica del nuevo año activada (importando los datos del año anterior al primer login de un usuario)"; break;
case "Creazione automatica nuovo anno disattivata":	$messaggio = "Creación automatica nuevo año desactivada"; break;
case "Creazione automatica nuovo anno attivata":	$messaggio = "Creación automatica nuevo año activada"; break;
case "Sostituisci la parola":  			$messaggio = "Reemplazar la palabra"; break;
case "Parole da sostituire":  			$messaggio = "Palabras a reemplazar"; break;
case "La parola da sostituire è stata aggiunta":	$messaggio = "La palabra a reemplazar ha sido añadida"; break;
case "La parola da sostituire è stata eliminata":	$messaggio = "La palabra a reemplazar ha sido eliminada"; break;
case "modifica il documento":  			$messaggio = "modifica el documento"; break;
case "Aggiungi ai documenti":  			$messaggio = "Añadir a los documentos"; break;
case "variabili personalizzate":  		$messaggio = "variables personalizadas"; break;
case "Cambia il numero dei documenti":  	$messaggio = "Cambiar el número de documentos"; break;
case "Il numero di documenti è stato cambiato":	$messaggio = "El número de documentos ha sido cambiado"; break;
case "Il numero di documenti è sbagliato":  	$messaggio = "El número de documentos está equivocado"; break;
case "Indirizzo email":  			$messaggio = "Dirección de correo electrónico"; break;
case "Mascherare la provenienza delle email sull'envelope":	$messaggio = "Enmascarar la proveniencia de las email en el envelope"; break;
case "Il mascheramento della provenienza delle email è stato cambiato":	$messaggio = "El enmascaramiento de la proveniencia de las email ha sido cambiado"; break;
case "SI":  					$messaggio = "SI"; break;
case "NO":  					$messaggio = "NO"; break;
case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Carpetas en donde crear las páginas para el sitio web"; break;
case "percorsi separati da virgole relativi":	$messaggio = "recorridos separados por comas relativos"; break;
case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "a la carpeta de HotelDruid, si no empiezan con /"; break;
case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "No tengo permisos para escribir en el directorio"; break;
case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "El directorio insertado <div style=\"display: inline; color: red;\">no existe</div>"; break;
case "Le cartelle dove vengono create le pagine per il sito web sono state cambiate":	$messaggio = "Los directorios donde crear páginas para el sitio web han sido cambiados"; break;
case "Selezionare in modo predefinito":  	$messaggio = "Seleccionar de manera predefinida"; break;
case "tutte le prenotazioni":  			$messaggio = "todas las reservas"; break;
case "prenotazioni del periodo corrente":  	$messaggio = "reservas del período actual"; break;
case "La selezione predefinita delle prenotazioni nella tabella con tutte le prenotazioni è stata cambiata":	$messaggio = "La selección predefinida de las reservas en la tabla con todas las reservas ha sido cambiada"; break;
case "Numero di righe dopo cui ripetere la riga delle date":	$messaggio = "Número de líneas antes de repetir la línea de las fechas"; break;
case "Il numero  di righe dopo cui ripetere la riga delle date è stato cambiato":	$messaggio = "El número de líneas antes de repetir la línea de las fechas ha sido cambiado"; break;
case "orario entrata stimato":  		$messaggio = "horario entrada estimativo"; break;
case "Mostrare i giorni nella riga delle date?":	$messaggio = "Enseñar los dias en la línea de las fechas?"; break;
case "I giorni da mostrare nella tabella dei mesi sono stati cambiati":	$messaggio = "Los dias a enseñar en la línea de las fechas han sido cambiados"; break;
case "Nazioni":  				$messaggio = "Naciones"; break;
case "Elimina tutte":  				$messaggio = "Eliminar todas"; break;
case "Ripristina predefinite":  		$messaggio = "Restaurar predefinidas"; break;
case "Importa le nazioni":  			$messaggio = "Importar la naciones"; break;
case "Regioni/provincie":  			$messaggio = "Regiones"; break;
case "Importa le regioni/provincie":  		$messaggio = "Importar las regiones"; break;
case "Nazione cancellata":  			$messaggio = "Nación borrada"; break;
case "Regione/provincia cancellata":  		$messaggio = "Región borrada"; break;
case "Nuova nazione aggiunta":  		$messaggio = "Nueva nación añadida"; break;
case "Nazioni predefinite ripristinate":  	$messaggio = "Naciones predefinidas restauradas"; break;
case "Nazioni cancellate":  			$messaggio = "Naciones borradas"; break;
case "Nazioni importate":  			$messaggio = "Naciones importadas"; break;
case "Nuova regione/provincia aggiunta":  	$messaggio = "Nueva región añadida"; break;
case "Regioni/provincie predefinite ripristinate":	$messaggio = "Regiones predefinidas restauradas"; break;
case "Regioni/provincie cancellate":  		$messaggio = "Regiones borradas"; break;
case "Regioni/provincie importate":  		$messaggio = "Regiones importadas"; break;
case "Parentele":  				$messaggio = "Emparentados"; break;
case "Importa le parentele":  			$messaggio = "Importar los emparentados"; break;
case "Parentela cancellata":  			$messaggio = "Emparentado borrado"; break;
case "Nuova parentela aggiunta":  		$messaggio = "Nuevo emparentado añadido"; break;
case "Parentele predefinite ripristinate":  	$messaggio = "Emparentados predefinidos restaurados"; break;
case "Parentele cancellate":  			$messaggio = "Emparentados borrados"; break;
case "Parentele importate":  			$messaggio = "Emparentados importados"; break;
case "origine":  				$messaggio = "origen"; break;
case "Origini delle prenotazioni":  		$messaggio = "Origenes de las reservas"; break;
case "Nuova origine delle prenotazioni aggiunta":	$messaggio = "Nueva origen de las reservas añadida"; break;
case "Origine delle prenotazioni eliminata":  	$messaggio = "Origen de las reservas eliminada"; break;
case "Nome combinazione":  			$messaggio = "Nombre combinación"; break;
case "prenotazioni correnti e future":  	$messaggio = "reservas corrientes y futuras"; break;
case "Personalizzazioni di <b>tutti gli utenti</b>":  	$messaggio = "Personalizaciones de <b>todos los usuarios</b>"; break;
case "tutti gli utenti":  			$messaggio = "todos los usuarios"; break;
case "Personalizzazioni del gruppo":  		$messaggio = "Personalizaciones del grupo"; break;
case "gruppo":  				$messaggio = "grupo"; break;
case "Log delle query di modifica generate":	$messaggio = "Log de las queries de modificación hechas"; break;
case "da tutti gli utenti":  			$messaggio = "por todos los usuarios"; break;
case "dall'utente":  				$messaggio = "por el usuario"; break;
case "dal gruppo":  				$messaggio = "por el grupo"; break;
case "attivato":				$messaggio = "activado"; break;
case "disattivato":				$messaggio = "desactivado"; break;
case "Vedi i log":  				$messaggio = "Mirar los logs"; break;
case "Log delle query di modifica effettuate dagli utenti negli ultimi":	$messaggio = "Logs de las queries de modificación hechas por los usuarios en los últimos"; break;
case "giorni":  				$messaggio = "días"; break;
case "Utente":  				$messaggio = "Usuario"; break;
case "Data":  					$messaggio = "Fecha"; break;
case "Query":  					$messaggio = "Query"; break;
case "Cancella tutti i log":  			$messaggio = "Borrar todos los logs"; break;
case "Log delle query di modifica degli utenti normali disattivato":	$messaggio = "Log de las queries de modificación de los usuarios normales desactivado"; break;
case "Log delle query di modifica degli utenti normali attivato":	$messaggio = "Log de las queries de modificación de los usuarios normales activado"; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Alinear la disponibilidad con la fecha de llegada?"; break;
case "L'allineamento dei giorni con la disponibilità nella tabella dei mesi è stato cambiato":	$messaggio = "La alineación de los días con la disponibilidad en la tabla de los meses ha sido cambiada"; break;
case "Torna indietro":  			$messaggio = "Volver atrás"; break;
case "Allineare la disponibilità con le date di arrivo potrebbe generare confusione ed errori sulle date di partenza, si è sicuri di voler continuare?":	$messaggio = "Alinear la disponibilidad con las fechas de llegada podría generar confusión y errores sobre las fechas de salida, está seguro de querer continuar?"; break;
case "Documenti di identità":  			$messaggio = "Documentos de identidad"; break;
case "Tipo di documento di identità eliminato":	$messaggio = "Tipo de documento de identidad eliminado"; break;
case "Nuovo tipo di documento di identità aggiunto":	$messaggio = "Nuevo tipo de documento de identidad añadido"; break;
case "Tipi di documento di identità predefiniti ripristinati":	$messaggio = "Tipos de documento de identidad predefinidos restaurados"; break;
case "Tipi di documento di identità cancellati":	$messaggio = "Tipos de documento de identidad borrados"; break;
case "Tipi di documento di identità importati":	$messaggio = "Tipos de documento de identidad importados"; break;
case "Importa i documenti di identità":  	$messaggio = "Importar los documentos de identidad"; break;
case "codice":  				$messaggio = "código"; break;
case "Nuova nazione":  				$messaggio = "Nueva nación"; break;
case "Nuova regione/provincia":  		$messaggio = "Nueva región"; break;
case "Nuovo documento d'identità":  		$messaggio = "Nuevo documento de identidad"; break;
case "Nuova parentela":  			$messaggio = "Nuevo emparentado"; break;
case "Elimina tutti":  				$messaggio = "Eliminar todos"; break;
case "Ripristina predefiniti":  		$messaggio = "Restaurar predefinidos"; break;
case "Città":  					$messaggio = "Ciudades"; break;
case "Nuova città":  				$messaggio = "Nueva ciudad"; break;
case "Importa le città":  			$messaggio = "Importar las ciudades"; break;
case "Città cancellata":  			$messaggio = "Ciudad borrada"; break;
case "Nuova città aggiunta":  			$messaggio = "Nueva ciudad añadida"; break;
case "Città predefinite ripristinate":  	$messaggio = "Ciudades predefinidas restauradas"; break;
case "Città cancellate":  			$messaggio = "Ciudades borradas"; break;
case "Città importate":  			$messaggio = "Ciudades importadas"; break;
case "nella regione/provincia di":  		$messaggio = "en la región de"; break;
case "nella nazione":  				$messaggio = "en la nación"; break;
case "Titoli dei clienti":  			$messaggio = "Títulos de los clientes"; break;
case "sesso":  					$messaggio = "sexo"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "f"; break;
case "Titolo dei clienti eliminato":  		$messaggio = "Título de los clientes eliminado"; break;
case "Nuovo titolo dei clienti aggiunto":  	$messaggio = "Nuevo título de los clientes añadido"; break;
case "I dati della struttura sono stati cambiati":	$messaggio = "Los datos de la estructura han sido cambiados"; break;
case "Dati della struttura":  			$messaggio = "Datos de la estructura"; break;
case "Nome":  					$messaggio = "Nombre"; break;
case "Tipo":  					$messaggio = "Tipo"; break;
case "Numero stelle":  				$messaggio = "Número estrellas"; break;
case "Nazione":  				$messaggio = "Nación"; break;
case "Comune":  				$messaggio = "Ciudad"; break;
case "Indirizzo":  				$messaggio = "Dirección"; break;
case "CAP":  					$messaggio = "Código postal"; break;
case "Telefono":  				$messaggio = "Teléfono"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Codice fiscale":  			$messaggio = "Número Identificación Fiscal"; break;
case "Parita iva":  				$messaggio = "Cert. Identificación Fiscal"; break;
case "Modifica i dati della struttura":  	$messaggio = "Modificar los datos de la estructura"; break;
case "Clicca su un documento per modificarlo":	$messaggio = "Hacer clic sobre un documento para modificarlo"; break;
case "Cambia l'ordine dei documenti":  		$messaggio = "Cambiar el orden de los documentos"; break;
case "Applica i cambiamenti":  			$messaggio = "Aplicar los cambios"; break;
case "Documento":  				$messaggio = "Documento"; break;
case "ex":  					$messaggio = "ex"; break;
case "L'ordine dei documenti è stato cambiato":	$messaggio = "El orden de los documentos ha sido cambiado"; break;
case "Sito web":  				$messaggio = "Sitio web"; break;
case "Nome contatto":  				$messaggio = "Nombre contacto"; break;
case "l'ordine delle tariffe è stato cambiato":	$messaggio = "el orden de las tarifas ha sido cambiado"; break;
case "cambia l'ordine delle tariffe":  		$messaggio = "cambiar el orden de las tarifas"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "valore predefinito a cui arrotondare le percentuali dei prezzi":	$messaggio = "valor predefinido al que redondear los porcentajes de los precios"; break;
case "il":  					$messaggio = "el"; break;
case "è stato cambiato":  			$messaggio = "ha sido cambiado"; break;
case "password per la visualizzazione dei dati delle carte di credito":	$messaggio = "contraseña para ver los datos de las tarjetas de crédito"; break;
case "attivata":  				$messaggio = "activada"; break;
case "disattivata":  				$messaggio = "desactivada"; break;
case "cambia la password":  			$messaggio = "cambiar contraseña"; break;
case "<b>Attenzione</b>: se si perde questa password non sarà più possibile leggere i dati delle carte di credito inserite":	$messaggio = "<b>Atención</b>: si se pierde esta contraseña ya no será posible leer los datos de las tarjetas de crédito"; break;
case "nuova password":  			$messaggio = "nueva contraseña"; break;
case "ripetere password":  			$messaggio = "repetir contraseña"; break;
case "attiva la password":  			$messaggio = "activar la contraseña"; break;
case "le password inserite non coincidono":  	$messaggio = "las contraseñas insertadas no coinciden"; break;
case "errore nelle funzioni ssl":  		$messaggio = "error en las funciones ssl"; break;
case "<b class=\"colred\">Attenzione</b>: tutti i dati delle carte di credito verranno cancellati":	$messaggio = "<b class=\"colred\">Atención</b>: todos los datos de las tarjetas de crédito serán borrados"; break;
case "continua":  				$messaggio = "continua"; break;
case "vecchia password":  			$messaggio = "vieja contraseña"; break;
case "cambiata":  				$messaggio = "cambiada"; break;
case "piano":  					$messaggio = "piso"; break;
case "casa":  					$messaggio = "casa"; break;
case "2°":  					$messaggio = "2°"; break;
case "3°":  					$messaggio = "3°"; break;
case "2° codice":  				$messaggio = "2° código"; break;
case "3° codice":  				$messaggio = "3er código"; break;
case "Tabella con i documenti salvati":  	$messaggio = "Tabla con los documentos salvados"; break;
case "Il numero delle righe della tabella con i documenti salvati è stato cambiato":	$messaggio = "El número de líneas de la tabla con los documentos salvados ha sido cambiado"; break;
case "valore a cui arrotondare le percentuali delle tasse":	$messaggio = "valor al que redondear los porcentajes de las tasas"; break;
case "commissioni":  				$messaggio = "comisiones"; break;
case "resto commissioni":  			$messaggio = "resto comisiones"; break;
case "documenti salvati":  			$messaggio = "documentos salvados"; break;
case "Scegli le righe aggiuntive da mostrare":	$messaggio = "Escoger las líneas extras a enseñar"; break;
case "tasse":  					$messaggio = "tasas"; break;
case "trasferito in cassa":  			$messaggio = "tranferido en caja"; break;
case "cambia le righe":  			$messaggio = "cambiar las líneas"; break;
case "Le righe aggiuntive sono state cambiate":	$messaggio = "Las líneas extras han sido cambiadas"; break;
case "totale":  				$messaggio = "total"; break;
case "soldi prenotazioni cancellate":  		$messaggio = "dinero de reservas borradas"; break;
case "cognome ospite se differente":  		$messaggio = "apellido huespéd si es diferente"; break;
case "Ragione sociale":  			$messaggio = "Razón social"; break;
case "URL del logo":  				$messaggio = "URL del logo"; break;
case "Nome delle unità da affittare":  		$messaggio = "Nombre de las unidades a alquilar"; break;
case "nome personalizzato":  			$messaggio = "nombre personalizado"; break;
case "singolare":  				$messaggio = "singular"; break;
case "plurale":  				$messaggio = "plural"; break;
case "genere":  				$messaggio = "género"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "f"; break;
case "Il nome delle unità da affittare è stato cambiato":	$messaggio = "El nombre de las unidades a alquilar ha sido cambiado"; break;
case "Tabelle con le casse":  			$messaggio = "Tablas con las cajas"; break;
case "Il numero delle righe delle tabelle con le casse è stato cambiato":	$messaggio = "El número de líneas de las tablas con las cajas ha sido cambiado"; break;
case "Elimina il documento":  			$messaggio = "Eliminar el documento"; break;
case "Sei sicuro di voler eliminare il documento":	$messaggio = "Está seguro de querer eliminar el documento"; break;
case "Il documento è stato eliminato":	$messaggio = "El documento ha sido eliminado"; break;
case "Campi da considerare per la ricerca dei clienti":	$messaggio = "Campos a considerar para la búsqueda de los clientes"; break;
case "cognome":  				$messaggio = "apellido"; break;
case "email":  					$messaggio = "correo electrónico"; break;
case "nome":  					$messaggio = "nombre"; break;
case "telefono":  				$messaggio = "teléfono"; break;
case "città":  					$messaggio = "ciudad"; break;
case "indirizzo":  				$messaggio = "dirección"; break;
case "codice postale":  			$messaggio = "código postal"; break;
case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "Los campos a considerar para la búsqueda de los clientes han sido cambiados"; break;
case "Nome delle unità singole":  		$messaggio = "Nombre de las unidades individuales"; break;
case "Tabella dei messaggi":  			$messaggio = "Tabla de los mensajes"; break;
case "Il numero di righe della tabella dei messaggi è stato cambiato":	$messaggio = "El número de líneas de la tabla con los mensajes ha sido cambiado"; break;
case "Scarica le email di richiesta disponibiltà dal server di posta":	$messaggio = "Decargar los emails de pedido disponibilidad desde el servidor de correo"; break;
case "per es.":  				$messaggio = "por ej."; break;
case "Protocollo":  				$messaggio = "Protocolo"; break;
case "Porta":  					$messaggio = "Puerta"; break;
case "default":  				$messaggio = "predefinida"; break;
case "persoalizzata":  				$messaggio = "personalizada"; break;
case "Nome utente":  				$messaggio = "Nombre de usuario"; break;
case "Password":  				$messaggio = "Contraseña"; break;
case "lasciare vuota per chiedere ogni volta":	$messaggio = "dejar vacio para preguntar cada vez"; break;
case "Identificazione messaggi di richiesta":	$messaggio = "Indentificaciòn de los mensajes de pedido"; break;
case "Messaggio iniziale":  			$messaggio = "Mensaje inicial"; break;
case "Qualsiasi messaggio":  			$messaggio = "Qualquier mensaje"; break;
case "da":  					$messaggio = "desde"; break;
case "con oggetto contenete":  			$messaggio = "con asunto que contenga"; break;
case "I dati per lo scaricamento delle email sono sbagliati o incompleti":	$messaggio = "Los datos para descargar los emails son equivocados o incompletos"; break;
case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "La Decarga de los emails de pedido disponibilidad desde el servidor de correo ha sido cambiada"; break;
case "Colori delle prenotazioni":  		$messaggio = "Colores de las reservas"; break;
case "Tutto pagato":  				$messaggio = "Todo pagado"; break;
case "Caparra pagata":  			$messaggio = "Fianza pagada"; break;
case "Confermate":  				$messaggio = "Confirmadas"; break;
case "Non confermate":  			$messaggio = "No confirmadas"; break;
case "I colori sono sbagliati":  		$messaggio = "Los colores están equivocados"; break;
case "I colori delle prenotazioni sono stati cambiati":	$messaggio = "Los colores de las reservas han sido cambiados"; break;
case "Campi personalizzati dei clienti":  	$messaggio = "Campos personalizados de los clientes"; break;
case "Nuovo campo personalizzato dei clienti aggiunto":	$messaggio = "Nuevo campos personalizado para los clientes añadido"; break;
case "Campo personalizzato dei clienti eliminato":	$messaggio = "Campos personalizado para los clientes eliminado"; break;
case "tipo":  					$messaggio = "tipo"; break;
case "booleano":  				$messaggio = "booleano"; break;
case "testo":  					$messaggio = "texto"; break;
case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "El campo personalizado contiene caracteres no consentidos"; break;
case "Gestire anche i codici CVC delle carte di credito":	$messaggio = "Gestionar también los códigos CVC de las tarjetas de crédito"; break;
case "Esonero di responsabilità":  		$messaggio = "Exención de responsabilidad"; break;
case "la gestione dei codici CVC avverrà sotto la propria responsabilità, essendo a conoscenza che gli standard di sicurezza PCI ne vietano la registrazione":	$messaggio = "La Gestión de los códigos CVC se llevará a cabo bajo su propria responsabilidad, sabiendo que las normas de seguridad PCI prohiben guardarlos"; break;
case "L'accettazione di questa clausola conferma che gli sviluppatori di questo software sono liberi da ogni responsibilità sulla sicurezza di questi dati":	$messaggio = "La aceptación de esta cláusula confirma que los desarolladores de este software están libres de toda responsabilidad sobre la seguridad de estos datos"; break;
case "Accetto":  				$messaggio = "Acepto"; break;
case "Declino":  				$messaggio = "Renuncio"; break;
case "La gestione dei codici cvc è stata cambiata":	$messaggio = "La Gestión de los códigos CVC ha sido cambiada"; break;
case "Scegli le righe con i totali da mostrare":	$messaggio = "Escoger cuales líneas con los totales enseñar"; break;
case "giornaliero":  				$messaggio = "diario"; break;
case "mensile":  				$messaggio = "mensual"; break;
case "tabella":  				$messaggio = "tabla"; break;
case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Las líneas enseñadas en las tablas de las cajas han sido cambiadas"; break;
case "partenze e prenotazioni correnti":  	$messaggio = "salidas y reservas corrientes"; break;
case "Commenti personalizzati delle prenotazioni":	$messaggio = "Comentarios personalizados de las reservas"; break;
case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Comentario personalizado de la reserva eliminado"; break;
case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "Nuevo comentario personalizado de la reserva añadido"; break;
case "Punto vendita ed inventario":  		$messaggio = "Punto de venta e inventario"; break;
case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Orden en el inventario y punto de venta"; break;
case "alfabetico":  				$messaggio = "alfabético"; break;
case "per ordine di inserimento":  		$messaggio = "por orden de inserción"; break;
case "Tasti per operazioni nel punto vendita":	$messaggio = "Botones para las operaciones en el punto de venta"; break;
case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "El orden en el inventario y punto de venta ha sido cambiado"; break;
case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Los botones para las operaciones en el punto de venta han sido cambiados"; break;
case "Attenzione":  				$messaggio = "Atención"; break;
case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "los enlaces para la exportación de los calendarios en formato ical han cambiado, recordarse de actualizarlos en los calendarios externos"; break;
case "La tariffa":  				$messaggio = "La tarifa"; break;
case "è ancora in uso nelle interconnessioni":	$messaggio = "está siendo todavía utilizada en las interconexiones"; break;
case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "por lo menos 8 caracteres, con letras y números o símbulos"; break;
case "diversa dalle ultime":  			$messaggio = "distinta de las últimas"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>