<?php

$lista_documentiid = "";
$cod_documentiid = "";
$cod2_documentiid = "";
$cod3_documentiid = "";

$lista_documentiid[0] = "Tess. App.to Ag.custodia";
$cod_documentiid[0] = "ACMIL";
$lista_documentiid[1] = "Tess. Sott.li Ag.custodia";
$cod_documentiid[1] = "ACSOT";
$lista_documentiid[2] = "Tess. Uff.li Ag.custodia";
$cod_documentiid[2] = "ACUFF";
$lista_documentiid[3] = "Tess. Militare Truppa A.m";
$cod_documentiid[3] = "AMMIL";
$lista_documentiid[4] = "Tess. Sottufficiali A.m.";
$cod_documentiid[4] = "AMSOT";
$lista_documentiid[5] = "Tess. Ufficiali A.m.";
$cod_documentiid[5] = "AMUFF";
$lista_documentiid[6] = "Tess. App.to Carabinieri";
$cod_documentiid[6] = "CCMIL";
$lista_documentiid[7] = "Tess. Sottufficiali Cc";
$cod_documentiid[7] = "CCSOT";
$lista_documentiid[8] = "Tess. Ufficiale";
$cod_documentiid[8] = "CCUFF";
$lista_documentiid[9] = "Certificato D'identita'";
$cod_documentiid[9] = "CERID";
$lista_documentiid[10] = "Tess. Ag. E Ag.sc. C.f.s.";
$cod_documentiid[10] = "CFMIL";
$lista_documentiid[11] = "Tess. Sottuficiali C.f.s.";
$cod_documentiid[11] = "CFSOT";
$lista_documentiid[12] = "Tess. Ufficiali C.f.s.";
$cod_documentiid[12] = "CFUFF";
$lista_documentiid[13] = "Tess. S.i.s.d.e.";
$cod_documentiid[13] = "DESIS";
$lista_documentiid[14] = "Tess. Militare E.i.";
$cod_documentiid[14] = "EIMIL";
$lista_documentiid[15] = "Tess. Sottufficiali E.i.";
$cod_documentiid[15] = "EISOT";
$lista_documentiid[16] = "Tess. Ufficiali E.i.";
$cod_documentiid[16] = "EIUFF";
$lista_documentiid[17] = "Tess. App.to Finanziere";
$cod_documentiid[17] = "GFMIL";
$lista_documentiid[18] = "Tess. Sott.li G.d.f.";
$cod_documentiid[18] = "GFSOT";
$lista_documentiid[19] = "Tess. Pol. Trib. G.d.f.";
$cod_documentiid[19] = "GFTRI";
$lista_documentiid[20] = "Tess. Ufficiali G.d.f.";
$cod_documentiid[20] = "GFUFF";
$lista_documentiid[21] = "Carta Identita' Elettronica";
$cod_documentiid[21] = "IDELE";
$lista_documentiid[22] = "Carta Di Identita'";
$cod_documentiid[22] = "IDENT";
$lista_documentiid[23] = "Tess. Pers. Magistrati";
$cod_documentiid[23] = "MAGIS";
$lista_documentiid[24] = "Tess. Milit. M.m.";
$cod_documentiid[24] = "MMMIL";
$lista_documentiid[25] = "Tess. Sottuficiali M.m.";
$cod_documentiid[25] = "MMSOT";
$lista_documentiid[26] = "Tess. Ufficiali M.m.";
$cod_documentiid[26] = "MMUFF";
$lista_documentiid[27] = "Tess. Parlamentari";
$cod_documentiid[27] = "PARLA";
$lista_documentiid[28] = "Passaporto Diplomatico";
$cod_documentiid[28] = "PASDI";
$lista_documentiid[29] = "Passaporto Ordinario";
$cod_documentiid[29] = "PASOR";
$lista_documentiid[30] = "Passaporto Di Servizio";
$cod_documentiid[30] = "PASSE";
$lista_documentiid[31] = "Patente Di Guida";
$cod_documentiid[31] = "PATEN";
$lista_documentiid[32] = "Patente Nautica";
$cod_documentiid[32] = "PATNA";
$lista_documentiid[33] = "Tess. Agenti/ass.ti P.p.";
$cod_documentiid[33] = "PPAGE";
$lista_documentiid[34] = "Tess. Ispettori P.p.";
$cod_documentiid[34] = "PPISP";
$lista_documentiid[35] = "Tess. Sovrintendenti P.p.";
$cod_documentiid[35] = "PPSOV";
$lista_documentiid[36] = "Tess. Ufficiali P.p.";
$cod_documentiid[36] = "PPUFF";
$lista_documentiid[37] = "Tess. Agenti/ass.ti P.s.";
$cod_documentiid[37] = "PSAPP";
$lista_documentiid[38] = "Tess. Polizia Femminile";
$cod_documentiid[38] = "PSFEM";
$lista_documentiid[39] = "Tess. Funzionari P.s.";
$cod_documentiid[39] = "PSFUN";
$lista_documentiid[40] = "Tess. Ispettori P.s.";
$cod_documentiid[40] = "PSISP";
$lista_documentiid[41] = "Tess. Sovrintendenti P.s.";
$cod_documentiid[41] = "PSSOT";
$lista_documentiid[42] = "Tess. Ufficiali P.s.";
$cod_documentiid[42] = "PSUFF";
$lista_documentiid[43] = "Tess. Milit. Truppa Sismi";
$cod_documentiid[43] = "SDMIL";
$lista_documentiid[44] = "Tess. Sottufficiali Sismi";
$cod_documentiid[44] = "SDSOT";
$lista_documentiid[45] = "Tess. Ufficiali Sismi";
$cod_documentiid[45] = "SDUFF";
$lista_documentiid[46] = "Tess. Iscr. Albo Med/chi.";
$cod_documentiid[46] = "TEAMC";
$lista_documentiid[47] = "Tess. Iscriz. Albo Odont.";
$cod_documentiid[47] = "TEAOD";
$lista_documentiid[48] = "Tes. Unico Per La Camera";
$cod_documentiid[48] = "TECAM";
$lista_documentiid[49] = "Tess. Corte Dei Conti";
$cod_documentiid[49] = "TECOC";
$lista_documentiid[50] = "Tes.doganale Ril.min.fin.";
$cod_documentiid[50] = "TEDOG";
$lista_documentiid[51] = "Tess. Ferrov. Senato";
$cod_documentiid[51] = "TEFSE";
$lista_documentiid[52] = "Tess. Min.pubb.istruzione";
$cod_documentiid[52] = "TEMPI";
$lista_documentiid[53] = "Tess. Militare Nato";
$cod_documentiid[53] = "TENAT";
$lista_documentiid[54] = "Tes. Ente Naz. Assis.volo";
$cod_documentiid[54] = "TENAV";
$lista_documentiid[55] = "Tess.min.polit.agric.for.";
$cod_documentiid[55] = "TEPOL";
$lista_documentiid[56] = "Tess.iscr.albo Architetti";
$cod_documentiid[56] = "TESAR";
$lista_documentiid[57] = "Tessera Iscr. Albo Avvoc.";
$cod_documentiid[57] = "TESAV";
$lista_documentiid[58] = "Tess. Corte D'appello";
$cod_documentiid[58] = "TESCA";
$lista_documentiid[59] = "Tess. Consiglio Di Stato";
$cod_documentiid[59] = "TESCS";
$lista_documentiid[60] = "Tessera Riconosc. D.i.a.";
$cod_documentiid[60] = "TESDI";
$lista_documentiid[61] = "Tess. Membro Equip. Aereo";
$cod_documentiid[61] = "TESEA";
$lista_documentiid[62] = "Tess.iscr. Albo Ingegneri";
$cod_documentiid[62] = "TESIN";
$lista_documentiid[63] = "Tess. Ministero Lavori Pu";
$cod_documentiid[63] = "TESLP";
$lista_documentiid[64] = "Tess. Min.ben.e Att.cult.";
$cod_documentiid[64] = "TESMB";
$lista_documentiid[65] = "Tess. Ministero Difesa";
$cod_documentiid[65] = "TESMD";
$lista_documentiid[66] = "Tess. Ministero Finanze";
$cod_documentiid[66] = "TESMF";
$lista_documentiid[67] = "Tess. Ministero Giustizia";
$cod_documentiid[67] = "TESMG";
$lista_documentiid[68] = "Tess. Ministero Interno";
$cod_documentiid[68] = "TESMI";
$lista_documentiid[69] = "Tess. Minist. Trasp/navig";
$cod_documentiid[69] = "TESMN";
$lista_documentiid[70] = "Tess. Ministero Sanita'";
$cod_documentiid[70] = "TESMS";
$lista_documentiid[71] = "Tess. Ministero Tesoro";
$cod_documentiid[71] = "TESMT";
$lista_documentiid[72] = "Tessera Dell'ordine Notai";
$cod_documentiid[72] = "TESNO";
$lista_documentiid[73] = "Tess. Ordine Giornalisti";
$cod_documentiid[73] = "TESOG";
$lista_documentiid[74] = "Tess. Pres.za Cons. Min.";
$cod_documentiid[74] = "TESPC";
$lista_documentiid[75] = "Tess. Pubblica Istruzione";
$cod_documentiid[75] = "TESPI";
$lista_documentiid[76] = "Tes. Poste E Telecomunic.";
$cod_documentiid[76] = "TESPT";
$lista_documentiid[77] = "Tessera U.n.u.c.i.";
$cod_documentiid[77] = "TESUN";
$lista_documentiid[78] = "Tess. Identif.telecom It.";
$cod_documentiid[78] = "TETEL";
$lista_documentiid[79] = "Tes. Ferroviaria Deputati";
$cod_documentiid[79] = "TFERD";
$lista_documentiid[80] = "Tes. Ferrov. Ex Deputati";
$cod_documentiid[80] = "TFEXD";
$lista_documentiid[81] = "Tess. App.to/vig. Urbano";
$cod_documentiid[81] = "VIMIL";
$lista_documentiid[82] = "Tess. Sott.li Vig. Urbani";
$cod_documentiid[82] = "VISOT";
$lista_documentiid[83] = "Tess. Uff.li Vig.urbani";
$cod_documentiid[83] = "VIUFF";
$lista_documentiid[84] = "Tess. App.to/vig. Vv.ff.";
$cod_documentiid[84] = "VVMIL";
$lista_documentiid[85] = "Tess. Sottuff.li Vv.ff.";
$cod_documentiid[85] = "VVSOT";
$lista_documentiid[86] = "Tess. Ufficiali Vv.ff.";
$cod_documentiid[86] = "VVUFF";

?>