<?php

$lista_nazioni = "";
$cod_nazioni = "";
$cod2_nazioni = "";
$cod3_nazioni = "";

$lista_nazioni[0] = "Austria";
#$cod_nazioni[0] = "00001";
$cod2_nazioni[0] = "AT";
$lista_nazioni[1] = "Belgium";
#$cod_nazioni[1] = "00002";
$cod2_nazioni[1] = "BE";
$lista_nazioni[2] = "Czech Republic";
$cod2_nazioni[2] = "CZ";
$lista_nazioni[3] = "Cyprus";
$cod2_nazioni[3] = "CY";
$lista_nazioni[4] = "Denmark";
$cod2_nazioni[4] = "DK";
$lista_nazioni[5] = "Estonia";
$cod2_nazioni[5] = "EE";
$lista_nazioni[6] = "Finland";
$cod2_nazioni[6] = "FI";
$lista_nazioni[7] = "France";
$cod2_nazioni[7] = "FR";
$lista_nazioni[8] = "Germany";
$cod2_nazioni[8] = "DE";
$lista_nazioni[9] = "Greece";
$cod2_nazioni[9] = "GR";
$lista_nazioni[10] = "Ireland";
$cod2_nazioni[10] = "IE";
$lista_nazioni[11] = "Latvia";
$cod2_nazioni[11] = "LV";
$lista_nazioni[12] = "Lithuania";
$cod2_nazioni[12] = "LT";
$lista_nazioni[13] = "Luxembourg";
$cod2_nazioni[13] = "LU";
$lista_nazioni[14] = "Malta";
$cod2_nazioni[14] = "MT";
$lista_nazioni[15] = "Netherlands";
$cod2_nazioni[15] = "NL";
$lista_nazioni[16] = "Poland";
$cod2_nazioni[16] = "PL";
$lista_nazioni[17] = "Portugal";
$cod2_nazioni[17] = "PT";
$lista_nazioni[18] = "United Kingdom";
$cod2_nazioni[18] = "GB";
$lista_nazioni[19] = "Slovakia";
$cod2_nazioni[19] = "SK";
$lista_nazioni[20] = "Slovenia";
$cod2_nazioni[20] = "SI";
$lista_nazioni[21] = "Spain";
$cod2_nazioni[21] = "ES";
$lista_nazioni[22] = "Sweden";
$cod2_nazioni[22] = "SE";
$lista_nazioni[23] = "Hungary";
$cod2_nazioni[23] = "HU";
$lista_nazioni[24] = "Albania";
$cod2_nazioni[24] = "AL";
$lista_nazioni[25] = "Andorra";
$cod2_nazioni[25] = "AD";
$lista_nazioni[26] = "Belarus";
$cod2_nazioni[26] = "BY";
$lista_nazioni[27] = "Bosnia And Herzegovina";
$cod2_nazioni[27] = "BA";
$lista_nazioni[28] = "Bulgaria";
$cod2_nazioni[28] = "BG";
$lista_nazioni[29] = "Croatia";
$cod2_nazioni[29] = "HR";
$lista_nazioni[30] = "Iceland";
$cod2_nazioni[30] = "IS";
$lista_nazioni[31] = "Liechtenstein";
$cod2_nazioni[31] = "LI";
$lista_nazioni[32] = "Macedonia";
$cod2_nazioni[32] = "MK";
$lista_nazioni[33] = "Moldova";
$cod2_nazioni[33] = "MD";
$lista_nazioni[34] = "Monaco";
$cod2_nazioni[34] = "MC";
$lista_nazioni[35] = "Montenegro";
$cod2_nazioni[35] = "ME";
$lista_nazioni[36] = "Norway";
$cod2_nazioni[36] = "NO";
$lista_nazioni[37] = "Romania";
$cod2_nazioni[37] = "RO";
$lista_nazioni[38] = "Russia";
$cod2_nazioni[38] = "RU";
$lista_nazioni[39] = "San Marino";
$cod2_nazioni[39] = "SM";
$lista_nazioni[40] = "Vatican City";
$cod2_nazioni[40] = "VA";
$lista_nazioni[41] = "Serbia";
$cod2_nazioni[41] = "YU";
$lista_nazioni[42] = "Switzerland";
$cod2_nazioni[42] = "CH";
$lista_nazioni[43] = "Turkey";
$cod2_nazioni[43] = "TR";
$lista_nazioni[44] = "Ukraine";
$cod2_nazioni[44] = "UA";
$lista_nazioni[45] = "Afghanistan";
$cod2_nazioni[45] = "AF";
$lista_nazioni[46] = "Saudi Arabia";
$cod2_nazioni[46] = "SA";
$lista_nazioni[47] = "Armenia";
$cod2_nazioni[47] = "AM";
$lista_nazioni[48] = "Azerbaijan";
$cod2_nazioni[48] = "AZ";
$lista_nazioni[49] = "Bahrein";
$cod2_nazioni[49] = "BH";
$lista_nazioni[50] = "Bangladesh";
$cod2_nazioni[50] = "BD";
$lista_nazioni[51] = "Bhutan";
$cod2_nazioni[51] = "BT";
$lista_nazioni[52] = "Brunei";
$cod2_nazioni[52] = "BN";
$lista_nazioni[53] = "Cambodia";
$cod2_nazioni[53] = "KH";
$lista_nazioni[54] = "China";
$cod2_nazioni[54] = "CN";
$lista_nazioni[55] = "South Korea";
$cod2_nazioni[55] = "KR";
$lista_nazioni[56] = "North Korea";
$cod2_nazioni[56] = "KP";
$lista_nazioni[57] = "United Arab Emirates";
$cod2_nazioni[57] = "AE";
$lista_nazioni[58] = "Philippines";
$cod2_nazioni[58] = "PH";
$lista_nazioni[59] = "Georgia";
$cod2_nazioni[59] = "GE";
$lista_nazioni[60] = "Japan";
$cod2_nazioni[60] = "JP";
$lista_nazioni[61] = "Jordan";
$cod2_nazioni[61] = "JO";
$lista_nazioni[62] = "India";
$cod2_nazioni[62] = "IN";
$lista_nazioni[63] = "Indonesia";
$cod2_nazioni[63] = "ID";
$lista_nazioni[64] = "Iran";
$cod2_nazioni[64] = "IR";
$lista_nazioni[65] = "Iraq";
$cod2_nazioni[65] = "IQ";
$lista_nazioni[66] = "Israel";
$cod2_nazioni[66] = "IL";
$lista_nazioni[67] = "Kazakhstan";
$cod2_nazioni[67] = "KZ";
$lista_nazioni[68] = "Kyrgyzstan";
$cod2_nazioni[68] = "KG";
$lista_nazioni[69] = "Kuwait";
$cod2_nazioni[69] = "KW";
$lista_nazioni[70] = "Laos";
$cod2_nazioni[70] = "LA";
$lista_nazioni[71] = "Lebanon";
$cod2_nazioni[71] = "LB";
$lista_nazioni[72] = "Malaysia";
$cod2_nazioni[72] = "MY";
$lista_nazioni[73] = "Maldives";
$cod2_nazioni[73] = "MV";
$lista_nazioni[74] = "Mongolia";
$cod2_nazioni[74] = "MN";
$lista_nazioni[75] = "Myanmar";
$cod2_nazioni[75] = "MM";
$lista_nazioni[76] = "Nepal";
$cod2_nazioni[76] = "NP";
$lista_nazioni[77] = "Oman";
$cod2_nazioni[77] = "OM";
$lista_nazioni[78] = "Pakistan";
$cod2_nazioni[78] = "PK";
$lista_nazioni[79] = "Qatar";
$cod2_nazioni[79] = "QA";
$lista_nazioni[80] = "Singapore";
$cod2_nazioni[80] = "SG";
$lista_nazioni[81] = "Syria";
$cod2_nazioni[81] = "SY";
$lista_nazioni[82] = "Sri Lanka";
$cod2_nazioni[82] = "LK";
$lista_nazioni[83] = "Tajikistan";
$cod2_nazioni[83] = "TJ";
$lista_nazioni[84] = "Taiwan";
$cod2_nazioni[84] = "TW";
$lista_nazioni[85] = "Palestine";
$cod2_nazioni[85] = "PS";
$lista_nazioni[86] = "Thailand";
$cod2_nazioni[86] = "TH";
$lista_nazioni[87] = "Timor-Leste";
$cod2_nazioni[87] = "TL";
$lista_nazioni[88] = "Turkmenistan";
$cod2_nazioni[88] = "TM";
$lista_nazioni[89] = "Uzbekistan";
$cod2_nazioni[89] = "UZ";
$lista_nazioni[90] = "Vietnam";
$cod2_nazioni[90] = "VN";
$lista_nazioni[91] = "Yemen";
$cod2_nazioni[91] = "YE";
$lista_nazioni[92] = "Algeria";
$cod2_nazioni[92] = "DZ";
$lista_nazioni[93] = "Angola";
$cod2_nazioni[93] = "AO";
$lista_nazioni[94] = "Benin";
$cod2_nazioni[94] = "BJ";
$lista_nazioni[95] = "Botswana";
$cod2_nazioni[95] = "BW";
$lista_nazioni[96] = "Burkina Faso";
$cod2_nazioni[96] = "BF";
$lista_nazioni[97] = "Burundi";
$cod2_nazioni[97] = "BI";
$lista_nazioni[98] = "Cameroon";
$cod2_nazioni[98] = "CM";
$lista_nazioni[99] = "Cape Verde";
$cod2_nazioni[99] = "CV";
$lista_nazioni[100] = "Central African Republic";
$cod2_nazioni[100] = "CF";
$lista_nazioni[101] = "Chad";
$cod2_nazioni[101] = "TD";
$lista_nazioni[102] = "Comoros";
$cod2_nazioni[102] = "KM";
$lista_nazioni[103] = "Republic Of Congo";
$cod2_nazioni[103] = "CG";
$lista_nazioni[104] = "Dem. Rep. Of Congo";
$cod2_nazioni[104] = "CD";
$lista_nazioni[105] = "Côte D'Ivoire";
$cod2_nazioni[105] = "CI";
$lista_nazioni[106] = "Egypt";
$cod2_nazioni[106] = "EG";
$lista_nazioni[107] = "Eritrea";
$cod2_nazioni[107] = "ER";
$lista_nazioni[108] = "Ethiopia";
$cod2_nazioni[108] = "ET";
$lista_nazioni[109] = "Gabon";
$cod2_nazioni[109] = "GA";
$lista_nazioni[110] = "Gambia";
$cod2_nazioni[110] = "GM";
$lista_nazioni[111] = "Ghana";
$cod2_nazioni[111] = "GH";
$lista_nazioni[112] = "Djibouti";
$cod2_nazioni[112] = "DJ";
$lista_nazioni[113] = "Guinea";
$cod2_nazioni[113] = "GN";
$lista_nazioni[114] = "Guinea-Bissau";
$cod2_nazioni[114] = "GW";
$lista_nazioni[115] = "Equatorial Guinea";
$cod2_nazioni[115] = "GQ";
$lista_nazioni[116] = "Kenya";
$cod2_nazioni[116] = "KE";
$lista_nazioni[117] = "Lesotho";
$cod2_nazioni[117] = "LS";
$lista_nazioni[118] = "Liberia";
$cod2_nazioni[118] = "LR";
$lista_nazioni[119] = "Libya";
$cod2_nazioni[119] = "LY";
$lista_nazioni[120] = "Madagascar";
$cod2_nazioni[120] = "MG";
$lista_nazioni[121] = "Malawi";
$cod2_nazioni[121] = "MW";
$lista_nazioni[122] = "Mali";
$cod2_nazioni[122] = "ML";
$lista_nazioni[123] = "Morocco";
$cod2_nazioni[123] = "MA";
$lista_nazioni[124] = "Mauritania";
$cod2_nazioni[124] = "MR";
$lista_nazioni[125] = "Mauritius";
$cod2_nazioni[125] = "MU";
$lista_nazioni[126] = "Mozambique";
$cod2_nazioni[126] = "MZ";
$lista_nazioni[127] = "Namibia";
$cod2_nazioni[127] = "NA";
$lista_nazioni[128] = "Niger";
$cod2_nazioni[128] = "NE";
$lista_nazioni[129] = "Nigeria";
$cod2_nazioni[129] = "NG";
$lista_nazioni[130] = "Rwanda";
$cod2_nazioni[130] = "RW";
$lista_nazioni[131] = "São Tomé And Príncipe";
$cod2_nazioni[131] = "ST";
$lista_nazioni[132] = "Senegal";
$cod2_nazioni[132] = "SN";
$lista_nazioni[133] = "Seychelles";
$cod2_nazioni[133] = "SC";
$lista_nazioni[134] = "Sierra Leone";
$cod2_nazioni[134] = "SL";
$lista_nazioni[135] = "Somalia";
$cod2_nazioni[135] = "SO";
$lista_nazioni[136] = "South Africa";
$cod2_nazioni[136] = "ZA";
$lista_nazioni[137] = "Sudan";
$cod2_nazioni[137] = "SD";
$lista_nazioni[138] = "Swaziland";
$cod2_nazioni[138] = "SZ";
$lista_nazioni[139] = "Tanzania";
$cod2_nazioni[139] = "TZ";
$lista_nazioni[140] = "Togo";
$cod2_nazioni[140] = "TG";
$lista_nazioni[141] = "Tunisia";
$cod2_nazioni[141] = "TN";
$lista_nazioni[142] = "Uganda";
$cod2_nazioni[142] = "UG";
$lista_nazioni[143] = "Zambia";
$cod2_nazioni[143] = "ZM";
$lista_nazioni[144] = "Zimbabwe";
$cod2_nazioni[144] = "ZW";
$lista_nazioni[145] = "Antigua And Barbuda";
$cod2_nazioni[145] = "AG";
$lista_nazioni[146] = "Argentina";
$cod2_nazioni[146] = "AR";
$lista_nazioni[147] = "Bahamas";
$cod2_nazioni[147] = "BS";
$lista_nazioni[148] = "Barbados";
$cod2_nazioni[148] = "BB";
$lista_nazioni[149] = "Belize";
$cod2_nazioni[149] = "BZ";
$lista_nazioni[150] = "Bolivia";
$cod2_nazioni[150] = "BO";
$lista_nazioni[151] = "Brazil";
$cod2_nazioni[151] = "BR";
$lista_nazioni[152] = "Canada";
$cod2_nazioni[152] = "CA";
$lista_nazioni[153] = "Chile";
$cod2_nazioni[153] = "CL";
$lista_nazioni[154] = "Colombia";
$cod2_nazioni[154] = "CO";
$lista_nazioni[155] = "Costa Rica";
$cod2_nazioni[155] = "CR";
$lista_nazioni[156] = "Cuba";
$cod2_nazioni[156] = "CU";
$lista_nazioni[157] = "Dominica";
$cod2_nazioni[157] = "DM";
$lista_nazioni[158] = "Dominican Republic";
$cod2_nazioni[158] = "DO";
$lista_nazioni[159] = "Ecuador";
$cod2_nazioni[159] = "EC";
$lista_nazioni[160] = "El Salvador";
$cod2_nazioni[160] = "SV";
$lista_nazioni[161] = "Jamaica";
$cod2_nazioni[161] = "JM";
$lista_nazioni[162] = "Grenada";
$cod2_nazioni[162] = "GD";
$lista_nazioni[163] = "Guatemala";
$cod2_nazioni[163] = "GT";
$lista_nazioni[164] = "Guyana";
$cod2_nazioni[164] = "GY";
$lista_nazioni[165] = "Haiti";
$cod2_nazioni[165] = "HT";
$lista_nazioni[166] = "Honduras";
$cod2_nazioni[166] = "HN";
$lista_nazioni[167] = "Mexico";
$cod2_nazioni[167] = "MX";
$lista_nazioni[168] = "Nicaragua";
$cod2_nazioni[168] = "NI";
$lista_nazioni[169] = "Panama";
$cod2_nazioni[169] = "PA";
$lista_nazioni[170] = "Paraguay";
$cod2_nazioni[170] = "PY";
$lista_nazioni[171] = "Peru";
$cod2_nazioni[171] = "PE";
$lista_nazioni[172] = "Saint Kitts And Nevis";
$cod2_nazioni[172] = "KN";
$lista_nazioni[173] = "Saint Lucia";
$cod2_nazioni[173] = "LC";
$lista_nazioni[174] = "Saint Vincent And Grenadines";
$cod2_nazioni[174] = "VC";
$lista_nazioni[175] = "United States Of America";
$cod2_nazioni[175] = "US";
$lista_nazioni[176] = "Suriname";
$cod2_nazioni[176] = "SR";
$lista_nazioni[177] = "Trinidad And Tobago";
$cod2_nazioni[177] = "TT";
$lista_nazioni[178] = "Uruguay";
$cod2_nazioni[178] = "UY";
$lista_nazioni[179] = "Venezuela";
$cod2_nazioni[179] = "VE";
$lista_nazioni[180] = "Australia";
$cod2_nazioni[180] = "AU";
$lista_nazioni[181] = "Fiji";
$cod2_nazioni[181] = "FJ";
$lista_nazioni[182] = "Kiribati";
$cod2_nazioni[182] = "KI";
$lista_nazioni[183] = "Marshall Islands";
$cod2_nazioni[183] = "MH";
$lista_nazioni[184] = "Micronesia";
$cod2_nazioni[184] = "FM";
$lista_nazioni[185] = "Nauru";
$cod2_nazioni[185] = "NR";
$lista_nazioni[186] = "New Zealand";
$cod2_nazioni[186] = "NZ";
$lista_nazioni[187] = "Palau";
$cod2_nazioni[187] = "PW";
$lista_nazioni[188] = "Papua New Guinea";
$cod2_nazioni[188] = "PG";
$lista_nazioni[189] = "Solomon Islands";
$cod2_nazioni[189] = "SB";
$lista_nazioni[190] = "Samoa";
$cod2_nazioni[190] = "WS";
$lista_nazioni[191] = "Tonga";
$cod2_nazioni[191] = "TO";
$lista_nazioni[192] = "Tuvalu";
$cod2_nazioni[192] = "TV";
$lista_nazioni[193] = "Vanuatu";
$cod2_nazioni[193] = "VU";
$lista_nazioni[194] = "Italy";
$cod2_nazioni[194] = "IT";
$lista_nazioni[195] = "Kosovo";
$cod2_nazioni[195] = "XK";
$lista_nazioni[196] = "South Sudan";
$cod2_nazioni[196] = "SS";

?>