<?php

switch ($messaggio) {

case "Vedi le prenotazioni":  			$messaggio = "Mira las reservas"; break;
case "presenti dal":  				$messaggio = "presentes desde"; break;
case "al":  					$messaggio = "hasta"; break;
case "Senza colori":  				$messaggio = "Sin colores"; break;
case "Con colori":  				$messaggio = "Con colores"; break;
case "Tabella prenotazioni precedenti al":  	$messaggio = "Tabla con las reservas precedentes al"; break;
case "Tabella prenotazioni successive al":  	$messaggio = "Tabla con las reservas siguientes al"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Tabla con todas las reservas"; break;
case "Cognome_cliente":  			$messaggio = "Apellido_cliente"; break;
case "Data_iniziale":  				$messaggio = "Fecha_inicial"; break;
case "Data_finale":  				$messaggio = "Fecha_final"; break;
case "sett":  					$messaggio = "sem"; break;
case "gio":  					$messaggio = "días"; break;
case "Tariffa_completa":  			$messaggio = "Tarifa_comleta"; break;
case "Caparra":  				$messaggio = "Fianza"; break;
case "Pagato":  				$messaggio = "Pagado"; break;
case "Da_pagare":  				$messaggio = "A_pagar"; break;
case "Pers.":  					$messaggio = "Pers."; break;
case "Commento":  				$messaggio = "Comentario"; break;
case "Costo_uni.":  				$messaggio = "Coste_úni."; break;
case "Costo_sett.":  				$messaggio = "Coste_sem."; break;
case "Costo_gio.":  				$messaggio = "Coste_dia."; break;
case "Soldi di prenotazioni cancellate":  	$messaggio = "Dinero de reservas borradas"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Trasferito in cassa":  			$messaggio = "Transferido en caja"; break;
case "RESTO":  					$messaggio = "RESTO"; break;
case "Sei sicuro di voler cancellare la spesa":	$messaggio = "Estás seguro de querer borrar el gasto"; break;
case "del valore di":  				$messaggio = "del valor de"; break;
case "Sei sicuro di voler cancellare l'entrata":	$messaggio = "Estás seguro de querer borrar la entrada"; break;
case "SI":  					$messaggio = "SI"; break;
case "NO":  					$messaggio = "NO"; break;
case "Entrata o spesa":  			$messaggio = "Entrada o gasto"; break;
case "cacellata":  				$messaggio = "borrada"; break;
case "Costo o spesa già cancellati":  		$messaggio = "Coste o gasto ya borrado"; break;
case "Tutte le spese del":  			$messaggio = "Todos los gastos del"; break;
case "nella cassa principale":  		$messaggio = "en la caja principal"; break;
case "Natura_spesa":  				$messaggio = "Razón_del_gasto"; break;
case "Importo":  				$messaggio = "Importe"; break;
case "Inserita_da":  				$messaggio = "Insertado_por"; break;
case "Data_di_inserimento":  			$messaggio = "Fecha_de_inserción"; break;
case "Cancella":  				$messaggio = "Borrar"; break;
case "Tutte le entrate del":  			$messaggio = "Todas las entradas del"; break;
case "Natura_entrata":  			$messaggio = "Razón_de_la_entrada"; break;
case "cancella":  				$messaggio = "borrar"; break;
case "entrata presa dalle prenotazioni":  	$messaggio = "entrada cogida de las reservas"; break;
case "Inserisci nuove spese o entrate":  	$messaggio = "Insertar nuevos gastos o entradas"; break;
case "Storia entrate-uscite prenotazioni":  	$messaggio = "Historial de pagos de las reservas"; break;
case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "Estás seguro de querer borrar el coste añadido"; break;
case "Il costo aggiuntivo":  			$messaggio = "El coste añadido"; break;
case "Il costo aggiuntivo è cambiato nel frattempo, non è stato cancellato":	$messaggio = "El coste añadido ha cambiado mientras tanto, no ha sido borrado"; break;
case "è stato cancellato":  			$messaggio = "ha sido borrado"; break;
case "I periodi sono stati aggiunti fino al":  	$messaggio = "Los períodos han sido añadidos hasta el"; break;
case "Tabella con periodi e relative tariffe del":	$messaggio = "Tabla con períodos y relativas tarifas del"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Inizio_settimana":  			$messaggio = "Inicio_semana"; break;
case "Inizio_giorno":  				$messaggio = "Inicio_día"; break;
case "Fine_settimana":  			$messaggio = "Fin_semana"; break;
case "Fine_giorno":  				$messaggio = "Fin_día"; break;
case "Aggiungi periodi":  			$messaggio = "Añadir períodos"; break;
case "fino al mese":  				$messaggio = "hasta el més"; break;
case "Tabella con i costi aggiuntivi del":  	$messaggio = "Tabla con los costes añadidos del"; break;
case "Nome":  					$messaggio = "Nombre"; break;
case "Tipo":  					$messaggio = "Tipo"; break;
case "Prezzo":  				$messaggio = "Precio"; break;
case "Da_assegnare":  				$messaggio = "A_asignar"; break;
case "finale":  				$messaggio = "síngulo"; break;
case "Sempre":  				$messaggio = "Siempre"; break;
case "Su_richiesta":  				$messaggio = "Bajo_pedido"; break;
case "chidere_per_quanto_moltiplicare":  	$messaggio = "preguntar_por_cuanto_multiplicar"; break;
case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "considera_como_camas_extras"; break;
case "settimanale":  				$messaggio = "semanal"; break;
case "giornaliero":  				$messaggio = "diario"; break;
case "tutte":  				$messaggio = "todas"; break;
case "tutti":  				$messaggio = "todos"; break;
case "_le":  					$messaggio = "_las"; break;
case "_i":  					$messaggio = "_los"; break;
case "_settimane":  				$messaggio = "_semanas"; break;
case "_giorni":  				$messaggio = "_días"; break;
case "_meno_una":  				$messaggio = "_menos_una"; break;
case "con_n°_di_settimane":  			$messaggio = "con_n°_de_semanas"; break;
case "con_n°_di_giorni":  			$messaggio = "con_n°_de_días"; break;
case "_da_chiedere":  				$messaggio = "_a_preguntar"; break;
case "percentuale":  				$messaggio = "porcentaje"; break;
case "% arrotondato_a_":  			$messaggio = "% redondeado_a_"; break;
case "Caparre, commissioni e tasse del":  	$messaggio = "Fianzas, comisiones y tasas del"; break;
case "Arrotondato_a":  				$messaggio = "Redondeado_a"; break;
case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Ir a la página de inserción de precios"; break;
case "chiamati":  				$messaggio = "llamados"; break;
case "Cerca i clienti con cognome o email":  	$messaggio = "Busca los clientes con apellido o email"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Tabla con todos los clientes"; break;
case "pag. prec.":  				$messaggio = "pág. ant."; break;
case "pag. succ.":  				$messaggio = "pág suc."; break;
case "Cognome":  				$messaggio = "Apellido"; break;
case "Nome":  					$messaggio = "Nombre"; break;
case "Telefono":  				$messaggio = "Teléfono"; break;
case "Indirizzo":  				$messaggio = "Dirección"; break;
case "Città":  					$messaggio = "Ciudad"; break;
case "Nazione":  				$messaggio = "Nación"; break;
case "CAP":  					$messaggio = "Código pos."; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "Correo electrónico"; break;
case "Data_di_nascita":  			$messaggio = "Fecha_de_nacimiento"; break;
case "2°telefono":  				$messaggio = "2° teléfono"; break;
case "Commento":  				$messaggio = "Comentario"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 1 para la"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 2 para la"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 3 para la"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 4 para la"; break;
case "La regola di assegnazione è stata cancellata":	$messaggio = "La regla de asignación ha sido borrada"; break;
case "La regola di assegnazione è già stata cancellata":	$messaggio = "La regla de asignación había sido ya borrada"; break;
case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Tabla con las reglas de asignación 1 del"; break;
case "Motivazione":  				$messaggio = "Motivación"; break;
case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Tabla con las reglas de asignación 2 del"; break;
case "Tariffa":  				$messaggio = "Tarifa"; break;
case "Inserisci nuove regole":  		$messaggio = "Insertar nuevas reglas"; break;
case "Il numero inserito esiste già":  		$messaggio = "El número insertado ya existe"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "Torna indietro":  			$messaggio = "Volver atrás"; break;
case "Casa":  					$messaggio = "Casa"; break;
case "Piano":  					$messaggio = "Piso"; break;
case "Capienza_massima":  			$messaggio = "Capacidad_máxima"; break;
case "Priorità":  				$messaggio = "Prioridad"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "modifica":  				$messaggio = "modificar"; break;
case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
case "persone":  				$messaggio = "personas"; break;
case "s":  					$messaggio = "s"; break;
case "g":  					$messaggio = "d"; break;
case "Mostra":  				$messaggio = "Enseñar"; break;
case "Non_mostrare":  				$messaggio = "No_enseñar"; break;
case "Regole":  				$messaggio = "Reglas"; break;
case "Tariffe abbinate":  			$messaggio = "Tarifas asociadas"; break;
case "pagine":  				$messaggio = "páginas"; break;
case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "Se harán los siguientes cambios"; break;
case "I soldi pagati per la prenotazione":  	$messaggio = "El dinero pagado para la reserva"; break;
case "a nome di":  				$messaggio = "a nombre de"; break;
case "verranno cambiati da":  			$messaggio = "será cambiado de"; break;
case "a":  					$messaggio = "a"; break;
case "saldo":  					$messaggio = "diferencia"; break;
case "Le prenotazioni <b>non sono state modificate</b> perchè sono cambiate nel frattempo":	$messaggio = "Las reservas <b>no han sido modificadas</b> porqué han cambiado mientras tanto"; break;
case "porre per le prenotazioni selezionate":  	$messaggio = "poner para las reservas seleccionadas"; break;
case "cambia":  				$messaggio = "Cambiar"; break;
case "ponendo":  				$messaggio = "poniendo"; break;
case "tutto pagato":  				$messaggio = "todo pagado"; break;
case "caparra pagata":  			$messaggio = "fianza pagada"; break;
case "pagato niente":  				$messaggio = "nada pagado"; break;
case "pagina":  				$messaggio = "página"; break;
case "di":  					$messaggio = "de"; break;
case "la conferma":  				$messaggio = "la confimación"; break;
case "La prenotazione":  			$messaggio = "La reserva"; break;
case "verrà confermata":  			$messaggio = "será confirmada"; break;
case "Data di inserimento":  			$messaggio = "Fecha de inserción"; break;
case "Calcola il subtotale delle prenotazioni selezionate":	$messaggio = "Calcular el subtotal de las reservas seleccionadas"; break;
case "selezionate precedentemente":  		$messaggio = "seleccionadas precedentemente"; break;
case "Saldo totale":  				$messaggio = "Diferencia total"; break;
case "l'anno":  				$messaggio = "el año"; break;
case "dal database":  				$messaggio = "de la base de datos"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<b style=\"color: red;\">ATENCION</b>: al pulsar <b>\"<i>Continua</i>\"</b>, todos los datos que se refieren al año"; break;
case "verranno <b>cancellati</b>":  		$messaggio = "serán <b>borrados</b>"; break;
case "L'anno":  				$messaggio = "El año"; break;
case "è stato cancellato dal batabase":  	$messaggio = "ha sido cancelado de la base de datos"; break;
case "Non è stato possibile cancellare l'anno":	$messaggio = "No ha sido posible cancelar el año"; break;
case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "de la base de datos, controlar los permisos del directorio dati"; break;
case "Profilo":  				$messaggio = "Perfil"; break;
case "Cliente":  				$messaggio = "Cliente"; break;
case "cliente":  				$messaggio = "cliente"; break;
case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Tabla con las reglas de asignación 3 del"; break;
case "Utente":  				$messaggio = "Usuario"; break;
case "Periodi_permessi":  			$messaggio = "Periodos_permitidos"; break;
case "unico":  					$messaggio = "único"; break;
case "fisso":  					$messaggio = "fijo"; break;
case "percentuale su tariffa":  		$messaggio = "porcentaje de la tarifa"; break;
case "percentuale su totale":  			$messaggio = "porcentaje del total"; break;
case "varia_con_la_prenotazione":  		$messaggio = "cambia_con_la_reserva"; break;
case "non_varia_con_la_prenotazione":  		$messaggio = "no_cambia_con_la_reserva"; break;
case "_meno_l'ultima":  			$messaggio = "_menos_la_última"; break;
case "_meno_l'ultimo":  			$messaggio = "_menos_el_último"; break;
case "_meno_la_prima":  			$messaggio = "_menos_la_primera"; break;
case "_meno_il_primo":  			$messaggio = "_menos_el_primero"; break;
case "giorni":  				$messaggio = "dias"; break;
case "moltiplicare_per_persone":  		$messaggio = "multiplicar_por_personas"; break;
case "moltiplicare_per_persone_totali":  	$messaggio = "multiplicar_por_personas_totales"; break;
case "moltiplicare_per_1":  			$messaggio = "multiplicar_por_1"; break;
case "massimo_":  				$messaggio = "máximo_"; break;
case "_nella_stessa_settimana":  		$messaggio = "_en_la_misma_semana"; break;
case "_nello_stesso_giorno":  			$messaggio = "_en_el_mismo_día"; break;
case "Prenotazione intera in":  		$messaggio = "Reserva entera en"; break;
case "Parte della prentoazione in":  		$messaggio = "Parte de la reserva en"; break;
case "Solo settimane della prenotazione in":  	$messaggio = "Solo semanas de la reserva en"; break;
case "Solo giorni della prenotazione in":  	$messaggio = "Solo dias de la reserva en"; break;
case " o ":  					$messaggio = " o "; break;
case " a ":  					$messaggio = " a "; break;
case "_si":  					$messaggio = "_si"; break;
case "_no":  					$messaggio = "_no"; break;
case "_e_":  					$messaggio = "_y_"; break;
case "associato_a_settimane_specifiche":  	$messaggio = "asociado_a_semanas_específicas"; break;
case "non_associato_a_settimane_specifiche":  	$messaggio = "no_asociado_a_semanas_específicas"; break;
case "associato_a_giorni_specifici":  		$messaggio = "asociado_a_días_específicos"; break;
case "non_associato_a_giorni_specifici":  	$messaggio = "no_asociado_a_días_específicos"; break;
case "modifica con prenotazione":  		$messaggio = "modificar con reserva"; break;
case "percentuale su caparra":  		$messaggio = "porcentaje de la fianza"; break;
case "percentuale su resto caparra":  		$messaggio = "porcentaje del resto de la fianza"; break;
case "Cancellati":  				$messaggio = "Borrados"; break;
case "clienti":  				$messaggio = "clientes"; break;
case "OK":  					$messaggio = "OK"; break;
case "Annulla":  				$messaggio = "Cancelar"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "Estas seguro de querer <div style=\"display: inline; color: red;\"><b>borrar"; break;
case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "clientes</b></div> que no estan asociados a ninguna reserva y ningun pago"; break;
case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "tarjetas de crédito</b></div> asociadas a clientes que no tienen reservas en el futuro y ninguna reserva no pagada"; break;
case "Cancella i clienti senza prenotazioni":	$messaggio = "Borrar los clientes sin reservas"; break;
case "Metodo pagamento":  			$messaggio = "Método pago"; break;
case "Tariffe":  				$messaggio = "Tarifas"; break;
case "del":  					$messaggio = "del"; break;
case "Modifica tutti i campi della tabella":  	$messaggio = "Modificar todos los campos de la tabla"; break;
case "Modifica i campi della tabella":  	$messaggio = "Modificar los campos de la tabla"; break;
case "Applica i cambiamenti":  			$messaggio = "Aplicar los cambios"; break;
case "documento di tipo":  			$messaggio = "documento tipo"; break;
case "visualizza":  				$messaggio = "Ver"; break;
case "Vedi tutte le prenotazioni":  		$messaggio = "Mirar todas las reservas"; break;
case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Tabla con las reglas de asignación 4 del"; break;
case "Numero di persone":  			$messaggio = "Número de personas"; break;
case "assegna_se_":  				$messaggio = "asignar_con_"; break;
case "più_di_":  				$messaggio = "más_de_"; break;
case "meno_di_":  				$messaggio = "menos_de_"; break;
case "_giorni_da_inizio":  			$messaggio = "_dias_del_principio"; break;
case "assegna_con_":  				$messaggio = "asignar_con_"; break;
case "_o_più_prenotazioni":  			$messaggio = "_o_más_reservas"; break;
case "Modifica i prezzi":  			$messaggio = "Modificar los precios"; break;
case "<div style=\"display: inline; color: red;\">Non</div> è stato possibile inserire alcuni prezzi":	$messaggio = "<div style=\"display: inline; color: red;\">No</div> ha sido posible insertar algunos precios"; break;
case "I prezzi sono stati aggiornati":  	$messaggio = "Los precios han sido actualizados"; break;
case "Tutte le prenotazioni":  			$messaggio = "Todas las reservas"; break;
case "Solo arrivi":  				$messaggio = "Solo llegadas"; break;
case "Solo partenze":  				$messaggio = "Solo salidas"; break;
case "dal":  					$messaggio = "desde"; break;
case "Vedi":  					$messaggio = "Mirar"; break;
case "Tabella con tutti gli arrivi":  		$messaggio = "Tabla con todas las llegadas"; break;
case "Tabella con tutte le partenze":  		$messaggio = "Tabla con todas las salidas"; break;
case "prova ad importare i prezzi":  		$messaggio = "intenta importar los precios"; break;
case "giornalmente":  				$messaggio = "diariamente"; break;
case "settimanalmente":  			$messaggio = "semanalmente"; break;
case "Origine":  				$messaggio = "Origen"; break;
case "Modifica come gruppo le prenotazioni mostrate in tabella":	$messaggio = "Modificar como grupo las reservas enseñadas en la tabla"; break;
case "Modifica come gruppo le prenotazioni selezionate":	$messaggio = "Modificar como grupo las reservas seleccionadas"; break;
case "Statistiche":  				$messaggio = "Estadísticas"; break;
case "Anni":  					$messaggio = "Años"; break;
case "Numero di prenotazioni per mese":  	$messaggio = "Número de reservas por mes"; break;
case "Entrate dalle prenotazioni per mese":  	$messaggio = "Entradas de las reservas por mes"; break;
case "Entrate progressive dalle prenotazioni":	$messaggio = "Entradas progresivas de las reservas"; break;
case "Numero di prenotazioni per origine":  	$messaggio = "Número de reservas por origen"; break;
case "Entrate dalle prenotazioni per origine":	$messaggio = "Entradas de las reservas por origen"; break;
case "Cambia":  				$messaggio = "Cambiar"; break;
case "Mesi":  					$messaggio = "Meses"; break;
case "Entrate per metodo di pagamento":  	$messaggio = "Entradas por método de pago"; break;
case "Descrizione":  				$messaggio = "Descripción"; break;
case "magazzino":  				$messaggio = "almacen"; break;
case "inventario":  				$messaggio = "inventario"; break;
case "aggiungi":  				$messaggio = "añadir"; break;
case "Codice":  				$messaggio = "Código"; break;
case "Beni inventario":  			$messaggio = "Bienes en inventario"; break;
case "Mancanti":  				$messaggio = "Faltantes"; break;
case "bene eliminato":  			$messaggio = "Bien eliminado"; break;
case "bene aggiunto":  				$messaggio = "Bien añadido"; break;
case "magazzino eliminato":  			$messaggio = "almacén eliminado"; break;
case "magazzino aggiunto":  			$messaggio = "almacén añadido"; break;
case "Inventario importato":  			$messaggio = "Inventario importado"; break;
case "Importa l'invetario":  			$messaggio = "Importar el inventario"; break;
case "dal magazzino":  				$messaggio = "desde el almacén"; break;
case "Incompatibilità":  			$messaggio = "Incompatibilidades"; break;
case "raggruppa":  				$messaggio = "agrupar"; break;
case "con email":  				$messaggio = "con email"; break;
case "Importa":  				$messaggio = "Importar"; break;
case "per persona":  				$messaggio = "por persona"; break;
case "con meno di":  				$messaggio = "con menos de"; break;
case "dall'inizio":  				$messaggio = "del principio"; break;
case "dalla fine":  				$messaggio = "del final"; break;
case "Mostra solo tariffe selezionate":  	$messaggio = "Enseñar solo las tarifas seleccionadas"; break;
case "mostra prezzi settimanali":  		$messaggio = "enseñar precios semanales"; break;
case "mostra prezzi giornalieri":  		$messaggio = "enseñar precios diarios"; break;
case "periodi di":  				$messaggio = "períodos de"; break;
case "Valore":  				$messaggio = "Valor"; break;
case "della tariffa":  				$messaggio = "de la tarifa"; break;
case "piano":  					$messaggio = "piso"; break;
case "casa":  					$messaggio = "casa"; break;
case "documento":  				$messaggio = "documento"; break;
case "documenti salvati":  			$messaggio = "documentos salvados"; break;
case "in":  					$messaggio = "en"; break;
case "numero":  				$messaggio = "número"; break;
case "nome file":  				$messaggio = "nombre del archivo"; break;
case "prenotazioni":  				$messaggio = "reservas"; break;
case "azione":  				$messaggio = "acción"; break;
case "anno":  					$messaggio = "año"; break;
case "elimina":  				$messaggio = "eliminar"; break;
case "fai l'upload del documento numero":  	$messaggio = "hacer el upload del documento número"; break;
case "fai l'upload":  				$messaggio = "hacer el upload"; break;
case "si è sicuri di voler <b class=\"colred\">cancellare</b> il documento":	$messaggio = "Estas seguro de querer <b class=\"colred\">borrar</b> el documento"; break;
case "cancellato":  				$messaggio = "borrado"; break;
case "inviato":  				$messaggio = "enviado"; break;
case "Commissioni":  				$messaggio = "Comisiones"; break;
case "Tasse":  					$messaggio = "Tasas"; break;
case "senza_commissioni":  			$messaggio = "sin_comisiones"; break;
case "Documenti_salvati":  			$messaggio = "Documentos_salvados"; break;
case "TASSE":  					$messaggio = "TASAS"; break;
case "resto":  					$messaggio = "resto"; break;
case "cancella_periodi":  			$messaggio = "borrar_períodos"; break;
case "Sei sicuro di voler cancellare le commissioni dal":	$messaggio = "Estás seguro de querer borrar las comisiones desde el"; break;
case "sulla tariffa":  				$messaggio = "sobre la tarifa"; break;
case "Le commissioni sono state cancellate":  	$messaggio = "Las comisiones han sido borradas"; break;
case "Le commissioni sono cambiate nel frattempo, non sono state cancellate":	$messaggio = "Las comisiones han cambiado mientras tanto, no han sido borradas"; break;
case "giorno":  				$messaggio = "día"; break;
case "settimana":  				$messaggio = "semana"; break;
case "costi agg.":  				$messaggio = "costes añad."; break;
case "sconto":  				$messaggio = "descuento"; break;
case "Numero di prenotazioni per nazionalità del cliente titolare":	$messaggio = "Número de reservas por nacionalidad del cliente titular"; break;
case "Entrate dalle prenotazioni per nazionalità del cliente titolare":	$messaggio = "Entradas de las reservas por nacionalidad del cliente titular"; break;
case "Prezzi con":  				$messaggio = "Precios con"; break;
case "Prenotazioni anno corrente":  		$messaggio = "Reservas año corriente"; break;
case "con prenotazioni inserite":  		$messaggio = "con reservas insertadas"; break;
case "fino al":  				$messaggio = "hasta"; break;
case "nella cassa chiamata":  			$messaggio = "en la caja llamada"; break;
case "Totale nella cassa principale":  		$messaggio = "Total en la caja principal"; break;
case "Totale nella cassa":  			$messaggio = "Total en la caja"; break;
case "Nuova cassa chiamata":  			$messaggio = "Nueva caja llamada"; break;
case "Crea":  					$messaggio = "Crear"; break;
case "Una cassa chiamata":  			$messaggio = "Una caja llamada"; break;
case "è stata creata":  			$messaggio = "ha sido creada"; break;
case "Cassa chiamata":  			$messaggio = "Caja llamada"; break;
case "La cassa chiamata":  			$messaggio = "La caja llamada"; break;
case "è stata cancellata":  			$messaggio = "ha sido borrada"; break;
case "Eventuali entrate e spese presenti in cassa non sono state cancellate":	$messaggio = "Eventuales entradas y gastos presentes en caja no han sido borrados"; break;
case "Modifica i beni già inseriti":  		$messaggio = "Modificar los bienes ya insertados"; break;
case "Modifica i beni":  			$messaggio = "Modificar los bienes"; break;
case "I beni sono stati modificati":  		$messaggio = "Los bienes han sido modificados"; break;
case "p":  					$messaggio = "p"; break;
case "e combina":  				$messaggio = "y combinar"; break;
case "percentuale su fisso della tariffa":	$messaggio = "porcentaje del fijo de la tarifa"; break;
case "percentuale su una persona della tariffa":	$messaggio = "porcentaje de una persona de la tarifa"; break;
case "non più di":  				$messaggio = "no más de"; break;
case "non più del numero di persone":  		$messaggio = "no más del número de personas"; break;
case "non più del numero totale di persone":  	$messaggio = "no más del número total de personas"; break;
case "meno":  					$messaggio = "menos"; break;
case "aggiungendo":  				$messaggio = "añadiendo"; break;
case "più di":  				$messaggio = "más de"; break;
case "prezzi importati":  			$messaggio = "precios importados"; break;
case "dalla tariffa":  				$messaggio = "desde la tarifa"; break;
case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Borrar las tarjetas de crédito de reservas pasadas"; break;
case "password per le carte di credito":  	$messaggio = "contraseña para las tarjetas de crédito"; break;
case "Cancellate":  				$messaggio = "Borradas"; break;
case "carte di credito":  			$messaggio = "tarjetas de crédito"; break;
case "password errata":  			$messaggio = "contraseña equivocada"; break;
case "Creare":  				$messaggio = "Crear"; break;
case "Aggiungi":  				$messaggio = "Añadir"; break;
case "persona":  				$messaggio = "persona"; break;
case "chiusa":  				$messaggio = "cerrada"; break;
case "presenti in data":  			$messaggio = "presentes el"; break;
case "comprese partenze":  			$messaggio = "incluyendo las salidas"; break;
case "escludere_da_totale_percentuale":  	$messaggio = "excluir_del_total_para_porcentaje"; break;
case "da varie tariffe":  			$messaggio = "desde varias<br>tarifas"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)


?>