
html,body { margin: 0; padding: 0; height: 100%; border: none; }

table.nav_bar tr td { padding: 1px 0 3px 0; }
table.nav_bar tr td a { color: #666666; padding: 3px 0 4px 0; }
table.nav_bar tr td b { padding: 3px 0 4px 0; }

table.t1 tr:hover, table.t1wc tr:hover, table.m1 tr:hover, table.m2 tr:hover  { background-color: #eeeeee; }
table.t1 tr:first-child, table.m1 tr:first-child, table.m2 tr:first-child  { background-color: transparent; }

table.t1, table.m2, table.me1 { border-radius: 8px; }
table.t1 tr:first-child td:first-child, table.m2 tr:first-child td:first-child, table.me1 tr:first-child td:first-child { border-top-left-radius: 8px; }
table.t1 tr:first-child td:last-child, table.m2 tr:first-child td:last-child, table.me1 tr:first-child td:last-child { border-top-right-radius: 8px; }
table.t1 tr:last-child td:last-child, table.m2 tr:last-child td:last-child, table.me1 tr:last-child td:last-child { border-bottom-right-radius: 8px; }
table.t1 tr:last-child td:first-child, table.m2 tr:last-child td:first-child, table.me1 tr:last-child td:first-child { border-bottom-left-radius: 8px; }

table.t1 tr:first-child td, table.me1 tr:first-child td { background: url("../img/bar_bg_top.png") repeat-x left top; }
table.t1, table.me1 { background: url("../img/bar_bg_bot.png") repeat-x left bottom; }
table.me1 table, table.me1 table tr:first-child td { background: transparent; }
table.t1 tr:hover, table.t1wc tr:hover, table.m1 tr:hover, table.m2 tr:hover { background-color: #eeeeee; }
table.t1 tr:first-child, table.m1 tr:first-child, table.m2 tr:first-child { background-color: transparent; }
table.t1 tr td { border-color: #abbbc1; }

button { padding-left: 6px; padding-right: 6px; }
button:not([class]) { padding-left: 0; padding-right: 0; }


/* Main menu */
#mm_sub0 { height: 26px; }
#mm_sub1 { height: 12px; }
#mm_sub2 { height: 12px; }
#mm_sub3 { height: 22px; }
#mm_act td { height: 36px; vertical-align: top; }
#mm_sub4  { padding: 10px 6px 10px 6px }
