<?php

switch ($messaggio) {

case "Configura e personalizza HotelDruid":	$messaggio = "Configure and customize HotelDruid"; break;
case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
case "cambia la lingua":  			$messaggio = "change language"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Table with all the reservations"; break;
case "Cambia la valuta":  			$messaggio = "Change currency"; break;
case "Scegli le colonne da far comparire":  	$messaggio = "Choose the colums that will appear"; break;
case "n° di settimane":  			$messaggio = "n° of weeks"; break;
case "n° di giorni":  				$messaggio = "n° of days"; break;
case "caparra":  				$messaggio = "deposit"; break;
case "pagato":  				$messaggio = "paid"; break;
case "resto da pagare":  			$messaggio = "rest to pay"; break;
case "n° di persone":  				$messaggio = "n° of people"; break;
case "commento":  				$messaggio = "comment"; break;
case "costo aggiuntivo unico":  		$messaggio = "single extra cost"; break;
case "abbreviazione":  				$messaggio = "abbreviation"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "weekly extra cost"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daily extra cost"; break;
case "cambia le colonne":  			$messaggio = "change columns"; break;
case "Tabelle dei mesi":  			$messaggio = "Months tables"; break;
case "Numero di tabelle del 2° tipo":  		$messaggio = "Number of 2nd type tables"; break;
case "cambia":  				$messaggio = "change"; break;
case "Torna al menù principale":  		$messaggio = "Back to main menu"; break;
case "a":  					$messaggio = "to"; break;
case "La lingua è stata cambiata":  		$messaggio = "Language has been changed"; break;
case "La valuta è stata cambiata":  		$messaggio = "Currency has been changed"; break;
case "Le colonne sono state cambiate":  	$messaggio = "Columns have been changed"; break;
case "Il numero di tabelle è stato cambiato":  	$messaggio = "The number of tables has been changed"; break;
case "Documenti":  				$messaggio = "Documents"; break;
case "documento":  				$messaggio = "document"; break;
case "cambia i nomi dei documenti":  		$messaggio = "change documents names"; break;
case "I nomi dei documenti sono stati cambiati":	$messaggio = "Documents names have been changed"; break;
case "Formato di visualizzazione dei soldi":  	$messaggio = "Money viewing format"; break;
case "cambia formato":  			$messaggio = "change format"; break;
case "Il formato di visualizzazione dei soldi è stato cambiato":	$messaggio = "Money viewing format has been changed"; break;
case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "Le date dei menù a tendina sono state cambiate":	$messaggio = "Dates for drop-down menus have been changed"; break;
case "Scegli le date":  			$messaggio = "Choose dates"; break;
case "nei menù a tendina":  			$messaggio = "in drop-down menus"; break;
case "dal":  					$messaggio = "from"; break;
case "al":  					$messaggio = "to"; break;
case "Tronca i cognomi nelle tabelle dopo ":	$messaggio = "Truncate surnames in the tables after "; break;
case "caratteri per colonna":  			$messaggio = "characters per column"; break;
case "La lunghezza dei cognomi nelle tabelle dei mesi è stata cambiata":	$messaggio = "Surnames length in the months tables has been changed"; break;
case "Cambia il numero delle tariffe":  	$messaggio = "Change the number of rates"; break;
case "per l'anno":  				$messaggio = "for year"; break;
case "Il numero delle tariffe è stato cambiato":	$messaggio = "The number of rates has been changed"; break;
case "Il numero di tariffe è sbagliato":  	$messaggio = "The number of rates is wrong"; break;
case "Sistema di backup":  			$messaggio = "Backup system"; break;
case "Il numero delle righe è sbagliato":  	$messaggio = "The number of rows is wrong"; break;
case "Cambia il numero delle righe":  		$messaggio = "Change the number of rows"; break;
case "Il numero delle righe della tabella con tutte le prenotazioni è stato cambiato":	$messaggio = "The number of rows of the table with all the reservations has been changed"; break;
case "Il numero delle righe della tabella con la storia delle entrate e delle uscite è stato cambiato":	$messaggio = "The number of rows of the payments history table has been changed"; break;
case "Tabella con la storia delle entate e uscite":	$messaggio = "Payments history table"; break;
case "Il formato di visualizzazione delle date è stato cambiato":	$messaggio = "Dates viewing format has been changed"; break;
case "Formato di visualizzazione delle date":	$messaggio = "Dates viewing format"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Table with all the clients"; break;
case "Il numero delle righe della tabella con tutti i clienti è stato cambiato":	$messaggio = "The number of rows of the table with all the clients has been changed"; break;
case "Si deve sceliere qualche dato da inserire nella colonna gruppo":	$messaggio = "You must choose some data to insert in the group column"; break;
case "Si deve inserire il nome della colonna gruppo":	$messaggio = "You must insert the name of the group column"; break;
case "La colonna gruppo è stata aggiunta":  	$messaggio = "The group column has been added"; break;
case "Aggiungi una colonna gruppo":  		$messaggio = "Add a group column"; break;
case "Aggiungi colonna gruppo":  		$messaggio = "Add group column"; break;
case "chiamata":  				$messaggio = "called"; break;
case "con":  					$messaggio = "with"; break;
case "colonna gruppo":  			$messaggio = "group column"; break;
case "separatore":  				$messaggio = "separator"; break;
case "spazio":  				$messaggio = "space"; break;
case "trattino":  				$messaggio = "hyphen"; break;
case "a capo":  				$messaggio = "new line"; break;
case "Pagine per il sito web":  		$messaggio = "Website pages"; break;
case " Do":  					$messaggio = " Su"; break;
case " Lu":  					$messaggio = " Mo"; break;
case " Ma":  					$messaggio = " Tu"; break;
case " Me":  					$messaggio = " We"; break;
case " Gi":  					$messaggio = " Th"; break;
case " Ve":  					$messaggio = " Fr"; break;
case " Sa":  					$messaggio = " Sa"; break;
case "Gen":  					$messaggio = "Jan"; break;
case "Feb":  					$messaggio = "Feb"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Apr"; break;
case "Mag":  					$messaggio = "May"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Aug"; break;
case "Set":  					$messaggio = "Sep"; break;
case "Ott":  					$messaggio = "Oct"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dec"; break;
case "nome della tariffa":  			$messaggio = "rate name"; break;
case "data di inserimento":  			$messaggio = "insertion date"; break;
case "tariffa completa":  			$messaggio = "complete rate"; break;
case "Gestione utenti":  			$messaggio = "Users management"; break;
case "Personalizzazioni dell'utente":  		$messaggio = "Customizations of user"; break;
case "Cambia":  				$messaggio = "Change"; break;
case "quelle di":  				$messaggio = "those of"; break;
case "Importa i nomi dei documenti":  		$messaggio = "Import document names"; break;
case "Importa":  				$messaggio = "Import"; break;
case "dell'utente":  				$messaggio = "of user"; break;
case "I minuti di durata di sessioni e transazioni sono stati cambiati":	$messaggio = "The duration in minutes of sessions and transactions has been changed"; break;
case "Le ore di anticipo dell'inizio delle prenotazioni sono state cambiate":	$messaggio = "The hours of advance of the beginning of reservations have been changed"; break;
case "Minuti dopo i quali considerare scadute sessioni e transazioni non aggiornate":	$messaggio = "Minutes after which consider expired not updated sessions and transactions"; break;
case "Numero di ore di cui anticipare il momento in cui si considera iniziata una prenotazione":	$messaggio = "Number of hours by which anticipate the moment in which reservations are considered begun"; break;
case "utente":  				$messaggio = "user"; break;
case "Interconnessioni":  			$messaggio = "Interconnections"; break;
case "Assegnazione automatica disattivata":  	$messaggio = "Automatic assignment disabled"; break;
case "Assegnazione automatica attivata":  	$messaggio = "Automatic assignment enabled"; break;
case "Attiva":  				$messaggio = "Enable"; break;
case "Disattiva":  				$messaggio = "Disable"; break;
case "Scegli il tema grafico":  		$messaggio = "Choose the graphic theme"; break;
case "Il tema grafico è stato cambiato":  	$messaggio = "Graphic theme has been changed"; break;
case "Registrazione degli orari di entrata ed uscita attivata":	$messaggio = "Registration of check-in and check-out enabled"; break;
case "Registrazione degli orari di entrata ed uscita disattivata":	$messaggio = "Registration of check-in and check-out disabled"; break;
case "Le ore di differenza con l'orario del server sono state cambiate":	$messaggio = "Hours of difference with server time have been changed"; break;
case "Ore di differenza con l'orario del server": 	$messaggio = "Hours of difference with server time"; break;
case "ora attuale":  				$messaggio = "current hour"; break;
case "numero":  				$messaggio = "number"; break;
case "cognome cliente":  			$messaggio = "client surname"; break;
case "data iniziale":  				$messaggio = "starting date"; break;
case "data finale":  				$messaggio = "ending date"; break;
case "Le colonne necessarie sono state cambiate":	$messaggio = "Needed columns have been changed"; break;
case "Non mostrare prenotazioni che non hanno almeno una di queste colonne necessarie (non selezionarene per mostrare tutte)":	$messaggio = "Don't show reservations that don't have at least one of these needed columns (don't select any to show all)"; break;
case "cambia le colonne necessarie":  		$messaggio = "change needed columns"; break;
case "Metodo di pagamento eliminato":  		$messaggio = "Payment method deleted"; break;
case "Nuovo metodo di pagamento aggiunto":  	$messaggio = "New payment method added"; break;
case "Metodi di pagamento":  			$messaggio = "Payment methods"; break;
case "elimina":  				$messaggio = "delete"; break;
case "aggiungi":  				$messaggio = "add"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Indicative availability overview"; break;
case "non mostrare":  				$messaggio = "do not show"; break;
case "Il modo di visualizzazione del quadro di disponibilità è stato cambiato":	$messaggio = "The availability overview display mode has been changed"; break;
case "Controllo disponibilità":  		$messaggio = "Availability check"; break;
case "settimane di intervallo":  		$messaggio = "weeks of interval"; break;
case "giorni di intervallo":  			$messaggio = "days of interval"; break;
case "Giorno di inizio/fine settimana cambiato":	$messaggio = "Beginning/end day of week changed"; break;
case "Giorno di inizio/fine settimana nelle tabelle":	$messaggio = "Beginning/end day of week in tables"; break;
case "Anno":  					$messaggio = "Year"; break;
case "Creazione automatica del nuovo anno disattivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Automatic creation of new year disabled (importing data from previous year at the first login of any user)"; break;
case "Creazione automatica del nuovo anno attivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Automatic creation of new year enabled (importing data from previous year at the first login of any user)"; break;
case "Creazione automatica nuovo anno disattivata":	$messaggio = "Automatic creation of new year disabled"; break;
case "Creazione automatica nuovo anno attivata":	$messaggio = "Automatic creation of new year enabled"; break;
case "Sostituisci la parola":  			$messaggio = "Replace the word"; break;
case "Parole da sostituire":  			$messaggio = "Words to replace"; break;
case "La parola da sostituire è stata aggiunta":	$messaggio = "The word to replace has been added"; break;
case "La parola da sostituire è stata eliminata":	$messaggio = "The word to replace has been deleted"; break;
case "modifica il documento":  			$messaggio = "modify document"; break;
case "Aggiungi ai documenti":  			$messaggio = "Add documents"; break;
case "variabili personalizzate":  		$messaggio = "custom variables"; break;
case "Cambia il numero dei documenti":  	$messaggio = "Change the number of documents"; break;
case "Il numero di documenti è stato cambiato":	$messaggio = "The number of documents has been changed"; break;
case "Il numero di documenti è sbagliato":  	$messaggio = "The number of documents is wrong"; break;
case "Indirizzo email":  			$messaggio = "Email address"; break;
case "Mascherare la provenienza delle email sull'envelope":	$messaggio = "Masquerade sender on the email envelope"; break;
case "Il mascheramento della provenienza delle email è stato cambiato":	$messaggio = "The masquerading of email sender has been changed"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Directories where website pages are created"; break;
case "percorsi separati da virgole relativi":	$messaggio = "comma separated paths relative"; break;
case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "to the HotelDruid directory, if they don't begin with /"; break;
case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "I don't have write permissions on directory"; break;
case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "The inserted directory <div style=\"display: inline; color: red;\">does not exist</div>"; break;
case "Le cartelle dove vengono create le pagine per il sito web sono state cambiate":	$messaggio = "The directories where website pages are created have been changed"; break;
case "Selezionare in modo predefinito":  	$messaggio = "By default select"; break;
case "tutte le prenotazioni":  			$messaggio = "all reservations"; break;
case "prenotazioni del periodo corrente":  	$messaggio = "current period reservations"; break;
case "La selezione predefinita delle prenotazioni nella tabella con tutte le prenotazioni è stata cambiata":	$messaggio = "The default selection of reservations in the table with all the reservations has been changed"; break;
case "Numero di righe dopo cui ripetere la riga delle date":	$messaggio = "Number of rows after which show again the dates row"; break;
case "Il numero  di righe dopo cui ripetere la riga delle date è stato cambiato":	$messaggio = "The number of rows after which show again the dates row has been changed"; break;
case "orario entrata stimato":  		$messaggio = "estimated check-in time"; break;
case "Mostrare i giorni nella riga delle date?":	$messaggio = "Show the days in the dates row?"; break;
case "I giorni da mostrare nella tabella dei mesi sono stati cambiati":	$messaggio = "The days to be shown in the dates row have been changed"; break;
case "Nazioni":  				$messaggio = "Nations"; break;
case "Elimina tutte":  				$messaggio = "Delete all"; break;
case "Ripristina predefinite":  		$messaggio = "Restore defaults"; break;
case "Importa le nazioni":  			$messaggio = "Import nations"; break;
case "Regioni/provincie":  			$messaggio = "Regions"; break;
case "Importa le regioni/provincie":  		$messaggio = "Import regions"; break;
case "Nazione cancellata":  			$messaggio = "Nation deleted"; break;
case "Regione/provincia cancellata":  		$messaggio = "Region deleted"; break;
case "Nuova nazione aggiunta":  		$messaggio = "New nation added"; break;
case "Nazioni predefinite ripristinate":  	$messaggio = "Default nations restored"; break;
case "Nazioni cancellate":  			$messaggio = "Nations deleted"; break;
case "Nazioni importate":  			$messaggio = "Nations imported"; break;
case "Nuova regione/provincia aggiunta":  	$messaggio = "New region added"; break;
case "Regioni/provincie predefinite ripristinate":	$messaggio = "Default regions restored"; break;
case "Regioni/provincie cancellate":  		$messaggio = "Regions deleted"; break;
case "Regioni/provincie importate":  		$messaggio = "Regions imported"; break;
case "Parentele":  				$messaggio = "Relatednesses"; break;
case "Importa le parentele":  			$messaggio = "Import relatednesses"; break;
case "Parentela cancellata":  			$messaggio = "Relatedness deleted"; break;
case "Nuova parentela aggiunta":  		$messaggio = "New relatedness added"; break;
case "Parentele predefinite ripristinate":  	$messaggio = "Default relatednesses restored"; break;
case "Parentele cancellate":  			$messaggio = "Relatednesses deleted"; break;
case "Parentele importate":  			$messaggio = "Relatednesses imported"; break;
case "origine":  				$messaggio = "origin"; break;
case "Origini delle prenotazioni":  		$messaggio = "Reservations origins"; break;
case "Nuova origine delle prenotazioni aggiunta":	$messaggio = "New reservations origin added"; break;
case "Origine delle prenotazioni eliminata":  	$messaggio = "Reservations origin deleted"; break;
case "Nome combinazione":  			$messaggio = "Combination name"; break;
case "prenotazioni correnti e future":  	$messaggio = "current and future reservations"; break;
case "Personalizzazioni di <b>tutti gli utenti</b>":  	$messaggio = "Customizations of <b>all users</b>"; break;
case "tutti gli utenti":  			$messaggio = "all users"; break;
case "Personalizzazioni del gruppo":  		$messaggio = "Customizations of group"; break;
case "gruppo":  				$messaggio = "group"; break;
case "Log delle query di modifica generate":	$messaggio = "Log of modification queries made"; break;
case "da tutti gli utenti":  			$messaggio = "by all users"; break;
case "dall'utente":  				$messaggio = "by user"; break;
case "dal gruppo":  				$messaggio = "by group"; break;
case "attivato":				$messaggio = "enabled"; break;
case "disattivato":				$messaggio = "disabled"; break;
case "Vedi i log":  				$messaggio = "View logs"; break;
case "Log delle query di modifica effettuate dagli utenti negli ultimi":	$messaggio = "Logs of modification queries made by users in the last"; break;
case "giorni":  				$messaggio = "days"; break;
case "Utente":  				$messaggio = "User"; break;
case "Data":  					$messaggio = "Date"; break;
case "Query":  					$messaggio = "Query"; break;
case "Cancella tutti i log":  			$messaggio = "Delete all logs"; break;
case "Log delle query di modifica degli utenti normali disattivato":	$messaggio = "Log of modification queries from normal users disabled"; break;
case "Log delle query di modifica degli utenti normali attivato":	$messaggio = "Log of modification queries from normal users enabled"; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Align availability with arrival date?"; break;
case "L'allineamento dei giorni con la disponibilità nella tabella dei mesi è stato cambiato":	$messaggio = "Days alignment with availability in months table has been changed"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Allineare la disponibilità con le date di arrivo potrebbe generare confusione ed errori sulle date di partenza, si è sicuri di voler continuare?":	$messaggio = "Aligning availability with arrival dates may generate confusion and mistakes on departure dates, are you sure you want to continue?"; break;
case "Documenti di identità":  			$messaggio = "Identity documents"; break;
case "Tipo di documento di identità eliminato":	$messaggio = "Type of identity document deleted"; break;
case "Nuovo tipo di documento di identità aggiunto":	$messaggio = "New type of identity document added"; break;
case "Tipi di documento di identità predefiniti ripristinati":	$messaggio = "Default types of identity document restored"; break;
case "Tipi di documento di identità cancellati":	$messaggio = "Types of identity document deleted"; break;
case "Tipi di documento di identità importati":	$messaggio = "Types of identity document imported"; break;
case "Importa i documenti di identità":  	$messaggio = "Import identity documents"; break;
case "codice":  				$messaggio = "code"; break;
case "Nuova nazione":  				$messaggio = "New nation"; break;
case "Nuova regione/provincia":  		$messaggio = "New region"; break;
case "Nuovo documento d'identità":  		$messaggio = "New identity document"; break;
case "Nuova parentela":  			$messaggio = "New relatedness"; break;
case "Elimina tutti":  				$messaggio = "Delete all"; break;
case "Ripristina predefiniti":  		$messaggio = "Restore defaults"; break;
case "Città":  					$messaggio = "Cities"; break;
case "Nuova città":  				$messaggio = "New city"; break;
case "Importa le città":  			$messaggio = "Import cities"; break;
case "Città cancellata":  			$messaggio = "City deleted"; break;
case "Nuova città aggiunta":  			$messaggio = "New city added"; break;
case "Città predefinite ripristinate":  	$messaggio = "Default cities restored"; break;
case "Città cancellate":  			$messaggio = "Cities deleted"; break;
case "Città importate":  			$messaggio = "Cities imported"; break;
case "nella regione/provincia di":  		$messaggio = "in region of"; break;
case "nella nazione":  				$messaggio = "in nation"; break;
case "Titoli dei clienti":  			$messaggio = "Clients titles"; break;
case "sesso":  					$messaggio = "gender"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "f"; break;
case "Titolo dei clienti eliminato":  		$messaggio = "Clients title deleted"; break;
case "Nuovo titolo dei clienti aggiunto":  	$messaggio = "New clients title added"; break;
case "I dati della struttura sono stati cambiati":	$messaggio = "Property data have been changed"; break;
case "Dati della struttura":  			$messaggio = "Property data"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero stelle":  				$messaggio = "Stars number"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "Comune":  				$messaggio = "City"; break;
case "Indirizzo":  				$messaggio = "Address"; break;
case "CAP":  					$messaggio = "Postal code"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "Modifica i dati della struttura":  	$messaggio = "Modify property data"; break;
case "Clicca su un documento per modificarlo":	$messaggio = "Click on a document to modify it"; break;
case "Cambia l'ordine dei documenti":  		$messaggio = "Change documents order"; break;
case "Applica i cambiamenti":  			$messaggio = "Apply changes"; break;
case "Documento":  				$messaggio = "Document"; break;
case "ex":  					$messaggio = "ex"; break;
case "L'ordine dei documenti è stato cambiato":	$messaggio = "Documents order has been changed"; break;
case "Sito web":  				$messaggio = "Website"; break;
case "Nome contatto":  				$messaggio = "Contact name"; break;
case "l'ordine delle tariffe è stato cambiato":	$messaggio = "rates order has been changed"; break;
case "cambia l'ordine delle tariffe":  		$messaggio = "change rates order"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "valore predefinito a cui arrotondare le percentuali dei prezzi":	$messaggio = "default rounding value for percentages of prices"; break;
case "il":  					$messaggio = "the"; break;
case "è stato cambiato":  			$messaggio = "has been changed"; break;
case "password per la visualizzazione dei dati delle carte di credito":	$messaggio = "password to view credit cards data"; break;
case "attivata":  				$messaggio = "enabled"; break;
case "disattivata":  				$messaggio = "disabled"; break;
case "cambia la password":  			$messaggio = "change password"; break;
case "<b>Attenzione</b>: se si perde questa password non sarà più possibile leggere i dati delle carte di credito inserite":	$messaggio = "<b>Warning</b>: if you lose this password you won't be able to read inserted credit cards data anymore"; break;
case "nuova password":  			$messaggio = "new password"; break;
case "ripetere password":  			$messaggio = "repeat password"; break;
case "attiva la password":  			$messaggio = "activate password"; break;
case "le password inserite non coincidono":  	$messaggio = "inserted passwords do not coincide"; break;
case "errore nelle funzioni ssl":  		$messaggio = "error in ssl functions"; break;
case "<b class=\"colred\">Attenzione</b>: tutti i dati delle carte di credito verranno cancellati":	$messaggio = "<b class=\"colred\">Warning</b>: all credit cards data will be deleted"; break;
case "continua":  				$messaggio = "continue"; break;
case "vecchia password":  			$messaggio = "old password"; break;
case "cambiata":  				$messaggio = "changed"; break;
case "piano":  					$messaggio = "floor"; break;
case "casa":  					$messaggio = "house"; break;
case "2°":  					$messaggio = "2nd"; break;
case "3°":  					$messaggio = "3rd"; break;
case "2° codice":  				$messaggio = "2nd code"; break;
case "3° codice":  				$messaggio = "3rd code"; break;
case "Tabella con i documenti salvati":  	$messaggio = "Table with saved documents"; break;
case "Il numero delle righe della tabella con i documenti salvati è stato cambiato":	$messaggio = "The number of rows of the table with saved documents has been changed"; break;
case "valore a cui arrotondare le percentuali delle tasse":	$messaggio = "rounding value for percentages of taxes"; break;
case "commissioni":  				$messaggio = "commissions"; break;
case "resto commissioni":  			$messaggio = "commissions rest"; break;
case "documenti salvati":  			$messaggio = "saved documents"; break;
case "Scegli le righe aggiuntive da mostrare":	$messaggio = "Choose extra rows to be shown"; break;
case "tasse":  					$messaggio = "taxes"; break;
case "trasferito in cassa":  			$messaggio = "transferred in cash box"; break;
case "cambia le righe":  			$messaggio = "change rows"; break;
case "Le righe aggiuntive sono state cambiate":	$messaggio = "Extra rows have been changed"; break;
case "totale":  				$messaggio = "total"; break;
case "soldi prenotazioni cancellate":  		$messaggio = "deleted reservations money"; break;
case "cognome ospite se differente":  		$messaggio = "guest surname if different"; break;
case "Ragione sociale":  			$messaggio = "Company name"; break;
case "URL del logo":  				$messaggio = "Logo URL"; break;
case "Nome delle unità da affittare":  		$messaggio = "Name of rental units"; break;
case "nome personalizzato":  			$messaggio = "custom name"; break;
case "singolare":  				$messaggio = "singular"; break;
case "plurale":  				$messaggio = "plural"; break;
case "genere":  				$messaggio = "gender"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "f"; break;
case "Il nome delle unità da affittare è stato cambiato":	$messaggio = "The name of the rental unit has been changed"; break;
case "Tabelle con le casse":  			$messaggio = "Cashboxes tables"; break;
case "Il numero delle righe delle tabelle con le casse è stato cambiato":	$messaggio = "The number of rows of the tables with the cashboxes has been changed"; break;
case "Elimina il documento":  			$messaggio = "Delete document"; break;
case "Sei sicuro di voler eliminare il documento":	$messaggio = "Are you sure you want to delete document"; break;
case "Il documento è stato eliminato":	$messaggio = "The document has been deleted"; break;
case "Campi da considerare per la ricerca dei clienti":	$messaggio = "Fields to be considered when searching clients"; break;
case "cognome":  				$messaggio = "surname"; break;
case "email":  					$messaggio = "email"; break;
case "nome":  					$messaggio = "name"; break;
case "telefono":  				$messaggio = "telephone"; break;
case "città":  					$messaggio = "city"; break;
case "indirizzo":  				$messaggio = "address"; break;
case "codice postale":  			$messaggio = "postal code"; break;
case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "The fields to be considered when searching clients have been changed"; break;
case "Nome delle unità singole":  		$messaggio = "Name of single units"; break;
case "Tabella dei messaggi":  			$messaggio = "Messages table"; break;
case "Il numero di righe della tabella dei messaggi è stato cambiato":	$messaggio = "The number of rows of the messages table has been changed"; break;
case "Scarica le email di richiesta disponibiltà dal server di posta":	$messaggio = "Download emails for availability enquiries from mail server"; break;
case "per es.":  				$messaggio = "e.g."; break;
case "Protocollo":  				$messaggio = "Protocol"; break;
case "Porta":  					$messaggio = "Port"; break;
case "default":  				$messaggio = "default"; break;
case "persoalizzata":  				$messaggio = "custom"; break;
case "Nome utente":  				$messaggio = "Username"; break;
case "Password":  				$messaggio = "Password"; break;
case "lasciare vuota per chiedere ogni volta":	$messaggio = "leave empty to ask each time"; break;
case "Identificazione messaggi di richiesta":	$messaggio = "Enquiry messages identification"; break;
case "Messaggio iniziale":  			$messaggio = "First post"; break;
case "Qualsiasi messaggio":  			$messaggio = "Any post"; break;
case "da":  					$messaggio = "from"; break;
case "con oggetto contenete":  			$messaggio = "with subject containing"; break;
case "I dati per lo scaricamento delle email sono sbagliati o incompleti":	$messaggio = "The data to download emails are wrong or incomplete"; break;
case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "The download of emails for availability enquiries from mail server has been changed"; break;
case "Colori delle prenotazioni":  		$messaggio = "Reservations colors"; break;
case "Tutto pagato":  				$messaggio = "All paid"; break;
case "Caparra pagata":  			$messaggio = "Deposit paid"; break;
case "Confermate":  				$messaggio = "Confirmed"; break;
case "Non confermate":  			$messaggio = "Not confirmed"; break;
case "I colori sono sbagliati":  		$messaggio = "Colors are wrong"; break;
case "I colori delle prenotazioni sono stati cambiati":	$messaggio = "Reservations colors have been changed"; break;
case "Campi personalizzati dei clienti":  	$messaggio = "Custom fields for clients"; break;
case "Nuovo campo personalizzato dei clienti aggiunto":	$messaggio = "New custom field for clients added"; break;
case "Campo personalizzato dei clienti eliminato":	$messaggio = "Custom field for clients deleted"; break;
case "tipo":  					$messaggio = "type"; break;
case "booleano":  				$messaggio = "boolean"; break;
case "testo":  					$messaggio = "text"; break;
case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "The custom field contains not allowed characters"; break;
case "Gestire anche i codici CVC delle carte di credito":	$messaggio = "Manage the CVC codes from credit cards too"; break;
case "Esonero di responsabilità":  		$messaggio = "Disclaimer"; break;
case "la gestione dei codici CVC avverrà sotto la propria responsabilità, essendo a conoscenza che gli standard di sicurezza PCI ne vietano la registrazione":	$messaggio = "the CVC codes will be managed under your own responsibility, being aware that PCI security standards forbid their storage"; break;
case "L'accettazione di questa clausola conferma che gli sviluppatori di questo software sono liberi da ogni responsibilità sulla sicurezza di questi dati":	$messaggio = "Accepting this clause confirms that the developers of this software are free from all responsibilities regarding the security of these data"; break;
case "Accetto":  				$messaggio = "I Accept"; break;
case "Declino":  				$messaggio = "I Decline"; break;
case "La gestione dei codici cvc è stata cambiata":	$messaggio = "The management of CVC codes has been changed"; break;
case "Scegli le righe con i totali da mostrare":	$messaggio = "Choose which totals to show in rows"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case "mensile":  				$messaggio = "montly"; break;
case "tabella":  				$messaggio = "table"; break;
case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
case "partenze e prenotazioni correnti":  	$messaggio = "departures and current reservations"; break;
case "Commenti personalizzati delle prenotazioni":	$messaggio = "Custom comments for reservations"; break;
case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Custom comment for reservation deleted"; break;
case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "New custom comment for reservation added"; break;
case "Punto vendita ed inventario":  		$messaggio = "Point of sale and inventory"; break;
case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Sorting in inventory and point of sale"; break;
case "alfabetico":  				$messaggio = "alphabetically"; break;
case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "i link per l'esportazione dei calendari in formato ical sono cambiati, ricordarsi di aggiornarli sui calendari esterni":	$messaggio = "the links to export calendars in ical format have changed, remember to update them on external calendars"; break;
case "La tariffa":  				$messaggio = "Rate"; break;
case "è ancora in uso nelle interconnessioni":	$messaggio = "is still in use in interconnections"; break;
case "almeno 8 caratteri, con lettere e numeri o simboli":	$messaggio = "at least 8 characters, with letters and numbers or symbols"; break;
case "diversa dalle ultime":  			$messaggio = "different from last"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>