<?php

switch ($messaggio) {

case "situazione alle":  			$messaggio = "situación a las"; break;
case "del":  					$messaggio = "del"; break;
case "Tabella prenotazioni del":  		$messaggio = "Tabla de reservas del"; break;
case "ERRORE":  				$messaggio = "ERROR"; break;
case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
case "Visualizza la tabella per la stampa":  	$messaggio = "Ver la tabla para imprimir"; break;
case "Visualizza la tabella con i giorni":  	$messaggio = "Ver la tabla con los días"; break;
case "documento di tipo":  			$messaggio = "documento tipo"; break;
case "visualizza":  				$messaggio = "Ver"; break;
case "Prenotazione non confermata":  		$messaggio = "Reserva no confirmada"; break;
case "Prenotazione confermata, caparra non pagata":	$messaggio = "Reserva confirmada, fianza no pagada"; break;
case "Caparra pagata":  			$messaggio = "Fianza pagada"; break;
case "Tutto pagato":  				$messaggio = "Todo pagado"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>