<?php

$lista_parentele = "";
$cod_parentele = "";
$cod2_parentele = "";
$cod3_parentele = "";

#$lista_parentele[0] = "Husband/Wife";
#$cod_parentele[0] = "001";
#$lista_parentele[1] = "Father/Mother";
#$cod_parentele[1] = "002";

?>