<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Volver atrás"; break;
case "Privilegi dell'utente":  			$messaggio = "Privilegos del usuario"; break;
case "Privilegi <b>globali</b>":  		$messaggio = "Privilegos <b>globales</b>"; break;
case "Modifica delle proprie personalizzazioni":	$messaggio = "Modificación de las proprias personalizaciones"; break;
case "Si":  					$messaggio = "Si"; break;
case "No":  					$messaggio = "No"; break;
case "Inserimento di nuovi clienti":  		$messaggio = "Inserción de nuevos clientes"; break;
case "Possibilità di vedere ed utilizzare nelle prenotazioni i clienti già inseriti":	$messaggio = "Posibilidad ded ver y utilizar en las reservas los clientes ya insertados"; break;
case "Solo":  					$messaggio = "Solo"; break;
case "i propri":  				$messaggio = "los proprios"; break;
case "Modifica e cancellazione dei clienti già inseriti":  	$messaggio = "Modificación y cancelación de los clientes ya insertados"; break;
case "dei propri":  				$messaggio = "de los proprios"; break;
case "Inserire in tutti i cognomi dei clienti inseriti da questo utente":	$messaggio = "Insertar en todos los apellidos de los clientes insertados por este usuario"; break;
case "Un prefisso":  				$messaggio = "Un prefijo"; break;
case "Un suffisso":  				$messaggio = "Un sufijo"; break;
case "Niente":  				$messaggio = "Nada"; break;
case "Modifica i privilegi globali":  		$messaggio = "Modificar los privilegios globales"; break;
case "Privilegi per l'anno":			$messaggio = "Privilegios para el año"; break;
case "Anno disattivato":  			$messaggio = "Año Inhabilitado"; break;
case "Attiva":  				$messaggio = "Habilitar"; break;
case "Anno attivato":  				$messaggio = "Año habilitado"; break;
case "Disattiva":  				$messaggio = "Inhabilitar"; break;
case "Prenotazioni inseribili solo nei periodi della regola di assegnazione 1 con le motivazioni selezionate":	$messaggio = "Reservas insertables solo en los períodos de la regla de asignación 1 con motivaciones seleccionadas"; break;
case "nessuna":  				$messaggio = "ninguna"; break;
case "Applica la regola 1":  			$messaggio = "Aplica la regla 1"; break;
case "Sempre":  				$messaggio = "Siempre"; break;
case "Solo per regole non selezionate":  	$messaggio = "Solo para reglas no seleccionadas"; break;
case "Mai":  					$messaggio = "Nunca"; break;
case "Mai, ma non spostare altre prenotazioni in periodi delle regole non selezionate se non vi si possono inserire prenotazioni":	$messaggio = "Nunca, pero no desplazar otras reservas en períodos de las reglas no seleccionadas si allí no se pueden insetar reservas"; break;
case "Permetti l'uso di tutte le <i>tariffe</i> nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permitir utilizar todas las <i>tarifas</i> cuando se insertan o modifican reservas"; break;
case "Permetti l'uso solo delle <i>tariffe</i> selezionate nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permitir utilizar solo las <i>tarifas</i> seleccionadas cuando se insertan o modifican reservas"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Permetti l'uso di tutti i <i>costi aggiuntivi</i> nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permitir utilizar todos los <i>costes añadidos</i> cuando se insertan o modifican reservas"; break;
case "Permetti l'uso solo dei <i>costi aggiuntivi</i> selezionati nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permitir utilizar solo los <i>costes añadidos</i> seleccionados cuando se insertan o modifican reservas"; break;
case "Costo unico":  				$messaggio = "Coste único"; break;
case "Costo settimanale":  			$messaggio = "Coste semanal"; break;
case "Costo giornaliero":  			$messaggio = "Coste diario"; break;
case "Permetti la visualizzazione di tutti i <i>documenti</i>":	$messaggio = "Permitir visualizar todos los <i>documentos</i>"; break;
case "Permetti la visualizzazione solo dei <i>documenti</i> selezionati":	$messaggio = "Permitir visualizar solo los <i>documentos</i> seleccionados"; break;
case "documento":  				$messaggio = "documento"; break;
case "Non permettere l'inserimento di <i>nuove prenotazioni</i>":	$messaggio = "No permitir insertar <i>nuevas reservas</i>"; break;
case "Permetti l'inserimento di <i>nuove prenotazioni</i> con le seguenti possibilità":	$messaggio = "Permitir insertar <i>nuevas reservas</i> con las siguientes posibilidades"; break;
case "Possibilità di confermare la prenotazione":	$messaggio = "Posibilidad de confirmar la reserva"; break;
case "Possibilità di inserire uno sconto":  	$messaggio = "Posibilidad de insertar un descuento"; break;
case "Possibilità di inserire la caparra e le commissioni":  	$messaggio = "Posibilidad de insertar la fianza y las comisiones"; break;
case "Possibilità di inserire dei costi aggiuntivi":	$messaggio = "Posibilidad de insertar costes añadidos"; break;
case "Possibilità di inserire il commento":  	$messaggio = "Posibilidad de insertar el comentario"; break;
case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Posibilidad de insertar los comentarios personalizados"; break;
case "Possibilità di inserire il numero di persone":	$messaggio = "Posibilidad de insertar el número de personas"; break;
case "Possibilità di inserire prenotazioni anche in periodi già iniziati":	$messaggio = "Posibilidad de insertar reservas también en períodos ya empezados"; break;
case "Prenotazioni che possono essere <i>modificate</i>":	$messaggio = "Reservas que pueden ser <i>modificadas</i>"; break;
case "Tutte":  					$messaggio = "Todas"; break;
case "le proprie":  				$messaggio = "las proprias"; break;
case "dei suoi gruppi":  			$messaggio = "de sus grupos"; break;
case "Nessuna":  				$messaggio = "Ninguna"; break;
case "Possibilità di modificare la data iniziale o finale":	$messaggio = "Posibilidad de modificar la fecha inicial o final"; break;
case "Possibilità di modificare la tariffa":  	$messaggio = "Posibilidad de modificar la tarifa"; break;
case "Si, con regola 2 a scelta":  		$messaggio = "Si, con la opción de la regla 2"; break;
case "Si, sempre con regola 2":  		$messaggio = "Si, siempre con regla 2"; break;
case "Possibilità di modificare il numero delle persone":	$messaggio = "Posibilidad de modificar el número de personas"; break;
case "Possibilità di vedere il commento":  	$messaggio = "Posibilidad de ver el comentario"; break;
case "Possibilità di modificare il commento":  	$messaggio = "Posibilidad de modificar el comentario"; break;
case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Posibilidad de ver y modificar los comentarios personalizados"; break;
case "Possibilità di modificare lo sconto":  	$messaggio = "Posibilidad de modificar el descuento"; break;
case "Possibilità di modificare la caparra e le commissioni":	$messaggio = "Posibilidad de modificar la fianza y las comisiones"; break;
case "Possibilità di modificare i costi aggiuntivi":	$messaggio = "Posibilidad de modificar los costes añadidos"; break;
case "Possibilità di modificare i soldi pagati e la conferma":	$messaggio = "Posibilidad de modificar el dinero pagado y la confirmación"; break;
case "Solo la conferma":  			$messaggio = "Solo la Confirmación"; break;
case "Possibilità di modificare prenotazioni già iniziate":	$messaggio = "Posibilidad de modificar reservas ya empezadas"; break;
case "Prenotazioni non più modificabili dopo un certo numero di ore dopo l'inserzione":	$messaggio = "Reservas ya no modificables después de un cierto número de horas después de su inserción"; break;
case "ore":  					$messaggio = "horas"; break;
case "Possibilità di cancellare le prenotazioni":	$messaggio = "Posibilidad de borrar la reserva"; break;
case "Solo quelle non iniziate":  		$messaggio = "Solo las no empezadas"; break;
case "Prenotazioni non più cancellabili dopo un certo numero di ore dopo l'inserzione":	$messaggio = "Reservas ya no borrables después de un cierto número de horas después de su inserción"; break;
case "Possibilità di inserire e cancellare le <i>spese</i>":	$messaggio = "Posibilidad de insertar y borrar los <i>gastos</i>"; break;
case "Possibilità di inserire e cancellare le <i>entrate</i>":	$messaggio = "Posibilidad de insertar y borrar las <i>entradas</i>"; break;
case "<i>Sottrarre le entrate</i> dal totale delle prenotazioni":	$messaggio = "<i>Subtraer las entradas</i> desde el total de las reservas"; break;
case "A scelta":  				$messaggio = "Preguntar"; break;
case "Immettere come <i>persona</i> che inserisce le spese o le entrate":	$messaggio = "Enseñar como <i>persona</i> que inserta los gastos o las entradas"; break;
case "Il nome dell'utente":  			$messaggio = "El nombre del usuario"; break;
case "Chiedere":  				$messaggio = "Preguntar"; break;
case "Nessuno":  				$messaggio = "Nadie"; break;
case "Possibilità di vedere la <i>tabella dei mesi</i>":	$messaggio = "Posibilidad de ver la <i>tabla de los meses</i>"; break;
case "Solo con":				$messaggio = "Solo con"; break;
case "prenotazioni proprie":			$messaggio = "reservas proprias"; break;
case "prenotazioni dai suoi gruppi":		$messaggio = "reservas de sus grupos"; break;
case "a lui":					$messaggio = "a él"; break;
case "ai suoi gruppi":				$messaggio = "a sus grupos"; break;
case "Possibilità di vedere la <i>tabella con tutte le prenotazioni</i>":	$messaggio = "Posibilidad de ver la <i>tabla con todas las reservas</i>"; break;
case "Possibilità di vedere le <i>tabelle con le entrate e le uscite</i>":	$messaggio = "Posibilidad de ver la <i>tabla con los gastos y las entradas</i>"; break;
case "entrate/uscite proprie":  		$messaggio = "gastos/entradas proprias"; break;
case "entrate/uscite dai suoi gruppi":  	$messaggio = "gastos/entradas de sus grupos"; break;
case "Possibilità di vedere la <i>tabella con i periodi e le tariffe</i>":	$messaggio = "Posibilidad de ver la <i>tabla con los períodos y las tarifas</i>"; break;
case "Solo con tariffe consentite":  		$messaggio = "Solo con tarifas permitidas"; break;
case "Possibilità di vedere la <i>tabella con le regole di assegnazione</i>":	$messaggio = "Posibilidad de ver la <i>tabla con las reglas de asignación</i>"; break;
case "Solo con regole consentite":  		$messaggio = "Solo con reglas permitidas"; break;
case "Modifica i privilegi dell'anno":  	$messaggio = "Modificar los privilegios del año"; break;
case "Testo del prefisso/suffisso dei clienti":	$messaggio = "Texto del prefijo/sufijo de los clientes"; break;
case "Si deve inserire il <div style=\"display: inline; color: red;\">prefisso/suffisso</div> da utilizzare per i clienti dell'utente":	$messaggio = "Hay que insertar el <div style=\"display: inline; color: red;\">prefijo/sufijo</div> a utilizar para los clientes del usuario"; break;
case "L'utente":  				$messaggio = "El usuario"; break;
case "potrà modificare le sue <b>personalizzazioni</b>":	$messaggio = "podrá modificar sus <b>personalizaciones</b>"; break;
case "non potrà più modificare le sue <b>personalizzazioni</b>":	$messaggio = "ya no podrá modificar sus <b>personalizaciones</b>"; break;
case "potrà inserire <b>nuovi clienti</b>":  	$messaggio = "podrá insertar <b>nuevos clientes</b>"; break;
case "non potrà più inserire <b>nuovi clienti</b>":	$messaggio = "ya no podrá insertar <b>nuevos clientes</b>"; break;
case "potrà modificare <b>tutti i clienti</b>":	$messaggio = "podrá modificar <b>todos los clientes</b>"; break;
case "potrà modificare solo i <b>propri clienti</b>":	$messaggio = "podrá modificar solo sus <b>proprios clientes</b>"; break;
case "e quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "y los de usuarios que pertenecen a sus grupos"; break;
case "non potrà più modificare <b>nessun cliente</b>":	$messaggio = "ya no podrá modificar <b>ningún cliente</b>"; break;
case "non potrà vedere <b>nessun cliente</b>":	$messaggio = "no podrá ver <b>ningún cliente</b>"; break;
case "potrà vedere solo i <b>propri clienti</b>":	$messaggio = "podrá ver solo sus <b>proprios clientes</b>"; break;
case "potrà vedere <b>tutti i clienti</b>":  	$messaggio = "podrá ver <b>todos los clientes</b>"; break;
case "Verrà aggiunto un <b>prefisso</b> a tutti i cognomi dei clienti inseriti dall'utente":	$messaggio = "se añadirá un <b>prefijo</b> a todos los apellidos de los clientes insertados por el usuario"; break;
case "Verrà aggiunto un <b>suffisso</b> a tutti i cognomi dei clienti inseriti dall'utente":	$messaggio = "se añadirá un <b>sufijo</b> a todos los apellidos de los clientes insertados por el usuario"; break;
case "Non verrà aggiunto più alcun <b>prefisso/suffisso</b> ai cognomi dei clienti inseriti dall'utente":	$messaggio = "ya no se añadirá ningún <b>prefijo/sufijo</b> a todos los apellidos de los clientes insertados por el usuario"; break;
case "Il nuovo testo del <b>prefisso/suffisso</b> dei cognomi dei clienti inseriti dall'utente":	$messaggio = "El nuevo texto del <b>prefijo/sufijo</b> de los clientes insertados por el usuario"; break;
case "sarà":  					$messaggio = "será"; break;
case "Continua":  				$messaggio = "Continuar"; break;
case "Anno <div style=\"display: inline; color: red;\">errato</div>":	$messaggio = "Año <div style=\"display: inline; color: red;\">equivocado</div>"; break;
case "Ore in cui si può modificare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Horas en las que se puede modificar la reserva <div style=\"display: inline; color: red;\">equivocadas</div>"; break;
case "Ore in cui si può cancellare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Horas en las que se puede borrar la reserva <div style=\"display: inline; color: red;\">equivocadas</div>"; break;
case "potrà inserire le sue prenotazioni in <b>tutti i periodi</b> del":	$messaggio = "podrá insertar sus reservas en <b>todos los períodos</b> del"; break;
case "potrà inserire le sue prenotazioni solo nei <b>periodi della regola 1</b> selezionati nel":	$messaggio = "podrá insertar sus reservas solo en los <b>períodos de la regla 1</b> seleccionados del"; break;
case "Verranno cambiate le motivazioni selezionate della <b>regola 1</b> per l'anno":	$messaggio = "Se cambiarán las motivaciones seleccionadas de la regla 1 para el año"; break;
case "verrà avvisato <b>sempre</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "será <b>siempre</b> avisado cuando insertará reservas en períodos de las reglas 1 del"; break;
case "verrà avvisato solo quando inserirà prenotazioni nei periodi delle regole 1 <b>non selezionate</b> del":	$messaggio = "será avisado solo cuando insertará reservas en períodos de las reglas 1 <b>no seleccionadas</b> del"; break;
case "non verrà avvisato <b>mai</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "no será <b>nunca</b> avisado cuando insertará reservas en períodos de las reglas 1 del"; break;
case "se non vi può inserire prenotazioni":	$messaggio = "si no puede insertar reservas en ellos"; break;
case "potrà utilizzare <b>tutte le tariffe</b> del":	$messaggio = "podrá utilizar <b>todas las tarifas</b> del"; break;
case "potrà utilizzare solo le <b>tariffe selezionate</b> del":	$messaggio = "podrá utilizar solo las <b>tarifas seleccionadas</b> del"; break;
case "Verranno cambiate le <b>tariffe selezionate</b> da utilizzare per l'anno":	$messaggio = "Se cambiarán las <b>tarifas seleccionadas</b> a utilizar para el año"; break;
case "potrà utilizzare <b>tutti i costi aggiuntivi</b> del":	$messaggio = "podrá utilizar <b>todos los costes añadidos</b> del"; break;
case "potrà utilizzare solo i <b>costi aggiuntivi selezionati</b> del":	$messaggio = "podrá utilizar solo los <b>costes añadidos seleccionados</b> del"; break;
case "Verranno cambiati i <b>costi aggiuntivi</b> da utilizzare per l'anno":	$messaggio = "Se cambiarán las <b>costes añadidos seleccionados</b> a utilizar para el año"; break;
case "potrà visualizzare <b>tutti i documenti</b> del":	$messaggio = "podrá visualizar <b>todos los documentos</b> del"; break;
case "potrà visualizzare solo i <b>documenti selezionati</b> del":	$messaggio = "podrá visualizar solo los <b>documentos seleccionados</b> del"; break;
case "Verranno cambiati i <b>documenti</b> visualizzabili per l'anno":	$messaggio = "Se cambiarán las <b>documentos seleccionados</b> a visualizar para el año"; break;
case "non potrà inserire <b>nuove prenotazioni</b> nel":	$messaggio = "no podrá insertar <b>nuevas reservas</b> en el"; break;
case "potrà inserire <b>nuove prenotazioni</b> nel":	$messaggio = "podrá insertar <b>nuevas reservas</b> en el"; break;
case "non potrà <b>confermare</b> le nuove prenotazioni inserite nel":	$messaggio = "no podrá <b>confirmar</b> las nuevas reservas insertadas en el"; break;
case "potrà <b>confermare</b> le nuove prenotazioni inserite nel":	$messaggio = "podrá <b>confirmar</b> las nuevas reservas insertadas en el"; break;
case "non potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar un <b>descuento</b> cuando inserta nuevas reservas en el"; break;
case "potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar un <b>descuento</b> cuando inserta nuevas reservas en el"; break;
case "non potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar una <b>fianza</b> y las <b>comisiones</b> cuando inserta nuevas reservas en el"; break;
case "potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar una <b>fianza</b> y las <b>comisiones</b> cuando inserta nuevas reservas en el"; break;
case "non potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar <b>costes añadidos</b> cuando inserta nuevas reservas en el"; break;
case "potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar <b>costes añadidos</b> cuando inserta nuevas reservas en el"; break;
case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar el <b>comentario</b> cuando inserta nuevas reservas en el"; break;
case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar el <b>comentario</b> cuando inserta nuevas reservas en el"; break;
case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar los <b>comentarios personalizados</b> cuando inserta nuevas reservas en el"; break;
case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar los <b>comentarios personalizados</b> cuando inserta nuevas reservas en el"; break;
case "non potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar el <b>número de las personas</b> cuando inserta nuevas reservas en el"; break;
case "potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar el <b>número de las personas</b> cuando inserta nuevas reservas en el"; break;
case "non potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "no podrá insertar nuevas reservas en <b>períodos ya empezados</b> en el"; break;
case "potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "podrá insertar nuevas reservas en <b>períodos ya empezados</b> en el"; break;
case "non potrà modificare <b>nessuna prenotazione</b> nel":	$messaggio = "no podrá modificar <b>ninguna reserva</b> en el"; break;
case "potrà modificare solo le <b>sue prenotazioni</b> nel":	$messaggio = "podrá modificar solo <b>sus reservas</b> en el"; break;
case "potrà modificare solo le <b>sue prenotazioni</b> e quelle di utenti appartenenti ai suoi gruppi nel":	$messaggio = "podrá modificar solo <b>sus reservas</b> y las de usuarios que pertenecen a sus grupos en el"; break;
case "potrà modificare <b>tutte le prenotazioni</b> nel":	$messaggio = "podrá modificar <b>todas las reservas</b> en el"; break;
case "non potrà modificare la <b>data iniziale o finale</b> delle prenotazioni nel":	$messaggio = "no podrá modificar la <b>fecha inicial o final</b> de las reservas en el"; break;
case "potrà modificare la <b>data iniziale o finale</b> delle prenotazioni nel":	$messaggio = "podrá modificar la <b>fecha inicial o final</b> de las reservas en el"; break;
case "non potrà modificare la <b>tariffa</b> delle prenotazioni nel":	$messaggio = "no podrá modificar la <b>tarifa</b> de las reservas en el"; break;
case "potrà modificare la <b>tariffa</b> delle prenotazioni, scegliendo se utilizzare la regola 2, nel":	$messaggio = "podrá modificar la <b>tarifa</b> de las reservas, escogiendo si utilizar la regla 2, en el"; break;
case "non potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "no podrá modificar el <b>número de las personas</b> de las reservas en el"; break;
case "potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "podrá modificar el <b>número de las personas</b> de las reservas en el"; break;
case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "no podrá ver el <b>comentario</b> de las reservas en el"; break;
case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "podrá ver el <b>comentario</b> de las reservas en el"; break;
case "non potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "no podrá modificar el <b>comentario</b> de las reservas en el"; break;
case "potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "podrá modificar el <b>comentario</b> de las reservas en el"; break;
case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "no podrá ver y modificar los <b>comentarios personalizados</b> de las reservas en el"; break;
case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "podrá ver y modificar los <b>comentarios personalizados</b> de las reservas en el"; break;
case "non potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "no podrá modificar el <b>descuento</b> de las reservas en el"; break;
case "potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "podrá modificar el <b>descuento</b> de las reservas en el"; break;
case "non potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "no podrá modificar la <b>fianza</b> y las <b>comisiones</b> de las reservas en el"; break;
case "potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "podrá modificar la <b>fianza</b> y las <b>comisiones</b> de las reservas en el"; break;
case "non potrà modificare i <b>costi aggiuntivi</b> delle prenotazioni nel":	$messaggio = "no podrá modificar los <b>costes añadidos</b> de las reservas en el"; break;
case "potrà modificare i <b>costi aggiuntivi</b> delle prenotazioni nel":	$messaggio = "podrá modificar los <b>costes añadidos</b> de las reservas en el"; break;
case "non potrà modificare i <b>soldi pagati</b> e la <b>conferma</b> delle prenotazioni nel":	$messaggio = "no podrá modificar el <b>dinero pagado</b> y la <b>confirmación</b> de las reservas en el"; break;
case "non potrà modificare i <b>soldi pagati</b> ma solo la <b>conferma</b> delle prenotazioni nel":	$messaggio = "no podrá modificar el <b>dinero pagado</b> sino solo la <b>confirmación</b> de las reservas en el"; break;
case "potrà modificare i <b>soldi pagati</b> e la <b>conferma</b> delle prenotazioni nel":	$messaggio = "podrá modificar el <b>dinero pagado</b> y la <b>confirmación</b> de las reservas en el"; break;
case "non potrà modificare le <b>prenotazioni già iniziate</b> nel":	$messaggio = "no podrá modificar las <b>reservas ya empezadas</b> en el"; break;
case "potrà modificare anche le <b>prenotazioni già iniziate</b> nel":	$messaggio = "podrá modificar las <b>reservas ya empezadas</b> en el"; break;
case "non avrà <b>limite di tempo</b> per modificare le prenotazioni nel":	$messaggio = "no tendrá <b>limite de tiempo</b> para modificar las reservas en el"; break;
case "non potrà più modificare le prenotazioni <b>dopo":	$messaggio = "ya no podrá modificar las reservas <b>después de"; break;
case "non potrà <b>cancellare</b> nessuna prenotazione nel":	$messaggio = "no podrá <b>borrar</b> ninguna reserva en el"; break;
case "potrà <b>cancellare</b> solo le prenotazioni non iniziate nel":	$messaggio = "podrá <b>borrar</b> solo las reservas que no han empezado en el"; break;
case "potrà <b>cancellare</b> tutte le prenotazioni nel":	$messaggio = "podrá <b>borrar</b> todas las reservas en el"; break;
case "non avrà <b>limite di tempo</b> per cancellare le prenotazioni nel":	$messaggio = "no tendrá <b>limite de tiempo</b> para borrar las reservas en el"; break;
case "ore</b> nel":  				$messaggio = "horas</b> en el"; break;
case "non potrà più cancellare le prenotazioni <b>dopo":	$messaggio = "ya no podrá borrar las reservas <b>después de"; break;
case "non potrà inserire le <b>spese</b> nel":	$messaggio = "no podrá insertar los <b>gastos</b> en el"; break;
case "potrà inserire le <b>spese</b> nel":  	$messaggio = "podrá insertar los <b>gastos</b> en el"; break;
case "non potrà inserire le <b>entrate</b> nel":	$messaggio = "no podrá insertar las <b>entradas</b> en el"; break;
case "potrà inserire le <b>entrate</b> nel":	$messaggio = "podrá insertar las <b>entradas</b> en el"; break;
case "Le entrate inserite non verranno mai <b>sottratte</b> dal totale delle prenotazioni nel":	$messaggio = "Las entradas insertadas no serán nunca <b>subtraidas</b> desde el total de las reservas en el"; break;
case "potrà decidere se <b>sottrarre</b> le entrate dal totale delle prentazioni nel":	$messaggio = "podrá decidir si <b>subtraer</b> las entradas desde el total de las reservas en el"; break;
case "Le entrate inserite verranno sempre <b>sottratte</b> dal totale delle prenotazioni nel":	$messaggio = "Las entradas insertadas serán siempre <b>subtraidas</b> desde el total de las reservas en el"; break;
case "Non verrà inserito nessuno come <b>persona</b> che inserisce le spese o le entrate nel":	$messaggio = "No se insertará a nadie como <b>persona</b> que inserta los gastos o las entradas en el"; break;
case "potrà scegliere chi inserire come <b>persona</b> che inserisce le spese e le entrate nel":	$messaggio = "podrá escoger quien insertar como <b>persona</b> que inserta los gastos o las entradas en el"; break;
case "Verrà sempre inserito il nome dell'utente":	$messaggio = "Se insertará siempre el nombre del usuario"; break;
case "come <b>persona</b> che inserisce le spese e le entrate nel": 	$messaggio = "como <b>persona</b> que inserta los gastos o las entradas en el"; break;
case "non potrà vedere le <b>tabelle dei mesi</b> del":	$messaggio = "no podrá ver las <b>tablas de los meses</b> del"; break;
case "nelle <b>tabelle dei mesi</b> del":  	$messaggio = "en las <b>tablas de los meses</b> del"; break;
case "potrà vedere le <b>tabelle dei mesi</b> del":	$messaggio = "podrá ver las <b>tablas de los meses</b> del"; break;
case "non potrà vedere la <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "no podrá ver la <b>tabla con todas las reservas</b> del"; break;
case "potrà vedere solo le proprie prenotazioni nella <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "podrá ver solo sus proprias reservas en la <b>tabla con todas las reservas</b> del"; break;
case "potrà vedere solo le prenotazioni sue e di utenti appartenenti ai suoi gruppi nella <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "podrá ver solo las reservas suyas y de usuarios que pertenecen a sus grupos en la <b>tabla con todas las reservas</b> del"; break;
case "potrà vedere la <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "podrá ver la <b>tabla con todas las reservas</b> del"; break;
case "non potrà vedere le <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "no podrá ver las <b>tablas con los gastos y las entradas</b> del"; break;
case "potrà vedere solo le proprie entrate/uscite nelle <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "podrá ver solo sus proprios gastos/entradas en las <b>tablas con los gastos y las entradas</b> del"; break;
case "potrà vedere solo le entrate/uscite sue e di utenti appartenenti ai suoi gruppi nelle <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "podrá ver solo los gastos/entradas suyos y de usuarios que pertenecen a sus grupos en las <b>tablas con los gastos y las entradas</b> del"; break;
case "potrà vedere le <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "podrá ver las <b>tablas con los gastos y las entradas</b> del"; break;
case "non potrà vedere la <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "no podrá ver la <b>tabla con los períodos y las tarifas</b> del"; break;
case "potrà vedere solo le tariffe a lui consentite nella <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "podrá ver solo las tarifas a él permitidas en la <b>tabla con los períodos y las tarifas</b> del"; break;
case "potrà vedere solo le tariffe consentite a lui e ad utenti dei suoi gruppi nella <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "podrá ver solo las tarifas permitidas a él y a usuarios de sus grupos en la <b>tabla con los períodos y las tarifas</b> del"; break;
case "potrà vedere la <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "podrá ver la <b>tabla con los períodos y las tarifas</b> del"; break;
case "non potrà vedere la <b>tabella con le regole di assegnazione</b> del":	$messaggio = "no podrá ver la <b>tabla con las reglas de asignación</b> del"; break;
case "potrà vedere solo le regole a lui consentite nella <b>tabella con le regole di assegnazione</b> del":	$messaggio = "podrá ver solo las reglas a él permitidas en la <b>tabla con las reglas de asignación</b> del"; break;
case "potrà vedere solo le regole consentite a lui e ad utenti dei suoi gruppi nella <b>tabella con le regole di assegnazione</b> del":	$messaggio = "podrá ver solo las reglas permitidas a él y a usuarios de sus grupos en la <b>tabla con las reglas de asignación</b> del"; break;
case "potrà vedere la <b>tabella con le regole di assegnazione</b> del":	$messaggio = "podrá ver la <b>tabla con las reglas de asignación</b> del"; break;
case "Possibilità di inserire più prenotazioni contemporaneamente":	$messaggio = "Posibilidad de insertar mas reservas contemporaneamente"; break;
case "non potrà inserire <b>più prenotazioni contemporaneamente</b> nel":	$messaggio = "no podrá insertar <b>mas reservas contemporaneamente</b> en el"; break;
case "potrà inserire <b>più prenotazioni contemporaneamente</b> nel":	$messaggio = "podrá insertar <b>mas reservas contemporaneamente</b> en el"; break;
case "Prenotazioni non più cancellabili dopo essere state confermate":	$messaggio = "Reservas ya no borrables después haber sido confirmadas"; break;
case "non potrà <b>cancellare</b> le prenotazioni confermate nel":	$messaggio = "no podrá <b>borrar</b> las reservas confirmadas en el"; break;
case "potrà <b>cancellare</b> le prenotazioni confermate nel":	$messaggio = "podrá <b>borrar</b> las reservas confirmadas en el"; break;
case "Possibilità di modificare l'orario di entrata ed uscita":	$messaggio = "Posibilidad de modificar el horario de entrada y salida"; break;
case "non potrà modificare l'orario di <b>entrata ed uscita</b> delle prenotazioni nel":	$messaggio = "no podrá modificar el <b>horario de entrada y salida</b> de las reservas en el"; break;
case "potrà modificare l'orario di <b>entrata ed uscita</b> delle prenotazioni nel":	$messaggio = "podrá modificar el <b>horario de entrada y salida</b> de las reservas en el"; break;
case "Possibilità di vedere i messaggi ricevuti":	$messaggio = "Posibilidad de ver los mensajes recibidos"; break;
case "Possibilità di mandare messaggi":  	$messaggio = "Posibilidad de enviar mensajes"; break;
case "non potrà vedere <b>i messaggi ricevuti</b>":	$messaggio = "no podrá ver <b>los mensajes recibidos</b>"; break;
case "potrà vedere <b>i messaggi ricevuti</b>":	$messaggio = "podrá ver <b>los mensajes recibidos</b>"; break;
case "non potrà <b>inviare messaggi</b>":	$messaggio = "no podrá <b>enviar mensajes</b>"; break;
case "potrà <b>inviare messaggi</b>":  		$messaggio = "podrá <b>enviar mensajes</b>"; break;
case "Possibilità di inserire l'orario di entrata":	$messaggio = "Posibilidad de insertar el horario de entrada"; break;
case "non potrà inserire l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá cambiar el <b>horario de entrada</b> cuando inserta nuevas reservas en el"; break;
case "potrà inserire la l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá cambiar el <b>horario de entrada</b> cuando inserta nuevas reservas en el"; break;
case "non potrà vedere e modificare il <b>codice prenotazione</b> nel":	$messaggio = "no podrá ver y modificar el <b>código de reserva</b> en el"; break;
case "potrà vedere e modificare il <b>codice prenotazione</b> nel":	$messaggio = "podrá ver y modificar el <b>código de reserva</b> en el"; break;
case "Possibilità di vedere e modificare il codice prenotazione":	$messaggio = "Posibilidad de ver y modificar el código de reserva"; break;
case "Possibilità di cambiare il cliente con un altro":	$messaggio = "Posibilidad de cambiar el cliente con otro"; break;
case "potrà cambiare il <b>cliente</b> delle prenotazioni nel":	$messaggio = "podrá cambiar el <b>cliente</b> de las reservas en el"; break;
case "non potrà cambiare il <b>cliente</b> delle prenotazioni nel":	$messaggio = "no podrá cambiar el <b>cliente</b> de las reservas en el"; break;
case "potrà inserire <b>più prenotazioni contemporaneamente ma non vicine</b> nel":	$messaggio = "podrá insertar <b>mas reservas contemporaneamente pero no cercanas</b> en el"; break;
case "Possibilità di modificare le prenotazioni vicine":	$messaggio = "Posibilidad de modificar las reservas cercanas"; break;
case "non potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "no podrá modificar las <b>reservas cercanas</b> en el"; break;
case "potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "podrá modificar las <b>reservas cercanas</b> en el"; break;
case "Possibilità di inserire l'origine":  	$messaggio = "Posibilidad de insertar el origen"; break;
case "Possibilità di modificare l'origine":  	$messaggio = "Posibilidad de modificar el origen"; break;
case "potrà inserire <b>l'origine della prenotazione</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar el <b>origen de la reserva</b> cuando inserta nuevas reservas en el"; break;
case "non potrà inserire <b>l'origine della prenotazione</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar el <b>origen de la reserva</b> cuando inserta nuevas reservas en el"; break;
case "potrà modificare il <b>l'origine</b> delle prenotazioni nel":	$messaggio = "podrá cambiar el <b>origen</b> de las reservas en el"; break;
case "non potrà modificare <b>l'origine</b> delle prenotazioni nel":	$messaggio = "no podrá cambiar el <b>origen</b> de las reservas en el"; break;
case "Possibilità di modificare le <i>tariffe</i> a lui permesse":	$messaggio = "Posibilidad de modificar las <i>tarifas</i> a él permitidas"; break;
case "Possibilità di inserire <i>nuovi costi aggiuntivi</i>":	$messaggio = "Posibilidad de insertar <i>nuevos costes añadidos</i>"; break;
case "rendendoli disponibili":			$messaggio = "haciendolos disponibles"; break;
case "solo a lui":  				$messaggio = "solo a él"; break;
case "a utenti dei suoi gruppi":  		$messaggio = "a los usuarios de sus grupos"; break;
case "Possibilità di modificare i <i>costi aggiuntivi</i> a lui permessi":	$messaggio = "Posibilidad de modificar los <i>costes añadidos</i> a él permitidos"; break;
case "non potrà modifcare le <b>tariffe a lui permesse</b> nel":	$messaggio = "no podrá modificar las <b>tarifas a él permitidas</b> en el"; break;
case "potrà modifcare le <b>tariffe a lui permesse</b> nel":	$messaggio = "podrá modificar las <b>tarifas a él permitidas</b> en el"; break;
case "non potrà inserire <b>nuovi costi aggiuntivi</b> nel":	$messaggio = "no podrá insertar <b>nuevos costes añadidos</b> en el"; break;
case "potrà inserire <b>nuovi costi aggiuntivi</b> il cui utilizzo sarà permesso a lui e agli utenti appartenenti ai suoi stessi gruppi nel":	$messaggio = "podrá insertar <b>nuevos costes añadidos</b> cuyo utilizo será permitido solo a él y a los usuarios que pertenecen a sus mismos grupos en el"; break;
case "potrà inserire <b>nuovi costi aggiuntivi</b> il cui utilizzo sarà permesso solo a lui nel":	$messaggio = "podrá insertar <b>nuevos costes añadidos</b> cuyo utilizo será permitido solo a él en el"; break;
case "non potrà modifcare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "no podrá modificar los <b>costes añadidos</b> a él permitidos en el"; break;
case "potrà modifcare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "podrá modificar los <b>costes añadidos</b> a él permitidos en el"; break;
case "Possibilità di cancellare i <i>costi aggiuntivi</i> a lui permessi":	$messaggio = "Posibilidad de borrar los <i>costes añadidos</i> a él permitidos"; break;
case "non potrà cancellare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "no podrá borrar los <b>costes añadidos</b> a él permitidos en el"; break;
case "potrà cancellare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "podrá borrar los <b>costes añadidos</b> a él permitidos en el"; break;
case "nelle <b>statistiche</b> del":  		$messaggio = "en las <b>estadídticas</b> del"; break;
case "non potrà vedere le <b>statistiche</b> del":	$messaggio = "no podrá ver las <b>estadídticas</b> del"; break;
case "potrà vedere le <b>statistiche</b> del":	$messaggio = "podrá ver las <b>estadídticas</b> del"; break;
case "Possibilità di vedere <i>le statistiche</i>":	$messaggio = "Posibilidad de ver <i>las estadídticas</i>"; break;
case "Possibilità di vedere i <i>beni dell'inventario</i>":	$messaggio = "Posibilidad de ver los <i>bienes del inventario</i>"; break;
case "Possibilità di inserire nuovi beni nell'inventario":	$messaggio = "Posibilidad de insertar nuevos bienes"; break;
case "Possibilità di vedere l'<i>inventario dei magazzini</i>":	$messaggio = "Posibilidad de ver el <i>inventario de los almacenes</i>"; break;
case "Possibilità di inserire nuovi magazzini":	$messaggio = "Posibilidad de insertar nuevos almacenes"; break;
case "Possibilità di aggiungere e cancellare beni":	$messaggio = "Posibilidad de añadir y borrar bienes"; break;
case "Solo in":  				$messaggio = "Solo en"; break;
case "magazzini propri":  			$messaggio = "proprios almacenes"; break;
case "magazzini dei suoi gruppi":  		$messaggio = "almacenes de sus grupos"; break;
case "Possibilità di modificare le quantità dei beni":	$messaggio = "Posibilidad de modificar la cantidad de los bienes"; break;
case "non potrà vedere i <b>beni dell'inventario</b>":	$messaggio = "no podrá ver los <b>bienes del inventario</b>"; break;
case "potrà vedere solo i <b>suoi beni dell'inventario</b>":	$messaggio = "podrá ver solo <b>sus proprios bienes del inventario</b>"; break;
case "potrà vedere i <b>beni dell'inventario</b>":	$messaggio = "podrá ver los <b>bienes del inventario</b>"; break;
case "non potrà <b>inserire nuovi beni</b> nell'inventario":	$messaggio = "no podrá <b>insertar nuevos bienes</b> en el inventario"; break;
case "potrà <b>inserire nuovi beni</b> nell'inventario":	$messaggio = "podrá <b>insertar nuevos bienes</b> en el inventario"; break;
case "non potrà vedere <b>l'inventario":  	$messaggio = "no podrá ver el <b>inventario"; break;
case "potrà vedere <b>l'inventario":  		$messaggio = "podrá ver el <b>inventario"; break;
case "dei magazzini</b>":  			$messaggio = "de los almacenes</b>"; break;
case "solo dei suoi magazzini</b>":  		$messaggio = "solo de sus almacenes</b>"; break;
case "e di quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "y de los de usuarios que pertenecen a sus grupos"; break;
case "non potrà <b>inserire nuovi magazzini</b>":	$messaggio = "no podrá <b>insertar nuevos almacenes</b>"; break;
case "potrà <b>inserire nuovi magazzini</b>":	$messaggio = "podrá <b>insertar nuevos almacenes</b>"; break;
case "non potrà <b>aggiungere e cancellare beni</b>":	$messaggio = "no podrá <b>añadir y borrar bienes</b>"; break;
case "potrà <b>aggiungere e cancellare beni</b>":	$messaggio = "podrá <b>añadir y borrar bienes</b>"; break;
case "nei magazzini":  				$messaggio = "en los almacenes"; break;
case "solo nei suoi magazzini":  		$messaggio = "solo en sus almacenes"; break;
case "e in quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "y en los de usuarios que pertenecen a sus grupos"; break;
case "non potrà <b>modificare le quantità dei beni</b>":	$messaggio = "no podrá <b>modificar la cantidad de los bienes</b>"; break;
case "potrà <b>modificare le quantità dei beni</b>":	$messaggio = "podrá <b>modificar la cantidad de los bienes</b>"; break;
case "creazione, download e cancellazione del backup completo":	$messaggio = "creación, descarga y borrado del backup completo"; break;
case "potrà creare i <b>backup</b>":  		$messaggio = "podrá crear los <b>backups</b>"; break;
case "non potrà più creare i <b>backup</b>":  	$messaggio = "ya no podrá crear los <b>backups</b>"; break;
case "Possibilità di vedere la <i>tabella con i documenti salvati</i>":	$messaggio = "Posibilidad de ver la <i>tabla con los documentos salvados</i>"; break;
case "Solo con documenti consentiti":  		$messaggio = "Solo con documentos permitidas"; break;
case "non potrà vedere la <b>tabella con i documenti salvati</b> del":	$messaggio = "no podrá ver la <b>tabla con los documentos salvados</b> del"; break;
case "potrà vedere solo i documenti a lui consentiti nella <b>tabella con i documenti salvati</b> del":	$messaggio = "podrá ver solo documentos a él permitidos en la <b>tabla con los documentos salvados</b> del"; break;
case "potrà vedere la <b>tabella con i documenti salvati</b> del":	$messaggio = "podrá ver la <b>tabla con los documentos salvados</b> del"; break;
case "Permetti l'uso solo delle <i>casse</i> selezionate":	$messaggio = "Permitir utilizar solo las <i>cajas</i> seleccionadas"; break;
case "Permetti l'uso di tutte le <i>casse</i>":	$messaggio = "Permitir utilizar todas las <i>cajas</i>"; break;
case "cassa principale":  			$messaggio = "caja principal"; break;
case "potrà usare <b>tutte le casse</b>":  	$messaggio = "podrá utilizar <b>tutta las cajas</b>"; break;
case "potrà usare solo le <b>casse selezionate</b>":	$messaggio = "podrá utilizar solo las <b>cajas seleccionadas</b>"; break;
case "Verranno cambiate le <b>casse</b> utilizzabili":	$messaggio = "Se cambiarán las <b>cajas</b> utilizables"; break;
case "Inserire sempre i pagamenti delle prenotazioni nella cassa":	$messaggio = "Insertar siempre los pagos de las reservas en la caja"; break;
case "I pagamenti inseriti nelle prenotazioni dall'utente":	$messaggio = "Los pagos insertados en las reservas por el usuario"; break;
case "verranno anche registrati come entrate nella cassa chiamata":	$messaggio = "serán registrados también como entradas en la caja llamada"; break;
case "non verranno registrati in cassa nel":	$messaggio = "no serán registrados en caja en el"; break;
case "nel":  					$messaggio = "en el"; break;
case "Modifica dei documenti":  		$messaggio = "Modificar documentos"; break;
case "potrà modificare i <b>documenti</b>":  	$messaggio = "podrá modificar los <b>documentos</b>"; break;
case "non potrà più modificare i <b>documenti</b>":	$messaggio = "ya no podrá modificar los <b>documentos</b>"; break;
case "Possibilità di vedere email, telefoni e fax dei clienti":	$messaggio = "Posibilidad de ver emails, teléfonos y faxes de los clientes"; break;
case "Possibilità di vedere l'indirizzo dei clienti":	$messaggio = "Posibilidad de ver la dirección de los clientes"; break;
case "potrà vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "podrá ver <b>emails, teléfonos y faxes</b> de los clientes"; break;
case "non potrà più vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "ya no podrá ver <b>emails, teléfonos y faxes</b> de los clientes"; break;
case "potrà vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "podrá ver <b>la dirección</b> de los clientes"; break;
case "non potrà più vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "ya no podrá ver <b>la dirección</b> de los clientes"; break;
case "Mostrare le prenotazioni non permesse come":	$messaggio = "Mostrar las reservas no permitidas como"; break;
case "oscurate":  				$messaggio = "oscurecidas"; break;
case "periodi vuoti":  				$messaggio = "períodos vacios"; break;
case "solo correnti e future":  		$messaggio = "solo corrientes y futuras"; break;
case "vedrà le prenotazioni non permesse come <em>oscurate</em>":	$messaggio = "verá las reservas no permitidas como <em>oscurecidas</em>"; break;
case "vedrà le prenotazioni non permesse come <em>periodi vuoti</em>":	$messaggio = "verá las reservas no permitidas como <em>períodos vacios</em>"; break;
case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed oscurate nel presente e nel futuro</em>":	$messaggio = "verá las reservas no permitidas como <em>períodos vacios en el pasado y oscurecidas en el presente y futuro</em>"; break;
case "Possibilità di cancellare o sovrascrivere i documenti salvati":	$messaggio = "Posibilidad de borrar o sobrescribir los documentos guardados"; break;
case "potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "podrá <b>borrar y sobrescribir los documentos</b> guardados en"; break;
case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "no podrá <b>borrar y sobrescribir los documentos</b> guardados en"; break;
case "Creazione e modifica delle interconnessioni":	$messaggio = "Creación y modificación de las interconexiones"; break;
case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "podrá crear y modificar las <b>interconexiones</b>"; break;
case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "ya no podrá crear y modificar las <b>interconexiones</b>"; break;
case "Modifica dei documenti come API":  	$messaggio = "Modificar documentos como API"; break;
case "potrà modificare i <b>documenti come API</b>":	$messaggio = "podrá modificar los <b>documentos como API</b>"; break;
case "Attenzione":  				$messaggio = "Atención"; break;
case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "esto podrá dar acceso a los datos de todas las reservas"; break;
case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "ya no podrá modificar los <b>documentos como API</b>"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>