<?php

switch ($messaggio) {

case "Tabella tariffe del":  			$messaggio = "Rates table of"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "aggiungi":  				$messaggio = "add"; break;
case "settimane":  				$messaggio = "weeks"; break;
case "giorni":  				$messaggio = "days"; break;
case "la nuova foto è stata aggiunta":  	$messaggio = "the new photo has been added"; break;
case "l'url della foto è sbagliata":  		$messaggio = "the photo url is wrong"; break;
case "foto eliminata":  			$messaggio = "photo deleted"; break;
case "foto della tariffa":  			$messaggio = "photos of rate"; break;
case "elimina":  				$messaggio = "delete"; break;
case "url di una nuova foto":  			$messaggio = "new photo url"; break;
case "descrizione della tariffa":  		$messaggio = "description of rate"; break;
case "modifica":  				$messaggio = "modify"; break;
case "aggiornata":  				$messaggio = "updated"; break;
case "commento":  				$messaggio = "comment"; break;
case "commento della foto":  			$messaggio = "comment of photo"; break;
case "aggiornato":  				$messaggio = "updated"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>