<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Go back"; break;
case "Privilegi dell'utente":  			$messaggio = "Privileges of user"; break;
case "Privilegi <b>globali</b>":  		$messaggio = "<b>Global</b> privileges"; break;
case "Modifica delle proprie personalizzazioni":	$messaggio = "Modify his own customizations"; break;
case "Si":  					$messaggio = "Yes"; break;
case "No":  					$messaggio = "No"; break;
case "Inserimento di nuovi clienti":  		$messaggio = "Insert new clients"; break;
case "Possibilità di vedere ed utilizzare nelle prenotazioni i clienti già inseriti":	$messaggio = "Possibility to view and use in reservations clients already inserted"; break;
case "Solo":  					$messaggio = "Only"; break;
case "i propri":  				$messaggio = "his own"; break;
case "Modifica e cancellazione dei clienti già inseriti":  	$messaggio = "Modify and delete already inserted clients"; break;
case "dei propri":  				$messaggio = "his own"; break;
case "Inserire in tutti i cognomi dei clienti inseriti da questo utente":	$messaggio = "Insert in all clients surnames inserted by this user"; break;
case "Un prefisso":  				$messaggio = "A prefix"; break;
case "Un suffisso":  				$messaggio = "A suffix"; break;
case "Niente":  				$messaggio = "Nothing"; break;
case "Modifica i privilegi globali":  		$messaggio = "Modify global privileges"; break;
case "Privilegi per l'anno":			$messaggio = "Privileges for year"; break;
case "Anno disattivato":  			$messaggio = "Year disabled"; break;
case "Attiva":  				$messaggio = "Enable"; break;
case "Anno attivato":  				$messaggio = "Year enabled"; break;
case "Disattiva":  				$messaggio = "Disable"; break;
case "Prenotazioni inseribili solo nei periodi della regola di assegnazione 1 con le motivazioni selezionate":	$messaggio = "Reservations insertable only in periods of the assignment rule 1 with selected motivations"; break;
case "nessuna":  				$messaggio = "no one"; break;
case "Applica la regola 1":  			$messaggio = "Apply rule 1"; break;
case "Sempre":  				$messaggio = "Always"; break;
case "Solo per regole non selezionate":  	$messaggio = "Only for not selected rules"; break;
case "Mai":  					$messaggio = "Never"; break;
case "Mai, ma non spostare altre prenotazioni in periodi delle regole non selezionate se non vi si possono inserire prenotazioni":	$messaggio = "Never, but do not move other reservations in the periods of not selected rules if it's not permitted to insert reservations there"; break;
case "Permetti l'uso di tutte le <i>tariffe</i> nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permit the usage of all <i>rates</i> when inserting and modifying reservations"; break;
case "Permetti l'uso solo delle <i>tariffe</i> selezionate nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permit only the usage of selected <i>rates</i> when inserting and modifying reservations"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "Permetti l'uso di tutti i <i>costi aggiuntivi</i> nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permit the usage of all the <i>extra costs</i> when inserting and modifying reservations"; break;
case "Permetti l'uso solo dei <i>costi aggiuntivi</i> selezionati nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permit only the usage of selected <i>extra costs</i> when inserting and modifying reservations"; break;
case "Costo unico":  				$messaggio = "Single cost"; break;
case "Costo settimanale":  			$messaggio = "Weekly cost"; break;
case "Costo giornaliero":  			$messaggio = "Daily cost"; break;
case "Permetti la visualizzazione di tutti i <i>documenti</i>":	$messaggio = "Permit the visualization of all <i>documents</i>"; break;
case "Permetti la visualizzazione solo dei <i>documenti</i> selezionati":	$messaggio = "Permit the visualization of selected <i>documents</i> only"; break;
case "documento":  				$messaggio = "document"; break;
case "Non permettere l'inserimento di <i>nuove prenotazioni</i>":	$messaggio = "Do not permit the insertion of <i>new reservations</i>"; break;
case "Permetti l'inserimento di <i>nuove prenotazioni</i> con le seguenti possibilità":	$messaggio = "Permit the insertion of <i>new reservations</i> with the following possibilities"; break;
case "Possibilità di confermare la prenotazione":	$messaggio = "Possibility to confirm the reservation"; break;
case "Possibilità di inserire uno sconto":  	$messaggio = "Possibility to insert a discount"; break;
case "Possibilità di inserire la caparra e le commissioni":	$messaggio = "Possibility to insert deposit and commissions"; break;
case "Possibilità di inserire dei costi aggiuntivi":	$messaggio = "Possibility to insert extra costs"; break;
case "Possibilità di inserire il commento":  	$messaggio = "Possibility to insert the comment"; break;
case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Possibility to insert custom comments"; break;
case "Possibilità di inserire il numero di persone":	$messaggio = "Possibility to insert the number of people"; break;
case "Possibilità di inserire prenotazioni anche in periodi già iniziati":	$messaggio = "Possibility to insert reservations also in periods already begun"; break;
case "Prenotazioni che possono essere <i>modificate</i>":	$messaggio = "Reservations that can be <i>modified</i>"; break;
case "Tutte":  					$messaggio = "All"; break;
case "le proprie":  				$messaggio = "own ones"; break;
case "dei suoi gruppi":  			$messaggio = "from his groups"; break;
case "Nessuna":  				$messaggio = "No one"; break;
case "Possibilità di modificare la data iniziale o finale":	$messaggio = "Possibility to modify the beginning or ending date"; break;
case "Possibilità di modificare la tariffa":  	$messaggio = "Possibility to modify the rate"; break;
case "Si, con regola 2 a scelta":  		$messaggio = "Yes, with rule 2 at will"; break;
case "Si, sempre con regola 2":  		$messaggio = "Yes, always with rule 2"; break;
case "Possibilità di modificare il numero delle persone":	$messaggio = "Possibility to modify the number of people"; break;
case "Possibilità di vedere il commento":  	$messaggio = "Possibility to view the comment"; break;
case "Possibilità di modificare il commento":  	$messaggio = "Possibility to modify the comment"; break;
case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Possibility to view and modify custom comments"; break;
case "Possibilità di modificare lo sconto":  	$messaggio = "Possibility to modify the discount"; break;
case "Possibilità di modificare la caparra e le commissioni":  	$messaggio = "Possibility to modify deposit and commissions"; break;
case "Possibilità di modificare i costi aggiuntivi":	$messaggio = "Possibility to modify extra costs"; break;
case "Possibilità di modificare i soldi pagati e la conferma":	$messaggio = "Possibility to modify money paid and confirmation"; break;
case "Solo la conferma":  			$messaggio = "Only confirmation"; break;
case "Possibilità di modificare prenotazioni già iniziate":	$messaggio = "Possibility to modify already begun reservations"; break;
case "Prenotazioni non più modificabili dopo un certo numero di ore dopo l'inserzione":	$messaggio = "Reservations not modifiable anymore after a certain number of hours after insertion"; break;
case "ore":  					$messaggio = "hours"; break;
case "Possibilità di cancellare le prenotazioni":	$messaggio = "Possibility to delete reservations"; break;
case "Solo quelle non iniziate":  		$messaggio = "Only not begun ones"; break;
case "Prenotazioni non più cancellabili dopo un certo numero di ore dopo l'inserzione":	$messaggio = "Reservations not deletable anymore after a certain number of hours after insertion"; break;
case "Possibilità di inserire e cancellare le <i>spese</i>":	$messaggio = "Possibility to insert and delete <i>expenses</i>"; break;
case "Possibilità di inserire e cancellare le <i>entrate</i>":	$messaggio = "Possibility to insert and delete <i>incomes</i>"; break;
case "<i>Sottrarre le entrate</i> dal totale delle prenotazioni":	$messaggio = "<i>Subtract the incomes</i> from the total of the reservations"; break;
case "A scelta":  				$messaggio = "At will"; break;
case "Immettere come <i>persona</i> che inserisce le spese o le entrate":	$messaggio = "Show as <i>person</i> that inserts expenses and incomes"; break;
case "Il nome dell'utente":  			$messaggio = "The username"; break;
case "Chiedere":  				$messaggio = "Ask"; break;
case "Nessuno":  				$messaggio = "No one"; break;
case "Possibilità di vedere la <i>tabella dei mesi</i>":	$messaggio = "Possibility to view <i>tables with months</i>"; break;
case "Solo con":				$messaggio = "Only with"; break;
case "prenotazioni proprie":			$messaggio = "own reservations"; break;
case "prenotazioni dai suoi gruppi":		$messaggio = "reservations from his groups"; break;
case "a lui":					$messaggio = "to him"; break;
case "ai suoi gruppi":				$messaggio = "to his groups"; break;
case "Possibilità di vedere la <i>tabella con tutte le prenotazioni</i>":	$messaggio = "Possibility to view the <i>table with all the reservations</i>"; break;
case "Possibilità di vedere le <i>tabelle con le entrate e le uscite</i>":	$messaggio = "Possibility to view the <i>table with expenses and incomes</i>"; break;
case "entrate/uscite proprie":  		$messaggio = "own expenses/incomes"; break;
case "entrate/uscite dai suoi gruppi":  	$messaggio = "expenses/incomes from his groups"; break;
case "Possibilità di vedere la <i>tabella con i periodi e le tariffe</i>":	$messaggio = "Possibility to view the <i>table with the periods and the rates</i>"; break;
case "Solo con tariffe consentite":  		$messaggio = "Only with rates permitted"; break;
case "Possibilità di vedere la <i>tabella con le regole di assegnazione</i>":	$messaggio = "Possibility to view the <i>table with assignment rules</i>"; break;
case "Solo con regole consentite":  		$messaggio = "Only with rules permitted"; break;
case "Modifica i privilegi dell'anno":  	$messaggio = "Modify privileges of year"; break;
case "Testo del prefisso/suffisso dei clienti":	$messaggio = "Text of the prefix/suffix of clients"; break;
case "Si deve inserire il <div style=\"display: inline; color: red;\">prefisso/suffisso</div> da utilizzare per i clienti dell'utente":	$messaggio = "You must insert the <div style=\"display: inline; color: red;\">prefix/suffix</div> to be used for clients of user"; break;
case "L'utente":  				$messaggio = "The user"; break;
case "potrà modificare le sue <b>personalizzazioni</b>":	$messaggio = "will be able to modify his <b>customizations</b>"; break;
case "non potrà più modificare le sue <b>personalizzazioni</b>":	$messaggio = "will not be able to modify his <b>customizations</b> anymore"; break;
case "potrà inserire <b>nuovi clienti</b>":  	$messaggio = "will be able to insert <b>new clients</b>"; break;
case "non potrà più inserire <b>nuovi clienti</b>":	$messaggio = "will not be able to insert <b>new clients</b> anymore"; break;
case "potrà modificare <b>tutti i clienti</b>":	$messaggio = "will be able to modify <b>all clients</b>"; break;
case "potrà modificare solo i <b>propri clienti</b>":	$messaggio = "will be able to modify only his <b>own clients</b>"; break;
case "e quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "and the ones from users belonging to his groups"; break;
case "non potrà più modificare <b>nessun cliente</b>":	$messaggio = "will not be able to modify <b>any client</b> anymore"; break;
case "non potrà vedere <b>nessun cliente</b>":	$messaggio = "will not be able to view <b>any client</b>"; break;
case "potrà vedere solo i <b>propri clienti</b>":	$messaggio = "will be able to view only his <b>own clients</b>"; break;
case "potrà vedere <b>tutti i clienti</b>":  	$messaggio = "will be able to view <b>all clients</b>"; break;
case "Verrà aggiunto un <b>prefisso</b> a tutti i cognomi dei clienti inseriti dall'utente":	$messaggio = "A <b>prefix</b> will be added to all clients surnames inserted by user"; break;
case "Verrà aggiunto un <b>suffisso</b> a tutti i cognomi dei clienti inseriti dall'utente":	$messaggio = "A <b>suffix</b> will be added to all clients surnames inserted by user"; break;
case "Non verrà aggiunto più alcun <b>prefisso/suffisso</b> ai cognomi dei clienti inseriti dall'utente":	$messaggio = "A <b>suffix</b> won't be added anymore to clients surnames inserted by user"; break;
case "Il nuovo testo del <b>prefisso/suffisso</b> dei cognomi dei clienti inseriti dall'utente":	$messaggio = "The new text of the <b>prefix/suffix</b> of clients surnames inserted by user"; break;
case "sarà":  					$messaggio = "will be"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "Anno <div style=\"display: inline; color: red;\">errato</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Wrong</div> year"; break;
case "Ore in cui si può modificare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Hours in which is possible to modify reservations are <div style=\"display: inline; color: red;\">wrong</div>"; break;
case "Ore in cui si può cancellare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Hours in which is possible to delete reservations are <div style=\"display: inline; color: red;\">wrong</div>"; break;
case "potrà inserire le sue prenotazioni in <b>tutti i periodi</b> del":	$messaggio = "will be able to insert his reservations in <b>all periods</b> of"; break;
case "potrà inserire le sue prenotazioni solo nei <b>periodi della regola 1</b> selezionati nel":	$messaggio = "will be able to insert his reservations only in <b>periods of rule 1</b> selected in"; break;
case "Verranno cambiate le motivazioni selezionate della <b>regola 1</b> per l'anno":	$messaggio = "Motivations of <b>rule 1</b> selected will be changed for year"; break;
case "verrà avvisato <b>sempre</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "will be <b>always</b> informed before inserting reservations in periods of rule 1 of"; break;
case "verrà avvisato solo quando inserirà prenotazioni nei periodi delle regole 1 <b>non selezionate</b> del":	$messaggio = "will be informed only when inserting reservations in periods of rule 1 <b>not selected</b> of"; break;
case "non verrà avvisato <b>mai</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "will <b>never</b> be informed when inserting reservations in periods of rule 1 of"; break;
case "se non vi può inserire prenotazioni":	$messaggio = "if he can't insert reservations there"; break;
case "potrà utilizzare <b>tutte le tariffe</b> del":	$messaggio = "will be able to use <b>all rates</b> of"; break;
case "potrà utilizzare solo le <b>tariffe selezionate</b> del":	$messaggio = "will be able to use only <b>selected rates</b> of"; break;
case "Verranno cambiate le <b>tariffe selezionate</b> da utilizzare per l'anno":	$messaggio = "<b>Selected rates</b> will be changed for year"; break;
case "potrà utilizzare <b>tutti i costi aggiuntivi</b> del":	$messaggio = "will be able to use <b>all extra costs</b> of"; break;
case "potrà utilizzare solo i <b>costi aggiuntivi selezionati</b> del":	$messaggio = "will be able to use only <b>selected extra costs</b> of"; break;
case "Verranno cambiati i <b>costi aggiuntivi</b> da utilizzare per l'anno":	$messaggio = "<b>Selected extra costs</b> will be changed for year"; break;
case "potrà visualizzare <b>tutti i documenti</b> del":	$messaggio = "will be able to view <b>all documents</b> of"; break;
case "potrà visualizzare solo i <b>documenti selezionati</b> del":	$messaggio = "will be able to view only <b>selected documents</b> of"; break;
case "Verranno cambiati i <b>documenti</b> visualizzabili per l'anno":	$messaggio = "<b>Selected documents</b> will be changed for year"; break;
case "non potrà inserire <b>nuove prenotazioni</b> nel":	$messaggio = "will not be able to insert <b>new reservations</b> in"; break;
case "potrà inserire <b>nuove prenotazioni</b> nel":	$messaggio = "will be able to insert <b>new reservations</b> in"; break;
case "non potrà <b>confermare</b> le nuove prenotazioni inserite nel":	$messaggio = "will not be able to <b>confirm</b> new reservations inserted in"; break;
case "potrà <b>confermare</b> le nuove prenotazioni inserite nel":	$messaggio = "will be able to <b>confirm</b> new reservations inserted in"; break;
case "non potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert a <b>discount</b> when inserts new reservations in"; break;
case "potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert a <b>discount</b> when inserts new reservations in"; break;
case "non potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
case "potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
case "non potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>extra costs</b> when inserts new reservations in"; break;
case "potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>extra costs</b> when inserts new reservations in"; break;
case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>comment</b> when inserts new reservations in"; break;
case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>comment</b> when inserts new reservations in"; break;
case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>custom comments</b> when inserts new reservations in"; break;
case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>custom comments</b> when inserts new reservations in"; break;
case "non potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>number of people</b> when he inserts new reservations in"; break;
case "potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>number of people</b> when he inserts new reservations in"; break;
case "non potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "will not be able to insert new reservations in <b>already begun periods</b> in"; break;
case "potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "will be able to insert new reservations in <b>already begun periods</b> in"; break;
case "non potrà modificare <b>nessuna prenotazione</b> nel":	$messaggio = "will not be able to modify <b>any reservation</b> in"; break;
case "potrà modificare solo le <b>sue prenotazioni</b> nel":	$messaggio = "will be able to modify only his <b>own reservations</b> in"; break;
case "potrà modificare solo le <b>sue prenotazioni</b> e quelle di utenti appartenenti ai suoi gruppi nel":	$messaggio = "will be able to modify only his <b>own reservations</b> and those owned by users belonging to his groups in"; break;
case "potrà modificare <b>tutte le prenotazioni</b> nel":	$messaggio = "will be able to modify <b>all reservations</b> in"; break;
case "non potrà modificare la <b>data iniziale o finale</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>beginning or ending date</b> of reservations in"; break;
case "potrà modificare la <b>data iniziale o finale</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>beginning or ending date</b> of reservations in"; break;
case "non potrà modificare la <b>tariffa</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>rate</b> of reservations in"; break;
case "potrà modificare la <b>tariffa</b> delle prenotazioni, scegliendo se utilizzare la regola 2, nel":	$messaggio = "will be able to modify the <b>rate</b> of reservations, choosing if use rule 2, in"; break;
case "non potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>number of people</b> of reservations in"; break;
case "potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>number of people</b> of reservations in"; break;
case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to view the <b>comment</b> of reservations in"; break;
case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to view the <b>comment</b> of reservations in"; break;
case "non potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>comment</b> of reservations in"; break;
case "potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>comment</b> of reservations in"; break;
case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will not be able to view and modify <b>custom comments</b> of reservations in"; break;
case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will be able to view and modify <b>custom comments</b> of reservations in"; break;
case "non potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>discount</b> of reservations in"; break;
case "potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>discount</b> of reservations in"; break;
case "non potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>deposit</b> and the <b>commissions</b> of reservations in"; break;
case "potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>deposit</b> and the <b>commissions</b> of reservations in"; break;
case "non potrà modificare i <b>costi aggiuntivi</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>extra costs</b> of reservations in"; break;
case "potrà modificare i <b>costi aggiuntivi</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>extra costs</b> of reservations in"; break;
case "non potrà modificare i <b>soldi pagati</b> e la <b>conferma</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>money paid</b> and the <b>confirmation</b> of reservations in"; break;
case "non potrà modificare i <b>soldi pagati</b> ma solo la <b>conferma</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>money paid</b> but only the <b>confirmation</b> of reservations in"; break;
case "potrà modificare i <b>soldi pagati</b> e la <b>conferma</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>money paid</b> and the <b>confirmation</b> of reservations in"; break;
case "non potrà modificare le <b>prenotazioni già iniziate</b> nel":	$messaggio = "will not be able to modify <b>already begun reservations</b> in"; break;
case "potrà modificare anche le <b>prenotazioni già iniziate</b> nel":	$messaggio = "will be able to modify also <b>already begun reservations</b> in"; break;
case "non avrà <b>limite di tempo</b> per modificare le prenotazioni nel":	$messaggio = "will have no <b>time limit</b> to modify reservations"; break;
case "non potrà più modificare le prenotazioni <b>dopo":	$messaggio = "will not be able to modify reservations anymore <b>after"; break;
case "non potrà <b>cancellare</b> nessuna prenotazione nel":	$messaggio = "will not be able to <b>delete</b> any reservation in"; break;
case "potrà <b>cancellare</b> solo le prenotazioni non iniziate nel":	$messaggio = "will be able to <b>delete</b> only not begun reservations in"; break;
case "potrà <b>cancellare</b> tutte le prenotazioni nel":	$messaggio = "will be able to <b>delete</b> all reservations in"; break;
case "non avrà <b>limite di tempo</b> per cancellare le prenotazioni nel":	$messaggio = "will have no <b>time limit</b> to delete reservations"; break;
case "ore</b> nel":  				$messaggio = "hours</b> in"; break;
case "non potrà più cancellare le prenotazioni <b>dopo":	$messaggio = "will not be able to delete reservations anymore <b>after"; break;
case "non potrà inserire le <b>spese</b> nel":	$messaggio = "will not be able to insert <b>expenses</b> in"; break;
case "potrà inserire le <b>spese</b> nel":  	$messaggio = "will be able to insert <b>expenses</b> in"; break;
case "non potrà inserire le <b>entrate</b> nel":	$messaggio = "will not be able to insert <b>incomes</b> in"; break;
case "potrà inserire le <b>entrate</b> nel":	$messaggio = "will be able to insert <b>incomes</b> in"; break;
case "Le entrate inserite non verranno mai <b>sottratte</b> dal totale delle prenotazioni nel":	$messaggio = "The inserted incomes will never be <b>subtracted</b> from the total of the reservations in"; break;
case "potrà decidere se <b>sottrarre</b> le entrate dal totale delle prentazioni nel":	$messaggio = "will be able to <b>subtract</b> the incomes from the total of the reservations in"; break;
case "Le entrate inserite verranno sempre <b>sottratte</b> dal totale delle prenotazioni nel":	$messaggio = "The inserted incomes will be always <b>subtracted</b> from the total of the reservations in"; break;
case "Non verrà inserito nessuno come <b>persona</b> che inserisce le spese o le entrate nel":	$messaggio = "Nobody will be inserted as the <b>person</b> that inserts the incomes and the expenses in"; break;
case "potrà scegliere chi inserire come <b>persona</b> che inserisce le spese e le entrate nel":	$messaggio = "will be able to choose who insert as the <b>person</b> that inserts the incomes and the expenses in"; break;
case "Verrà sempre inserito il nome dell'utente":	$messaggio = "Will be always inserted the username"; break;
case "come <b>persona</b> che inserisce le spese e le entrate nel": 	$messaggio = "as the <b>person</b> that inserts the incomes and the expenses in"; break;
case "non potrà vedere le <b>tabelle dei mesi</b> del":	$messaggio = "will not be able to view the <b>months tables</b> of"; break;
case "nelle <b>tabelle dei mesi</b> del":  	$messaggio = "in the <b>months tables</b> of"; break;
case "potrà vedere le <b>tabelle dei mesi</b> del":	$messaggio = "will be able to view the <b>months tables</b> of"; break;
case "non potrà vedere la <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "will not be able to view the <b>table with all reservations</b> of"; break;
case "potrà vedere solo le proprie prenotazioni nella <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "will be able to view only his own reservations in the <b>table with all reservations</b> of"; break;
case "potrà vedere solo le prenotazioni sue e di utenti appartenenti ai suoi gruppi nella <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "will be able to view only reservations from him and from users belonging to his groups in the <b>table with all reservations</b> of"; break;
case "potrà vedere la <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "will be able to view the <b>table with all reservations</b> of"; break;
case "non potrà vedere le <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "will not be able to view the <b>table with the incomes and the expenses</b> of"; break;
case "potrà vedere solo le proprie entrate/uscite nelle <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "will be able to view only his own incomes/expenses in the <b>table with the incomes and the expenses</b> of"; break;
case "potrà vedere solo le entrate/uscite sue e di utenti appartenenti ai suoi gruppi nelle <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "will be able to view only incomes/expenses from him and from users belonging to his groups in the <b>table with the incomes and the expenses</b> of"; break;
case "potrà vedere le <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "will be able to view the <b>table with the incomes and the expenses</b> of"; break;
case "non potrà vedere la <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "will not be able to view the <b>table with the periods and the rates</b> of"; break;
case "potrà vedere solo le tariffe a lui consentite nella <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "will be able to view only rates permitted to him in the <b>table with the periods and the rates</b> of"; break;
case "potrà vedere solo le tariffe consentite a lui e ad utenti dei suoi gruppi nella <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "will be able to view only rates permitted to him and to users of his groups in the <b>table with the periods and the rates</b> of"; break;
case "potrà vedere la <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "will be able to view the <b>table with the periods and the rates</b> of"; break;
case "non potrà vedere la <b>tabella con le regole di assegnazione</b> del":	$messaggio = "will not be able to view the <b>table with the assignment rules</b> of"; break;
case "potrà vedere solo le regole a lui consentite nella <b>tabella con le regole di assegnazione</b> del":	$messaggio = "will be able to view only rules permitted to him in the <b>table with the assignment rules</b> of"; break;
case "potrà vedere solo le regole consentite a lui e ad utenti dei suoi gruppi nella <b>tabella con le regole di assegnazione</b> del":	$messaggio = "will be able to view only rules permitted to him and to users of his groups in the <b>table with the assignment rules</b> of"; break;
case "potrà vedere la <b>tabella con le regole di assegnazione</b> del":	$messaggio = "will be able to view the <b>table with the assignment rules</b> of"; break;
case "Possibilità di inserire più prenotazioni contemporaneamente":	$messaggio = "Possibility to insert more reservations contemporaneously"; break;
case "non potrà inserire <b>più prenotazioni contemporaneamente</b> nel":	$messaggio = "will not be able to insert <b>more reservations contemporaneously</b> in"; break;
case "potrà inserire <b>più prenotazioni contemporaneamente</b> nel":	$messaggio = "will be able to insert <b>more reservations contemporaneously</b> in"; break;
case "Prenotazioni non più cancellabili dopo essere state confermate":	$messaggio = "Reservations not deletable anymore after being confirmed"; break;
case "non potrà <b>cancellare</b> le prenotazioni confermate nel":	$messaggio = "will not be able to <b>delete</b> confirmed reservations in"; break;
case "potrà <b>cancellare</b> le prenotazioni confermate nel":	$messaggio = "will be able to <b>delete</b> confirmed reservations in"; break;
case "Possibilità di modificare l'orario di entrata ed uscita":	$messaggio = "Possibility to modify check-in and check-out hours"; break;
case "non potrà modificare l'orario di <b>entrata ed uscita</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>check-in and check-out hours</b> of reservations in"; break;
case "potrà modificare l'orario di <b>entrata ed uscita</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>check-in and check-out hours</b> of reservations in"; break;
case "Possibilità di vedere i messaggi ricevuti":	$messaggio = "Possibility to view received messages"; break;
case "Possibilità di mandare messaggi":  	$messaggio = "Possibility to send messages"; break;
case "non potrà vedere <b>i messaggi ricevuti</b>":	$messaggio = "will not be able to view <b>received messages</b>"; break;
case "potrà vedere <b>i messaggi ricevuti</b>":	$messaggio = "will be able to view <b>received messages</b>"; break;
case "non potrà <b>inviare messaggi</b>":	$messaggio = "will not be able to <b>send messages</b>"; break;
case "potrà <b>inviare messaggi</b>":  		$messaggio = "will be able to <b>send messages</b>"; break;
case "Possibilità di inserire l'orario di entrata":	$messaggio = "Possibility to insert the checkin hour"; break;
case "non potrà inserire l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to change the <b>checkin hour</b> when inserts new reservations in"; break;
case "potrà inserire la l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to change the <b>checkin hour</b> when inserts new reservations in"; break;
case "non potrà vedere e modificare il <b>codice prenotazione</b> nel":	$messaggio = "will not be able to view and modify the <b>reservation code</b> in"; break;
case "potrà vedere e modificare il <b>codice prenotazione</b> nel":	$messaggio = "will be able to view and modify the <b>reservation code</b> in"; break;
case "Possibilità di vedere e modificare il codice prenotazione":	$messaggio = "Possibility to view and modify the reservation code"; break;
case "Possibilità di cambiare il cliente con un altro":	$messaggio = "Possibility to change the client with another one"; break;
case "potrà cambiare il <b>cliente</b> delle prenotazioni nel":	$messaggio = "will be able to change the <b>client</b> of reservations in"; break;
case "non potrà cambiare il <b>cliente</b> delle prenotazioni nel":	$messaggio = "will not be able to change the <b>client</b> of reservations in"; break;
case "potrà inserire <b>più prenotazioni contemporaneamente ma non vicine</b> nel":	$messaggio = "will be able to insert <b>more reservations contemporaneously but not in nearby apartments</b> in"; break;
case "Possibilità di modificare le prenotazioni vicine":	$messaggio = "Possibility to modify nearby reservations"; break;
case "non potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "will not be able to modify <b>nearby reservations</b> in"; break;
case "potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "will be able to modify <b>nearby reservations</b> in"; break;
case "Possibilità di inserire l'origine":  	$messaggio = "Possibility to insert the origin"; break;
case "Possibilità di modificare l'origine":  	$messaggio = "Possibility to modify the origin"; break;
case "potrà inserire <b>l'origine della prenotazione</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>reservation origin</b> when inserts new reservations in"; break;
case "non potrà inserire <b>l'origine della prenotazione</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>reservation origin</b> when inserts new reservations in"; break;
case "potrà modificare il <b>l'origine</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>origin</b> of reservations in"; break;
case "non potrà modificare <b>l'origine</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>origin</b> of reservations in"; break;
case "Possibilità di modificare le <i>tariffe</i> a lui permesse":	$messaggio = "Possibility to modify the <i>rates</i> permitted to him"; break;
case "Possibilità di inserire <i>nuovi costi aggiuntivi</i>":	$messaggio = "Possibility to insert <i>new extra costs</i>"; break;
case "rendendoli disponibili":			$messaggio = "making them available"; break;
case "solo a lui":  				$messaggio = "only to him"; break;
case "a utenti dei suoi gruppi":  		$messaggio = "to users from his groups"; break;
case "Possibilità di modificare i <i>costi aggiuntivi</i> a lui permessi":	$messaggio = "Possibility to modify the <i>extra costs</i> permitted to him"; break;
case "non potrà modifcare le <b>tariffe a lui permesse</b> nel":	$messaggio = "will not be able to modify the <b>rates pemitted to him</b> in"; break;
case "potrà modifcare le <b>tariffe a lui permesse</b> nel":	$messaggio = "will be able to modify the <b>rates pemitted to him</b> in"; break;
case "non potrà inserire <b>nuovi costi aggiuntivi</b> nel":	$messaggio = "will not be able to insert <b>new extra costs</b> in"; break;
case "potrà inserire <b>nuovi costi aggiuntivi</b> il cui utilizzo sarà permesso a lui e agli utenti appartenenti ai suoi stessi gruppi nel":	$messaggio = "will be able to insert <b>new extra costs</b> which utilization will be permitted to him and to users belonging to his groups in"; break;
case "potrà inserire <b>nuovi costi aggiuntivi</b> il cui utilizzo sarà permesso solo a lui nel":	$messaggio = "will be able to insert <b>new extra costs</b> which utilization will be permitted only to him in"; break;
case "non potrà modifcare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "will not be able to modify the <b>extra costs pemitted to him</b> in"; break;
case "potrà modifcare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "will be able to modify the <b>extra costs pemitted to him</b> in"; break;
case "Possibilità di cancellare i <i>costi aggiuntivi</i> a lui permessi":	$messaggio = "Possibility to delete the <i>extra costs</i> permitted to him"; break;
case "non potrà cancellare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "will not be able to delete the <b>extra costs pemitted to him</b> in"; break;
case "potrà cancellare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "will be able to delete the <b>extra costs pemitted to him</b> in"; break;
case "nelle <b>statistiche</b> del":  		$messaggio = "in the <b>statistics</b> of"; break;
case "non potrà vedere le <b>statistiche</b> del":	$messaggio = "will not be able to view the <b>statistics</b> of"; break;
case "potrà vedere le <b>statistiche</b> del":	$messaggio = "will be able to view the <b>statistics</b> of"; break;
case "Possibilità di vedere <i>le statistiche</i>":	$messaggio = "Possibility to view <i>the statistics</i>"; break;
case "Possibilità di vedere i <i>beni dell'inventario</i>":	$messaggio = "Possibility to view <i>inventory items</i>"; break;
case "Possibilità di inserire nuovi beni nell'inventario":	$messaggio = "Possibility to insert new inventory items"; break;
case "Possibilità di vedere l'<i>inventario dei magazzini</i>":	$messaggio = "Possibility to view <i>stockrooms inventory</i>"; break;
case "Possibilità di inserire nuovi magazzini":	$messaggio = "Possibility to insert new stockrooms"; break;
case "Possibilità di aggiungere e cancellare beni":	$messaggio = "Possibility to add and delete items"; break;
case "Solo in":  				$messaggio = "Only in"; break;
case "magazzini propri":  			$messaggio = "own stockrooms"; break;
case "magazzini dei suoi gruppi":  		$messaggio = "stockrooms from his groups"; break;
case "Possibilità di modificare le quantità dei beni":	$messaggio = "Possibility to modify items quantity"; break;
case "non potrà vedere i <b>beni dell'inventario</b>":	$messaggio = "will not be able to view the <b>inventory items</b>"; break;
case "potrà vedere solo i <b>suoi beni dell'inventario</b>":	$messaggio = "will be able to view only <b>his own inventory items</b>"; break;
case "potrà vedere i <b>beni dell'inventario</b>":	$messaggio = "will be able to view the <b>inventory items</b>"; break;
case "non potrà <b>inserire nuovi beni</b> nell'inventario":	$messaggio = "will not be able to <b>insert new items</b> in inventory"; break;
case "potrà <b>inserire nuovi beni</b> nell'inventario":	$messaggio = "will be able to <b>insert new items</b> in inventory"; break;
case "non potrà vedere <b>l'inventario":  	$messaggio = "will not be able to view the <b>inventory"; break;
case "potrà vedere <b>l'inventario":  		$messaggio = "will be able to view the <b>inventory"; break;
case "dei magazzini</b>":  			$messaggio = "of stockrooms</b>"; break;
case "solo dei suoi magazzini</b>":  		$messaggio = "only of his own stockrooms</b>"; break;
case "e di quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "and of those from users belonging to his groups"; break;
case "non potrà <b>inserire nuovi magazzini</b>":	$messaggio = "will not be able to <b>insert new stockrooms</b>"; break;
case "potrà <b>inserire nuovi magazzini</b>":	$messaggio = "will be able to <b>insert new stockrooms</b>"; break;
case "non potrà <b>aggiungere e cancellare beni</b>":	$messaggio = "will not be able to <b>add or delete items</b>"; break;
case "potrà <b>aggiungere e cancellare beni</b>":	$messaggio = "will be able to <b>add or delete items</b>"; break;
case "nei magazzini":  				$messaggio = "in stockrooms"; break;
case "solo nei suoi magazzini":  		$messaggio = "only in is own stockrooms"; break;
case "e in quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "and in those from users belonging to his groups"; break;
case "non potrà <b>modificare le quantità dei beni</b>":	$messaggio = "will not be able to <b>modify items quantity</b>"; break;
case "potrà <b>modificare le quantità dei beni</b>":	$messaggio = "will be able to <b>modify items quantity</b>"; break;
case "creazione, download e cancellazione del backup completo":	$messaggio = "create, download and delete the complete backup"; break;
case "potrà creare i <b>backup</b>":  		$messaggio = "will be able to create <b>backups</b>"; break;
case "non potrà più creare i <b>backup</b>":  	$messaggio = "will not be able to create <b>backups</b>"; break;
case "Possibilità di vedere la <i>tabella con i documenti salvati</i>":	$messaggio = "Possibility to view the <i>table with saved documents</i>"; break;
case "Solo con documenti consentiti":  		$messaggio = "Only with documents permitted"; break;
case "non potrà vedere la <b>tabella con i documenti salvati</b> del":	$messaggio = "will not be able to view the <b>table with saved documents</b> of"; break;
case "potrà vedere solo i documenti a lui consentiti nella <b>tabella con i documenti salvati</b> del":	$messaggio = "will be able to view only documents permitted to him in the <b>table with saved documents</b> of"; break;
case "potrà vedere la <b>tabella con i documenti salvati</b> del":	$messaggio = "will be able to view the <b>table with saved documents</b> of"; break;
case "Permetti l'uso solo delle <i>casse</i> selezionate":	$messaggio = "Permit the usage of selected <i>cashboxes</i> only"; break;
case "Permetti l'uso di tutte le <i>casse</i>":	$messaggio = "Permit the usage of all <i>cashboxes</i>"; break;
case "cassa principale":  			$messaggio = "main cashbox"; break;
case "potrà usare <b>tutte le casse</b>":  	$messaggio = "will be able to use <b>all cashboxes</b>"; break;
case "potrà usare solo le <b>casse selezionate</b>":	$messaggio = "will be able to use only <b>selected cashboxes</b>"; break;
case "Verranno cambiate le <b>casse</b> utilizzabili":	$messaggio = "The <b>cashboxes</b> that can be used will be changed"; break;
case "Inserire sempre i pagamenti delle prenotazioni nella cassa":	$messaggio = "Always insert reservations payments in cashbox"; break;
case "I pagamenti inseriti nelle prenotazioni dall'utente":	$messaggio = "Payments inserted in reservations by user"; break;
case "verranno anche registrati come entrate nella cassa chiamata":	$messaggio = "will be also registered as incomes in cashbox called"; break;
case "non verranno registrati in cassa nel":	$messaggio = "will not be registered in any cashbox in"; break;
case "nel":  					$messaggio = "in"; break;
case "Modifica dei documenti":  		$messaggio = "Modify documents"; break;
case "potrà modificare i <b>documenti</b>":  	$messaggio = "will be able to modify <b>documents</b>"; break;
case "non potrà più modificare i <b>documenti</b>":	$messaggio = "will not be able to modify <b>documents</b> anymore"; break;
case "Possibilità di vedere email, telefoni e fax dei clienti":	$messaggio = "Possibility to view emails, telephones and faxes of clients"; break;
case "Possibilità di vedere l'indirizzo dei clienti":	$messaggio = "Possibility to view the address of clients"; break;
case "potrà vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "will be able to view <b>emails, telephones and faxes</b> of clients"; break;
case "non potrà più vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "will not be able to view <b>emails, telephones and faxes</b> of clients"; break;
case "potrà vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "will be able to view <b>the address</b> of clients"; break;
case "non potrà più vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "will not be able to view <b>the address</b> of clients"; break;
case "Mostrare le prenotazioni non permesse come":	$messaggio = "Show not permitted reservations as"; break;
case "oscurate":  				$messaggio = "obscured"; break;
case "periodi vuoti":  				$messaggio = "empty periods"; break;
case "solo correnti e future":  		$messaggio = "only current and future"; break;
case "vedrà le prenotazioni non permesse come <em>oscurate</em>":	$messaggio = "will see not permitted reservations as <em>obscured</em>"; break;
case "vedrà le prenotazioni non permesse come <em>periodi vuoti</em>":	$messaggio = "will see not permitted reservations as <em>empty periods</em>"; break;
case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed oscurate nel presente e nel futuro</em>":	$messaggio = "will see not permitted reservations as <em>empty periods in the past, obscured in the present and future</em>"; break;
case "Possibilità di cancellare o sovrascrivere i documenti salvati":	$messaggio = "Possibility to delete and overwrite saved documents"; break;
case "potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will be able to <b>delete and overwrite documents</b> saved in"; break;
case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will not be able to <b>delete and overwrite documents</b> saved in"; break;
case "Creazione e modifica delle interconnessioni":	$messaggio = "Create and modify interconnections"; break;
case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "will be able to create and modify <b>interconnections</b>"; break;
case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "will not be able to create and modify <b>interconnections</b>"; break;
case "Modifica dei documenti come API":  	$messaggio = "Modify documents as API"; break;
case "potrà modificare i <b>documenti come API</b>":	$messaggio = "will be able to modify <b>documents as API</b>"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "this can allow access to data of all reservations"; break;
case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "will not be able to modify <b>documents as API</b> anymore"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>